/**
 * L211_1601_0101
 * Check behavior of the class
 * Label - Check behavior of the display
 *
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * Label - Check behavior of the display
 * @extends IApplication
 */
public class L211_1601_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * Label - Check behavior of the display
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1"
    };

    String[][] menuListItem2 = {
        /* Menu for checking display operations */
        {
            "Ŀ1 ",
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("ִ");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "");
            errDialog.setText(e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        setTitle("L211");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "˳");

        /* Add each component to screen */
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * Label - Check behavior of the display
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;
    Button button;

    int ButtonIndex = 0;
    int menu1Index;
    int menu2Index;
    int backCount=0;
    int foreCount=0;
    Label LabelObj = new Label();
    TextBox textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int menu1Index, int menu2Index, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(menu1Index, menu2Index);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "");
            errDialog.setText(e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        setTitle("L211");
        setSoftLabel(Frame.SOFT_KEY_1, "˳");
        setSoftLabel(Frame.SOFT_KEY_2, "");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    void testPanel(int menu1Index, int menu2Index) {

        switch(menu1Index) {

        /* Check display operations */
        case 0:

            switch(menu2Index) {
            case 0:
                LabelObj.setText("");
                LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
                break;
            	
            default:
                break;
            }

            add(LabelObj);
            
            break;

        default:
            break;
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(L211_1601_0101.mainPanel);
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button ) {
            if ( ButtonIndex == 0) {
                LabelObj.setForeground(ColorBox.colors[foreCount]);
            } if ( ButtonIndex == 1) {
                LabelObj.setForeground(ColorBox.colors[foreCount]);
                LabelObj.setBackground(ColorBox.colors[backCount]);
            }
            foreCount++;
            if ( foreCount > 15 ) {
                foreCount = 0;
                backCount++;
                if ( backCount > 15 ) {
                    backCount = 0;
                    
                }
            }
        }
    }
}

/**
 * Color setting for checking behavior of the class
 */
class ColorBox {
    static int[] colors = {
        Graphics.getColorOfName(Graphics.BLACK),
        Graphics.getColorOfName(Graphics.BLUE),
        Graphics.getColorOfName(Graphics.LIME),
        Graphics.getColorOfName(Graphics.AQUA),
        Graphics.getColorOfName(Graphics.RED),
        Graphics.getColorOfName(Graphics.FUCHSIA),
        Graphics.getColorOfName(Graphics.YELLOW),
        Graphics.getColorOfName(Graphics.WHITE),
        Graphics.getColorOfName(Graphics.GRAY),
        Graphics.getColorOfName(Graphics.NAVY),
        Graphics.getColorOfName(Graphics.GREEN),
        Graphics.getColorOfName(Graphics.TEAL),
        Graphics.getColorOfName(Graphics.MAROON),
        Graphics.getColorOfName(Graphics.PURPLE),
        Graphics.getColorOfName(Graphics.OLIVE),
        Graphics.getColorOfName(Graphics.SILVER),
    };
    static String[] names = {
    "BLACK",
    "BLUE",
    "LIME",
    "AQUA",
    "RED",
    "FUCHSIA",
    "YELLOW",
    "WHITE",
    "GRAY",
    "NAVY",
    "GREEN",
    "TEAL",
    "MAROON",
    "PURPLE",
    "OLIVE",
    "SILVER",
    };
}
