/**
 * L212_1201_0101
 * MainPanel
 *
 * Check behavior of TextBox class (behavior of UI boundary)
 *
 */

import com.nttdocomo.ui.*;
import java.lang.*;

/**
 * Main class for checking behavior of the TextBox class and the class
 * @extends IApplication
 */

public class L212_1201_0101 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the TextBox class and the class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
           "1"
    };
    private TextBox[] textBox = new TextBox[30];
    private Button button = new Button("ִ");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "");
            errDialog.setText(e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    public void showMainPanel() {

        
        /* Settings of display items */
        setTitle("L212");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);

            textBox[0] = new TextBox("TextBox", 20, 1, TextBox.DISPLAY_ANY);
            add(textBox[0]);

        setSoftLabel(Frame.SOFT_KEY_1, "˳");
        setSoftLabel(Frame.SOFT_KEY_2, "");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                  
                   textBox[0].setSize(255,255);
                   textBox[0].setText("123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012");
                   break;
            }
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Call the addResult method when soft key2 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            addResult("");
        }
    }

    /**
     * Add output to the textBox[0]
     * @param aMessage Output character strings
     */
    public void addResult(String aMessage) {
//L212_1202_0105
        textBox[0].setText(textBox[0].getText()+aMessage);
    }
}


/**
 * Sub screen1 for checking behavior of  ImageButton class
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel1 extends Panel implements SoftKeyListener{

    private Frame previousFrame = null;
    private TextBox[] textBox = new TextBox[31];

    /**
     * Constructor of NextPanel1
     * @param aPrev Object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;

        /* Settings of display items */
        setTitle("L212");

        for ( int i = 0; i < 31; i++ ) {
//L212_1201_0102
            textBox[i] = new TextBox("TextBox"+(i+1), 20, 1, TextBox.DISPLAY_ANY);
            add(textBox[i]);
        }

        setSoftLabel(Frame.SOFT_KEY_1, "˳");
        setSoftLabel(Frame.SOFT_KEY_2, "");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

