
/**
 * L211_0801_0101.java
 * 
 * L211_0801_0101
 * MenuPanel
 * TestPanel
 * 
 * Class's operational test(Font)
 * 
 */

import com.nttdocomo.ui.*;

/**
 * Main class of class's operational test (Font)
 * @extends IApplication
 */
public class L211_0801_0101 extends IApplication {

    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * Menu screen for class's operational (Font) test
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {

    ListBox menu1 = null;                    /* Process selection menu */
    Button execButton = null;                /* execute button */
    int index = 0;

    /* Items in process selection menu(menu1menu2) */
    String[] menu1Item = {
        "1",
        "2",
      
    };

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.getMessage());
        } catch(Error e) {
            showMsg(e.getMessage());
        }
    }

    /**
     * Display menu screen
     */
    public void showMainPanel() {
        /* Display title/sub title */
        setTitle("L211");

        /* Add creation of components */
        menu1 = new ListBox(ListBox.CHOICE, 2);
        execButton = new Button("");
        menu1.setItems(menu1Item);
        add(menu1);
        add(execButton);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"}");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "uT");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * When soft key 1 is released, end the application
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }


    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When execute button is pressed store menu index into a variable and evoke a method for checking behavior*/
        if ( aType == ComponentListener.BUTTON_PRESSED ) {
            try {
                int menu1Index = menu1.getSelectedIndex();
                Display.setCurrent(new testCanvas(menu1Index, this));
            } catch(Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
        }
    }
}


/**
 * Screen area confirmation screen class
 * @extends Canvas
 */
class testCanvas extends Canvas {

    static int size = 12;
    static int count = 0;
    static int setsize = 0;

    /* Variable in order to return to the previous screen */
    Frame previousFrame = null;

    int index;
    Font font;
    int h;
    int adh;
    int z = 1;

    int[] font_face = {
        0x71000000,
        0x72000000,
        0x73000000,
    };

    int[] font_style = {
        0x70100000,
        0x70110000,
        0x70120000,
        0x70130000,
    };

    int[] font_size = {
        0x70000100,
        0x70000200,
        0x70000300 
    };

    int[] font_type = {
        0x00000000,
        0x00000001,
    };

    /* Creation of message dialog (error/Information) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"~");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "T");

    /**
     * Constructor of testCanvas class
     * @param aType  Location of items of Menu
     * @param aFrame  Screen
     */
    public testCanvas(int aType, Frame aFrame) {

        /* Assign the previous screen */
        previousFrame = aFrame;
        index = aType;
        
        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"}");
        setSoftLabel(Frame.SOFT_KEY_2,"^");

        setsize = 0;
        repaint();
    }


    /**
     * Screen depiction
     */
    public void paint(Graphics g) {

        g.clearRect(0,-(setsize*count),getWidth(),getHeight()+(setsize*count));
        g.setOrigin(0,setsize);

        g.lock();
        int y = 45;
        int x = 0;
        g.drawLine(0,15,getWidth(),15);

        switch (index) {
            case 0:
                font = Font.getDefaultFont();
                
                g.drawString(":" + font.getHeight() + "  "
                   + "e:" + font.stringWidth(""),5,30);
                break;
            case 1:
                g.drawString("38ؼҦ",5,30);
                for (int i = 0; i < 3; i++) {
                    for (int j = 0; j < 4; j++) {
                        for (int k = 0; k < 3; k++) {
                            font = Font.getFont(
                                font_face[i]|font_style[j]|font_size[k]);
                            g.setFont(font);
                            g.drawString(z +".",5,y);
                            y += 20;
                            z++;
                        }
                    }
                }
                for (int l = 0; l < 2; l++) {
                    font = Font.getFont(font_type[l]);
                    g.setFont(font);
                    g.drawString(z +".",5,y);
                    y += 20;
                    z ++;
                }
                size = font.getHeight();
                z = 1;
                break;
        }
        g.unlock(true);
    }

    /**
     * Process in case of events occurrence by key operation
     * @param type  Event type
     * @param param  Event parameter
     */


    /**
     * Define the behavior for the case soft key being released
     * @param aSoftKey  Type of soft key
     */
    public void processEvent(int type,int param) {
        if(type == Display.KEY_PRESSED_EVENT) {
            switch(param) {
                case Display.KEY_SOFT1:
                    IApplication.getCurrentApp().terminate();
                    break;
                case Display.KEY_SOFT2:
                    if(previousFrame != null) {
                        Display.setCurrent(previousFrame);
                    }
                    break;
                case Display.KEY_DOWN:
                    count -= 1;
                    setsize -= size;
                    repaint();
                    break;
                case Display.KEY_UP:
                    count += 1;
                    setsize += size;
                    repaint();
                    break;
                default:
            }
        }
    }
}
