/**
 * L212_0902_0101
 * UI boundary operations
 * Check behavior for the maximum and excessive setting of the ListBox
 *
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * UI boundary operations
 * Check behavior for the maximum and excessive setting of the ListBox
 * @extends IApplication
 */
public class L212_0902_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * UI boundary operations
 * Check behavior for the maximum and excessive setting of the ListBox
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem = {
       "1",
    };

    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "~");
            errDialog.setText(e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        setTitle("L212");
        menuList.setItems(menuListItem);
        setSoftLabel(Frame.SOFT_KEY_1, "}");

        /* Add each component to screen */
        add(menuList);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int testType = menuList.getSelectedIndex();
            Display.setCurrent(new SubPanel(testType, this));
        }
    }
}

/**
 * UI boundary operations
 * Check behavior for the maximum and excessive setting of the ListBox
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    int testType;
    Label classLabel = new Label();
    TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);
    
    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt, Frame aFrame) {

        /* Object name setting */
        testType = anInt;
        prevFrame = aFrame;

        try {
            /* Display sub panels */
            ShowSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "~");
            errDialog.setText(e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        ListBox menuList   = new ListBox(ListBox.CHECK_BOX);

        try {
            /* Setting of the items in the ListBox */
            switch(testType) {

//L212_0902_0202
            case 0:
               

                /* Set the maximum value (Two byte characters after the 14th one byte character)*/
               String[] menuListItem3 = {
                   "Aw÷tW̴̷`w÷"
            };
                menuList.setItems(menuListItem3);
                break;
                
            default:
                break;
            }
   
            add(menuList);
            resultText.setText("T{");
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "~");
            errDialog.setText(e.toString());
            errDialog.show();
        }

        /* Settings of display items */
        setTitle("L212");
        setSoftLabel(Frame.SOFT_KEY_1, "}");
        setSoftLabel(Frame.SOFT_KEY_2, "^");
        
        /* Add each component to screen */
        add(resultText);

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(L212_0902_0101.mainPanel);
        }
    }
}
