/**
 * L212_1002_0201
 * UI boundary operations
 * Check behavior of Panel display - Check behavior for the excessive setting being specified
 *
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * UI boundary operations
 * Check behavior of Panel display - Check behavior for the excessive setting being specified
 * @extends IApplication
 */
public class L212_1002_0201 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * UI boundary operations
 * Check behavior of Panel display - Check behavior for the excessive setting being specified
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem = {
        "1",
        "2",
    };

    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "~");
            errDialog.setText(e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        setTitle("L212");
        menuList.setItems(menuListItem);
        setSoftLabel(Frame.SOFT_KEY_1, "}");

        /* Add each component to screen */
        add(menuList);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int testType = menuList.getSelectedIndex();
            Display.setCurrent(new SubPanel(testType, this));
        }
    }
}

/**
 * UI boundary operations
 * Check behavior of Panel display - Check behavior for the excessive setting being specified
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    ListBox menuList   = new ListBox(ListBox.CHECK_BOX);
    int testType;

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        testType = anInt;
        
        try {
            /* Display sub panels */
            ShowSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "~");
            errDialog.setText(e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */

        switch(testType) {


//L212_1002_0202
        case 0:
            /* Set 10 two byte characters to soft key1 */
            setSoftLabel(Frame.SOFT_KEY_1, "W̰`ҽ");
            break;
            
//L212_1002_0203
//L212_1002_0204
       case 1:
            /* Set two byte characters to the 31th character and after of the title */
           setTitle("Aw÷tW̴̷`w÷tW");

            /* Set two byte characters to the 2nd character and after of the soft key */
            setSoftLabel(Frame.SOFT_KEY_1, "Aw÷tW");
            break;

        default:
            break;
        }
        
        setSoftLabel(Frame.SOFT_KEY_2, "^");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Return to the main screen when soft key2 is released
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(L212_1002_0201.mainPanel);
        }
    }
}
