/**
 * L221_0402_0101.java
 * 
 * L221_0402_0101
 * MainPanel
 * 
 * Check screen area
 * 
*/

import java.util.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Main class for checking screen area
 * @extends IApplication
 */
public class L221_0402_0101 extends IApplication {
    public void start() {
        MainPanel mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Main screen for checking screen area
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener {

    /* Creation of message dialog (error/Information) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"~");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "T");

    /* execute button */
    Button execButton = null;
    /* Create menu for selecting process */
    ListBox mainMenu = new ListBox(ListBox.CHOICE,1);
    /* Menu item for selecting process */
    String[] mainItem = {
       "1",
    };

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {

        try {
            showMainPanel();
        } catch(Exception e) {
            err.setText(e.toString());
        } catch(Error e) {
            err.setText(e.toString());
        }

    }

    /**
     * Display main screen for checking screen area
     */
    public void showMainPanel() {

        /* Display title */
        setTitle("L221");

        /* Text box for displaying test result */
        TextBox resultTextBox = new TextBox("", getWidth(), 3, 
                                                TextBox.DISPLAY_ANY);
        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"}");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* Setting of the main menu */
        mainMenu.setItems(mainItem);

        /* Setting of the execute button */
        execButton = new Button("");

        /* Add component to the screen */
        add(mainMenu);
        add(execButton);
        add(resultTextBox);

    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * softKeyReleased
     * When soft key 1 is released, end the application
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        /* Completed when soft key 1 is released */
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aPram) {

        /* Transit to the screen that is compliant with menu by pressing execute button */
        if ( aComponent == execButton
             && aType == BUTTON_PRESSED ) {
            if (mainMenu.getSelectedIndex() == 1) {
                Display.setCurrent(new testPanel(this));

            } else {
                Display.setCurrent(new testCanvas(
                    mainMenu.getSelectedIndex(),this));
            }
        }
    }
}               


/**
 * Screen area confirmation screen class
 * @extends Canvas
 */
class testCanvas extends Canvas {

    static int size = 12;
    static int count = 0;
    static int setsize = 0;

    /* Variable in order to return to the previous screen */
    Frame previousFrame = null;
    int index;
    Font font;

    String[] all_kind = {
        "",
    };

    int[] all_contents = {
        0x00000000,
        0x00000001,
        0x71000000,
        0x72000000,
        0x73000000,
        0x70100000,
        0x70110000,
        0x70120000,
        0x70130000,
        0x70000100,
        0x70000200,
        0x70000300 
    };

    /* Creation of message dialog (error/Information) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"~");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "T");

    /**
     * Constructor of testCanvas class
     * @param aType  Location of items of Menu
     * @param aFrame  Screen
     */
    public testCanvas(int aType, Frame aFrame) {

        /* Assign the previous screen */
        previousFrame = aFrame;
        index = aType;
        
        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"}");
        setSoftLabel(Frame.SOFT_KEY_2,"^");

        setsize = 0;
        repaint();
    }

	public void paint(Graphics g) {

		g.clearRect(0,-(setsize*count),getWidth(),getHeight()+(setsize*count));
        g.setOrigin(0,setsize);

		g.lock();
        int y = 30;
        int x = 0;
        g.drawLine(0,15,getWidth(),15);

        switch (index) {
            /* Two byte characters */
           // L221_0402_0103
            case 0:
                 for (int i =0; i < 12; i++) {
                     font = Font.getFont(all_contents[i]);
                     g.setFont(font);
                     g.drawString(all_kind[0],15,y);
                   g.drawString("" + font.getHeight() + "x" 
                        + font.stringWidth(all_kind[0]),40,y);
                     y += 15;
                }
                 size = font.getHeight();
        g.drawLine(0,y,getWidth(),y);
                 break;

        }
		g.unlock(true);
    }

    /**
     * Process in case of events occurrence by key operation
     * @param type  Event type
     * @param param  Event parameter
     */


    /**
     * Define the behavior for the case soft key being released
     * @param aSoftKey  Type of soft key
     */
    public void processEvent(int type,int param) {
        if(type == Display.KEY_PRESSED_EVENT) {
            switch(param) {
                case Display.KEY_SOFT1:
                    IApplication.getCurrentApp().terminate();
                    break;
                case Display.KEY_SOFT2:
                    if(previousFrame != null) {
                        Display.setCurrent(previousFrame);
                    }
                    break;
                case Display.KEY_DOWN:
                    count -= 1;
                    setsize -= size;
                    repaint();
                    break;
                case Display.KEY_UP:
                    count += 1;
                    setsize += size;
                    repaint();
                    break;
                default:
			}
		}
    }
}

/**
 * Screen area confirmation screen class
 * @extends Panel
 * @implements SoftKeyListener
 */
class testPanel extends Panel implements SoftKeyListener {

    /* Creation of message dialog (error/Information) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"~");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "T");

    /* Variable in order to return to the previous screen */
    Frame previousFrame = null;

    Label label[] = new Label[8];

    /**
     * Constructor of testPanel class
     * @param aFrame  Screen
     */
    public testPanel(Frame aFrame) {

        /* Assign the previous screen */
        previousFrame = aFrame;

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"}");
        setSoftLabel(Frame.SOFT_KEY_2,"^");

        /* Listener setting */
        setSoftKeyListener(this);

    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Define the behavior for the case soft key being released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            if ( previousFrame != null ) {
                Display.setCurrent(previousFrame);
            }
        }
    }
}
