/**
 * L311_0201_0102
 *
 * HTTP connection/check the communication between server and clients for Servlet
 *
 */

import java.io.*;
import java.net.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
 * check the communication behavior between server and clients for MainClass of Servlet
 * @extends HttpServlet
 */
public class L311_0201_0102 extends HttpServlet {

    /**
     * doGet method
     * @param request  HttpServletRequest
     * @param response HttpServletResponse
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response)
        throws IOException, ServletException {
        // L311_0201_0102
        /* getParameter */
        Enumeration enum = request.getParameterNames();
        String data = "";
        while( enum.hasMoreElements() ) {
            String key = (String)enum.nextElement();
            String[] v = request.getParameterValues(key);
            data += v[0];
        }
        response.setContentType("text/plain");
        response.setContentLength(data.length());
        PrintWriter out = response.getWriter();
        out.println(data);
    }

    /**
     * doGet method
     * @param request  HttpServletRequest
     * @param response HttpServletResponse
     */
    public void doPost(HttpServletRequest request, HttpServletResponse response)
        throws IOException, ServletException {
        /* getInpuStream */
        ServletInputStream sis = request.getInputStream();
        byte[] data = new byte[1024];
        int len = sis.read(data,0,1024);
        sis.close();
        if( len <= 0 ){
            return;
        }
        String s1 = "";
            /* URLEncode */
            // L311_0201_0203
            String ss = new String(data,1,len-1,"UTF8");
            //byte[] bb = URLdecode(ss);
            //s1 = new String(bb,"UTF8");
            s1 = decode(ss);
        response.setContentType("text/plain; charset=UTF8");
        PrintWriter out = response.getWriter();
            out.print("URLEncode:");
        String s0 = new String("灣們");
        if( s1.compareTo(s0) == 0 ) {
            out.print("OK:");
        } else {
            out.print("NG:");
        }
        out.print(s1);
        out.close();
    }

    /**
     * URLdecode
     * @param s  URLEncode String
     * @return byte[]  URLDecode String
     */
    private String decode(String s) throws NullPointerException,
                                                 IllegalArgumentException {
        if(s == null){
            throw new NullPointerException();
        }
        StringBuffer sb = new StringBuffer();
        for(int i=0; i<s.length(); i++) {
            char c = s.charAt(i);
            switch (c) {
                case '+':
                    sb.append(' ');
                    break;
                case '%':
                    try {
                        sb.append((char)Integer.parseInt(
                                        s.substring(i+1,i+3),16));
                    } catch (NumberFormatException e) {
                        throw new IllegalArgumentException(
                            "String is not x-www-form-urlencoded");
                    }
                    i += 2;
                    break;
                default:
                    sb.append(c);
                    break;
            }
        }
        // Undo conversion to external encoding
        String result = sb.toString();
        try {
            byte[] inputBytes = result.getBytes("ISO8859_1");
            result = new String(inputBytes,"UTF8");
        } catch (UnsupportedEncodingException e) {
            // The system should always have 8859_1
           System.out.println("****** Unsupported Encoding *****");
        }
        return result;
    }

    /**
     * Convert utf8 -> unicode method
     * @param  s     utf8 String
     * @return String  unicode string
     */
    private String utf82unicode(String s)
        throws UnsupportedEncodingException {

        return new String(s.getBytes("8859_1"), "UTF8");
    }

    /**
     * Convert unicode -> utf8 method
     * @param  s     unicode String
     * @return String  utf8 string
     */
    private String unicode2utf8(String s)
        throws UnsupportedEncodingException {

        return new String(s.getBytes("UTF8"), "8859_1");
    }
}
