/**
 * L311_0107_0101
 * MainPanel
 *
 * HTTP basic behavior/check the exceptions thrown at connection
 *
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the exceptions thrown at connection 
 * @extends IApplication
 */
public class L311_0107_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result.");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the exceptions thrown at connection 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        Button  execButton       = new Button("Ejecutar");
        TextBox status           = new TextBox("", 20,1,TextBox.DISPLAY_ANY);
        int flag = 0;

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("L311");
            setSoftLabel(Frame.SOFT_KEY_1, "Exit");

            /* Add each component to screen */
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);
            add(status);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if ( aType == ComponentListener.BUTTON_PRESSED) {
                if( aComponent == execButton ) {
                    flag = 0;
                } else {
                    return;
                }
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;

            /* URL creation */
            String url = getSourceURL();
                url += "data";

           int c = 1;
           long beforemem = 0;
           long aftermem = 0;
           Runtime rt =  Runtime.getRuntime();

            status.setText("Conectando");
            /* execute HTTP connection */
           while (c != 20){
            try {
                beforemem = rt.freeMemory();

                con = (HttpConnection) Connector.open(url,Connector.READ,true);
                con.setRequestMethod(HttpConnection.GET);
//                con.setRequestMethod(con.GET);
                con.connect();
//                ins = con.openInputStream();
                /* the fastest connection speed is 10240/3600 second, and the period of time for reading the input stream is indefinite. */
//                for( int i=0; i<con.getLength(); i++ ) {
//                    int b = ins.read();
//                }
//                ins.close();
                con.close();
                rt.gc();

            } catch ( ConnectionException ce ) {
                status.setText("Desconectado excepcionalmente");
                switch( ce.getStatus() ) {
                case ConnectionException.OUT_OF_SERVICE:
                    // L311_0107_0110
                    showDialog("ConnectionException(OUT_OF_SERVICE)");
                    break;
                default:
                    showDialog("ConnectionException(other-status)");
                    break;
                }
            } catch( InterruptedIOException ie ) {
                // L311_0107_0206
                // L311_0107_0207
                // L311_0107_0208
                aftermem = rt.freeMemory();
//                status.setText("Desconectado excepcionalmente");
                showDialog("InterruptedIOException");
            } catch( Exception e ) {
                status.setText("Desconectado excepcionalmente");
                showDialog(e.toString());
                return;
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
            }
        c++;
        }
        status.setText("Desconectado normalmente");
        }
    }
}
