/**
 * L311_0201_0102
 * MainPanel
 *
 * HTTP basic behavior/check the behavior between server and clients
 *
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;
import com.nttdocomo.net.*;


/**
 * HTTP basic behavior/main class of checking the behavior between server and clients
 * @extends IApplication
 */
public class L311_0201_0102 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Rsultat");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the behavior between server and clients 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
           "Test1",
        };

        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("Excuter");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("L311");
            setSoftLabel(Frame.SOFT_KEY_1, "Quit");

            /* Add each component to screen */
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  is = null;
            DataOutputStream dos = null;

            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL();
            url += "L311_0201_0102";

            /* execute HTTP connection */
            String msg = new String("");
            byte[] data = new byte[128];
            int len = 0;
            try {
                con = (HttpConnection) Connector.open(url,
                                Connector.READ_WRITE, true);
                    con.setRequestMethod(con.POST);
                    /* output */
                    dos = con.openDataOutputStream();
                    switch( idx ) {

                    case 0:
                        dos.write(3);
                        byte[] cc = msg.getBytes("UTF8");
                        dos.write(cc,0,cc.length);
                        break;
                    }
                dos.close();
                con.connect();
                is = con.openInputStream();
                len = is.read(data);
                is.close();
                con.close();
            } catch( Exception e ) {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
                showDialog(e.toString());
                return;
            }
            if( len <= 0 ) {
                showDialog("len=" + len);
            } else {
                showDialog(new String(data,0,len));
            }
        }
    }
}
