/**
 * J011_0305_0101
 *
 * HttpConnection method action check
 *
 * $Id: J011_0305_0101.java,v 1.1 2001/11/30 02:47:28 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * HttpConnection method action check main class
 * @extends IApplication
 */
public class J011_0305_0101 extends IApplication {
    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * HttpConnection method action check main screen
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener {
        String menulist[]={
            "0.close",
            "1.connect",
            "2.getDate",
            "3.getEncoding",
            "4.getExpiration",
            "5.getHeaderField",
            "6.getLastModified",
            "7.getLength",
            "8.getResponseCode",
            "9.getResponseMessage",
            "10.getType",
            "11.getURL",
            "12.openInputStream",
            "13.openOutputStream",
            "14.setIfModifiedSince",
            "15.setRequestMethod",
            "16.setRequestProperty"
        };
        Label title;
        ListBox menu;
        Button exe;
        TextBox out;

        /**
         * constructor of MainPanel class
         */
        MainPanel() {
            /* create a component */
            setTitle("API class normal route");
            title=new Label("HttpConnection method's behavior");
            title.setSize(getWidth(),title.getHeight());
            add(title);
            menu=new ListBox(ListBox.CHOICE);
            menu.setItems(menulist);
            add(menu);
            exe = new Button("execute");
            add(exe);
            out = new TextBox("", 20, 5, TextBox.DISPLAY_ANY);
            add(out);

            /* setting of the listener */
            setSoftKeyListener(this);
            setSoftLabel(Frame.SOFT_KEY_1, "exit");
            setComponentListener(this);
        }

        /**
         * terminate the application when softkey is pushed
         * @param anIndex Index of the softkey
         */
        public void softKeyPressed(int anIndex) {
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * do nothing when a softkey1 is released
         * @param anIndex Index of the softkey
         */
        public void softKeyReleased(int anIndex) {
        }

        /**
         * get the event on a component
         * @param aComponent The component on which an event occurs
         * @param aType Type of an event.
         * @param aParam Parameter of an event
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* when the menu is choiced */
            if( aComponent == menu && aType == ComponentListener.SELECTION_CHANGED ) {
                /* clear the  */
                out.setText("");
            }

            /* when  the exsecution button is pushed */
            if (aComponent == exe && aType == ComponentListener.BUTTON_PRESSED) {
                /* test the menu which is choiced */
                test(menu.getSelectedIndex());
            }
        }

        /**
         * functional outline :HttpConnection method action test 
         * @param anIndex Index of the menu which is choiced
         */
        public void test(int anIndex) {
            HttpConnection  con=null;
            InputStream     is=null;
            OutputStream    os=null;
            String          filename="J011_0305_0101.jam";

            out.setText("");
            switch( anIndex ) {
                // J011_0301_0342
                // J011_0305_0101
                case 0:         /* close() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        con.close();
                        out.setText("OK");
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0343
                // J011_0305_0102
                case 1:         /* connect() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        out.setText("OK");
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    try {
                        con.close();
                    } catch (Exception e ) {
                    }
                    break;
                // J011_0301_0344
                // J011_0305_0103
                case 2:         /* getDate() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        long d = con.getDate();
                        con.close();
                        out.setText("OK:" + d);
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0345
                // J011_0305_0104
                case 3:         /* getEncoding() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        String encd= con.getEncoding();
                        con.close();
                        out.setText("OK:"+encd);
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0346
                // J011_0305_0105
                case 4:         /* getExpiration() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        long exp= con.getExpiration();
                        con.close();
                        out.setText("OK:"+exp);
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0347
                // J011_0305_0106
                case 5:         /* getHeaderField() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        String head1 = con.getHeaderField("Content-Type");
                        String head2 = con.getHeaderField("Host");
                        con.close();
                        out.setText("OK:Content-Type="+head1+"\n"+
                                    "OK:Host="+head2);
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0348
                // J011_0305_0107
                case 6:         /* getLastModified() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        long mod= con.getLastModified();
                        con.close();
                        out.setText("OK:"+mod);
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0349
                // J011_0305_0108
                case 7:         /* getLength() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        long len= con.getLength();
                        con.close();
                        out.setText("OK:"+len);
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0350
                // J011_0305_0109
                case 8:         /* getResponseCode() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        int res= con.getResponseCode();
                        con.close();
                        out.setText("OK:"+res);
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0351
                // J011_0305_0110
                case 9:         /* getResponseMessage() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+ filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        String res= con.getResponseMessage();
                        con.close();
                        out.setText("OK:"+res);
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0352
                // J011_0305_0111
                case 10:            /* getType() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+ filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        String type= con.getType();
                        con.close();
                        out.setText("OK:"+type);
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0353
                // J011_0305_0112
                case 11:            /* getURL() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+ filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        String url= con.getURL();
                        con.close();
                        out.setText("OK:"+url);
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0354
                // J011_0305_0113
                case 12:            /* openInputStream() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+ filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        is = con.openInputStream();
                        if ( is != null ) {
                            int c=is.read();
                            is.close();
                        }
                        out.setText("OK");
                        con.close();
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0355
                // J011_0305_0114
                case 13:            /* openOutputStream() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            "../cgi-bin/post.cgi",
                                            Connector.WRITE, true);
                        con.setRequestMethod(HttpConnection.POST);
                        os = con.openOutputStream();
                        if ( os != null ) {
                            os.write(64);
                            os.close();
                        }
                        out.setText("OK");
                        con.connect();
                        con.close();
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0356
                // J011_0305_0115
                case 14:            /* setIfModifiedSince() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+ filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.setIfModifiedSince(100000000);
                        con.connect();
                        con.close();
                        out.setText("OK");
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                // J011_0301_0357
                // J011_0305_0116
                case 15:            /* setRequestMethod() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+ filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        out.setText("OK");
                    } catch (Exception e ) {
                        out.setText("NG1:"+ e.toString());
                        break;
                    }
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+ 
                                            "../cgi-bin/post.cgi",
                                            Connector.WRITE, true);
                        con.setRequestMethod(HttpConnection.POST);
                        out.setText("OK");
                    } catch (Exception e ) {
                        out.setText("NG2:"+ e.toString());
                        break;
                    }
//                    try {
//                        con=(HttpConnection) Connector.open(getSourceURL()+ filename,
//                                            Connector.READ, true);
//                        con.setRequestMethod(HttpConnection.HEAD);
//                        out.setText("OK");
//                    } catch (Exception e ) {
//                        out.setText("NG3:"+ e.toString());
//                        break;
//                    }
                    break;
                // J011_0301_0358
                // J011_0305_0117
                case 16:            /* setRequestProperty() */
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+ filename,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.setRequestProperty("Content-Type","text/plain");
                        con.setRequestProperty("If-Modified-Since",
                                "Thu, 04 Oct 2001 13:41:16");
                        con.setRequestProperty("XXXXX","");
                        con.connect();
                        con.close();
                        out.setText("OK");
                    } catch (Exception e ) {
                        out.setText("NG:"+ e.toString());
                    }
                    break;
                default:
                    break;
            }
        }
    }
}
