/**
 * J011_0306_0201
 *
 * HttpConnection logic exception generating operation check
 *
 * $Id: J011_0306_0201.java,v 1.1 2001/11/30 02:50:18 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * HttpConnection Logic exception generating operation check main class
 * @extends IApplication
 */
public class J011_0306_0201 extends IApplication {
    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * HttpConnection Logic exception generating operation check main screen
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener {
        String menuList[]={
            "1.open",
            "2.connect",
            "3.openInputStream",
            "4.openOutputStream",
            "5.getEncoding",
            "6.getLength",
            "7.getType",
            "8.setRequestMethod",
            "9.setRequestProperty",
            "10.getResponseCode",
            "11.getResponseMessage",
            "12.getHeaderField",
            "13.getDate",
            "14.getExpiration",
            "15.getLastModified",
            "16.setIfModifiedSince",
            "17.read",
            "18.skip",
            "19.available",
            "20.write"
        };
        String subItems[][] = {
            {
                "1 not available",
                "2.NO_RESOURCE",
                "3.URL>255",
                "4 mode incorrect",
                "6 The URL is an IP address.",
                "7 incorrect URL",
                "8 incorrect scheme",
                "9 incorrect port"
            },
            {
                "1 method not defined",
                "2 insufficient headers",
                "3 communication error",
                "4 non-2xx response",
                "5 transit to suspend state",
                "7 not available",
                "8 Another connection exists."
            },
            {
                "1 before connecting",
                "2 WRITE mode"
            },
            {
                "1 after connecting",
                "2 READ mode",
            },
            {
                "1 before connecting"
            },
            {
                "1 before connecting"
            },
            {
                "1 before connecting"
            },
            {
                "1 after connecting",
                "2 null argument",
                "3 The argument is out of regulation.",
                "4.WRITE-GET",
                "5.READ-POST",
          
            },
            {
                "1 after connecting"
            },
            {
                "1 before connecting"
            },
            {
                "1 before connecting"
            },
            {
                "1 before connecting"
            },
            {
                "1 before connecting"
            },
            {
                "1 before connecting"
            },
            {
                "1 before connecting"
            },
            {
                "1 after connecting"
            },
            {
                "1 not available",
                "2 transit to suspend state"
            },
            {
                "1 not available"
            },
            {
                "1 not available"
            },
            {
                "1 not available",
                "2 too large data"
            },
        };

        Label title;
        ListBox menu;
        ListBox menu2;
        Button exe;

        /**
         * constructor of MainPanel class
         */
        MainPanel() {
            /* create a component */
            setTitle("API class normal route");
            title=new Label("HttpConnection's behavior for thrown exceptions");
            title.setSize(getWidth(),title.getHeight());
            add(title);
            menu=new ListBox(ListBox.CHOICE);
            menu.setItems(menuList);
            add(menu);
            menu2=new ListBox(ListBox.CHOICE);
            menu2.setItems(subItems[0]);
            add(menu2);
            exe = new Button("execute");
            add(exe);

            /* setting of the listener */
            setSoftKeyListener(this);
            setSoftLabel(Frame.SOFT_KEY_1, "exit");
            setComponentListener(this);
        }

        /**
         * terminate the application when softkey is pushed
         * @param anIndex Index of the softkey
         */
        public void softKeyPressed(int anIndex) {
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * do nothing when a softkey1 is released
         * @param anIndex Index of the softkey
         */
        public void softKeyReleased(int anIndex) {
        }

        /**
         * get the event on a component
         * @param aComponent The component on which an event occurs
         * @param aType Type of an event.
         * @param aParam Parameter of an event
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* when menu1 is choiced */
            if( aComponent == menu && aType == ComponentListener.SELECTION_CHANGED ) {
                /* Item setup of menu2 */
                menu2.setItems(subItems[menu.getSelectedIndex()]);
            }

            /* when  the exsecution button is pushed */
            if (aComponent == exe && aType == ComponentListener.BUTTON_PRESSED) {
                /* test the menu which is choiced */
                test(menu.getSelectedIndex());
            }
        }

        /**
         * dialog display method
         * @param   aText chalacter sequence which is displaied
         */
        public void showDialog(String aText) {
            Dialog  d = new Dialog(Dialog.BUTTON_OK, "notification");
            d.setText(aText);
            d.show();
        }

        /**
         * Testing HttpConnection logic exception generating operation 
         * @param anIndex Index of the menu which is choiced
         */
        public void test(int anIndex) {
            HttpConnection  con=null;
            InputStream     is=null;
            OutputStream    os=null;
            String          filename="J011_0306_0201.jam";
            String          largefile = "../data/10kdata";
            int             i;

            switch( anIndex ) {
            case 0:         /* open() */
                switch( menu2.getSelectedIndex() ) {
                case 0:         /* not available */
                    // J011_0306_0201
                    try {
                        con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        showDialog("NG: no Exception");
                    } catch (RuntimeException e ) {
                        showDialog("RuntimeException:"+e.getMessage());
                    } catch( Exception e1 ) {
                        showDialog("NG:" + e1.toString());
                    }
                    break;
                case 1:         /* NO_RESOURCE */
                    // J011_0306_0202
                    HttpConnection conArray[] = new HttpConnection[99];
                    for( i=0; i<99; i++ ) {
                        conArray[i] = null;
                    }
                    for( i=0; i<99; i++ ) {
                        try {
                            conArray[i]=(HttpConnection) Connector.open(getSourceURL()+
                                                filename,
                                                Connector.READ, true);
                            conArray[i].setRequestMethod(HttpConnection.GET);
                            conArray[i].connect();
                        } catch (ConnectionException e ) {
                            if( e.getStatus() == e.NO_RESOURCE ) {
                                showDialog("ConnectionException(NO_RESOURCE):"
                                            +e.getMessage());
                            
                            } else if( e.getStatus() == e.RESOURCE_BUSY ) {
                                showDialog("ConnectionException(RESOURCE_BUSY):"
                                            +e.getMessage());
                            } else {
                                showDialog("ConnectionException(status="
                                            +e.getStatus() + "):"
                                            +e.getMessage());
                            }
                            break;
                        } catch( Exception e1 ) {
                            showDialog("NG:" + e1.toString());
                            break;
                        }
                    }
                    if( i==99 ) {
                        showDialog("NG: no Exception");
                    }
                    for( i=0; i<99; i++ ) {
                        if( conArray[i] != null ) {
                            try {
                                conArray[i].close();
                            } catch( Exception e ) {
                            }
                        }
                    }
                    break;
                case 2:             /* URL is too long */
                    // J011_0306_0203
                    String url = getSourceURL();
                    for( i=0; i<25; i++ ) {
                        url += "1234567890";
                    }
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        showDialog("NG: no Exception");
                    } catch ( IllegalArgumentException e ) {
                        showDialog("IllegalArgumentException:"+e.getMessage());
                    } catch( Exception e1 ) {
                        showDialog("NG:" + e1.toString());
                    }
                    break;
                case 3:             /* improper mode */
                    // J011_0306_0204
                    try {
                        con=(HttpConnection) Connector.open(
                                            getSourceURL() + filename,
                                            999, true);
                        showDialog("NG: no Exception");
                    } catch ( IllegalArgumentException e ) {
                        showDialog("IllegalArgumentException:"+e.getMessage());
                    } catch( Exception e1 ) {
                        showDialog("NG:" + e1.toString());
                    }
                    break;
              
                case 4:             /* IP specification */
                    // J011_0306_0206
                    try {
                        con=(HttpConnection) Connector.open(
                                            "http://172.1.20.185/",
                                            Connector.READ, true);
                        showDialog("NG: no Exception");
                    } catch ( IllegalArgumentException e ) {
                        showDialog("IllegalArgumentException:"+e.getMessage());
                    } catch( Exception e1 ) {
                        showDialog("NG:" + e1.toString());
                    }
                    break;
                case 5:             /* incorrect URL */
                    // J011_0306_0208
                    try {
                        con=(HttpConnection) Connector.open(
                                            "http://www.yahoo.com/",
                                            Connector.READ, true);
                        showDialog("NG: no Exception");
                    } catch ( SecurityException e ) {
                        showDialog("SecurityException:"+e.getMessage());
                    } catch( Exception e1 ) {
                        showDialog("NG:" + e1.toString());
                    }
                    break;
                case 6:             /* incorrect scheme  */
                    // J011_0306_0209
                    String url1 = getSourceURL();
                    String url2 = new String("https:");
                    if( url1.startsWith(url2) ) {
                        url2 = new String("http:");
                        url2 += url1.substring(6);
                    } else {
                        url2 += url1.substring(5);
                    }
                    try {
                        con=(HttpConnection) Connector.open(
                                            url2 + filename,
                                            Connector.READ, true);
                        showDialog("NG: no Exception");
                    } catch ( SecurityException e ) {
                        showDialog("SecurityException:"+e.getMessage());
                    } catch( Exception e1 ) {
                        showDialog("NG:" + e1.toString());
                    }
                    break;
                case 7:             /* port error */
                    // J011_0306_0210
                    url1 = getSourceURL();
                    int idx1 = url1.indexOf(".jp/");
                    url2 = url1.substring(0,idx1+3);
                    url2 += ":12345";
                    url2 += url1.substring(idx1+3);
                    try {
                        con=(HttpConnection) Connector.open(
                                            url2 + filename,
                                            Connector.READ, true);
                        showDialog("NG: no Exception");
                    } catch ( SecurityException e ) {
                        showDialog("SecurityException:"+e.getMessage());
                    } catch( Exception e1 ) {
                        showDialog("NG:" + e1.toString());
                    }
                    break;
                }
                break;
            case 1:         /* connect() */
                switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0211
                    case 0:         /* The method hasn't been defined */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                        filename,
                                        Connector.READ, true);
                        } catch (Exception e ) {
                            showDialog("NG1:"+e.toString());
                            break;
                        }
                        try {
                            con.connect();
                            showDialog("NG: no Exception");
                        } catch( ConnectionException e ) {
                            if( e.getStatus() == e.ILLEGAL_STATE ) {
                                showDialog("ConnectionException(ILLEGAL_STATE):"+
                                            e.getMessage());
                            } else {
                                showDialog("ConnectionException(status="+
                                            e.getStatus() + "):" + e.getMessage());
                            }
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            con.close();
                        } catch( Exception e ) {
                        }
                        break;
                    // J011_0306_0212
                    case 1:         /* header is insufficient */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                        filename,
                                        Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                            con.setRequestProperty("Content-Type","");
                        } catch (Exception e ) {
                            showDialog("NG1:"+e.toString());
                            break;
                        }
                        try {
                            con.connect();
                            showDialog("NG: no Exception");
                        } catch( ConnectionException e ) {
                            if( e.getStatus() == e.ILLEGAL_STATE ) {
                                showDialog("ConnectionException(ILLEGAL_STATE):"+
                                            e.getMessage());
                            } else {
                                showDialog("ConnectionException(status="+
                                            e.getStatus() + "):" + e.getMessage());
                            }
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            con.close();
                        } catch( Exception e ) {
                        }
                        break;
                    // J011_0306_0213
                    case 2:         /* connection error */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                        largefile,
                                        Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+e.toString());
                            break;
                        }
                        try {
                            con.connect();
                            showDialog("NG: no Exception");
                        } catch( ConnectionException e ) {
                            if( e.getStatus() == e.ILLEGAL_STATE ) {
                                showDialog("ConnectionException(ILLEGAL_STATE):"+
                                            e.getMessage());
                            } else {
                                showDialog("ConnectionException(status="+
                                            e.getStatus() + "):" + e.getMessage());
                            }
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            con.close();
                        } catch( Exception e ) {
                        }
                        break;
                    // J011_0306_0214
                    case 3:         /* the response is not 2xx */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                        "no-such-file",
                                        Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+e.toString());
                            break;
                        }
                        try {
                            con.connect();
                            showDialog("NG: no Exception");
                        } catch( ConnectionException e ) {
                            if( e.getStatus() == e.HTTP_ERROR ) {
                                showDialog("ConnectionException(HTTP_ERROR):"+
                                            e.getMessage());
                            } else {
                                showDialog("ConnectionException(status="+
                                            e.getStatus() + "):" + e.getMessage());
                            }
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            con.close();
                        } catch( Exception e ) {
                        }
                        break;
                    // J011_0306_0215
                    case 4:         /* while transitting to suspend state -- achieved by voice arrival */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                        largefile,
                                        Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+e.toString());
                            break;
                        }
                        try {
                            con.connect();
                            showDialog("NG: no Exception");
                        } catch( InterruptedIOException e ) {
                            showDialog("InterruptedIOException:"+
                                            e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            con.close();
                        } catch( Exception e ) {
                        }
                        break;
                    // J011_0306_0217
                    case 5:         /* not available */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                        filename,
                                        Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                            con.connect();
                            con.close();
                        } catch (Exception e ) {
                            showDialog("NG1:"+e.toString());
                            break;
                        }
                        try {
                            con.connect();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:"+
                                            e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            con.close();
                        } catch( Exception e ) {
                        }
                        break;
                    // J011_0306_0218
                    case 6:         /* another thread is connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                        filename,
                                        Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                            ConnectThread cThread = new ConnectThread(
                                                    getSourceURL()+largefile);
                            cThread.start();
                        } catch (Exception e ) {
                            showDialog("NG1:"+e.toString());
                            break;
                        }
                        try {
                            Thread.sleep(1000);
                        } catch( Exception e ) {
                        }
                        try {
                            con.connect();
                            showDialog("NG: no Exception");
                        } catch( ConnectionException e ) {
                            if( e.getStatus() == e.RESOURCE_BUSY ) {
                                showDialog("ConnectionException(RESOURCE_BUSY):"+
                                            e.getMessage());
                            } else {
                                showDialog("ConnectionException(status="+
                                            e.getStatus() + "):" +e.getMessage());
                            }
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            con.close();
                        } catch( Exception e ) {
                        }
                        break;
                    }
                    break;
                case 2:             /* openInputStream() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0219
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            is = con.openInputStream();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( is != null ) {
                                is.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    // J011_0306_0220
                    case 1:         /* WRITE mode */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            "../cgi-bin/post.cgi",
                                            Connector.WRITE, true);
                            con.setRequestMethod(HttpConnection.POST);
                            con.connect();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            is = con.openInputStream();
                            showDialog("NG: no Exception");
                        } catch( ConnectionException e ) {
                            if( e.getStatus() == e.ILLEGAL_STATE ) {
                                showDialog("ConnectionException(ILLEGAL_STATE):"+
                                            e.getMessage());
                            } else {
                                showDialog("ConnectionException(status="+
                                            e.getStatus() + "):" + e.getMessage());
                            }
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( is != null ) {
                                is.close();
                            }
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 3:             /* openOutputStream() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0221
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            "../cgi-bin/post.cgi",
                                            Connector.WRITE, true);
                            con.setRequestMethod(HttpConnection.POST);
                            con.connect();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            os = con.openOutputStream();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( os != null ) {
                                os.close();
                            }
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    // J011_0306_0222
                    case 1:         /* READ mode */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            "../cgi-bin/post.cgi",
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            os = con.openOutputStream();
                            showDialog("NG: no Exception");
                        } catch( ConnectionException e ) {
                            if( e.getStatus() == e.ILLEGAL_STATE ) {
                                showDialog("ConnectionException(ILLEGAL_STATE):"+
                                            e.getMessage());
                            } else {
                                showDialog("ConnectionException(status="+
                                            e.getStatus() + "):" + e.getMessage());
                            }
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( os != null ) {
                                os.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 4:             /* getEncoding() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0223
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            String msg= con.getEncoding();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 5:             /* getLength() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0224
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            long len = con.getLength();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 6:             /* getType() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0225
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            String msg= con.getType();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 7:             /* setRequestMethod() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0226
                    case 0:         /* after connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                            con.connect();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            con.setRequestMethod(HttpConnection.GET);
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    // J011_0306_0227
                    case 1:         /* null */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            con.setRequestMethod(null);
                            showDialog("NG: no Exception");
                        } catch( NullPointerException e ) {
                            showDialog("NullPointerException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    // J011_0306_0228
                    case 2:         /* the argument out of specification */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            con.setRequestMethod("HEADER");
                            showDialog("NG: no Exception");
                        } catch( IllegalArgumentException e ) {
                            showDialog("IllegalArgumentException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    // J011_0306_0229
                    case 3:         /* WRITE-GET */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            "../cgi-bin/post.cgi",
                                            Connector.WRITE, true);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            con.setRequestMethod(HttpConnection.GET);
                            showDialog("NG: no Exception");
                        } catch( IllegalArgumentException e ) {
                            showDialog("IllegalArgumentException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    // J011_0306_0230
                    case 4:         /* READ-POST */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            con.setRequestMethod(HttpConnection.POST);
                            showDialog("NG: no Exception");
                        } catch( IllegalArgumentException e ) {
                            showDialog("IllegalArgumentException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                  break;
                case 8:             /* setRequestProperty() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0232
                    case 0:         /* after connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                            con.connect();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            con.setRequestProperty("Content-Type","text/plain");
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
         
                case 9:             /* getResponseCode() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0233
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            int res = con.getResponseCode();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 10:                /* getResponseMessage() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0234
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            String msg = con.getResponseMessage();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 11:                /* getHeaderField() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0235
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            String msg = con.getHeaderField("Content-Type");
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 12:                /* getDate() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0236
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            long d = con.getDate();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 13:                /* getExpiration() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0237
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            long d = con.getExpiration();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 14:                /* getLastModified() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0238
                    case 0:         /* before connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            long d = con.getLastModified();
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 15:                /* setIfModifiedSince() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0239
                    case 0:         /* after connecting */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                            con.connect();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            con.setIfModifiedSince(100000000);
                            showDialog("NG: no Exception");
                        } catch( RuntimeException e ) {
                            showDialog("RuntimeException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 16:                /* InputStream.read() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0240
                    case 0:         /* not available */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                            con.connect();
                            is = con.openInputStream();
                            is.close();
                            con.close();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            int c = is.read();
                            showDialog("NG: no Exception");
                        } catch( IOException e ) {
                            showDialog("IOException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( is != null ) {
                                is.close();
                            }
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    // J011_0306_0241
                    case 1:         /* transit to suspend state */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            largefile,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                            con.connect();
                            is = con.openInputStream();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        for( i=0; i<99; i++ ) {
                            boolean errFlag =false;
                            for( int j=0; j<99; j++ ) {
                                try {
                                    int c = is.read();
                                } catch( InterruptedIOException e ) {
                                    showDialog("InterruptedIOException:" + e.getMessage());
                                    errFlag = true;
                                    break;
                                } catch( Exception e2 ) {
                                    showDialog("NG3:"+e2.toString());
                                    errFlag = true;
                                    break;
                                }
                            }
                            if( errFlag ) {
                                break;
                            }
                            try {
                                Thread.sleep(100);
                            } catch( Exception e ) {
                                showDialog("sleep-Exception:" + e.getMessage());
                                break;
                            }
                        }
                        if( i == 99 ) {
                            showDialog("NG: no Exception");
                        }
                        try {
                            if( is != null ) {
                                is.close();
                            }
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 17:                /* InputStream.skip() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0243
                    case 0:         /* not available */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                            con.connect();
                            is = con.openInputStream();
                            con.close();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            is.skip(1);
                            showDialog("NG: no Exception");
                        } catch( IOException e ) {
                            showDialog("IOException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( is != null ) {
                                is.close();
                            }
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 18:                /* InputStream.available() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0244
                    case 0:         /* not available */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            filename,
                                            Connector.READ, true);
                            con.setRequestMethod(HttpConnection.GET);
                            con.connect();
                            is = con.openInputStream();
                            con.close();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            int c = is.available();
                            showDialog("NG: no Exception");
                        } catch( IOException e ) {
                            showDialog("IOException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( is != null ) {
                                is.close();
                            }
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                case 19:                /* OutputStream.write() */
                    switch( menu2.getSelectedIndex() ) {
                    // J011_0306_0245
                    case 0:         /* not available */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            "../cgi-bin/post.cgi",
                                            Connector.WRITE, true);
                            con.setRequestMethod(HttpConnection.POST);
                            os = con.openOutputStream();
                            os.close();
                            con.connect();
                            con.close();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        try {
                            os.write(65);
                            showDialog("NG: no Exception");
                        } catch( IOException e ) {
                            showDialog("IOException:" + e.getMessage());
                        } catch( Exception e2 ) {
                            showDialog("NG3:"+e2.toString());
                        }
                        try {
                            if( os != null ) {
                                os.close();
                            }
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    // J011_0306_0246
                    case 1:         /* excess data */
                        try {
                            con=(HttpConnection) Connector.open(getSourceURL()+
                                            "../cgi-bin/post.cgi",
                                            Connector.WRITE, true);
                            con.setRequestMethod(HttpConnection.POST);
                            os = con.openOutputStream();
                        } catch (Exception e ) {
                            showDialog("NG1:"+ e.toString());
                            break;
                        }
                        for( i=0; i<5121; i++ ) {
                            try {
                                os.write(65);
                            } catch( IOException e ) {
                                showDialog("IOException:" + e.getMessage());
                                break;
                            } catch( Exception e2 ) {
                                showDialog("NG3:"+e2.toString());
                                break;
                            }
                        }
                        if( i == 5121 ) {
                            showDialog("NG: no Exception");
                        }
                        try {
                            if( os != null ) {
                                os.close();
                            }
                            if( con != null ) {
                                con.close();
                            }
                        } catch (Exception e3 ) {
                        }
                        break;
                    }
                    break;
                default:
                    break;
            }
        }



        /**
         * ConnectThread
         * @extends Thread
         */
        class ConnectThread extends Thread {
            String  url;

            /**
             * constructor
             * @param   anUrl      connecting URL
             */
            public ConnectThread( String anUrl ) {
                url = anUrl;
            }

            /**
             * run method
             */
            public void run() {
                HttpConnection c;
                try {
                    c = (HttpConnection) Connector.open(url,
                                            Connector.READ,true);
                    c.setRequestMethod(HttpConnection.GET);
                    c.connect();
                    Thread.sleep(1000);
                    c.close();
                } catch( Exception e ) {
                    showDialog("ConnectThread: " + e.toString());
                }
            }
        }
    }
}
	
