/**
 * J011_1106_0101
 * MainPanel
 *
 * AudioPresenter class action check (normal route)
 *
 * $Id: J011_1106_0101.java,v 1.3 2002/04/25 07:25:29 torikatu Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.util.*;

/**
 * AudioPresenter class action check main class
 * @extends IApplication
 */
public class J011_1106_0101 extends IApplication{
    
    /**
     * starting method for I-appli
     */
    public void start(){
        Display.setCurrent(new MainPanel());
    }
}

/**
 * AudioPresenter class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements MediaListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener,MediaListener{
    String[] menuListItem = {
        "0 test 1",
        "2 test 3",
        "3 test 4",
        "4 test 5",
        "5 test 6",
        "6 test 7",
        "7 test 8",
        "8 test 9",
        "9 test 10",
        "10 test 11",
        "11 test 12",
        "12 test 13",
        "13 test 14",
        "14 test 15",
        "15 test 16"
//        "16 test 17"
    };
    
    Frame subFrame ;
    Label classLabel = new Label("AudioPresenter");
    ListBox menuList = new ListBox(ListBox.CHOICE);
    TextBox resultBox =new TextBox("",20,2,TextBox.DISPLAY_ANY);
    Button execButton = new Button("execute");
    Button stopButton = new Button("stop");
    AudioPresenter ap = null;
    
    /**
     * constructer of the MainPanel
     */
    public MainPanel(){
        try{
            /* display the MainPanel */
            showMainPanel();
        }catch(Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }
    }
    
    /**
     * display the main panel
     */
    void showMainPanel(){
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
    
        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);
        add(stopButton);
        add(resultBox);
    
        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }
    
    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex){}
    
    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex){
        /* terminate the application when softkey1 is released */
        if(anIndex == Frame.SOFT_KEY_1){
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Event type
     * @param aParam  parameter of the event
     */
    public void componentAction(Component aComponent,int aType,int aParam){
        /* processing when the execution button is pushed */
        if(aComponent == execButton && aType == ComponentListener.BUTTON_PRESSED){
            test();
        }
        /* processing when the stop button is pushed */
        if(aComponent == stopButton && aType == ComponentListener.BUTTON_PRESSED){
            ap.stop();
        }
    }
    
    /**
     * create the test method
     * each  event processing when the excecution button is pushed
     */
    public void test(){
        /* takes the figure when choosing from the list box. */
        int index = menuList.getSelectedIndex();
        
        switch (index) {
            //J011_1106_0101
            /**
             * test can't be excecuted
             */
                   
            //J011_1106_0102
            case 0:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.setSound(ms);
                    ap.play();
                    ap.setSound(ms);
                    resultBox.setText("NG: No exception has detected.");
                }catch(UIException anUIException){
                    if (anUIException.getStatus() == 1){
                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
                    }else{
                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
            
            //J011_1106_0104
            case 1:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.setSound(null);
                    ap.play();
                    resultBox.setText("NG: No exception has detected.");
                }catch(NullPointerException aNullPointerException){
                    resultBox.setText("OK : NullPointerException : " +aNullPointerException.getMessage());
                }catch(Exception anException){
                    resultBox.setText("NG : " +anException.toString());
                }
                break;
                
            //J011_1106_0105
            case 2:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///pika.wav");
                    ms.use();
                    ap.setSound(ms);
                    ap.play();
                    resultBox.setText("NG: No exception has detected.");
                }catch(UIException anUIException){
                    if (anUIException.getStatus() == 4 ){
						// 2003/03/26 ->
                        //resultBox.setText("UIException(OK) : " +anUIException.getMessage());
						resultBox.setText("UIException(OK) : " +anUIException.getMessage()
							 				+ "(UNSUPPORTED_FORMAT)");
						// 2003/03/26 <-
                    }else{
                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
            
            //J011_1106_0106
            case 3:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.setSound(ms);
                    MediaData md = MediaManager.getData("resource:///MFi-norm.mld");
                    md.use();
                    ap.setData(md);
                    ap.play();
                    resultBox.setText("NG: No exception has detected.");
                }catch(Exception anException){
                    resultBox.setText("OK: An exception has detected.");
                }
                break;
                
            //J011_1106_0107
            case 4:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaData md =MediaManager.getData("resource:///MFi-norm.mld");
                    md.use();
                    ap.setData(md);
                    ap.play();
                    resultBox.setText("OK: Please report that setData is supported.");
                }catch(UnsupportedOperationException anUnsupportedOperationException){
                    resultBox.setText("OK : UnsupportedOperationException : "+anUnsupportedOperationException.getMessage());
                }catch(Exception anException){
                    resultBox.setText("NG : " +anException.toString());
                }
                break;
                
            //J011_1106_0108
            case 5:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.setSound(ms);
                    ap.play();
                    MediaData md = MediaManager.getData("resource:///MFi-norm.mld");
                    md.use();
                    ap.setData(md);
                    resultBox.setText("NG: No exception has detected.");
                }catch(UnsupportedOperationException anUnsupportedOperationException){
                    resultBox.setText("UnsupportedOperationException");
                }catch(UIException anUIException){
                    if (anUIException.getStatus() == 1 ){
                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
                    }else{
                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
                
            //J011_1106_0109
            case 6:
                try{
                    ap = AudioPresenter.getAudioPresenter();
		    MediaData md = null;
                    ap.setData(md);
                    ap.play();
                    resultBox.setText("NG: No exception has detected.");
                }catch(UnsupportedOperationException anUnsupportedOperationException){
                    resultBox.setText("UnsupportedOperationException : "+anUnsupportedOperationException.getMessage());
                }catch(NullPointerException aNullException){
                    resultBox.setText("OK : NullPointerException");
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
            
            //J011_1106_0110
            case 7:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaData md = MediaManager.getData("resource:///pika.wav");
                    md.use();
                    ap.setData(md);
                    ap.play();
                    resultBox.setText("NG: No exception has detected.");
                }catch(UnsupportedOperationException anUnsupportedOperationException){
                    resultBox.setText("UnsupportedOperationException");
                }catch(UIException anUIException){
                    if(anUIException.getStatus() == 4 ){
                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
                    }else{
                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
                
            //J011_1106_0111
            case 8:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaData md = MediaManager.getData("resource:///MFi-norm.mld");
                    md.use();
                    ap.setData(md);
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.setSound(ms);
                    ap.play();
                    resultBox.setText("NG: No exception has detected.");
                }catch(UnsupportedOperationException anUnsupportedOperationException){
                    resultBox.setText("UnsupportedOperationException");
                }catch(Exception anException){
                    resultBox.setText("OK: An exception has detected.");
                }
                break;
            
            //J011_1106_0112
            case 9:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.play();
                    resultBox.setText("NG: No exception has detected.");
                }catch(UIException anUIException){
                    if(anUIException.getStatus() == 1 ){
                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
                    }else{
                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
                
            //J011_1106_0113
            case 10:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///pika.wav");
                    ap.setSound(ms);
                    ap.play();
                    resultBox.setText("NG: No exception has detected.");
                }catch(UIException anUIException){
                    if(anUIException.getStatus() == 1 ){
                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
                    }else{
                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
                
            //J011_1106_0114
            /**
             * test can't be excecuted
             */
            
            //J011_1106_0115
            /**
             * test can't be excecuted
             */
            
            //J011_1106_0116
            /**
             * test can't be excecuted
             */
            
            //J011_1106_0117
            case 11:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.setSound(ms);
                    ap.play();
                    ms.unuse();
                    resultBox.setText("No exception is detected.");
                }catch(UIException anUIException){
                    if(anUIException.getStatus() == 1 ){
                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
                    }else{
                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
                
            //J011_1106_0118
            case 12:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.setSound(ms);
                    ap.play();
                    ms.dispose();
                    resultBox.setText("No exception is detected.");
                }catch(UIException anUIException){
                    if(anUIException.getStatus() == 1 ){
                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
                    }else{
                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
                
            //J011_1106_0119
            case 13:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.play();
                    ap.stop();
                    resultBox.setText("NG: No exception has detected.");
                }catch(UIException anUIException){
                    if(anUIException.getStatus() == 1 ){
                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
                    }else{
                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
                
            //J011_1106_0120
            case 14:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ap.setSound(ms);
                    ap.stop();
                    resultBox.setText("NG: No exception has detected.");
                }catch(UIException anUIException){
                    if(anUIException.getStatus() == 1 ){
                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
                    }else{
                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                }
                break;
                
            //J011_1106_0121
//            case 15:
//                try{
//                    ap = AudioPresenter.getAudioPresenter();
//                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
//                    ms.use();
//                    ap.setSound(ms);
//2002/08/01 DoJa1.5                    ap.setAttribute(AudioPresenter.ATTR_SYNC_ON,0);
//                    ap.setAttribute(AudioPresenter.AUDIO_PLAYING,0);
//                    resultBox.setText("NG: No exception has detected.");
//                }catch(IllegalArgumentException anIllegalArgumentException){
//                    resultBox.setText("IllegalArgumentException(OK) : " +anIllegalArgumentException.getMessage());
//                }catch(Exception anException){
//                    resultBox.setText("NG : " +anException.toString());
//                }
//                break;
                
//2002/07/25 DoJa1.5            //J011_1106_0122
//2002/07/25 DoJa1.5            case 17:
//2002/07/25 DoJa1.5                try{
//2002/07/25 DoJa1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 DoJa1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
//2002/07/25 DoJa1.5                    ms.use();
//2002/07/25 DoJa1.5                    int time = 10000;
//2002/07/25 DoJa1.5                    ap.play(time);
//2002/07/25 DoJa1.5                    resultBox.setText("");
//2002/07/25 DoJa1.5                }catch(UIException anUIException){
//2002/07/25 DoJa1.5                    if(anUIException.getStatus() == 1 ){
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }else{
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }
//2002/07/25 DoJa1.5                }catch(Exception anException){
//2002/07/25 DoJa1.5                    resultBox.setText("NG : "+anException.toString());
//2002/07/25 DoJa1.5                }
//2002/07/25 DoJa1.5                break;
                    
//2002/07/25 DoJa1.5            //J011_1106_0123
//2002/07/25 DoJa1.5            case 18:
//2002/07/25 DoJa1.5                try{
//2002/07/25 DoJa1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 DoJa1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
//2002/07/25 DoJa1.5                    ap.setSound(ms);
//2002/07/25 DoJa1.5                    int time = 10000;
//2002/07/25 DoJa1.5                    ap.play(time);
//2002/07/25 DoJa1.5                    resultBox.setText("");
//2002/07/25 DoJa1.5                }catch(UIException anUIException){
//2002/07/25 DoJa1.5                    if(anUIException.getStatus() == 1 ){
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }else{
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }
//2002/07/25 DoJa1.5                }catch(Exception anException){
//2002/07/25 DoJa1.5                    resultBox.setText("NG : "+anException.toString());
//2002/07/25 DoJa1.5                }
//2002/07/25 DoJa1.5                break;
            
            //J011_1106_0124
            /**
             * test can't be excecuted
             */
                
//2002/07/25 DoJa1.5            //J011_1106_0125
//2002/07/25 DoJa1.5            case 19:
//2002/07/25 DoJa1.5                try{
//2002/07/25 DoJa1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 DoJa1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
//2002/07/25 DoJa1.5                    ms.use();
//2002/07/25 DoJa1.5                    ap.play();
//2002/07/25 DoJa1.5                    ap.pause();
//2002/07/25 DoJa1.5                    resultBox.setText("");
//2002/07/25 DoJa1.5                }catch(UIException anUIException){
//2002/07/25 DoJa1.5                    if(anUIException.getStatus() == 1 ){
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }else{
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }
//2002/07/25 DoJa1.5                }catch(Exception anException){
//2002/07/25 DoJa1.5                    resultBox.setText("NG : "+anException.toString());
//2002/07/25 DoJa1.5                }
//2002/07/25 DoJa1.5                break;
                    
//2002/07/25 DoJa1.5            //J011_1106_0126
//2002/07/25 DoJa1.5            case 20:
//2002/07/25 DoJa1.5                try{
//2002/07/25 DoJa1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 DoJa1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
//2002/07/25 DoJa1.5                    ap.setSound(ms);
//2002/07/25 DoJa1.5                    ap.play();
//2002/07/25 DoJa1.5                    ap.pause();
//2002/07/25 DoJa1.5                    resultBox.setText("");
//2002/07/25 DoJa1.5                }catch(UIException anUIException){
//2002/07/25 DoJa1.5                    if(anUIException.getStatus() == 1 ){
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }else{
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }
//2002/07/25 DoJa1.5                }catch(Exception anException){
//2002/07/25 DoJa1.5                    resultBox.setText("NG : "+anException.toString());
//2002/07/25 DoJa1.5                }
//2002/07/25 DoJa1.5                break;
                
//2002/07/25 DoJa1.5            //J011_1106_0127
//2002/07/25 DoJa1.5            case 21:
//2002/07/25 DoJa1.5                try{
//2002/07/25 DoJa1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 DoJa1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
//2002/07/25 DoJa1.5                    ms.use();
//2002/07/25 DoJa1.5                    ap.play();
//2002/07/25 DoJa1.5                    ap.restart();
//2002/07/25 DoJa1.5                    resultBox.setText("");
//2002/07/25 DoJa1.5                }catch(UIException anUIException){
//2002/07/25 DoJa1.5                    if(anUIException.getStatus() == 1 ){
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }else{
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }
//2002/07/25 DoJa1.5               }catch(Exception anException){
//2002/07/25 DoJa1.5                    resultBox.setText("NG : "+anException.toString());
//2002/07/25 DoJa1.5                }
//2002/07/25 DoJa1.5                break;
                    
//2002/07/25 DoJa1.5            //J011_1106_0128
//2002/07/25 DoJa1.5            case 22:
//2002/07/25 DoJa1.5                try{
//2002/07/25 DoJa1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 DoJa1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
//2002/07/25 DoJa1.5                    ap.setSound(ms);
//2002/07/25 DoJa1.5                    ap.play();
//2002/07/25 DoJa1.5                    ap.restart();
//2002/07/25 DoJa1.5                    resultBox.setText("");
//2002/07/25 DoJa1.5                }catch(UIException anUIException){
//2002/07/25 DoJa1.5                    if(anUIException.getStatus() == 1 ){
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }else{
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }
//2002/07/25 DoJa1.5                }catch(Exception anException){
//2002/07/25 DoJa1.5                    resultBox.setText("NG : "+anException.toString());
//2002/07/25 DoJa1.5                }
//2002/07/25 DoJa1.5                break;
                
            //J011_1106_0129
            /**
             * test can't be excecuted
             */
            
            //J011_1106_0130
            /**
             * test can't be excecuted
             */
            
            //J011_1106_0131
            /**
             * test can't be excecuted
             */
                
//2002/07/25 DoJa1.5            //J011_1106_0132
//2002/07/25 DoJa1.5            case 23:
//2002/07/25 DoJa1.5                try{
//2002/07/25 DoJa1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 DoJa1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
//2002/07/25 DoJa1.5                    ms.use();
//2002/07/25 DoJa1.5                    ap.setSound(ms);
//2002/07/25 DoJa1.5                    ap.play();
//2002/07/25 DoJa1.5                    ap.pause();
//2002/07/25 DoJa1.5                    ap.restart();
//2002/07/25 DoJa1.5                    ms.unuse();
//2002/07/25 DoJa1.5                    resultBox.setText("");
//2002/07/25 DoJa1.5                }catch(UIException anUIException){
//2002/07/25 DoJa1.5                    if(anUIException.getStatus() == 1 ){
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }else{
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }
//2002/07/25 DoJa1.5                }catch(Exception anException){
//2002/07/25 DoJa1.5                    resultBox.setText("NG : "+anException.toString());
//2002/07/25 DoJa1.5                }
//2002/07/25 DoJa1.5                break;
                
//2002/07/25 DoJa1.5            //J011_1106_0133
//2002/07/25 DoJa1.5            case 24:
//2002/07/25 DoJa1.5                try{
//2002/07/25 DoJa1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 DoJa1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
//2002/07/25 DoJa1.5                    ms.use();
//2002/07/25 DoJa1.5                    ap.setSound(ms);
//2002/07/25 DoJa1.5                    ap.play();
//2002/07/25 DoJa1.5                    ap.pause();
//2002/07/25 DoJa1.5                    ap.restart();
//2002/07/25 DoJa1.5                    ms.dispose();
//2002/07/25 DoJa1.5                    resultBox.setText("");
//2002/07/25 DoJa1.5                }catch(UIException anUIException){
//2002/07/25 DoJa1.5                    if(anUIException.getStatus() == 1 ){
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(OK) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }else{
//2002/07/25 DoJa1.5                        resultBox.setText("UIException(NG) : " +anUIException.getMessage());
//2002/07/25 DoJa1.5                    }
//2002/07/25 DoJa1.5                }catch(Exception anException){
//2002/07/25 DoJa1.5                    resultBox.setText("NG : "+anException.toString());
//2002/07/25 DoJa1.5                }
//2002/07/25 DoJa1.5                break;
//2002/07/25 DoJa1.5                
            default:
                break;
        }
    }
    
    /**
     * event processing of MediaAction
     * @source  media presenter is handed over ,which is the source of a notice
     * @type event type
     * @param event parameter
     */
    public void mediaAction(MediaPresenter source,int type,int param){}
}
