/**
 * J011_1502_0101 
 * Main Panel
 *
 * ComponentListener class action check (normal route)
 *
 * $Id: J011_1502_0101.java,v 1.1 2001/12/01 12:46:12 misato Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;

/**
 * ComponentListener class action check main class
 * @extends IApplication
 */
public class J011_1502_0101 extends IApplication{
    /**
     * starting method for I-appli
     */
    public void start(){
        Display.setCurrent(new MainPanel());
    }
}

/**
 * ComponentListener class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    String[] menuListItem = {
        "0 test 1",
        "1 test 2",
        "2 test 3",
        "3 test 4"
    };
    
    String[] exceptionItem = {
        "BUTTON_PRESSED",
        "SELECTION_CHANGED",
        "TEXT_CHANGED"
    };
    
    Frame subFrame ;
    Label classLabel = new Label("ComponentListener");
    ListBox menuList = new ListBox(ListBox.CHOICE);
    TextBox resultBox = new TextBox("",20,2,TextBox.DISPLAY_ANY);
    Button execButton = new Button("execute");
    Button testButton = new Button("test 4");
    
    /**
     * constructer of the MainPanel
     */
    public MainPanel(){
        try{
            /* display the MainPanel */
            showMainPanel();
        }catch(Exception anException){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"error");
            errDialog.setText("Error:" +anException.toString());
            errDialog.show();
        }
    }
    
    /**
     * display the main panel
     */
    void showMainPanel(){
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API normal route");
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        
        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);
        add(testButton);
        add(resultBox);
        
        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
        
        /**
         * constant member check
         * The following is confirming Constant member can't be set the value
         * Confirm the failure in building and delete to the end of the method
         */
        
        /*
        //J011_1502_0101
        ComponentListener.BUTTON_PRESSED == 0;
        //J011_1502_0102
        ComponentListener.SELECTION_CHANGED == 0;
        //J011_1502_0103
        ComponentListener.TEXT_CHANGED == 0;
        */
    }
    
    /**
     * do nothing when the softkey is pushed
     */
    public void softKeyPressed(int anIndex){}
    
    /**
     * terminate application when the softkey is released
     */
    public void softKeyReleased(int anIndex){
        /* terminate the application when softkey1 is released*/
        if(anIndex == Frame.SOFT_KEY_1){
            IApplication.getCurrentApp().terminate();
        }
    }
    
    /**
     * get the event on a component
     * @param aComponent the component on which an event occurred
     * @param aType event type
     * @param aParam event parameter
     */
    public void componentAction(Component aComponent,int aType,int aParam){
        /* processing when the list choice is changed */
        if(aComponent == menuList && aType == ComponentListener.SELECTION_CHANGED){
            resultBox.setText("");
        }
        
        /* processing when the execution button is pushed */
        if(aComponent == execButton && aType == ComponentListener.BUTTON_PRESSED){
            resultBox.setText(result(menuList.getSelectedIndex()));
        }
        
        /* processing when test4 button is pushed */
        if(aComponent == testButton && aType == ComponentListener.BUTTON_PRESSED){
            test();
        }
    }
    
    String result(int anIndex){
        String resultStr;
        
        /**
         * get the event on a component
         * @param anIndex the index number which selected in listbox
         * @return
         */
        switch(anIndex){
            //J011_1502_0201
            case 0 :
                resultStr = isOK(ComponentListener.BUTTON_PRESSED == 1);
                break;
            
            //J011_1502_0202
            case 1 :
                resultStr = isOK(ComponentListener.SELECTION_CHANGED == 2);
                break;
                
            //J011_1502_0203
            case 2 :
                resultStr = isOK(ComponentListener.TEXT_CHANGED == 3);
                break;
                
            default:
                resultStr = "ERROR\nMissing Operation";
            break;
        }
        
        /**
         * When a judgment result is NG, an actual value is set as NG addition information
         */
        if(resultStr.equals("NG")){
            resultStr += "\n"+exceptionItem[anIndex];
        }
        return resultStr;
    }
    
    /**
     * The justification of a constant definition is judged and the character sequence OK/NG is returned.
     * @param aResult Constant definition judging
     * @implements ComponentListener
     */
    String isOK(boolean aResult){
        return(aResult ? "OK":"NG");
    }
    
    /**
     * create the test method
     * operation when the test4 button was pressed
     */
    void test(){
        int index = menuList.getSelectedIndex();
        
        switch(index){
            //J011_1505_0101
            case 3:
                resultBox.setText("OK");
                break;
                
            default:
                resultBox.setText("NG");
                break;
        }
    }
}