/**
 * J011_1902_0101
 *
 * Font class action check (normal route)
 * Constant member definition check
 *
 * $Id: J011_1902_0101.java,v 1.1 2001/12/01 13:27:24 horikoshi Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;


/**
 * Font class action check main class
 * @extends IApplication
 */
public class J011_1902_0101 extends IApplication {

    /**
     * starting i-Appli start()
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * Font class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menu = {
        "01 TYPE_DEFAULT",
        "02 TYPE_HEADING",
        "03 FACE_SYSTEM",
        "04 FACE_MONOSPACE",
        "05 FACE_PROPORTIONAL",
        "06 STYLE_PLAIN",
        "07 STYLE_BOLD",
        "08 STYLE_ITALIC",
        "09 STYLE_BOLDITALIC",
        "10 SIZE_SMALL",
        "11 SIZE_MEDIUM",
        "12 SIZE_LARGE"
    };

    int[] Num = {
        0x00000000,
        0x00000001,
        0x71000000,
        0x72000000,
        0x73000000,
        0x70100000,
        0x70110000,
        0x70120000,
        0x70130000,
        0x70000100,
        0x70000200,
        0x70000300 
    };

    Frame   nextFrame;
    Label   title       = new Label("check definition of the Font constant");
    ListBox menu_Li     = new ListBox(ListBox.CHOICE);
    TextBox execTextBox = new TextBox("TextBox", 20, 3, TextBox.DISPLAY_ANY);
    Button  execButton  = new Button("execute");
    int     selection;
    int     ret;

    /**
     * MainPanel constructor(normal route)
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            /* processing when the exception occurs */
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    void showMainPanel() {

        /* setting of the display item */
        menu_Li.setItems(menu);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(title);
        add(menu_Li);
        add(execButton);
        add(execTextBox);

        /* register the softkey listener */
        setSoftKeyListener(this);
        /* register the component listener */
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of the pushed softkey 
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when SOFT_KEY_1 is released
     * @param anIndex the value of the released softkey 
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when SOFT_KEY_1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * process when the action other than softkey happens
     * @param source the component on which the event occurs
     * @param type event type
     * @param param event parameter
     */
    public void componentAction(Component source, int type, int param) {

        /* when the list is chosen */
        if (source == menu_Li && type == ComponentListener.SELECTION_CHANGED) {

            /* clear the content in the result displaying textbox */
            execTextBox.setText("");
        }

        /* when the fix-key is pushed on the condition the execution button is focused */
        if (source == execButton 
            && type == ComponentListener.BUTTON_PRESSED) {

            /* get the chosen item */
            selection = menu_Li.getSelectedIndex();

            /* this confirms about whether or not it is possible to get a value.
  */
            ReturnNum myReturnNum = new ReturnNum(selection);
            ret = myReturnNum.retNum();
            if (Num[selection] == ret) {
                execTextBox.setText("\"OK!\"\nThe answer="+Integer.toHexString(Num[selection])
                                        +"\nThe result="+Integer.toHexString(ret));
            } else {
                execTextBox.setText("\"NG!\"\nThe answer="+Integer.toHexString(Num[selection])
                                        +"\nThe result="+Integer.toHexString(ret));
            }
        }
    }
}

/**
 * Font class constant definition check
 */
class ReturnNum {

    Font    f;
    int     selection;

    /**
     * ReturnNum constructor(initializing)
     */
    ReturnNum(int type) {
        selection = type;
    }

    public int retNum() {

//J011_1902_0101 -
//J011_1902_0112
        /* confirm that the value cannot be put in static member -> it have been confirmed by the compile error */
/*
        f.TYPE_DEFAULT      = -1;
        f.TYPE_HEADING      = -1;
        f.FACE_SYSTEM       = -1;
        f.FACE_MONOSPACE    = -1;
        f.FACE_PROPORTIONAL = -1;
        f.STYLE_PLAIN       = -1;
        f.STYLE_BOLD        = -1;
        f.STYLE_ITALIC      = -1;
        f.STYLE_BOLDITALIC  = -1;
        f.SIZE_SMALL        = -1;
        f.SIZE_MEDIUM       = -1;
        f.SIZE_LARGE        = -1;
*/

        /* confirm that the value have been defined as the fixed constant */
        switch (selection) {
//J011_1902_0201
            case 0:
                return    f.TYPE_DEFAULT;
//J011_1902_0202
            case 1:
                return    f.TYPE_HEADING;
//J011_1902_0203
            case 2:
                return    f.FACE_SYSTEM;
//J011_1902_0204
            case 3:
                return    f.FACE_MONOSPACE;
//J011_1902_0205
            case 4:
                return    f.FACE_PROPORTIONAL;
//J011_1902_0206
            case 5:
                return    f.STYLE_PLAIN;
//J011_1902_0207
            case 6:
                return    f.STYLE_BOLD;
//J011_1902_0208
            case 7:
                return    f.STYLE_ITALIC;
//J011_1902_0209
            case 8:
                return    f.STYLE_BOLDITALIC;
//J011_1902_0210
            case 9:
                return    f.SIZE_SMALL;
//J011_1902_0211
            case 10:
                return    f.SIZE_MEDIUM;
//J011_1902_0212
            case 11:
                return    f.SIZE_LARGE;
            default:
                return    (-1);
        }
    }
}
