/**
 * J011_2603_0101
 *
 * ImageLabel class action check (normal route)
 * the constructor checking part
 *
 * $Id: J011_2603_0101.java,v 1.1 2001/12/01 13:27:48 horikoshi Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;


/**
 * ImageLabel class action check main class
 * @extends IApplication
 */
public class J011_2603_0101 extends IApplication {

    /**
     * starting i-Appli start()
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * ImageLabel class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menu1 = {
        "01 ImageLabel()",
        "02 ImageLabel(xxx)",
    };

    String[] menu2_01 = {
        "01 the label is not designated",
        "02 the label is designated"
    };

    String[] menu2_02 = {
        "01 put an image",
        "02 the label is designated"
    };

    Frame   nextFrame;
    Label   title      = new Label("ImageLabel constructor");
    ListBox menu_Li    = new ListBox(ListBox.CHOICE);
    ListBox menu_Li2   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");
    int     firstType;
    int     secondType;

    /**
     * MainPanel constructor(initializing)
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            /* processing when the exception occurs */
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error:window1");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    void showMainPanel() {

        /* setting of the display item */
        menu_Li.setItems(menu1);
        menu_Li2.setItems(menu2_01);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(title);
        add(menu_Li);
        add(menu_Li2);
        add(execButton);

        /* register the softkey listener */
        setSoftKeyListener(this);
        /* register the component listener */
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of the pushed softkey 
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when SOFT_KEY_1 is released
     * @param anIndex the value of the released softkey 
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when SOFT_KEY_1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * process when the action other than softkey happens
     * @param source the component on which the event occurs
     * @param type event type
     * @param param event parameter
     */
    public void componentAction(Component source, int type, int param) {

        /* when item in the menu1 is selected */
        if (source == menu_Li && type == ComponentListener.SELECTION_CHANGED) {

            /* get the chosen item */
            firstType = menu_Li.getSelectedIndex();

            /* set the selection list in menu 1 */
            switch (firstType) {
                case 0:
                    menu_Li2.setItems(menu2_01);
                    break;
                case 1:
                    menu_Li2.setItems(menu2_02);
                    break;
                default:
                    break;
            }
        }

        /* when the fix-key is pushed on the condition the execution button is focused */
        if (source == execButton 
            && type == ComponentListener.BUTTON_PRESSED) {

            /* get the chosen item */
            secondType = menu_Li2.getSelectedIndex();

            try {
                nextFrame = new NextPanel1(this, firstType, secondType);
            } catch (Exception e) {
                /* in case of exception */
                throw new RuntimeException("The selected item is not exist.");
            }
            /* setting the screen which is se */
            Display.setCurrent(nextFrame);
        }

    }
}


/**
 * NextPanel1 class
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel1 extends Panel implements SoftKeyListener {

    Frame      mainFrame;
    Frame      nextFrame;
    TextBox    resultText = new TextBox("", 20, 3, TextBox.DISPLAY_ANY);
    String     resultstr  = new String();
    int        firstType;
    int        secondType;
    Image      img;
    ImageLabel imgLabel;
    MediaImage mi;

    /**
     * NextPanel class constructor(initializing)
     * @param f  pass the screen on
     * @param type the selected value in the listbox1
     * @param type2 the selected value in the listbox2
     */
    public NextPanel1(Frame frame, int type, int type2) {

        /* setting the parameter */
        mainFrame = frame;
        firstType = type;
        secondType = type2;

        try {
            /* display the result of action testing on the screen */
            Resultinit();
            showResult();
        } catch (Exception e) {
            /* processing when the exception occurs */
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error:window2");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the testing result on the screen
     */
    public void Resultinit() {
        /* setting of the softkey */
        setSoftLabel(Frame.SOFT_KEY_1, "back");

        /* setting each component */
        setTitle("ImageLabel execution result");
    
        /* register the softkey listener */
        setSoftKeyListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of the pushed softkey 
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * return to the previous screen when SOFT_KEY_1 is released
     * @param anIndex the value of the released softkey 
     */
    public void softKeyReleased(int anIndex) {

        /* return to the previous screen when SOFT_KEY_1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            Display.setCurrent(mainFrame);
        }
    }

    /**
     * method which display the result
     */
    public void showResult() {

        try {
            /* get the image file from JAR */
            mi = MediaManager.getImage("resource:///dosei.jpeg");

            /* load the image file into the memory */
            mi.use();

            /* ImageLabel(): when the parameter doesn't exist */
            if (firstType == 0) {

                switch (secondType) {
                /* when the label setting does'nt exist */
                case 0:
//J011_2603_0101
                    imgLabel = new ImageLabel();
                    /* setting the label invisible */
                    imgLabel.setVisible(false);
                    /* change the label color from default to other */
                    imgLabel.setBackground(0x00ffff00);
                    resultstr = "verify that no label is displayed (nothing is displayed).";
                    resultText.setText(resultstr);
                    break;

                /* when the label setting exists */
                case 1:
//J011_2603_0102
                    imgLabel = new ImageLabel();
                    /* setting the label visible */
                    imgLabel.setVisible(true);
                    /* change the label color from default to other */
                    imgLabel.setBackground(0x00ffff00);
                    resultstr = "verify that a small label (default size) is displayed.";
                    resultText.setText(resultstr);
                    break;
                default:
                    break;
                }

            /* ImageLabel(xxx): when the parameter exists */
            } else if (firstType == 1) {

                switch (secondType) {
                /* when the image is set */
                case 0:
//J011_2603_0201
                    img = mi.getImage();
                    imgLabel = new ImageLabel(img);
                    resultstr = "verify that the image [dosei.jpeg] is displayed.";
                    resultText.setText(resultstr);
                    break;
                /* when the label setting exists */
                case 1:
//J011_2603_0202
                    img = mi.getImage();
                    imgLabel = new ImageLabel(img);
                    /* setting the label visible */
                    imgLabel.setVisible(true);
                    /* make the label size larger than image */
                    imgLabel.setSize(100,100);
                    /* change the label color from default to other */
                    imgLabel.setBackground(0x00ffff00);
                    resultstr = "verify that the image is on the larger label.";
                    resultText.setText(resultstr);
                    break;
                default:
                    break;
                }
            }
        } catch (Exception e) {
            /* in case of image file loading error */
            Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR,
                                    "loading the image failed.");
        }
        
        /* add the result to the screen */
        add(imgLabel);
        add(resultText);
    }
}

