/**
 * J011_3501_0101.java
 *
 * J011_3501_0101
 * MainPanel
 *
 * MediaListener class action checking
 * 
 * $Id: J011_3501_0101.java,v 1.2 2001/12/02 05:15:54 waka Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * MediaListener class action checking main class
 * @extends IApplication
 */
public class J011_3501_0101 extends IApplication {
    /**
     * I-appli starting method
     */
    public void start() {
        MainPanel mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * MediaListener action checking main class
 * @extends  Panel
 * @implements  SoftKeyListener
 * @implements  ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener, MediaListener{

    Button testButton1,testButton2;
    MediaImage testMediaImage;
    VisualPresenter testVisualPresenter = new VisualPresenter();
    MediaResource testMediaResource;

    /**
     * Constructor of MainPanel class
     */
    MainPanel() {
        try {
            showPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * component displaying method
     */
    void showPanel() {

        /* display title,subtitle */
        setTitle("API class normal route");
        Label subTitle = new Label("MediaListener");
        subTitle.setSize(getWidth(), subTitle.getHeight());

        /* create and add the action checking button */
        testButton1 = new Button("PLY");
        testButton2 = new Button("STP");
        add(testButton1);
        add(testButton2);

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        setMedia();

    }

    /**
     * setting method for the media for checking
     */
    void setMedia() {
        try {
            testMediaImage = MediaManager.getImage("resource:///J011_35.gif");
            testMediaResource = (MediaResource)testMediaImage;
//          testMediaResource = testVisualPresenter.getMediaResource();
            testMediaResource.use();
            testVisualPresenter.setImage(testMediaImage);
            testVisualPresenter.setMediaListener(this);
            add(testVisualPresenter);
        } catch(ConnectionException ce) {
            showMsg("ConnectionException:" + ce.getMessage());
        }
    }

    /**
     * action checking method
     * @param  buttonType action checking button
     */
    void test(int buttonType) {
        switch (buttonType) {
            case 1:
                testVisualPresenter.play();
                break;
            case 2:
                testVisualPresenter.stop();
                break;
        }
    }

    /**
     * dialog display method
     * @param  aMsg dialog display message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * terminate the application when the softkey1 is released
     * shift to the previous screen in case of softkey2
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if ( aSoftKey == Frame.SOFT_KEY_1 ) {
            IApplication.getCurrentApp().terminate();
        }

    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {
        if ( aAction == BUTTON_PRESSED ) {
            if ( aComponent == testButton1 ) {
                test(1);
            }
            if ( aComponent == testButton2 ) {
                test(2);
            }
        }
    }

    /**
     * get the notice from media presenter
     * @param  aMedia media presenter which is the source of the notice
     * @param  aAction event type
     * @param  aParam event parameter
     */
    public void mediaAction(MediaPresenter aMedia, int aAction, int aParam){
// J011_3505_0201
        /* processing when place button is pressed */
        if ( aAction == VisualPresenter.VISUAL_PLAYING ) {
            showMsg("Status: PLAYING");
        }
        /* processing when stop button is pressed */
        if ( aAction == VisualPresenter.VISUAL_STOPPED ) {
            showMsg("Status: STOPPED");
        }
    }
}