/**
 * J011_4204_0201
 * MainPanel
 *
 * ShortTimer class action check(normal route)
 *
 * $Id: J011_4204_0201.java,v 1.1 2001/11/30 04:14:42 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * ShortTimer class action check main class
 * @extends IApplication
 */
public class J011_4204_0201 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * ShortTimer class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "0.repeat-true",
        "1.repeat-false",
        "2.getResolution",
        "3.start",
        "4.stop",
        "5.dispose",
        "6.dispose2"
    };

    Label   classLabel       = new Label("ShorTimer method's behavior");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);

        // J011_4203_0201
        //ShortTimer ngTimer = new ShortTimer();
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            test();
        }
    }


    /**
     * testing the selected menu
     */
    public void test() {
        /* create timer canvas */
        STimerCanvas sc = new STimerCanvas(this, menuList.getSelectedIndex());
        /* display timer canvas */
        Display.setCurrent(sc);
    }
}


/**
 * ShorTimer class action check canvas
 * @extends Canvas
 */
class STimerCanvas extends Canvas {

    int fH, fD;
    int sH, sW;
    ShortTimer st = null;
    int count = 0;
    Frame   previous;
    int     flag = 0;
    boolean start = false;

   /**
     * STimerCanvas class constructor
     * @param prevFrame  mainPanel
     * @param aFlag type of testing
     */
    public STimerCanvas(Frame prevFrame, int aFlag) {
        previous = prevFrame;
        flag = aFlag;
        setSoftLabel(Canvas.SOFT_KEY_1, "start");
        setSoftLabel(Canvas.SOFT_KEY_2, "back");
        fH = Font.getDefaultFont().getHeight();
        fD = Font.getDefaultFont().getDescent();
        sH = getHeight();
        sW = getWidth();

        switch( flag ) {
        case 0:         // J011_4204_0202
            /* with no break */
        case 2:         // J011_4205_0201
            /* with no break */
        case 3:         // J011_4205_0202
            /* with no break */
        case 4:         // J011_4205_0203
            /* with no break */
        case 5:         // J011_4205_0204
            /* with no break */
        case 6:         // J011_4205_0205
            /* create interval timer  */
            st = ShortTimer.getShortTimer(this, 0, 500, true);
            break;
        case 1:         // J011_4204_0203
            /* create one shot timer */
            st = ShortTimer.getShortTimer(this, 0, 500, false);
            break;
        }
    }

   /**
     * canvas drawing method
     * @param g Graphics object of canvas
     */
    public void paint(Graphics g) {
        g.lock();
        g.clearRect(0, 0, getWidth(), getHeight());
        g.unlock(true);
        drawText("timer test", 0, 0);
        drawText("timer", 0, 1);
    }

   /**
     * drawing method
     * @param text the character string which is displayed
     * @param x x coordinates of the position which is displayed
     * @param the number of lines from the position where it is drawn
     */
    public synchronized void drawText(String text, int x, int line) {
        Graphics g = getGraphics();
        Font f = Font.getDefaultFont();
        int len = text.length();
        int y = (line+1) * fH;
        int endindex = 0;
        int startindex = 0;
        g.lock();
        while (len > 0) {
        endindex = f.getLineBreak(text, startindex, len, sW-x);
        g.clearRect(x, y-fH, sW, fH);
        g.drawString(text.substring(startindex, endindex), x, y-fD);
        y += fH;
        len -= (endindex-startindex);
        startindex = endindex;
        }
        g.unlock(true);
    }

    /**
     * event receive method
     * @param aType event type
     * @param aParam Parameter of an event
     */
    public void processEvent(int type, int param) {
        /* timer event */
        if (type == Display.TIMER_EXPIRED_EVENT) {
            count++;
            drawText(String.valueOf(count), 50, 1);
        }

        /* key event */
        if (type == Display.KEY_RELEASED_EVENT) {
            switch (param) {
            /* when the start key is pushed */
            case Display.KEY_SOFT1:
                if( st == null ) {
                    break;
                }
                /* timer start */
                if( start == false ) {
                    st.start();
                }

                if( flag <= 2 ) {
                    start = true;
                    if( flag == 2 )  {      /* getResolution() */
                        int res = st.getResolution();
                        drawText("timer's resolution" + res, 0, 2);
                    }
                } else if( flag <= 4 ) {
                    if( start == false ) {
                        start = true;
                        setSoftLabel(Canvas.SOFT_KEY_1, "stop");
                    } else {
                        st.stop();
                        start=false;
                        setSoftLabel(Canvas.SOFT_KEY_1, "start");
                    }
                } else {          /* dispose() */
                    if( start == false ) {
                        start = true;
                        setSoftLabel(Canvas.SOFT_KEY_1, "rev");
                    } else {
                        st.dispose();
                        setSoftLabel(Canvas.SOFT_KEY_1, "rev2");
                    }
                }
                break;

            /* when the return key is pushed */
            case Display.KEY_SOFT2:
                /* destroy short timer */
                if( st != null ) {
                    st.dispose();
                }
                /* return to the main menu screen */
                Display.setCurrent(previous);
                break;
            }
        }
    }
}

// J011_4201_0201
/*
 * subclass of ShortTimer
 * @extends ShortTimer
 */
//class MyShortTimer extends ShortTimer {
    /**
     * constructor
     */
//  public void MyShortTimer() {
//      ShortTimer();
//  }
//}
