/**
 * J011_4206_0101
 * MainPanel
 *
 * ShortTimer class exception action checking(normal route)
 *
 * $Id: J011_4206_0101.java,v 1.2 2001/12/01 04:55:29 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * ShortTimer class exception action checking main class
 * @extends IApplication
 */
public class J011_4206_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * ShortTimer class exception action checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "0.getShortTimer",
        "1.start",
        "2.dispose"
    };
    String[] subItem1 = {
        "0.NullPointerException",
        "1.IllegalArgumentException",
        "2.UIException(NO_RESOURCES)",
        "3.UIException(BUSY_RESOURCE)"
    };
    String[] subItem2 = {
        "0.interval",
        "1.one-shot",
        "2.UIException(NO_RESOURCES)"
    };
    String[] subItem3 = {
        "0.getResolution",
        "1.start",
        "2.stop"
    };

    Label   classLabel       = new Label("ShortTimer behavior for thrown exceptions");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    ListBox menuList2        = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        menuList2.setItems(subItem1);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(menuList2);
        add(execButton);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
            /* sub menu setting */
            switch( menuList.getSelectedIndex() ) {
                case 0:
                    menuList2.setItems(subItem1);
                    break;
                case 1:
                    menuList2.setItems(subItem2);
                    break;
                case 2:
                    menuList2.setItems(subItem3);
                    break;
            }
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            test();
        }
    }


    /**
     * testing the selected menu
     */
    public void test() {
        /* create timer canvas */
        STimerCanvas sc = new STimerCanvas(this, menuList.getSelectedIndex(),
                                            menuList2.getSelectedIndex() );
        /* display timer canvas */
        Display.setCurrent(sc);
    }
}


/**
 * ShortTimer class action check canvas
 * @extends Canvas
 */
class STimerCanvas extends Canvas {

    int fH, fD;
    int sH, sW;
    ShortTimer st = null;
    int count = 0;
    Frame   previous;
    int     flag = 0;
    int     flag2 = 0;
    boolean start = false;

   /**
     * STimerCanvas class constructor
     * @param prevFrame  mainPanel
     * @param aFlag type of testing
     */
    public STimerCanvas(Frame prevFrame, int aFlag, int aFlag2) {
        previous = prevFrame;
        flag = aFlag;
        flag2 = aFlag2;
        setSoftLabel(Canvas.SOFT_KEY_1, "start");
        setSoftLabel(Canvas.SOFT_KEY_2, "back");
        fH = Font.getDefaultFont().getHeight();
        fD = Font.getDefaultFont().getDescent();
        sH = getHeight();
        sW = getWidth();
    }

   /**
     * canvas drawing method
     * @param g Graphics object of canvas
     */
    public void paint(Graphics g) {
        g.lock();
        g.clearRect(0, 0, getWidth(), getHeight());
        g.unlock(true);
        drawText("test for timer exception", 0, 0);
    }

   /**
     * drawing method
     * @param text the character string which is displayed
     * @param x x coordinates of the position which is displayed
     * @param the number of lines from the position where it is drawn
     */
    public synchronized void drawText(String text, int x, int line) {
        Graphics g = getGraphics();
        Font f = Font.getDefaultFont();
        int len = text.length();
        int y = (line+1) * fH;
        int endindex = 0;
        int startindex = 0;
        g.lock();
        while (len > 0) {
        endindex = f.getLineBreak(text, startindex, len, sW-x);
        g.clearRect(x, y-fH, sW, fH);
        g.drawString(text.substring(startindex, endindex), x, y-fD);
        y += fH;
        len -= (endindex-startindex);
        startindex = endindex;
        }
        g.unlock(true);
    }

    /**
     * event receive method
     * @param aType event type
     * @param aParam Parameter of an event
     */
    public void processEvent(int type, int param) {
        /* timer event */
        if (type == Display.TIMER_EXPIRED_EVENT) {
            count++;
            drawText(String.valueOf(count), 50, 1);
        }

        /* key event */
        if (type == Display.KEY_RELEASED_EVENT) {
            /* when the start key is pushed */
            if (param == Display.KEY_SOFT1 ) {
                /* execute testing */
                switch( flag ) {
                    case 0:
                        // J011_4206_0101
                        // J011_4206_0102
                        // J011_4206_0103
                        // J011_4206_0104
                        doTest1();
                        break;
                    case 1:
                        // J011_4206_0201
                        // J011_4206_0202
                        doTest2();
                        break;
                    case 2:
                        // J011_4206_0301
                        doTest3();
                        break;
                }
            }

            /* when the return key is pushed */
            if( param == Display.KEY_SOFT2 ) {
                /* destroy short timer */
                if( st != null ) {
                    st.dispose();
                }
                /* return to the main menu screen */
                Display.setCurrent(previous);
            }
        }
    }

    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * getShortTimer.getShortTimer()exception testing method
     */
    public void doTest1() {
        switch( flag2 ) {
            // J011_4206_0101
            case 0:
                try {
                    st = ShortTimer.getShortTimer(null, 0, 500, true);
                    showDialog("NG: no Exception");
                } catch ( NullPointerException npe ) {
                    showDialog("NullPointerException:" + npe.getMessage());
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                }
                break;
            // J011_4206_0102
            case 1:
                try {
                    st = ShortTimer.getShortTimer(this, 0, -500, true);
                    showDialog("NG: no Exception");
                } catch ( IllegalArgumentException npe ) {
                    showDialog("IllegalArgumentException:" + npe.getMessage());
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                }
                break;
            // J011_4206_0103
            case 2:
                int i;
                for( i=0; i<999; i++ ) {
                    try {
                        ShortTimer stArray = ShortTimer.getShortTimer(this, i, 500, true);
                    } catch ( UIException uie ) {
                        if( uie.getStatus() == UIException.NO_RESOURCES ) {
                            showDialog("UIException(NO_RESOURCES):" + uie.getMessage());
                        }
                        else {
                            showDialog("UIException(status=" + uie.getStatus() +
                                        "):" + uie.getMessage());
                        }
                        break;
                    } catch( Exception e ) {
                        showDialog("NG:" + e.toString());
                        break;
                    }
                }
                if( i == 999 ) {
                    showDialog("No Exception after 999 ShortTimer");
                }
                break;
            // J011_4206_0104
            case 3:
                try {
                    st = ShortTimer.getShortTimer(this, 1, 500, true);
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                    break;
                }
                try {
                    st = ShortTimer.getShortTimer(this, 1, 500, true);
                    showDialog("NG: no Exception");
                } catch ( UIException uie ) {
                    if( uie.getStatus() == UIException.BUSY_RESOURCE ) {
                        showDialog("UIException(BUSY_RESOURCE):" + uie.getMessage());
                    }
                    else {
                        showDialog("UIException(status=" + uie.getStatus() +
                                    "):" + uie.getMessage());
                    }
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                }
                break;
        }
    }

    /**
     * getShortTimer.start() exception testing method
     */
    public void doTest2() {
        boolean repeat = true;
        if( flag2 == 1 ) {
            repeat = false;
        }

        try {
            st = ShortTimer.getShortTimer(this, 0, 500, repeat);
            st.start();
        } catch( Exception e ) {
            showDialog("NG:" + e.toString());
            return;
        }

        switch( flag2 ) {
        case 0:
            /* with no break */
        case 1:
            // J011_4206_0105
            // J011_4206_0106
            try {
                st.start();
            } catch( UIException uie ) {
                if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
                    showDialog("UIException(ILLEGAL_STATE):"+uie.getMessage());
                }
                else {
                    showDialog("UIException(status=" + uie.getStatus() +
                                "):"+uie.getMessage());
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
            break;
        case 2:
            // J011_4206_0107
            int i;
            for( i=0; i<999; i++ ) {
                ShortTimer stArray;
                try {
                    stArray = ShortTimer.getShortTimer(this, i, 500, true);
                } catch ( UIException uie ) {
                    showDialog("getShortTimer:UIException(NO_RESOURCES)");
                    break;
                } catch( Exception e ) {
                    showDialog("getShortTimer:NG:" + e.toString());
                    break;
                }
                try {
                    stArray.start();
                } catch ( UIException uie ) {
                    if( uie.getStatus() == UIException.NO_RESOURCES ) {
                        showDialog("UIException(NO_RESOURCES):" + uie.getMessage());
                    }
                    else {
                        showDialog("UIException(status=" + uie.getStatus() +
                                    "):" + uie.getMessage());
                    }
                    break;
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                    break;
                }
            }
            if( i == 999 ) {
                showDialog("No Exception after 999 ShortTimer");
            }
            break;
        }
    }


    /**
     * getShortTimer.dispose() exception testing metho
     */
    public void doTest3() {
        try {
            st = ShortTimer.getShortTimer(this, 0, 500, true);
            st.start();
            st.stop();
            st.dispose();
        } catch( Exception e ) {
            showDialog("NG:" + e.toString());
            return;
        }

        try {
            switch( flag2 ) {
            case 0:
                // J011_4206_0108
                st.getResolution();
                break;
            case 1:
                // J011_4206_0109
                st.start();
                break;
            case 2:
                // J011_4206_0110
                st.stop();
                break;
            }
        } catch( UIException uie ) {
            if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
                showDialog("UIException(ILLEGAL_STATE):" + uie.getMessage());
            }
            else {
                showDialog("UIException(status=" + uie.getStatus() +
                            "):" + uie.getMessage());
            }
        } catch( Exception e ) {
            showDialog("NG:" + e.toString());
        }
    }
}
