/**
 * J011_4401_0301
 * MainPanel
 *
 * TextBox class access level checking (normal route)
 *
 * $Id: J011_4401_0301.java,v 1.1 2001/11/30 04:17:23 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * TextBox class access level checking main class
 * @extends IApplication
 */
public class J011_4401_0301 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * TextBox class access level checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.TextBox",
        "2.setEnabled",
        "3.requestFocus",
        "4.setText",
        "5.getText",
        "6.setInputMode",
        "7.setEditable",
        "8.getHeight",
        "9.getWidth",
        "10.getX",
        "11.getY",
        "12.setBackground",
        "13.setForeground",
        "14.setLocation",
        "15.setSize",
        "16.setVisible"
    };

    Label   classLabel       = new Label("check the access level of the TextBox");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");
    TextBox outBox           = new TextBox("",20,1,TextBox.DISPLAY_ANY);
    TextBox testBox          = null;

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);
        add(outBox);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
            /* clear the output box */
            outBox.setText("");
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            test();
        }
    }


    /**
     * testing the selected menu
     */
    public void test() {
        /* create textbox when it has not been created */
        if( testBox == null ) {
            try {
                testBox = new TextBox("TextBox",16,1,TextBox.DISPLAY_ANY);
                add(testBox);
            } catch(Exception e) {
                outBox.setText("createNG:" + e.toString());
                return;
            }
        }

        /* execute each testing */
        switch( menuList.getSelectedIndex() ) {
            case 0:
                // J011_4401_0301
                if( testBox != null ) {
                    outBox.setText("OK");
                } else {
                    outBox.setText("NG");
                }
                break;
            case 1:
                // J011_4401_0302
                testBox.setEnabled(true);
                outBox.setText("OK");
                break;
            case 2:
                // J011_4401_0303
                testBox.requestFocus();
                outBox.setText("OK");
                break;
            case 3:
                // J011_4401_0304
                testBox.setText("setText");
                outBox.setText("OK");
                break;
            case 4:
                // J011_4401_0305
                String txt = testBox.getText();
                outBox.setText("OK");
                break;
            case 5:
                // J011_4401_0306
                testBox.setInputMode(TextBox.ALPHA);
                outBox.setText("OK");
                break;
            case 6:
                // J011_4401_0307
                testBox.setEditable(true);
                outBox.setText("OK");
                break;
            case 7:
                // J011_4401_0308
                int h = testBox.getHeight();
                outBox.setText("OK");
                break;
            case 8:
                // J011_4401_0309
                int w = testBox.getWidth();
                outBox.setText("OK");
                break;
            case 9:
                // J011_4401_0310
                int x = testBox.getX();
                outBox.setText("OK");
                break;
            case 10:
                // J011_4401_0311
                int y = testBox.getY();
                outBox.setText("OK");
                break;
            case 11:
                // J011_4401_0312
                testBox.setBackground(Graphics.getColorOfName(Graphics.WHITE));
                outBox.setText("OK");
                break;
            case 12:
                // J011_4401_0313
                testBox.setForeground(Graphics.getColorOfName(Graphics.BLACK));
                outBox.setText("OK");
                break;
            case 13:
                // J011_4401_0314
                testBox.setLocation(0,70);
                outBox.setText("OK");
                break;
            case 14:
                // J011_4401_0315
                testBox.setSize(80,20);
                outBox.setText("OK");
                break;
            case 15:
                // J011_4401_0316
                testBox.setVisible(true);
                outBox.setText("OK");
                break;
        }
    }
}
