/**
 * J011_4601_0201
 * MainPanel
 *
 * UIException class access level checking (normal route)
 *
 * $Id: J011_4601_0201.java,v 1.1 2001/11/30 04:31:39 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * UIException class access level checking main class
 * @extends IApplication
 */
public class J011_4601_0201 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * UIException class access level checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.protected",
        "2.public"
    };
    String[][] subItems = {
        {
            "1.STATUS_FIRST",
            "2.STATUS_LAST"
        },
        {
            "1.UIException()",
            "2.UIException(status)",
            "3.UIException(status,msg)",
            "4.getStatus()"
        }
    };

    Label   classLabel       = new Label("UIException access level");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    ListBox menuList2        = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        menuList2.setItems(subItems[0]);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(menuList2);
        add(execButton);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
            /* sub menu setting */
            menuList2.setItems(subItems[menuList.getSelectedIndex()]);
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            if( menuList.getSelectedIndex() == 0 ) {
                /* protected level behavior checking */
                test1();
            } else {
                /* checking public level behavior  */
                test2();
            }
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * checking protected level behavior
     */
    public void test1() {
        int value;

        /* execute each testing */
        switch( menuList2.getSelectedIndex() ) {
            case 0:
                // J011_4601_0201
                value = MyUIException.getSTATUS_FIRST();
                showDialog("OK: value=" + value);
                break;
            case 1:
                // J011_4601_0202
                value = MyUIException.getSTATUS_LAST();
                showDialog("OK: value=" + value);
                break;
        }
    }

    /**
     * checking public level behavior 
     */
    public void test2() {
        UIException uie;

        /* execute each testing */
        switch( menuList2.getSelectedIndex() ) {
            case 0:
                // J011_4601_0301
                uie = new UIException();
                showDialog("OK");
                break;
            case 1:
                // J011_4601_0302
                uie = new UIException(UIException.ILLEGAL_STATE);
                showDialog("OK");
                break;
            case 2:
                // J011_4601_0303
                uie = new UIException(UIException.ILLEGAL_STATE,"test of UIException");
                showDialog("OK");
                break;
            case 3:
                // j011_4601_0304
                uie = new UIException();
                int v = uie.getStatus();
                showDialog("OK");
                break;
        }
    }
}

/**
 * sub class of UIException
 * @extends UIException
 */
class MyUIException extends UIException {
    /**
     * constructor
     */
    public MyUIException() {
    }

    /**
     * get STATUS_FIRST
     */
    public static int getSTATUS_FIRST() {
        return STATUS_FIRST;
    }

    /**
     * get STATUS_LAST
     */
    public static int getSTATUS_LAST() {
        return STATUS_LAST;
    }
}
