/**
 * J011_4603_0201
 * MainPanel
 *
 * UIException class constructor behavior checking (normal route)
 *
 * $Id: J011_4603_0201.java,v 1.1 2001/11/30 04:32:42 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * UIException class constructor behavior checking main class
 * @extends IApplication
 */
public class J011_4603_0201 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * UIException class constructor behavior checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.UIException()",
        "2.UIException(status)",
        "3.UIException(status,msg)"
    };

    Label   classLabel       = new Label("UIException constructor's behavior");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* check behavior of the constructor */
            test();
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * check behavior of the constructor
     */
    public void test() {
        UIException uie;
        int         status  = 10;
        String      msg     = new String("test of UIException");

        /* execute each testing */
        switch( menuList.getSelectedIndex() ) {
            case 0:
                // J011_4603_0201
                // J011_4603_0202
                uie = new UIException();
                if( uie.getStatus() == UIException.UNDEFINED ) {
                    showDialog("OK");
                } else {
                    showDialog("NG: status=" + uie.getStatus());
                }
                break;
            case 1:
                // J011_4603_0203
                // J011_4603_0204
                uie = new UIException(status);
                if( uie.getStatus() == status ) {
                    showDialog("OK");
                } else {
                    showDialog("NG: status=" + uie.getStatus());
                }
                break;
            case 2:
                // J011_4603_00205
                // J011_4603_00206
                // J011_4603_00207
                uie = new UIException(status,msg);
                if( uie.getStatus() == status ) {
                    if( msg.compareTo(uie.getMessage()) == 0 ) {
                        showDialog("OK");
                    } else {
                        showDialog("NG: msg=" + uie.getMessage());
                    }
                } else {
                    showDialog("NG: status=" + uie.getStatus());
                }
                break;
        }
    }
}
