/**
 * J011_4705_0201
 * MainPanel
 *
 * VisualPresenter class method checking (normal route)
 *
 * $Id: J011_4705_0201.java,v 1.1 2001/11/30 04:35:24 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * VisualPresenter class method checking main screen
 * @extends IApplication
 */
public class J011_4705_0201 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * VisualPresenter class method checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.setData",
        "2.getMediaResource",
        "3.setAttribute",
        "4.setMediaListener",
    };
    String[]    filename = {
        "anima.gif",
        "89aT.gif"
    };

    Label   classLabel       = new Label("VisualPresenter method's behavior");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");
    Button  exitButton       = new Button("exit");
    TextBox state            = new TextBox("",16,1,TextBox.DISPLAY_ANY);
    VisualPresenter vp       = new VisualPresenter();
    MediaImage mi            = null;

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "play");
        setSoftLabel(Frame.SOFT_KEY_2, "stop");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);
        add(exitButton);
        add(vp);
        add(state);

        /* setImage */
        // J011_4705_0201
        try {
            mi = MediaManager.getImage("resource:///" + filename[0]);
            mi.use();
            vp.setImage(mi);
        } catch( Exception e) {
            mi = null;
            showDialog("unable to continue\nsetImage NG:" + e.toString());
        }

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * play and stop by releasing the soft key
     */
    public void softKeyReleased(int anIndex) {

        /* when the softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            /* start playing */
            if( mi != null ) {
                // J011_4705_0204
                // J011_4705_0205
                vp.play();
            }
        }

        /* when softkey2 is released */
        if (anIndex == Frame.SOFT_KEY_2) {
            /* stop playing */
            if( mi != null ) {
                // J011_4705_0206
                // J011_4705_0207
                vp.stop();
            }
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
        }

        /* when the terminate button is pushed */
        if (aComponent == exitButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* terminate the application */
            IApplication.getCurrentApp().terminate();
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* execute the selected testing */
            test();
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * execute the selected testing
     */
    public void test() {
        /* execute each testing */
        switch( menuList.getSelectedIndex() ) {
            case 0:
                // J011_4705_0202
                MediaData md;
                VisualPresenter vp2;
                try {
                    md = MediaManager.getData("resource:///" + filename[1]);
					// 2003/04/02 ->
					if ( md == null ) {
						showDialog("OK:Minimum spec is null");
						break;
					}
					// 2003/04/02 <-
                    md.use();
                    vp2 = new VisualPresenter();
                    add(vp2);
                    TextBox t2 = new TextBox("",16,1,TextBox.DISPLAY_ANY);
                    t2.setSize(getWidth(),3);
                    add(t2);
                } catch( Exception e ) {
                    showDialog("NG1:" + e.toString());
                    return;
                }
                try {
                    vp.setData(md);
                } catch( Exception e2 ) {
                    showDialog("NG2:" + e2.toString());
                    return;
                }
                showDialog("OK");
                break;
            case 1:
                // J011_4705_0203
                MediaResource mr = vp.getMediaResource();
                if( mr != null ) {
                    showDialog("OK");
                } else {
                    showDialog("NG");
                }
                break;
            case 2:
                // J011_4705_0208
                try {
                    vp.setAttribute(VisualPresenter.IMAGE_YPOS,30);
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                    return;
                }
                break;
            case 3:
                // J011_4705_0209
                vp.setMediaListener(new MediaListener() {
                    public void mediaAction(MediaPresenter mp, int t, int p) {
                        switch (t) {
                            case VisualPresenter.VISUAL_COMPLETE:
                                state.setText("replay completed");
                                break;
                            case VisualPresenter.VISUAL_PLAYING:
                                state.setText("now replaying");
                                break;
                            case VisualPresenter.VISUAL_STOPPED:
                                state.setText("stop replaying");
                                break;
                        }
                    }
                });
                break;
        }
    }
}
