/**
 * J011_4706_0101
 * MainPanel
 *
 * VisualPresenter class prescribed exception checking (normal route)
 *
 * $Id: J011_4706_0101.java,v 1.1 2001/11/30 04:36:41 lan Exp $
 */

import com.nttdocomo.lang.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * VisualPresenter class prescribed exception checking main class
 * @extends IApplication
 */
public class J011_4706_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * VisualPresenter class prescribed exception checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.setImage",
        "2.setData",
        "3.play",
        "4.stop",
        "5.setAttribute",
        "6.setSize"
    };
    String[][] subItems = {
        {
            "1.now replaying",
            "2.null",
            "3.out of system's offering",
            "4.image of inability to replay",
            "5.unused"
        },
        {
            "1.the terminal is not supported yet",
            "2.now replaying",
            "3.null",
            "4.out of system's offering"
        },
        {
            "1.not set",
            "2.after unusing",
            "3.after disposing",
            "4.unuse while replaying",
            "5.dispose while replaying",
            "6.native failed",
        },
        {
            "1.not set",
            "2.after unusing",
            "3.after disposing"
        },
        {
            "1.incorrect value"
        },
        {
            "1.width<0",
            "2.height<0",
            "3.both<0"
        }
    };

    String[]    filename = {
        "anima.gif",
        "Bell.mld",
        "error.gif"
    };

    Label   classLabel       = new Label("VisualPresenter behavior for thrown exceptions");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    ListBox menuList2        = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");
    Button  exitButton       = new Button("exit");
    VisualPresenter vp       = new VisualPresenter();
    VisualPresenter vp2      = new VisualPresenter();
    MediaImage mi            = null;

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        menuList2.setItems(subItems[0]);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "play");
        setSoftLabel(Frame.SOFT_KEY_2, "stop");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(menuList2);
        add(execButton);
        add(exitButton);
        add(vp);
        add(vp2);

        /* setImage */
        try {
            mi = MediaManager.getImage("resource:///" + filename[0]);
            mi.use();
            vp.setImage(mi);
        } catch( Exception e) {
            mi = null;
            showDialog("unable to continue\nsetImage NG:" + e.toString());
        }

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * play and stop by releasing the soft key
     */
    public void softKeyReleased(int anIndex) {

        /* when the softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            /* play */
            if( mi != null ) {
                try {
                    vp.play();
                } catch( UIException uie ) {
                    if( uie.getStatus() == uie.ILLEGAL_STATE ) {
                        showDialog("UIException(ILLEGAL_STATE):" +
                                    uie.getMessage());
                    } else {
                        showDialog("UIException(status=" + uie.getStatus() + "):" +
                                    uie.getMessage());
                    }
                } catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
            }
        }

        /* when softkey2 is released */
        if (anIndex == Frame.SOFT_KEY_2) {
            /* stop */
            if( mi != null ) {
                try {
                    vp.stop();
                } catch( UIException uie ) {
                    if( uie.getStatus() == uie.ILLEGAL_STATE ) {
                        showDialog("UIException(ILLEGAL_STATE):" +
                                    uie.getMessage());
                    } else {
                        showDialog("UIException(status=" + uie.getStatus() + "):" +
                                    uie.getMessage());
                    }
                } catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
            }
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
            /* sub menu setting */
            menuList2.setItems(subItems[menuList.getSelectedIndex()]);
        }

        /* when the terminate button is pushed */
        if (aComponent == exitButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* terminate the application */
            IApplication.getCurrentApp().terminate();
        }

        /* when  the execution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* execute the selected testing */
            test();
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * execute the selected testing
     */
    public void test() {
        int idx1 = menuList.getSelectedIndex();
        int idx2 = menuList2.getSelectedIndex();

        /* execute each testing */
        switch( idx1 ) {
        /* setImage */
        case 0:
            switch( idx2 ) {
            case 0:
                // J011_4706_0101
                try {
                    vp.play();
                } catch ( Exception e ) {
                    showDialog("NG1:" + e.toString());
                    return;
                }
                try {
                    vp.setImage(mi);
                    showDialog("NG2:no Exception");
                } catch( UIException uie ) {
                    if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
                        showDialog("UIException(ILLEGAL_STATE):"+uie.getMessage());
                    } else {
                        showDialog("UIException(status=" + uie.getStatus()
                                    + "):" + uie.getMessage());
                    }
                } catch( Exception e2 ) {
                    showDialog("NG3:" + e2.toString());
                }
                break;
            case 1:
                // J011_4706_0102
                try {
                    vp2.setImage(null);
                    showDialog("NG5:no Exception");
                } catch( NullPointerException npe ) {
                    showDialog("NullPointerException:"+npe.getMessage());
                } catch( Exception e ) {
                    showDialog("NG6:" + e.toString());
                }
                break;
            case 2:
                /* with no break */
            case 3:
                // J011_4706_0103
                // J011_4706_0104
                MediaImage ngImage;
                String f;
                if( idx2 == 2 ) {
                    f = filename[1];
                } else {
                    f = filename[2];
                }
                try {
                    ngImage = MediaManager.getImage("resource:///" + f);
                    ngImage.use();
                } catch( UIException uie ) {
                    showDialog("Image.use:UIException:" + uie.getMessage());
                    return;
                } catch( Exception e ) {
                    showDialog("NG7:" + e.toString());
                    return;
                }
                try {
                    vp2.setImage(ngImage);
                    showDialog("NG8:no Exception");
                } catch( UIException uie ) {
                    if( uie.getStatus() == UIException.UNSUPPORTED_FORMAT ) {
                        showDialog("UIException(UNSUPPORTED_FORMAT):"+
                                    uie.getMessage());
                    } else {
                        showDialog("UIException(status=" +uie.getStatus() + "):"+
                                    uie.getMessage());
                    }
                } catch( Exception e2 ) {
                    showDialog("NG10:" + e2.toString());
                }
                break;
            case 4:
                // J011_4706_0105
                try {
                    mi.unuse();
                    mi.dispose();
                } catch (Exception e) {
                    showDialog("NG04:" + e.toString());
                    break;
                }
                try {
                    mi = MediaManager.getImage("resource:///" + filename[0]);
                } catch( Exception e ) {
                    showDialog("NG05:" + e.toString());
                    break;
                }
                try {
                    vp.setImage(mi);
                } catch( UIException uie ) {
                    if( uie.getStatus() == uie.ILLEGAL_STATE ) {
                        showDialog("UIException(ILLEGAL_STATE):"+uie.getMessage());
                    } else {
                        showDialog("UIException(status=" + uie.getStatus() +
                                    "):"+uie.getMessage());
                    }
                } catch( Exception e ) {
                    showDialog("NG06:" + e.toString());
                }
            }
            break;

        /* setData() */
        case 1:
            MediaData   md;
            switch( idx2 ) {
            case 0:
                // J011_4706_0106
                try {
                    md = MediaManager.getData("resource:///"+filename[0]);
                    md.use();
                } catch( Exception e ) {
                    showDialog("NG11:" + e.toString());
                    return;
                }
                try {
                    vp2.setData(md);
                    showDialog("NG12:no Exception");
                } catch( UnsupportedOperationException uoe ) {
                    showDialog("UnsupportedOperationException:"+uoe.getMessage());
                } catch( Exception e1 ) {
                    showDialog("NG13:" + e1.toString());
                }
                break;
            case 1:
                // J011_4706_0107
                try {
                    vp.play();
                } catch ( Exception e ) {
                    showDialog("NG14:" + e.toString());
                    return;
                }
                try {
                    md = MediaManager.getData("resource:///"+filename[0]);
                    md.use();
                } catch( Exception e1 ) {
                    showDialog("NG15:" + e1.toString());
                    return;
                }
                try {
                    vp.setData(md);
                    showDialog("NG16:no Exception");
                } catch( UIException uie ) {
                    if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
                        showDialog("UIException(ILLEGAL_STATE):"+uie.getMessage());
                    } else {
                        showDialog("UIException(status=" + uie.getStatus()+
                                    "):" + uie.getMessage());
                    }
                } catch( Exception e2 ) {
                    showDialog("NG18:" + e2.toString());
                }
                break;
            case 2:
                // J011_4706_0108
                try {
					// 2003/04/03 ->
					md = MediaManager.getData("resource:///"+filename[0]);
                    //vp2.setData(null);
					vp2.setData(md);
					// 2003/04/03 <-
                    showDialog("NG19:no Exception");
                } catch( NullPointerException npe ) {
                    showDialog("NullPointerException:"+npe.getMessage());
                } catch( Exception e1 ) {
                    showDialog("NG20:" + e1.toString());
                }
                break;
            case 3:
                // J011_4706_0109
                try {
                    md = MediaManager.getData("resource:///"+filename[2]);
                    md.use();
                } catch( Exception e ) {
                    showDialog("NG21:" + e.toString());
                    return;
                }
                try {
                    vp2.setData(md);
                    showDialog("NG22:no Exception");
                } catch( UIException uie ) {
                    if( uie.getStatus() == UIException.UNSUPPORTED_FORMAT ) {
                        showDialog("UIException(UNSUPPORTED_FORMAT):"+
                                    uie.getMessage());
                    } else {
                        showDialog("UIException(status=" + uie.getStatus() +"):"+
                                    uie.getMessage());
                    }
                } catch( Exception e1 ) {
                    showDialog("NG24:" + e1.toString());
                }
                break;
            }
            break;

        /* play() */
        case 2:
            switch( idx2 ) {
            case 0:
                // J011_4706_0110
                try {
                    vp2.play();
                    showDialog("NG25:no Exception");
                } catch( UIException uie ) {
                    if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
                        showDialog("UIException(ILLEGAL_STATE):"+
                                    uie.getMessage());
                    } else {
                        showDialog("UIException(status=" + uie.getStatus() + "):"+
                                    uie.getMessage());
                    }
                } catch( Exception e2 ) {
                    showDialog("NG27:" + e2.toString());
                }
                break;
            case 1:
                // J011_4706_0111
                /* with no break */
				// 2003/04/02 ->
				try {
					mi.unuse();
					vp.play();
				} catch( UIException uie ) {
					if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
						showDialog("UIException(ILLEGAL_STATE):" + uie.getMessage());
					} else {
						showDialog("UIException(status=" + uie.getStatus() + "):" + 
									uie.getMessage());
					}
				} catch( Exception e2 ) {
					showDialog("NG:" + e2.toString());
				}
				break;
				// 2003/04/02 <-
            case 2:
                // J011_4706_0112
				/* 2003/04/02 ->
                try {
                    mi.unuse();
                    if( idx2 == 2 ) {
                        mi.dispose();
                    }
                } catch( Exception e ) {
                    showDialog("NG32:" + e.toString());
                    return;
                }
                try {
                    vp.play();
                    showDialog("NG33:no Exception");
                } catch( UIException uie ) {
                    if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
                        showDialog("UIException(ILLEGAL_STATE):"+
                                    uie.getMessage());
                    } else {
                        showDialog("UIException(status=" + uie.getStatus() + "):"+
                                    uie.getMessage());
                    }
                } catch( Exception e2 ) {
                    showDialog("NG35:" + e2.toString());
                }
                break;
				*/
				try {
					mi.dispose();
					vp.play();
				} catch( UIException uie ) {
					if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
						showDialog("UIException(ILLEGAL_STATE):" + uie.getMessage());
					} else {
						showDialog("UIException(status=" + uie.getStatus() + "):" + 
									uie.getMessage());
					}
				} catch( Exception e2 ) {
					showDialog("NG:" + e2.toString());
				}
				break;
				// 2003/04/02 <-
            case 3:
                // J011_4706_0113
                /* execute this while playing */
                try {
                    mi.unuse();
				// 2003/04/02 ->
				} catch( UIException uie ) {
					if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
						showDialog("UIException(ILLEGAL_STATE):" + uie.getMessage());
					} else {
						showDialog("UIException(status=" + uie.getStatus() + "):" + 
									uie.getMessage());
					}
				} catch( Exception e2 ) {
					showDialog("NG:" + e2.toString());
				}
                //} catch( Exception e) {}
				// 2003/04/02 <-
                break;
            case 4:
                // J011_4706_0114
                /* execute this while playing */
                try {
                    mi.dispose();
				// 2003/04/02 ->
				} catch( UIException uie ) {
					if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
						showDialog("UIException(ILLEGAL_STATE):" + uie.getMessage());
					} else {
						showDialog("UIException(status=" + uie.getStatus() + "):" + 
									uie.getMessage());
					}
				} catch( Exception e2 ) {
					showDialog("NG:" + e2.toString());
				}
                //} catch( Exception e) {}
				// 2003/04/02 <-
                break;
            case 5:
                // J011_4706_0115
                /* can not execute */
                showDialog("can not execute");
                break;
            }
            break;

        /* stop() */
        case 3:
            switch( idx2 ) {
            case 0:
                // J011_4706_0116
                try {
                    vp2.stop();
                    showDialog("NG36:no Exception");
                } catch( UIException uie ) {
                    if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
                        showDialog("UIException(ILLEGAL_STATE):"+
                                    uie.getMessage());
                    } else {
                        showDialog("UIException(status=" + uie.getStatus() + "):"+
                                    uie.getMessage());
                    }
                } catch( Exception e2 ) {
                    showDialog("NG38:" + e2.toString());
                }
                break;
            case 1:
                // J011_4706_0117
                /* with no break */
				// 2003/04/04 ->
				try {
					mi.unuse();
					vp.stop();
					showDialog("NG:no Exception");
				} catch( UIException uie ) {
					if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
						showDialog("UIException(ILLEGAL_STATE):" + uie.getMessage());
					} else {
						showDialog("UIException(status=" + uie.getStatus() + "):" + 
									uie.getMessage());
					}
				} catch( Exception e2 ) {
					showDialog("NG:" + e2.toString());
				}
				break;
				// 2003/04/04 <-
            case 2:
                // J011_4706_0118
                /* execute this while playing */
                try {
					// 2003/04/04 ->
                    //if( idx2 == 1 ) {
                        //mi.unuse();
                    //} else {
                        mi.dispose();
                    //}
                } catch( Exception e ) {
                    showDialog("NG39:" + e.toString());
                    return;
                }
                try {
                    vp.stop();
                    showDialog("NG40:no Exception");
                } catch( UIException uie ) {
                    if( uie.getStatus() == UIException.ILLEGAL_STATE ) {
                        showDialog("UIException(ILLEGAL_STATE):"+
                                    uie.getMessage());
                    } else {
                        showDialog("UIException(status=" + uie.getStatus() + "):"+
                                    uie.getMessage());
                    }
                } catch( Exception e2 ) {
                    showDialog("NG42:" + e2.toString());
                }
                break;
            }
            break;

        /* setAttribute() */
        case 4:
            // J011_4706_0119
            try {
                vp.setAttribute(VisualPresenter.IMAGE_XPOS,-9999);
                showDialog("NG43:no Exception");
            } catch( IllegalArgumentException iae ) {
                showDialog("IllegalArgumentException:"+iae.getMessage());
            } catch( Exception e ) {
                showDialog("NG44:" + e.toString());
            }
            break;

        /* setSize() */
        case 5:
            // J011_4706_0120
            // J011_4706_0121
            // J011_4706_0122
            int w=60;
            int h=60;
            if( idx2 == 0 ) {
                w = -1;
            } else if( idx2 == 1 ) {
                h = -1;
            } else {
                w = -1;
                h = -1;
            }
            try {
                vp.setSize(w,h);
                showDialog("NG45:no Exception");
            } catch( IllegalArgumentException iae ) {
                showDialog("IllegalArgumentException:"+iae.getMessage());
            } catch( Exception e ) {
                showDialog("NG47:" + e.toString());
            }
            break;
        }
    }
}
