/**
 * J011_4707_0101
 * MainPanel
 *
 * VisualPresenter class inheriting method behavior checking (normal route)
 *
 * $Id: J011_4707_0101.java,v 1.1 2001/11/30 04:38:18 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * VisualPresenter class inheriting method behavior checking main class
 * @extends IApplication
 */
public class J011_4707_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * VisualPresenter class inheriting method behavior checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.setLocation",
        "2.setSize",
        "3.setBackground",
        "4.setForeground",
        "5.setVisible",
        "6.getX",
        "7.getY",
        "8.getWidth",
        "9.getHeight"
    };
    String[][] subItems = {
        {
            "1.Layout=null, before addition",
            "2.Layout=null, after addition",
            "3.Layout!=null, before addition",
            "4.Layout!=null, after addition"
        },
        {
            "1.before addition",
            "2.after addition",
            "3.width<0",
            "4.height<0",
            "5.both<0"
        },
        {
            "1.before addition",
            "2.after addition",
            "3.illegal arguments"
        },
        {
            "1.before addition",
            "2.after addition",
            "3.illegal arguments"
        },
        {
            "1.before addition,b=true",
            "2.before addition,b=false"
        },
        {
            "1.x-coordinate"
        },
        {
            "1.y-coordinate"
        },
        {
            "1.width"
        },
        {
            "1.height"
        }
    };
    String[]    filename = {
        "89aT.gif"
    };

    Label   classLabel       = new Label("VisualPresenter succeeding method's behavior");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    ListBox menuList2        = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");
    Button  exitButton       = new Button("exit");
    VisualPresenter vp       = new VisualPresenter();
    MediaImage mi            = null;

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        menuList2.setItems(subItems[0]);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "display");
        setSoftLabel(Frame.SOFT_KEY_2, "nondisplay");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(menuList2);
        add(execButton);
        add(exitButton);
        add(vp);

        /* setImage */
        try {
            mi = MediaManager.getImage("resource:///" + filename[0]);
            mi.use();
            vp.setImage(mi);
        } catch( Exception e) {
            mi = null;
            showDialog("unable to continue\nsetImage NG:" + e.toString());
        }

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* display the component when the softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            // J011_4707_0203
            // J011_4707_0206
            vp.setVisible(true);
        }

        /* set the component invisible when the softkey2 is released  */
        if (anIndex == Frame.SOFT_KEY_2) {
            // J011_4707_0204
            // J011_4707_0205
            vp.setVisible(false);
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
            /* sub menu setting */
            menuList2.setItems(subItems[menuList.getSelectedIndex()]);
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* execute testing */
            test();
        }

        /* when the terminate button is pushed */
        if (aComponent == exitButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* terminate the application */
            IApplication.getCurrentApp().terminate();
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * testing the selected menu
     */
    public void test() {
        VisualPresenter t   = new VisualPresenter();
        int     idx1= menuList.getSelectedIndex();
        int     idx2= menuList2.getSelectedIndex();

        /* execute each testing */
        switch( idx1 ) {
            case 0:         /* setLocation() */
                switch( idx2 ) {
                    case 0:
                        // J011_4707_0101
                        setLayoutManager(null);
                        t.setLocation(0,0);
                        add(t);
                        t.setImage(mi);
                        break;
                    case 1:
                        // J011_4707_0102
                        setLayoutManager(null);
                        add(t);
                        t.setImage(mi);
                        t.setLocation(0,0);
                        break;
                    case 2:
                        // J011_4707_0103
                        t.setLocation(0,0);
                        add(t);
                        t.setImage(mi);
                        break;
                    case 3:
                        // J011_4707_0104
                        add(t);
                        t.setImage(mi);
                        t.setLocation(0,0);
                        break;
                }
                break;
            case 1:         /* setSize() */
                switch( idx2 ) {
                    case 0:
                        // J011_4707_0105
                        t.setSize(getWidth(),50);
                        add(t);
                        t.setImage(mi);
                        break;
                    case 1:
                        // J011_4707_0106
                        vp.setSize(getWidth(),50);
                        break;
                    case 2:
                        /* with no break */
                    case 3:
                        /* with no break */
                    case 4:
                        // J011_4707_0107
                        // J011_4707_0108
                        // J011_4707_0109
                        int w = -1;
                        int h = -1;
                        if( idx2 == 2 ) {
                            h = 30;
                        } else if( idx2 == 3 ) {
                            w = 60;
                        }
                        try {
                            vp.setSize(w,h);
                            showDialog("NG: no Exception");
                        } catch( IllegalArgumentException iae ) {
                            showDialog("OK:IllegalArgumentException");
                        } catch( Exception e ) {
                            showDialog("NG:" + e.toString());
                        }
                        break;
                }
                break;
            case 2:         /* setBackground() */
                switch( idx2 ) {
                    case 0:
                        // J011_4707_0110
                        t.setBackground(Graphics.getColorOfName(Graphics.BLUE));
                        add(t);
                        t.setImage(mi);
                        break;
                    case 1:
                        // J011_4707_0111
                        vp.setBackground(Graphics.getColorOfName(Graphics.BLUE));
                        break;
                    case 2:
                        // J011_4707_0112
                        try {
                            vp.setBackground(-1);
                            showDialog("NG: no Exception");
                        } catch( IllegalArgumentException iae ) {
                            showDialog("OK:IllegalArgumentException");
                        } catch( Exception e ) {
                            showDialog("NG:" + e.toString());
                        }
                        break;
                }
                break;
            case 3:         /* setForeground() */
                switch( idx2 ) {
                    case 0:
                        // J011_4707_0113
                        t.setForeground(Graphics.getColorOfName(Graphics.RED));
                        add(t);
                        t.setImage(mi);
                        break;
                    case 1:
                        // J011_4707_0114
                        vp.setForeground(Graphics.getColorOfName(Graphics.RED));
                        break;
                    case 2:
                        // J011_4707_0115
                        try {
                            vp.setForeground(-1);
                            showDialog("NG: no Exception");
                        } catch( IllegalArgumentException iae ) {
                            showDialog("OK:IllegalArgumentException");
                        } catch( Exception e ) {
                            showDialog("NG:" + e.toString());
                        }
                        break;
                }
                break;
            case 4:         /* setVisible() */
                switch( idx2 ) {
                    case 0:
                        // J011_4707_0201
                        VisualPresenter t1 = new VisualPresenter();
                        t1.setVisible(true);
                        add(t1);
                        t1.setImage(mi);
                        break;
                    case 1:
                        // J011_4707_0202
                        VisualPresenter t2 = new VisualPresenter();
                        t2.setVisible(false);
                        add(t2);
                        t2.setImage(mi);
                        break;
                }
                break;
            case 5:         /* getX() */
                // J011_4707_0207
                showDialog("getX():" + vp.getX());
                break;
            case 6:         /* getY() */
                // J011_4707_0208
                showDialog("getY():" + vp.getY());
                break;
            case 7:
                // J011_4707_0209
                showDialog("getWidth():" + vp.getWidth());
                break;
            case 8:
                // J011_4707_0210
                showDialog("getHeight():" + vp.getHeight());
                break;
        }
    }
}
