/**
 * J011_5005_0101
 * MainPanel
 *
 * TimeKeeper class behavior checking (normal route)
 *
 * $Id: J011_5005_0101.java,v 1.1 2001/12/02 04:35:23 hoshi Exp $
 */
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * TimeKeeper class behavior checking main class
 * @extends IApplication
 */
public class J011_5005_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * TimeKeeper class behavior checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements TimerListener
 */
class MainPanel
    extends Panel implements SoftKeyListener, ComponentListener, TimerListener {

    private final static int TIMER_INTERVAL = 1000;

    String[] menuListItem = {
        "0 get the resolution",
        "1 start the timer",
        "2 stop the timer",
        "3 dispose the timer"
    };

    Label   classLabel = new Label("TimeKeeper");
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");
    TextBox resultText = new TextBox("", 20, 1, TextBox.DISPLAY_ANY);
    TextBox statusText = new TextBox("Timer:0", 20, 1, TextBox.DISPLAY_ANY);

    Timer time = new Timer();
    TimeKeeper timeKeeper;

    int timerCounter = 0;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    void showMainPanel() {

        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);
        add(resultText);
        add(statusText);

        /* timer setting */
        time.setTime(TIMER_INTERVAL);
        time.setRepeat(true);
        time.setListener(this);
        timeKeeper = time;

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of softkey pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * @param anIndex the value of softkey released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            try {
                switch (menuList.getSelectedIndex()) {

                /* get the timer resolution */
                case 0:
                    // J011_5005_0101
                    resultText.setText("timer's resolution:" +
                        timeKeeper.getResolution());
                    break;

                /* timer start */
                case 1:
                    // J011_5005_0201
                    timeKeeper.start();
                    resultText.setText("start the timer");
                    break;

                /* timer stop */
                case 2:
                    // J011_5005_0301
                    timeKeeper.stop();
                    resultText.setText("stop the timer");
                    break;

                /* dispose the timer */
                case 3:
                    // J011_5005_0401
                    timeKeeper.stop();
                    timeKeeper.dispose();
                    resultText.setText("dispose the timer");
                    statusText.setText("");
                    break;
                default:
                    break;
                }
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                errorDialog.setText(e.toString());
                errorDialog.show();
            }
        }
    }

    /**
     * get the event on the timer
     * @param aTimer timer object
     */
    public void timerExpired(Timer aTimer) {
        statusText.setText("Timer:" + timerCounter++);
    }
}
