/**
 * J011_5103_0201
 * MainPanel
 * ListenerThread
 * MethodConfirm2
 *
 * Timer class behavior checking (normal route)
 *
 * $Id: J011_5103_0201.java,v 1.1 2001/12/02 04:34:47 hoshi Exp $
 */
import java.lang.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Timer class behavior checking main class
 * @extends IApplication
 */
public class J011_5103_0201 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * Timer class behavior checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    static final int TIMER_INTERVAL = 1000;

    String[] menuListItem = {
        "0 check the constructor",
        "1 check the method",
        "2 check the exception"
    };

    String[] defaultListItem = {
        "          "
    };

    String[] methodListItem = {
        "0 dispose",
        "1 getResoluti",
        "2 setListen 1",
        "3 setListen 2",
        "4 setTime",
        "5 start/stop",
        "6 setRepeat 1",
        "7 setRepeat 2"
    };

    String[] exceptionListItem = {
        " 0 start 1",
        " 1 start 2",
        " 2 start 3",
        " 3 setRepea 1",
        " 4 setRepea 2",
        " 5 setTime 1",
        " 6 setTime 2",
        " 7 setTime 3",
        " 8 getResolut",
        " 9 setListene",
        "10 stop"
    };

    Frame   subFrame;
    Label   classLabel  = new Label("Timer");
    ListBox menuList    = new ListBox(ListBox.CHOICE);
    ListBox subList     = new ListBox(ListBox.CHOICE);
    Button  execButton  = new Button("execute");
    TextBox resultText  = new TextBox("", 20, 1, TextBox.DISPLAY_ANY);
    Timer   timer;

    int timerCounter = 0;
    int currentMethod;
    boolean bStarted = false;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    void showMainPanel() {

        /* setting of the display item */
        menuList.setItems(menuListItem);
        subList.setEnabled(false);
        subList.setItems(defaultListItem);
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(subList);
        add(execButton);
        add(resultText);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of softkey pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * @param anIndex the value of softkey released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the selection of menu list is changed */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {

            /* clearing the result textbox */
            resultText.setText("");

            /* change the content of the sublist */
            setSubListItem(menuList.getSelectedIndex());
        }

        /* when the selection of sub list is changed */
        if (aComponent == subList
            && aType == ComponentListener.SELECTION_CHANGED) {

            /* clearing the result textbox */
            resultText.setText("");
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            timerCounter = 0;

            if (bStarted) {
                timer.dispose();
                bStarted = false;
            }

            switch (menuList.getSelectedIndex()) {

            /* constructor action check screen */
            case 0:
                ConstractorConfirm();
                break;

            /* method action checking screen */
            case 1:
                MethodConfirm(subList.getSelectedIndex());
                break;

            /* exception behavior checking screen */
            case 2:
                ExceptionConfirm(subList.getSelectedIndex());
                break;
            default:
                break;
            }
        }
    }

    /**
     * set the sublist item
     * @param aSelectedMenuIndex the selected value of menu list
     */
    void setSubListItem(int aSelectedMenuIndex) {

        /* change the sublist display by the selected menu item */
        switch (menuList.getSelectedIndex()) {

        /* when method behavior checking is selected */
        case 1:
            subList.setEnabled(true);
            subList.setItems(methodListItem);
            break;

        /* when exception behavior checking is selected */
        case 2:
            subList.setEnabled(true);
            subList.setItems(exceptionListItem);
            break;

        /* other */
        default:
            subList.setEnabled(false);
            subList.setItems(defaultListItem);
            break;
        }
    }

    /**
     * checking the behavior of the constructor
     */
    void ConstractorConfirm() {

        try {
            // J011_5103_0201
            timer = new Timer();
            resultText.setText("create a timer :OK");
            timer.dispose();
        } catch (Exception e) {
            Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
            errorDialog.setText(e.toString());
            errorDialog.show();
        }
    }

    /**
     * checking the behavior of the method
     * @param aSelectedSubIndex the selected value of the sublist
     */
    void MethodConfirm(int aSelectedSubIndex) {

        try {
            switch (aSelectedSubIndex) {
            case 0:
                // J011_5105_0101
                timer = new Timer();
                timer.dispose();
                resultText.setText("dispose the timer :OK");
                break;
            case 1:
                // J011_5105_0102
                timer = new Timer();
                resultText.setText("timer's resolution:" + timer.getResolution());
                timer.dispose();
                break;
            case 2:
                // J011_5105_0103
                timer = new Timer();
                timer.setTime(TIMER_INTERVAL);
                timer.setRepeat(true);
                timer.setListener(
                    new TimerListener() {
                        public void timerExpired(Timer t) {
                            if (t == timer) {
                                resultText.setText("Timer :" + timerCounter++);
                            }
                        }
                    }
                );
                timer.start();
                bStarted = true;
                break;
            case 3:
                // J011_5105_0104
                timer = new Timer();
                timer.setTime(TIMER_INTERVAL);
                timer.setRepeat(true);
                timer.setListener(
                    new TimerListener() {
                        public void timerExpired(Timer t) {
                            if (t == timer) {
                                resultText.setText("Timer :" + timerCounter++);
                            }
                        }
                    }
                );
                timer.start();

                ListenerThread lt = new ListenerThread(this.timer);
                lt.start();

                break;
            case 4:
                // J011_5105_0105
                timer = new Timer();
                timer.setTime(TIMER_INTERVAL / 2);
                timer.setRepeat(true);
                timer.setListener(
                    new TimerListener() {
                        public void timerExpired(Timer t) {
                            if (t == timer) {
                                resultText.setText("Timer :" + timerCounter++);
                            }
                        }
                    }
                );

                timer.start();
                bStarted = true;
                break;
            case 5:
            case 6:
            case 7:
                /* display the subpanel */
                subFrame = new MethodConfirm2(this, subList.getSelectedIndex());
                Display.setCurrent(subFrame);
                break;
            default:
                break;
            }

            /* keep the present method number */
            currentMethod = aSelectedSubIndex;

        } catch (UIException uie) {
            Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
            errorDialog.setText("UIE code:" + uie.getStatus());
            errorDialog.show();
        } catch (Exception e) {
            Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
            String str = e.toString();
            errorDialog.setText(str.substring(str.lastIndexOf('.')));
            errorDialog.show();
        }
    }

    /**
     * checking exception behavior
     * @param aSelectedSubIndex the selected value of the sublist
     */
    void ExceptionConfirm(int aSelectedSubIndex) {

        switch (aSelectedSubIndex) {
        case 0:
            // J011_5106_0201
            try {
                timer = new Timer();
                timer.setRepeat(true);
                timer.setTime(TIMER_INTERVAL);
                timer.start();
                timer.start();
            } catch (UIException uie) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = "UIException:" + uie.getMessage();
                if (uie.getStatus() == UIException.ILLEGAL_STATE) {
                    str += "(OK)";
                }
                else {
                    str += "(NG)";
                }
                errorDialog.setText(str);
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
        case 1:
            // J011_5106_0202
            try {
                timer = new Timer();
                timer.setRepeat(false);
                timer.setTime(TIMER_INTERVAL);
                timer.start();
                timer.start();
            } catch (UIException uie) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = "UIException:" + uie.getMessage();
                if (uie.getStatus() == UIException.ILLEGAL_STATE) {
                    str += "(OK)";
                }
                else {
                    str += "(NG)";
                }
                errorDialog.setText(str);
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
/*
   Though this test is for the resource insufficiency testing, 
   this is omitted because of the repeated resource insufficiency and of the unreliable behavior
        case 2:
            // J011_5106_0203
            for (int i = 0; i < TIMER_INTERVAL; i++) {
                try {
                    timer = new Timer();
                } catch(Exception e) {
                    Dialog errorDialog =
                        new Dialog(Dialog.DIALOG_ERROR, "exception occurs
                    errorDialog.setText("NG1:" + e.toString());
                    errorDialog.show();
                    return;
                }
                try {
                    timer.start();
                } catch(UIException uie) {
                    Dialog errorDialog =
                        new Dialog( Dialog.DIALOG_ERROR, "exception occurs");
                    String str = "UIException:" + uie.getMessage();
                    if (uie.getStatus() == UIException.NO_RESOURCES) {
                        str += "(OK)";
                    }
                    else {
                        str += "(NG)";
                    }
                    errorDialog.setText(str);
                    errorDialog.show();
                    return;
                } catch (Exception e) {
                    Dialog errorDialog =
                        new Dialog( Dialog.DIALOG_ERROR, "exception occurs");
                    errorDialog.setText("NG2:" + e.toString());
                    errorDialog.show();
                    return;
                }
                resultText.setText("timer:" + i);
            }
            break;
*/
        case 2:
            // J011_5106_0203
            try {
                timer = new Timer();
                timer.dispose();
                timer.start();
            } catch (UIException uie) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = "UIException:" + uie.getMessage();
                if (uie.getStatus() == UIException.ILLEGAL_STATE) {
                    str += "(OK)";
                }
                else {
                    str += "(NG)";
                }
                errorDialog.setText(str);
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
        case 3:
            // J011_5106_0204
            try {
                timer = new Timer();
                timer.start();
                timer.setRepeat(true);
            } catch (UIException uie) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = "UIException:" + uie.getMessage();
                if (uie.getStatus() == UIException.ILLEGAL_STATE) {
                    str += "(OK)";
                }
                else {
                    str += "(NG)";
                }
                errorDialog.setText(str);
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
        case 4:
            // J011_5106_0205
            try {
                timer = new Timer();
                timer.dispose();
                timer.setRepeat(true);
            } catch (UIException uie) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = "UIException:" + uie.getMessage();
                if (uie.getStatus() == UIException.ILLEGAL_STATE) {
                    str += "(OK)";
                }
                else {
                    str += "(NG)";
                }
                errorDialog.setText(str);
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
        case 5:
            // J011_5106_0206
            try {
                timer = new Timer();
                timer.start();
                timer.setTime(TIMER_INTERVAL);
            } catch (UIException uie) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = "UIException:" + uie.getMessage();
                if (uie.getStatus() == UIException.ILLEGAL_STATE) {
                    str += "(OK)";
                }
                else {
                    str += "(NG)";
                }
                errorDialog.setText(str);
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
        case 6:
            // J011_5106_0207
            try {
                timer = new Timer();
                timer.dispose();
                timer.setTime(TIMER_INTERVAL);
            } catch (UIException uie) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = "UIException:" + uie.getMessage();
                if (uie.getStatus() == UIException.ILLEGAL_STATE) {
                    str += "(OK)";
                }
                else {
                    str += "(NG)";
                }
                errorDialog.setText(str);
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
        case 7:
            // J011_5106_0208
            try {
                timer = new Timer();
                timer.setTime(-1);
            } catch (IllegalArgumentException iae) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                errorDialog.setText("IllegalAegumentException:"
                    + iae.getMessage());
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
        case 8:
            // J011_5106_0209
            try {
                timer = new Timer();
                timer.dispose();
                timer.getResolution();
            } catch (UIException uie) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = "UIException:" + uie.getMessage();
                if (uie.getStatus() == UIException.ILLEGAL_STATE) {
                    str += "(OK)";
                }
                else {
                    str += "(NG)";
                }
                errorDialog.setText(str);
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
        case 9:
            // J011_5106_0210
            try {
                timer = new Timer();
                timer.dispose();
                timer.setListener(
                    new TimerListener() {
                        public void timerExpired(Timer t) {
                            if (t == timer) {
                                resultText.setText("Timer :" + timerCounter++);
                            }
                        }
                    }
                );
            } catch (UIException uie) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = "UIException:" + uie.getMessage();
                if (uie.getStatus() == UIException.ILLEGAL_STATE) {
                    str += "(OK)";
                }
                else {
                    str += "(NG)";
                }
                errorDialog.setText(str);
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
        case 10:
            // J011_5106_0211
            try {
                timer = new Timer();
                timer.dispose();
                timer.stop();
            } catch (UIException uie) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = "UIException:" + uie.getMessage();
                if (uie.getStatus() == UIException.ILLEGAL_STATE) {
                    str += "(OK)";
                }
                else {
                    str += "(NG)";
                }
                errorDialog.setText(str);
                errorDialog.show();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                String str = e.toString();
                errorDialog.setText(str.substring(str.lastIndexOf('.')));
                errorDialog.show();
            }
            break;
        default:
            break;
        }
    }
}


/**
 * Listener changing checking thread
 * @extends Thread
 */
class ListenerThread extends Thread {

    Timer timer;

    /**
     * Listener changing checking thread constructor
     * @param aTimer timer object
     */
    ListenerThread(Timer aTimer) {
        this.timer = aTimer;
    }

    /**
     * execute Listener changing checking thread
     */
    public void run() {
        try {
            sleep(3000);
        } catch (Exception e) {}

        timer.setListener(
            new TimerListener() {
                public void timerExpired(Timer t) {
                    if (t == timer) {
                        timer.stop();
                        Dialog infoDialog =
                            new Dialog(Dialog.DIALOG_INFO, "result");
                        infoDialog.setText("OK: Listener Changed");
                        infoDialog.show();
                    }
                }
            }
        );
    }
}


/**
 * MethodConfirm2 class behavior checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements TimerListner
 */
class MethodConfirm2
    extends Panel implements SoftKeyListener, ComponentListener, TimerListener {

    static final int TIMER_INTERVAL = 1000;

    String[] titleLabelItem = {
        "start/stop",
        "setRepeat 1",
        "setRepeat 2"
    };

    Frame   prevFrame;
    Label   titleLabel  = new Label();
    Button  startButton = new Button("start the timer");
    Button  stopButton  = new Button("end the timer");
    TextBox resultText  = new TextBox("", 20, 1, TextBox.DISPLAY_ANY);

    Timer timer = new Timer();
    TimeKeeper timeKeeper;

    int timerCounter = 0;
    int subListIndex;

    /**
     * MethodConfirm2 class constructor
     * @param aPrev previous display frame 
     * @param aSubListIndex the selected value of sublist
     */
    public MethodConfirm2(Frame aPrev, int aSubListIndex) {

        /* setting the parameter field variable */
        prevFrame    = aPrev;
        subListIndex = aSubListIndex;

        try {
            /* subpanel display */
            showSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display subpanel
     */
    void showSubPanel() {

        /* timer setting */
        timer.setTime(TIMER_INTERVAL);
        timer.setListener(this);

        // J011_5105_0201
        if (subListIndex == 7) {
            timer.setRepeat(false);

        // J011_5105_0202
        } else {
            timer.setRepeat(true);
        }
        timeKeeper = timer;

        /* setting of the display item */
        titleLabel.setText(titleLabelItem[subListIndex - 5]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* adding each component on the display */
        add(titleLabel);
        add(startButton);
        add(stopButton);
        add(resultText);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of softkey pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * define the action when softkey is released
     * @param anIndex the value of softkey released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* timer is disposed and shift to the previous screen when softkey2 is released */
        if (anIndex == Frame.SOFT_KEY_2) {
            timer.dispose();
            Display.setCurrent(prevFrame);
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        try {
            /* when the timer start button is pressed */
            if (aComponent == startButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                // J011_5105_0106
                timer.start();
            }

            /* when the timer stop button is pressed */
            if (aComponent == stopButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                // J011_5105_0107
                timer.stop();
            }
        } catch (UIException uie) {
            Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
            errorDialog.setText("UIE code:" + uie.getStatus());
            errorDialog.show();
        } catch (Exception e) {
            Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
            String str = e.toString();
            errorDialog.setText(str.substring(str.lastIndexOf('.')));
            errorDialog.show();
        }
    }

    /**
     * get the event on the timer
     * @param aTimer timer object
     */
    public void timerExpired(Timer aTimer) {
        resultText.setText("Timer:" + timerCounter++);
    }
}

