/**
 * J011_5205_0101
 * MainPanel
 *
 * TimerListener class behavior checking (normal route)
 *
 * $Revision: 1.1 $
 */
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * TimerListener class behavior checking main class
 * @extends IApplication
 */
public class J011_5205_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * TimerListener class behavior checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements TimerListener
 */
class MainPanel
    extends Panel implements SoftKeyListener, ComponentListener, TimerListener {

    private final static int TIMER_INTERVAL = 1000;

    Label   classLabel = new Label("TimerListener");
    Button  execButton = new Button("execute");
    TextBox resultText = new TextBox("", 20, 1, TextBox.DISPLAY_ANY);
    TextBox statusText = new TextBox("Timer: 0", 20, 1, TextBox.DISPLAY_ANY);

    Timer time = new Timer();
    TimeKeeper timeKeeper;

    int timerCounter = 0;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    void showMainPanel() {

        /* setting of the display item */
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(execButton);
        add(resultText);
        add(statusText);

        /* timer setting */
        time.setTime(TIMER_INTERVAL);
        time.setRepeat(true);
        time.setListener(this);
        timeKeeper = time;

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of softkey pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * @param anIndex the value of softkey released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            try {
                /* get the timer resolution */
                /* timer start */
                timeKeeper.start();
            } catch (Exception e) {
                Dialog errorDialog = new Dialog(Dialog.DIALOG_ERROR, "An exception is detected.");
                errorDialog.setText(e.toString());
                errorDialog.show();
            }
        }
    }

    /**
     * get the event on the timer
     * @param aTimer timer object
     */
    // J011_5205_0101
    public void timerExpired(Timer aTimer) {
        resultText.setText("OK");
        statusText.setText("Timer :" + timerCounter++);
    }
}
