/**
 * J012_0901_0301
 * MainPanel
 *
 * URLEncoder boundary test
 *
 * $Id: J012_0901_0301.java,v 1.1 2001/12/02 04:40:10 hoshi Exp $
 */
import com.nttdocomo.ui.*;
import com.nttdocomo.net.*;


/**
 * URLEncoder boundary test main class
 * @extends IApplication
 */
public class J012_0901_0301 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * URLEncoder boundary test main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "0 the argument is its maximum value",
        "1 the argument's value is 0",
        "2 null argument"
    };

    Label   classLabel = new Label("URLEncoder boundary test");
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");


   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    void showMainPanel() {

        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /*
     * dialog display method
     * @param aText displayed character sequence
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }


    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of softkey pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * @param anIndex the value of softkey released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            test();
        }
    }


    /**
     * test the choiced decode
     */
    public void test() {
        switch(menuList.getSelectedIndex()) {
        case 0:
            // J012_0901_0301
            String orgStr = new String("");
            for (int i=0; i < 102; i++) {
                orgStr += "1234567890";
            }
            orgStr += " END";

            String enStr = URLEncoder.encode(orgStr);
            if (enStr.length() != 1024) {
                showDialog("NG:enStr.length=" + enStr.length());
            }

            String deStr = URLDecoder.decode(enStr);
            if ( deStr.compareTo(orgStr) == 0 ) {
                showDialog("OK");
            } else {
                showDialog("NG:decode()=" + enStr);
            }
            break;
        case 1:
            // J012_0902_0301
            try {
                enStr = URLEncoder.encode("");
                if (enStr.compareTo("") == 0) {
                    showDialog("OK");
                } else {
                    showDialog("NG:encode()=" + enStr);
                }
            } catch (NullPointerException npe) {
                showDialog("NG:NullPointerException");
            } catch (Exception e) {
                showDialog("NG:" + e.toString());
            }
            break;
        case 2:
            // J012_0904_0101
            try {
                URLEncoder.encode(null);
                showDialog("NG:no Exception");
            } catch (NullPointerException npe) {
                showDialog("OK:NullPointerException");
            } catch (Exception e) {
                showDialog("NG:" + e.toString());
            }
            break;
        }
    }
}
