/**
 * J012_1104_0101
 * MainPanel
 *
 * AudioPresenter class behavior checking (boundary test)
 *
 * $Id: J012_1104_0101.java,v 1.2 2002/04/25 08:02:22 torikatu Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;

/**
 * AudioPresenter class action check main class
 * @extends IApplication
 */
public class J012_1104_0101 extends IApplication{
    
    /**
     * starting method for I-appli
     */
    public void start(){
        Display.setCurrent(new MainPanel());
    }
}

/**
 * AudioPresenter class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements MediaListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    String[] menuListItem = {
        "0 test 1",
        "1 test 2",
        "2 test 3"
    };
    
    Frame subFrame ;
    Label classLabel = new Label("AudioPresenter");
    ListBox menuList = new ListBox(ListBox.CHOICE);
    TextBox resultBox =new TextBox("",20,2,TextBox.DISPLAY_ANY);
    Button execButton = new Button("execute");
    AudioPresenter ap = null;
    
    /**
     * constructer of the MainPanel
     */
    public MainPanel(){
        try{
            /* display the MainPanel */
            showMainPanel();
        }catch(Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }
    }
    
    /**
     * display the main panel
     */
    void showMainPanel(){
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
    
    /* adding each component on the display */
    add(classLabel);
    add(menuList);
    add(execButton);
    add(resultBox);
    
    /* setting the listener */
    setSoftKeyListener(this);
    setComponentListener(this);
    }
    
    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex){}
    
    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex){
        /* terminate the application when softkey1 is released */
        if(anIndex == Frame.SOFT_KEY_1){
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Event type
     * @param aParam  parameter of the event
     */
    public void componentAction(Component aComponent,int aType,int aParam){
        /* processing when the execution button is pushed */
        if(aComponent == execButton && aType == ComponentListener.BUTTON_PRESSED){
            test();
        }
    }
    
    /**
     * create the test method
     * each  event processing when the excecution button is pushed
     */
    public void test(){
        /* takes the figure when choosing from the list box. */
        int index = menuList.getSelectedIndex();
        
        switch (index) {
            //J012_1104_0102
            case 0 :
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaData md = MediaManager.getData("resource:///MFi-norm.mld");
                    md.use();
                    ap.setData(null);
                    resultBox.setText("NG: No exception has detected.");
                }catch(NullPointerException aNullPointerException){
                    resultBox.setText("OK : NullPointerException");
                }catch(Exception anException){
                    resultBox.setText("NG : " +anException.toString());
                }
                break;
                
            //J012_1104_0103
            case 1:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.setSound(ms);
                    ap.setMediaListener(null);
                    resultBox.setText("OK");
                }catch(Exception anException){
                    resultBox.setText("NG : " +anException.toString());
                }
                break;
            
            //J012_1103_0104
            case 2:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi-norm.mld");
                    ms.use();
                    ap.setSound(null);
                    resultBox.setText("NG: No exception has detected.");
                }catch(NullPointerException aNullPointerException){
                    resultBox.setText("OK : NullPointerException");
                }catch(Exception anException){
                    resultBox.setText("NG : " +anException.toString());
                }
                break;
                
            default:
            break;
        }
    }
}