/**
 * J011_1201_0301
 * 
 * 
 *
 * Button class behavior checking (boundary test)
 *
 * $Id: J012_1201_0301.java,v 1.2 2001/12/01 12:08:09 lan Exp $
 */
import com.nttdocomo.ui.*;

/**
 * Button class action check main class
 * @extends IApplication
 */
public class J012_1201_0301 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Button class behavior checking MainPanel
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    Button  button = new Button(" execute");
    Label   classLabel = new Label("Button");
    ListBox menuList = new ListBox(ListBox.CHOICE);
    ListBox menuList2 = new ListBox(ListBox.CHOICE);
    String[] menuListItem = {
       
        "3.non-prescribed maximum value",
        "4.prescribed minimum value",
        "5.null"
    };

    String[] subItems = {
        "1.Button",
        "2.setLabel"
    };

    /**
     * Constructor of MainPanel class
     */
    MainPanel(){
        /* setting of the display item */
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        menuList.setItems(menuListItem);
        menuList2.setItems(subItems);

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(menuList2);
        add(button);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
        
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if( aComponent == menuList ) {
            /* sub menu setting */
            menuList2.setItems(subItems);
        }

        if (aComponent == button) {
            /* create NextPanel1 class */
            Display.setCurrent(new NextPanel1((Frame) this,
                                menuList.getSelectedIndex(),
                                menuList2.getSelectedIndex()));
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param aSoftKey Index of the key
     */
    public void softKeyPressed(int aSoftKey) {}
    
    /**
     * terminate the application when softkey1 is released
     * @param aSoftKey Index of the key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}

/**
 * Button boundary checking class
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel1 extends Panel implements SoftKeyListener{
    Frame previousFrame = null;
    int idx1 = 0;
    int idx2 = 0;

    /**
     * constructer of NextPanel1 class
     * @param aFrame the object of MainPanel
     * @param anIndex1 selected index of menu1
     * @param anIndex2 selected index of menu2
     */
    NextPanel1(Frame aFrame,int anIndex1, int anIndex2){
        /* parameter storaging */
        previousFrame = aFrame;
        idx1 = anIndex1;
        idx2 = anIndex2;

        /* setting of the display item */
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_2,"back");

        /* setting the listener */
        setSoftKeyListener(this);

        /* excecute testing */
        test();
    }

    /*
     * dialog display method
     * @param   aText displayed character sequence
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "notification");
        d.setText(aText);
        d.show();
    }

    /**
     * do nothing when a softkey is pushed
     * @param aSoftKey Index of the key
     */
    public void softKeyPressed(int aSoftKey) {}
    
    /**
     * when softkey2 is released, return to the MainPanel screen
     * @param aSoftKey Index of the key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_2) {
            if(previousFrame != null){
                Display.setCurrent(previousFrame);
            }
        }
    }

    /**
     * Button boundary checking method
     */
    public void test() {
        Button b;
        String str = new String();

        switch( idx1 ) {
       
        case 0:
            /* maximum out of the prescribed */
            str = new String("");
            for( int i=0; i<102; i++ ) {
                str += "1024byte**";
            }
            str += " END";
            if( str.length() != 1024 ) {
                showDialog("NG:str.length=" + str.length());
                return;
            }
            break;
        case 1:
            /* minimum within the prescribed */
            str = new String("");
            break;
        case 2:
            /* null */
            str = null;
            break;
        default:
            showDialog("NG:parameter error!");
            break;
        }

        switch( idx2 ) {
        case 0:
           
            // J012_1201_0301
            // J012_1202_0101
            // J012_1204_0101
            b = new Button(str);
            add(b);
            break;
        case 1:
           
            // J012_1201_0302
            // J012_1202_0102
            // J012_1204_0102
            b = new Button();
            add(b);
            b.setLabel(str);
            break;
        }
    }
}
