/**
 * J012_1401_0301
 *
 *
 *
 * Component classs behavior checking (boundary test)
 *
 * $Id: J012_1401_0301.java,v 1.1 2001/11/30 02:25:33 yaeda Exp $
 */

import com.nttdocomo.ui.*;

/**
 * Component class action check main class
 * @extends IApplication
 */
public class J012_1401_0301 extends IApplication {
    
    /**
     * starting method for I-appli
     */
    public void start () {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Component class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener {
    
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private String[] menuListItem = {
            "1 test 1",
            "2 test 2",
            "3 test 3",
            "4 test 4"
    };
    private Button button1;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    public void showMainPanel() {

        /* setting of the display item */
        setTitle("API class boundary route");
        menuList.setItems(menuListItem);
        add(menuList);

        button1 = new Button("execute");
        add(button1);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button1 ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    /* create NextPanel1 */
                    Display.setCurrent(new NextPanel1((Frame) this));
                    break;
                case 1:
                    /* create NextPanel2 */
                    Display.setCurrent(new NextPanel2((Frame) this));
                    break;
                case 2:
                    /* create NextPanel3 */
                    NextPanel3 np3 = new NextPanel3((Frame) this);
                    Display.setCurrent(np3);
                    break;
                case 3:
                    /* create NextPanel4 */
                    Display.setCurrent(new NextPanel4((Frame) this));
                    break;
            }
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {
    }

    /**
     * terminate the application when softkey1 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}
/**
 * Component class action check sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel1 extends Panel implements SoftKeyListener,ComponentListener {

    private Frame previousFrame = null;
    private Button button1,button2;
    private TextBox textBox = new TextBox("", 20, 3, TextBox.DISPLAY_ANY);
    
    /**
     * NextPanel1 constructor
     * @param aPrev the object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;

        /* setting of the display item */
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        button1 = new Button("button 1");
        button2 = new Button("execute");
        add(button1);
        add(button2);
        add(textBox);
        button2.requestFocus();

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
        
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button2 ) {
            try {
//J012_1401_0301
                button1.setBackground(0x7FFFFFFF);
            } catch (IllegalArgumentException e) {
                textBox.setText("IllegalArgumentException");
            }
        }
    }
       
    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * terminate the application when the softkey2 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Component class action check sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel2 extends Panel implements SoftKeyListener,ComponentListener {

    private Frame previousFrame = null;
    private Button button1,button2;
    private TextBox textBox = new TextBox("", 20, 3, TextBox.DISPLAY_ANY);
    
    /**
     * NextPanel2 constructor
     * @param aPrev the object of MainPanel
     */
    public NextPanel2(Frame aPrev) {
        previousFrame = aPrev;

        /* setting of the display item */
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        button1 = new Button("button 1");
        button2 = new Button("execute");
        add(button1);
        add(button2);
        add(textBox);
        button2.requestFocus();

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
        
    }
    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button2 ) {
            try {
//J012_1401_0302
                button1.setForeground(0x7FFFFFFF);
            } catch (IllegalArgumentException e) {
                textBox.setText("IllegalArgumentException");
            }
        }
    }
       
    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int index) {}

    /**
     * terminate when softkey1,2 is released
     */
    public void softKeyReleased(int index) {
        if (index == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (index == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Component class action check sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel3 extends Panel implements SoftKeyListener,ComponentListener {

    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private Frame previousFrame = null;
    private Button button1,button2;
    private String[] menuListItem = {
            "01 put maximum value to argument X",
            "02 put maximum value to argument Y",
            "03 put maximum values to argument X and Y"
    };

    /**
     * NextPanel3 constructor
     * @param aPrev the object of MainPanel
     */
    public NextPanel3(Frame aPrev) {
        previousFrame = aPrev;

        /* setting of the display item */
        setLayoutManager(null);
        setTitle("API class boundary route");
        menuList.setItems(menuListItem);
        
        add(menuList);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        button1 = new Button("execute");
        button2 = new Button("button 1");
        button1.setLocation(0,20);
        add(button1);
        button2.setLocation(0,40);
        add(button2);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
        
    }
    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        /* clearing menu list */
        if ( aComponent == menuList ) {
            button2.setLocation(0,40);
        }

        if ( aComponent == button1 ) {
            Dialog dialog = new Dialog(Dialog.BUTTON_OK, "setLocation");
            switch(menuList.getSelectedIndex()){
                case 0:
//J012_1401_0303
                    button2.setLocation(0x7FFFFFFF,0x7FFFFFFF);
                    dialog.setText("X="+button2.getX()+", Y="+button2.getY());
                    break;
                case 1:
//J012_1401_0304
                    button2.setLocation(0x7FFFFFFF,0x7FFFFFFF);
                    dialog.setText("X="+button2.getX()+", Y="+button2.getY());
                    break;
                case 2:
//J012_1401_0305
                    button2.setLocation(0x7FFFFFFF,0x7FFFFFFF);
                    dialog.setText("X="+button2.getX()+", Y="+button2.getY());
                    break;
            }
            dialog.show();
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * terminate the application when the softkey2 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Component class action check sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel4 extends Panel implements SoftKeyListener,ComponentListener {

    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private Frame previousFrame = null;
    private Button button1,button2;
    private String[] menuListItem = {
            "01 maximum width",
            "02 maximum height",
            "03 maximum width and height"
    };

    /**
     * NextPanel4 constructor
     * @param aPrev the object of MainPanel
     */
    public NextPanel4(Frame aPrev) {
        previousFrame = aPrev;

        /* setting of the display item */
        setLayoutManager(null);
        setTitle("API class boundary route");
        menuList.setItems(menuListItem);
        
        add(menuList);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        button1 = new Button("execute");
        button2 = new Button("button 1");
        button1.setLocation(0,20);
        add(button1);
        button2.setLocation(0,40);
        add(button2);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
        
    }
    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        /* clearing menu list */
        if ( aComponent == menuList ) {
            button2.setLocation(0,40);
        }

        if ( aComponent == button1 ) {
            Dialog dialog = new Dialog(Dialog.BUTTON_OK, "setSize");
            switch(menuList.getSelectedIndex()){
                case 0:
//J012_1401_0306
                    button2.setSize(0x7FFFFFFF,40);
                    dialog.setText("width ="+button2.getWidth()+",height ="+button2.getHeight());
                    break;
                case 1:
//J012_1401_0307
                    button2.setSize(5,0x7FFFFFFF);
                    dialog.setText("width ="+button2.getWidth()+",height ="+button2.getHeight());
                    break;
                case 2:
//J012_1401_0308
                    button2.setSize(0x7FFFFFFF,0x7FFFFFFF);
                    dialog.setText("width ="+button2.getWidth()+",height ="+button2.getHeight());
                    break;
            }
            dialog.show();
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * terminate the application when the softkey2 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

