/**
 * J012_1402_0201
 *
 *
 *
 * Component classs behavior checking (boundary test)
 *
 * $Id: J012_1402_0201.java,v 1.1 2001/11/30 02:25:34 yaeda Exp $
 */

import com.nttdocomo.ui.*;

/**
 * Component class action check main class
 * @extends IApplication
 */
public class J012_1402_0201 extends IApplication {
    
    /**
     * starting method for I-appli
     */
    public void start () {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Component class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener {
    
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private String[] menuListItem = {
            "1 test 1",
            "2 test 2"
    };
    private Button button1;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    public void showMainPanel() {

        /* setting of the display item */
        setTitle("API class boundary route");
        menuList.setItems(menuListItem);
        add(menuList);

        button1 = new Button("execute");
        add(button1);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button1 ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    /* create NextPanel1 */
                    Display.setCurrent(new NextPanel1((Frame) this));
                    break;
                case 1:
                    /* create NextPanel2 */
                    Display.setCurrent(new NextPanel2((Frame) this));
                    break;
            }
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {
    }

    /**
     * terminate the application when softkey1 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}

/**
 * Component class action check sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel1 extends Panel implements SoftKeyListener,ComponentListener {

    private Frame previousFrame = null;
    private Button button1,button2;
    private TextBox textBox = new TextBox("", 20, 3, TextBox.DISPLAY_ANY);
    
    /**
     * NextPanel1 constructor
     * @param aPrev the object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;

        /* setting of the display item */
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        button1 = new Button("button 1");
        button2 = new Button("execute");
        add(button1);
        add(button2);
        add(textBox);
        button2.requestFocus();

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
        
    }
    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button2 ) {
            try {
//J012_1402_0201
                int min255 = Graphics.getColorOfRGB(255,255,255);
                int min0 = Graphics.getColorOfRGB(0,0,0);
                if ( min255 >= min0 ){
                    button1.setBackground((min0 - 1));
                    textBox.setText("OK");
                } else {
                    button1.setBackground((min255 - 1));
                    textBox.setText("OK");
                }
            } catch (IllegalArgumentException e) {
                textBox.setText("IllegalArgumentException");
            }
        }
    }
       
    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * terminate the application when the softkey2 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Component class action check sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel2 extends Panel implements SoftKeyListener,ComponentListener {

    private Frame previousFrame = null;
    private Button button1,button2;
    private TextBox textBox = new TextBox("", 20, 3, TextBox.DISPLAY_ANY);
    
    /**
     * NextPanel2 constructor
     * @param aPrev the object of MainPanel
     */
    public NextPanel2(Frame aPrev) {
        previousFrame = aPrev;

        /* setting of the display item */
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        button1 = new Button("button 1");
        button2 = new Button("execute");
        add(button1);
        add(button2);
        add(textBox);
        button2.requestFocus();

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
        
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button2 ) {
            try {
//J012_1402_0202
                int min255 = Graphics.getColorOfRGB(255,255,255);
                int min0 = Graphics.getColorOfRGB(0,0,0);
                if ( min255 >= min0 ){
                    button1.setForeground((min0 - 1));
                    textBox.setText("OK");
                } else {
                    button1.setForeground((min255 - 1));
                    textBox.setText("OK");
                }
            } catch (IllegalArgumentException e) {
                textBox.setText("IllegalArgumentException");
            }
        }
    }
       
    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * terminate the application when the softkey2 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

