/**
 * J012_1402_0303
 *
 *
 *
 * Component classs behavior checking (boundary test)
 *
 * $Id: J012_1402_0303.java,v 1.1 2001/11/30 02:25:35 yaeda Exp $
 */

import com.nttdocomo.ui.*;

/**
 * Component class action check main class
 * @extends IApplication
 */
public class J012_1402_0303 extends IApplication {
    
    /**
     * starting method for I-appli
     */
    public void start () {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Component class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener {
    
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private String[] menuListItem = {
            "1 the argument's value is 0",
            "2 value of the argument is -1"
    };
    private Button button1;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    public void showMainPanel() {

        /* setting of the display item */
        setTitle("API class boundary route");
        menuList.setItems(menuListItem);
        add(menuList);

        button1 = new Button("execute");
        add(button1);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button1 ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    /* create NextPanel1 */
                    Display.setCurrent(new NextPanel1((Frame) this));
                    break;
                case 1:
                    /* create NextPanel2 */
                    Display.setCurrent(new NextPanel2((Frame) this));
                    break;
            }
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}

/**
 * Component class action check sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel1 extends Panel implements SoftKeyListener,ComponentListener {

    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private Frame previousFrame = null;
    private Button button1,button2;
    private String[] menuListItem = {
            "1 argument X is 0",
            "2 argument Y is 0",
            "3 values of argument X and Y are both 0"
    };

    
    /**
     * NextPanel1 constructor
     * @param aPrev the object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;

        /* setting of the display item */
        setLayoutManager(null);
        menuList.setItems(menuListItem);
        add(menuList);
        menuList.setLocation(10,30);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        button1 = new Button("execute");
        button2 = new Button("button 1");
        add(button1);
        button1.setLocation(10,50);
        add(button2);
        button2.setLocation(10,70);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
        
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* clearing menu list */
        if ( aComponent == menuList ) {
            button2.setLocation(10,70);
        }

        if ( aComponent == button1 ) {
            Dialog dialog = new Dialog(Dialog.BUTTON_OK, "setLocation");
            switch(menuList.getSelectedIndex()){
                case 0:
                    try {
//J012_1402_0303
                        button2.setLocation(0,10);
                        dialog.setText("X="+button2.getX()+", Y="+button2.getY());
                        dialog.show();
                    } catch (Exception e) {
                        Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
                        errDialog.setText("Error:" + e.toString());
                        errDialog.show();
                    }
                    break;
                case 1:
                    try {
//J012_1402_0304
                        button2.setLocation(10,0);
                        dialog.setText("X="+button2.getX()+", Y="+button2.getY());
                        dialog.show();
                    } catch (Exception e) {
                        Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
                        errDialog.setText("Error:" + e.toString());
                        errDialog.show();
                    }
                    break;
                case 2:
                    try {
//J012_1402_0305
                        button2.setLocation(0,0);
                        dialog.setText("X="+button2.getX()+", Y="+button2.getY());
                        dialog.show();
                    } catch (Exception e) {
                        Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
                        errDialog.setText("Error:" + e.toString());
                        errDialog.show();
                    }
                break;
            }
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * terminate the application when the softkey2 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Component class action check sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel2 extends Panel implements SoftKeyListener,ComponentListener {

    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private Frame previousFrame = null;
    private Button button1,button2;
    private String[] menuListItem = {
            "1 argument X is -1",
            "2 argument Y is -1",
            "3 argument X and argument Y are both -1"
    };

    
    /**
     * NextPanel2 constructor
     * @param aPrev the object of MainPanel
     */
    public NextPanel2(Frame aPrev) {
        previousFrame = aPrev;

        /* setting of the display item */
        setLayoutManager(null);
        menuList.setItems(menuListItem);
        add(menuList);
        menuList.setLocation(10,30);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        button1 = new Button("execute");
        button2 = new Button("button 1");
        add(button1);
        button1.setLocation(10,50);
        add(button2);
        button2.setLocation(10,70);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
        
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* clearing menu list */
        if ( aComponent == menuList ) {
            button2.setLocation(10,70);
        }

        if ( aComponent == button1 ) {
            Dialog dialog = new Dialog(Dialog.BUTTON_OK, "setLocation");
            switch(menuList.getSelectedIndex()){
                case 0:
                    try {
//J012_1403_0103
                        button2.setLocation(-1,10);
                        dialog.setText("X="+button2.getX()+", Y="+button2.getY());
                        dialog.show();
                    } catch (Exception e) {
                        Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
                        errDialog.setText("Error:" + e.toString());
                        errDialog.show();
                    }
                    break;
                case 1:
                    try {
//J012_1403_0104
                        button2.setLocation(10,-1);
                        dialog.setText("X="+button2.getX()+", Y="+button2.getY());
                        dialog.show();
                    } catch (Exception e) {
                        Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
                        errDialog.setText("Error:" + e.toString());
                        errDialog.show();
                    }
                    break;
                case 2:
                    try {
//J012_1403_0105
                        button2.setLocation(-1,-1);
                        dialog.setText("X="+button2.getX()+", Y="+button2.getY());
                        dialog.show();
                    } catch (Exception e) {
                        Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
                        errDialog.setText("Error:" + e.toString());
                        errDialog.show();
                    }
                break;
            }
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * terminate the application when the softkey2 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}
