/**
 * J012_2001_0101
 *
 * Frame class behavior checking (boundary test)
 *
 * $Id: J012_2001_0101.java,v 1.1 2001/12/01 13:26:59 horikoshi Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;

/**
 * Frame class action check main class
 * @extends IApplication
 */
public class J012_2001_0101 extends IApplication {

    /**
     * starting i-Appli start()
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * Frame class action check main class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menu1 = {
        "01 when the value is prescribed maximum",
        "02 when the value is prescribed maximum + 1",
        "03 when the value is non-prescribed maximum",
        "04 when the value is prescribed minimum",
        "05 when the value is prescribed minimum - 1",
        "06 the value is non-prescribed minimum",
        "07 when the parameter is null"
    };

    String[] menu2_01 = {
        "01 Soft(str=MAX)",
        "02 Soft(key=MAX)",
        "03 Back(c=MAX)"
    };

    String[] menu2_02 = {
        "01 Soft(str=MAX+1)",
        "02 Soft(key=MAX+1)",
        "03 Back(c=MAX+1)"

    };

    String[] menu2_03 = {
        "01 Soft(argument str is MAX)",
        "02 Soft(argument key is MAX)",
        "03 Back(argument c is MAX)"
    };

    String[] menu2_04 = {
        "01 Soft(str=MIN)",
        "02 Soft(key=MIN)",
        "03 Back(c=MIN)"
    };

    String[] menu2_05 = {
        "01 Soft(key=MIN-1)",
        "02 Back(c=MIN-1)"
    };

    String[] menu2_06 = {
        "01 Back(argument c is MIN)"
    };

    String[] menu2_07 = {
        "01 Soft(str=null)"
    };

    Label   title      = new Label("Frame operation test");
    ListBox menu_Li    = new ListBox(ListBox.CHOICE);
    ListBox menu_Li2   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");
    int     firstType;
    int     secondType;
    Graphics g;

    /**
     * MainPanel constructor(initializing)
     */
    public MainPanel() {

        /* setting of the display item */
        menu_Li.setItems(menu1);
        menu_Li2.setItems(menu2_01);
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        this.setBackground(g.getColorOfName(Graphics.YELLOW));

        /* adding each component on the display */
        add(title);
        add(menu_Li);
        add(menu_Li2);
        add(execButton);

        /* register the softkey listener */
        setSoftKeyListener(this);
        /* register the component listener */
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of the pushed softkey 
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when SOFT_KEY_1 is released
     * @param anIndex the value of the released softkey 
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when SOFT_KEY_1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * process when the action other than softkey happens
     * @param source the component on which the event occurs
     * @param type event type
     * @param param event parameter
     */
    public void componentAction(Component source, int type, int param) {
        /* when item in the menu1 is selected */
        if (source == menu_Li && type == ComponentListener.SELECTION_CHANGED) {

            /* get the chosen item */
            firstType = menu_Li.getSelectedIndex();
            setSoftLabel(Frame.SOFT_KEY_1, "exit");
            this.setBackground(g.getColorOfName(Graphics.YELLOW));

            /* set the selection list in menu 1 */
            switch (firstType) {
                case 0:
                    menu_Li2.setItems(menu2_01);
                    break;
                case 1:
                    menu_Li2.setItems(menu2_02);
                    break;
                case 2:
                    menu_Li2.setItems(menu2_03);
                    break;
                case 3:
                    menu_Li2.setItems(menu2_04);
                    break;
                case 4:
                    menu_Li2.setItems(menu2_05);
                    break;
                case 5:
                    menu_Li2.setItems(menu2_06);
                    break;
                case 6:
                    menu_Li2.setItems(menu2_07);
                    /* displaying which is easy to see when executing */
                    setSoftLabel(Frame.SOFT_KEY_2, "key");
                    break;
                default:
                    break;
            }
        }

        /* when the fix-key is pushed on the condition the execution button is focused */
        if (source == execButton 
            && type == ComponentListener.BUTTON_PRESSED) {

            /* get the chosen item */
            secondType = menu_Li2.getSelectedIndex();

            switch (firstType) {
                case 0:
                    /* in case of the maximum of the parameter within the prescribed */
                    test1();
                    break;
                case 1:
                    /* in case of the maximum of the parameter +1 within the prescribed */
                    test2();
                    break;
                case 2:
                    /* in case of the maximum of the parameter out of the prescribed */
                    test3();
                    break;
                case 3:
                    /* in case of the minimum of the parameter within the prescribed */
                    test4();
                    break;
                case 4:
                    /* in case of the minimum of the parameter -1 within the prescribed */
                    test5();
                    break;
                case 5:
                    /* in case of the maximum of the parameter out of the prescribed */
//J012_2002_0303
                    this.setBackground(0);
                    break;
                case 6:
                    /* in case of null */
//J012_2004_0101
                    setSoftLabel(SOFT_KEY_2, null);
                    break;
                default:
                    break;
            }
        }
    }

    /**
     * in case of the maximum of the parameter checking method within the prescribed
     */
    public void test1() {
        switch (secondType) {
//J012_2001_0101
            case 0:
                setSoftLabel(SOFT_KEY_2, "1234");
                break;
//J012_2001_0102
            case 1:
                setSoftLabel(1,"OK");
                break;
//J012_2001_0103
            case 2:
                int max = 0;
                int min = 0;
                if (g.getColorOfRGB(255,255,255) > g.getColorOfRGB(0,0,0)) {
                    max = g.getColorOfRGB(255,255,255);
                    min = g.getColorOfRGB(0,0,0);
                } else {
                    min = g.getColorOfRGB(255,255,255);
                    max = g.getColorOfRGB(0,0,0);
                }
                this.setBackground(max);
                break;
        }
    }

    /**
     * in case of the maximum of the parameter +1 checking method within the prescribed
     */
    public void test2() {
        switch (secondType) {
//J012_2001_0201
            case 0:
                setSoftLabel(SOFT_KEY_2, "12345");
                break;
//J012_2001_0202
            case 1:
                try {
                    setSoftLabel(2,"OK");
                } catch (IllegalArgumentException e) {
                    showDialog("IllegalArgumentException");
                } catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
//J012_2001_0203
            case 2:
                int max = 0;
                int min = 0;
                if (g.getColorOfRGB(255,255,255) > g.getColorOfRGB(0,0,0)) {
                    max = g.getColorOfRGB(255,255,255);
                    min = g.getColorOfRGB(0,0,0);
                } else {
                    min = g.getColorOfRGB(255,255,255);
                    max = g.getColorOfRGB(0,0,0);
                }
                max += 1;
                try {
                    this.setBackground(max);
                } catch (IllegalArgumentException e) {
                    showDialog("IllegalArgumentException");
                } catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
        }
    }

    /**
     * in case of the maximum of the parameter checking method within the prescribed
     */
    public void test3() {
        switch (secondType) {
//J012_2001_0301
            case 0:
                String str = "";
                for (int i=0; i<1024; i++){
                    str += "a";
                }
                try {
                    setSoftLabel(SOFT_KEY_2, str);
                } catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
//J012_2001_0302
            case 1:
                try {
                    setSoftLabel(2,"OK");
                } catch (IllegalArgumentException e) {
                    showDialog("IllegalArgumentException");
                } catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
//J012_2001_0303
            case 2:
                int max = 0;
                int min = 0;
                if (g.getColorOfRGB(255,255,255) > g.getColorOfRGB(0,0,0)) {
                    max = g.getColorOfRGB(255,255,255);
                    min = g.getColorOfRGB(0,0,0);
                } else {
                    min = g.getColorOfRGB(255,255,255);
                    max = g.getColorOfRGB(0,0,0);
                }
                max += 1;
                try {
                    this.setBackground(max);
                } catch (IllegalArgumentException e) {
                    showDialog("IllegalArgumentException");
                } catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
        }
    }

    /**
     * in case of the minimum of the parameter checking method within the prescribed
     */
    public void test4() {
        switch (secondType) {
//J012_2002_0101
            case 0:
                String str = "";
                try {
                    setSoftLabel(SOFT_KEY_2, str);
                } catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
//J012_2002_0102
            case 1:
                try {
                    setSoftLabel(0,"OK");
                } catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
//J012_2002_0103
            case 2:
                int max = 0;
                int min = 0;
                if (g.getColorOfRGB(255,255,255) > g.getColorOfRGB(0,0,0)) {
                    max = g.getColorOfRGB(255,255,255);
                    min = g.getColorOfRGB(0,0,0);
                } else {
                    min = g.getColorOfRGB(255,255,255);
                    max = g.getColorOfRGB(0,0,0);
                }
                try {
                    this.setBackground(min);
                } catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
        }
    }

    /**
     * in case of the minimum of the parameter -1 checking method within the prescribed
     */
    public void test5() {
        switch (secondType) {
//J012_2002_0201
            case 0:
                try {
                    setSoftLabel(-1,"OK");
                } catch (IllegalArgumentException e) {
                    showDialog("IllegalArgumentException");
                } catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
//J012_2002_0202
            case 1:
                int max = 0;
                int min = 0;
                if (g.getColorOfRGB(255,255,255) > g.getColorOfRGB(0,0,0)) {
                    max = g.getColorOfRGB(255,255,255);
                    min = g.getColorOfRGB(0,0,0);
                } else {
                    min = g.getColorOfRGB(255,255,255);
                    max = g.getColorOfRGB(0,0,0);
                }
                min -= 1;
                try {
                    this.setBackground(min);
                } catch (IllegalArgumentException e) {
                    showDialog("IllegalArgumentException");
                } catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
        }
    }

    /**
     * setting of the dialog box which is going to be displayed
     * @param str the message on the dialog
     */
    public void showDialog(String str) {
        /* create the dialog box */
        Dialog    d = new Dialog(Dialog.BUTTON_OK, "result");
        /* put the character sequence */
        d.setText(str);
        /* display of the dialog box */
        d.show();
    }
}
