/**
 * FLMath.java   0.1 2000/01/26
 *
 * $Id: FMath.java,v 1.1 2001/11/30 04:44:17 lan Exp $
 */

/**
 * FLMath  methematic library for the fixed decimal point
 *
 * @author Naoki Takada
 * @version 2000/01/26
 */

public class FMath {

    /** FP: which means one in the fixed decimal point */
    public final static long FP = 1024;
    /** SH: the number of bit of the fraction portion  */
    public final static int SH = 10;

    /** ROUND: PI */
    final static long PI = 3217; // Math.PI*1024
    final static long PI2 = 2*PI; // 2*Math.PI*1024

    /** calculate square root of n
     *  the number of square root in the fixed point number
     * calculating
     * @param n fixed point number which is computed
     * @return square root of n which is fixed point number
     */
    public static long sqrt(long n) {
        long s, t;

        n <<= SH;

        if (n == 0) return 0;
        s = 1;
        t = n;

        while (s < t) {
            s <<= 1;
            t >>= 1;
        }

        do {
            t = s;
            s = (n / s + s) >> 1;
        } while (s < t);

        return t;
    }

    /** return sine of n
     * @param n radian which is fixed point number
     * @return sine which is fixed point number
     */
    public static long sin(long n) {
        // anyway, bring to + value
        while (n < 0) {
            n += PI2;
        }

        // rounding because the angle more than one round is unnecessary
        n = n % (PI2);

        // sin n (PI/2 < n < PI) is equal to sin(PI-n)
        if (n > (PI>>1) && n < PI) {
            return sin(PI-n);
        }

        // sin n (PI < n < PI*2) is equal to -sin(n-PI)
        if (n >= PI) {
            return -sin(n-PI);
        }

        // sin n (0< n < PI/2) the area is approximation (taylor expansion to 5)
        long n2 = (n * n) >> SH;
        long n3 = (n2 * n) >> SH;
        long n5 = (n2 * n3) >> SH;
        return n-(n3/6)+(n5/120);
    }

    /** return cos of n
     * @param n radian which is fixed point number
     * @return cos which is fixed point number
     */
    public static long cos(long n) {
        return sin(n + (PI>>1));
    }

    /** return tan of n
     * @param n radian which is fixed point number
     * @return tan which is fixed point number
     */
    public static long tan(long n) {
    // tan theta = sin theta / cos theta
        return (sin(n)<<SH)/cos(n);
    }

    /** return the absolute value
     * @param n signed parameter
     * @return the value n without sign
     */
    public static long abs(long n) {
        return (n>0 ? n : -n);
    }

}// FMath
