/**
 * J012_4001_0101.java
 * 
 * J012_4001_0101
 * MenuPanel
 * TestPanel
 * 
 * Panel class behavior checking (boundary test)
 * 
 * $Id: J012_4001_0101.java,v 1.2 2001/12/02 05:18:27 waka Exp $
 */

import com.nttdocomo.ui.*;

/**
 * Panel class behavior checking main class
 * @extends IApplication
 */
public class J012_4001_0101 extends IApplication {
    /**
     * starting method for I-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * Panel class boundary testing menu screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {

    protected int maxInt = 0x7FFFFFFF;       /* the maximum of int */
    ListBox menu1 = null;
    ListBox menu2 = null;                    /* selection processing  menu */
    Button execButton = null;                /* execution button */
    int maxColor;                            /* the maximum value of terminal color */

    /* processing selection menu item(main ,sub) */
    String[] menu1Item = {
        "0.setTitle()",
        "1.Background()",
        "2.listener",
        "3.exception",
    };

    String[][] menu2Item = {
        /* menu of setTitle */
        {
            "0.prescribed maximum",
            "1.prescribed maximum + 1",
            "2.non-prescribed minimum",
            "3.Null"
        },
        /* menu of Background */
        {
            "0.operation check 1"
        },
        /* menu of 0 listener */
        {
            "0.ComponentListener",
            "1.SoftKeyListener",
            "2.KeyListener"
        },
        /* menu of the exception */
        {
            "0.check the exception 1",
            "1.check the exception 2",
            "2.check the exception 3",
            "3.check the exception 4",
            "4.check the exception 5",
            "5.check the exception 6"
        }
    };

    /**
     * MenuPanel class constructor
     */
    MenuPanel() {
        try {
            showMenuPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * menu screen display
     */
    public void showMenuPanel() {
        /* menu/sub title display */
        setTitle("API class boundary route");
        Label subTitle = new Label("Panel");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);

        /* create/add the component */
        menu1 = new ListBox(ListBox.CHOICE, 8);
        menu2 = new ListBox(ListBox.CHOICE, 4);
        execButton = new Button("execute");
        menu1.setItems(menu1Item);
        menu2.setItems(menu2Item[0]);
        add(menu1);
        add(menu2);
        add(execButton);

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * behavior checking method. Displaying the dialog for exception checking , shifting to the checking screen for other checking
     * @param  menu1Index index of main menu
     * @param  menu2Index index of sub menu
     */
    void test(int menu1Index, int menu2Index) {

        boolean okFlag = false;

        if ( menu1Index == 3 ) {
            switch (menu2Index) {
// J012_4001_0202
            case 0:
                try {
                    Button addTestButton[] = new Button[1000000001];
                    int i;
                    for ( i = 0; i < 1000000000; i++ ) {
                        addTestButton[i] = new Button("AddTest");
                        add(addTestButton[i]);
                    }
                } catch(UIException uie) {
                    showMsg("\"OK\"UIException:" + uie.getMessage());
                } catch(OutOfMemoryError oome) {
                    showMsg("\"OK\"OutOfMemoryError");
                } catch(Exception e) {
                    showMsg(e.toString());
                } catch(Error e) {
                    showMsg(e.toString());
                }
                break;
// J012_4001_0203
            case 1:
                try {
                    Panel testPanel = new Panel();
                    getColorMax();
                    testPanel.setBackground(maxColor +1);
                } catch(IllegalArgumentException iae) {
                    showMsg("\"OK\"IAE:" + iae.getMessage());
                } catch(Exception e) {
                    showMsg(e.toString());
                } catch(Error e) {
                    showMsg(e.toString());
                }
                break;
// J012_4001_0204
            case 2:
                try {
                    Panel testPanel = new Panel();
                    testPanel.setBackground(maxInt);
                } catch(IllegalArgumentException iae) {
                    showMsg("\"OK\"IAE:" + iae.getMessage());
                } catch(Exception e) {
                    showMsg(e.toString());
                } catch(Error e) {
                    showMsg(e.toString());
                }
                break;
// J012_4001_0301
            case 3:
                try {
                    Panel testPanel = new Panel();
                    testPanel.setBackground(-1);
                } catch(IllegalArgumentException iae) {
                    showMsg("\"OK\"IAE:" + iae.getMessage());
                } catch(Exception e) {
                    showMsg(e.toString());
                } catch(Error e) {
                    showMsg(e.toString());
                }
                break;
// J012_4001_0405
            case 4:
                try {
                    add(null);
                } catch(NullPointerException npe) {
                    showMsg("\"OK\" NullPointerException:" + npe.getMessage());
                } catch(Exception e) {
                    showMsg(e.toString());
                } catch(Error e) {
                    showMsg(e.toString());
                }
                break;
// J012_4001_0406
            case 5:
                try {
                    Panel testPanel = new Panel();
                    testPanel.setFocusManager(null);
                } catch(NullPointerException npe) {
                    showMsg("\"OK\" NullPointerException:" + npe.getMessage());
                } catch(Exception e) {
                    showMsg(e.toString());
                } catch(Error e) {
                    showMsg(e.toString());
                }
                break;
            }
            return;
        }

        /* shift to the behavior checking Panel */
        Display.setCurrent(new TestPanel(menu1Index, menu2Index, this));

    }

    /**
     * display message dialog
     * @param  aMsg dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * the method which get the maximum color value of cell phone
     */
    void getColorMax() {
        int color0;
        int color255;

        color0 = Graphics.getColorOfRGB(0,0,0);
        color255 = Graphics.getColorOfRGB(255,255,255);

        if ( color0 >= color255 ) {
            maxColor = color0;
        } else {
            maxColor = color255;
        }
    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {
    }

    /**
     * terminate the application when the softkey1 is released
     * shift to the previous screen in case of softkey2
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when menu list(menu1) is selected , set the item(menu2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menu1 ) {
                menu2.setItems(menu2Item[menu1.getSelectedIndex()]);
            }
        }
        /* when the execution button is pressed, store the 2 menu indexes to the variable and call behavior checking method*/
        if ( aType == ComponentListener.BUTTON_PRESSED ) {
            try {

                int menu1Index = menu1.getSelectedIndex();
                int menu2Index = menu2.getSelectedIndex();

                test(menu1Index, menu2Index);

            } catch(Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
        }
    }

}

/**
 * Panel class boundary behavior checking screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class TestPanel extends Panel implements SoftKeyListener, ComponentListener {

    Frame previousFrame = null;         /* store the previous screen */
    Label subTitle = null;              /* sub title */
    int menu1Index = 0;
    int menu2Index = 0;
    String maxString = null;            /* store the longest character sequence */
    int maxColor;                       /* the maximum value of terminal color */
    Button testButton1, testButton2;
   /* SoftKeyListener test button */
    Button keyListenerPrev;
    Button keyListenerEnd;

    /**
     * TestPanel class constructor
     * @param  menu1Index index of menu1
     * @param  menu2Index index of menu2
     */
    TestPanel(int menu1Index, int menu2Index, Frame aFrame) {
        previousFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;

        /* menu/sub title display */
        setTitle("API class boundary route");
        subTitle = new Label("");
        add(subTitle);

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        setSoftLabel(Frame.SOFT_KEY_2,"back");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);

        if ( menu1Index == 0 ) {
            switch (menu2Index) {
            case 0:
// J012_4001_0101
                setTitle(strMax(16));
                subTitle.setText("the title consists of 16 characters");
                break;
            case 1:
// J012_4001_0201
                setTitle(strMax(255));
                subTitle.setText("the title consists of more than 16 characters");
                break;
            case 2:
// J012_4002_0101
                setTitle("");
                subTitle.setText("the title is 0 byte");
                break;
// J012_4004_0101
            case 3:
                setTitle(null);
                subTitle.setText("the title is null");
                break;
            }
        }

        if ( menu1Index == 1 ) {
            testButton1 = new Button("test 1");
            testButton2 = new Button("test 2");

            add(testButton1);
            add(testButton2);
            
            setComponentListener(new ComponentListener() {
                public void componentAction(Component aComponent, int aType, int aParam) {
// J012_4001_0102
                    if ( aType == ComponentListener.BUTTON_PRESSED ) {
                        if ( aComponent == testButton1 ) {
                            getColorMax();
                            setBackground(maxColor);
                        } else if ( aComponent == testButton2 ) {
                            getColorMax();
                            setBackground(0);
                        }
                    }
                }
            });
        }

        if ( menu1Index == 2 ) {

            switch (menu2Index) {
            /* testing of listener Null setting */
            case 0:
                subTitle.setText("Component listener is null");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                testButton1 = new Button("test");
                add(testButton1);

                setComponentListener(new ComponentListener() {
                    public void componentAction(Component aComponent, int aType, int aParam) {
                        if ( aType == ComponentListener.BUTTON_PRESSED ) {
                            showMsg("NG:the listener is displayed as null setting");
                        }
                    }
                });
// J012_4004_0102
                setComponentListener(null);

                break;
            case 1:
                subTitle.setText("SoftKey listener is null");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                keyListenerPrev = new Button("back");
                keyListenerEnd = new Button("exit");
                add(keyListenerPrev);
                add(keyListenerEnd);

                setSoftLabel(Frame.SOFT_KEY_1, "tes1");
                setSoftLabel(Frame.SOFT_KEY_2, "tes2");

                setSoftKeyListener(this);
                setKeyListener(new KeyListener() {
                    public void keyPressed(Panel aPanel, int aKey) {
                    }
                    public void keyReleased(Panel aPanel, int aKey) {
                        if ( aKey == Frame.SOFT_KEY_1 
                            || aKey == Frame.SOFT_KEY_2
                            ) {
                            showMsg("NG:the listener operated in null setting");
                        }
                    }
                });
// J012_4004_0103
                setSoftKeyListener(null);

                setComponentListener(this);
                setComponentListener(new ComponentListener() {
                    public void componentAction(Component aComponent, int aType, int aParam) {
                        /* setting of the return button and finish button(the alternative to the usual softkey action) */
                        if ( aComponent == keyListenerPrev 
                            && aType == ComponentListener.BUTTON_PRESSED) {
                            Display.setCurrent(previousFrame);
                        }
                        if ( aComponent == keyListenerEnd 
                            && aType == ComponentListener.BUTTON_PRESSED) {
                            IApplication.getCurrentApp().terminate();
                        }
                    }
                });
                break;

            case 2:
                subTitle.setText("Key listener is null");
                setKeyListener(new KeyListener() {
                    public void keyPressed(Panel aPanel, int aKey) {
                    }
                    public void keyReleased(Panel aPanel, int aKey) {
                        if ( aKey == Display.KEY_1 
                            || aKey == Display.KEY_2
                            || aKey == Display.KEY_3
                            || aKey == Display.KEY_4
                            || aKey == Display.KEY_5
                            || aKey == Display.KEY_6
                            || aKey == Display.KEY_7
                            || aKey == Display.KEY_8
                            || aKey == Display.KEY_9
                        ) {
                            showMsg("NG:the listener is displayed as null setting");
                        }
                    }
                });
// J012_4004_0104
                setKeyListener(null);
                break;
            }
        }
    }

    /**
     * create longest String
     * @param  maxStringValue string length which is created
     */
    String strMax(int maxStringValue) {
        int i;
        int j = 0;
        maxString = "";
        for ( i = 0; i < maxStringValue; i++ ) {
            if ( j == 10 ) {
                j = 0;
            }
            maxString = maxString + j;
            j++;
        }
        maxString = maxString;
        return maxString;
    }

    /**
     * the method which get the maximum color value of cell phone
     */
    void getColorMax() {
        int color0;
        int color255;

        color0 = Graphics.getColorOfRGB(0,0,0);
        color255 = Graphics.getColorOfRGB(255,255,255);

        if ( color0 >= color255 ) {
            maxColor = color0;
        } else {
            maxColor = color255;
        }
    }

    /**
     * display message dialog
     * @param  aMsg dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {
    }

    /**
     * terminate the application when the softkey1 is released
     * shift to the previous screen in case of softkey2
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {
    }
}
