/**
 * J012_4601_0101
 * MainPanel
 *
 * UIException class boundary test
 *
 * $Id: J012_4601_0101.java,v 1.1 2001/11/30 04:48:47 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * UIException class boundary test main class
 * @extends IApplication
 */
public class J012_4601_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * UIException class boundary test main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.non-prescribed maximum",
        "2.the argument is its minimum value",
        "3.non-prescribed minimum",
        "4.the argument is -1",
        "5.the argument is null"
    };
    String[][] subItems = {
        {
            "1.status=MaxInt",
            "2.status=MaxInt,msg",
            "3.msg=1024byte",
        },
        {
            "1.status=0",
            "2.status=0,msg"
        },
        {
            "1.msg=0byte"
        },
        {
            "1.status=-1",
            "2.status=-1,msg"
        },
        {
            "1.msg=null"
        }
    };

    Label   classLabel       = new Label("UIException boundary test");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    ListBox menuList2        = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");
    int     maxInt           = 0x7FFFFFFF;

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        menuList2.setItems(subItems[0]);
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(menuList2);
        execButton.setSize(getWidth(),execButton.getHeight());
        add(execButton);


        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
            /* sub menu setting */
            menuList2.setItems(subItems[menuList.getSelectedIndex()]);
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            switch( menuList.getSelectedIndex() ) {
                case 0:
                    /* maximum parameter within the prescribed */
                    test1();
                    break;
                case 1:
                    /* parameter minimum */
                    test2();
                    break;
                case 2:
                    /* minimum parameter out of the prescribed */
                    test3();
                    break;
                case 3:
                    /* behavior in case of the parameter -1 */
                    test4();
                    break;
                case 4:
                    /* behavior in case of the parameter null */
                    test5();
                    break;
            }
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }


    /**
     * behavior in case of the maximum parameter out of the prescribed
     */
    public void test1() {
        int idx = menuList2.getSelectedIndex();
        UIException uie;

        /* execute each testing */
        switch( idx ) {
            case 0:
                // J012_4601_0301
                uie = new UIException(maxInt);
                if( uie.getStatus() == maxInt ) {
                    showDialog("OK");
                } else {
                    showDialog("NG:status=" + uie.getStatus());
                }
                break;
            case 1:
                // J012_4601_0302
                uie = new UIException(maxInt,"my message");
                if( uie.getStatus() == maxInt ) {
                    showDialog("OK");
                } else {
                    showDialog("NG:status=" + uie.getStatus());
                }
                break;
            case 2:
                // J012_4601_0303
                String msg = new String("");
                for( int i=0; i<102; i++ ) {
                    msg += "1024byte  ";
                }
                msg += " END";
                if( msg.length() != 1024 ) {
                    showDialog("NG:msg.length=" + msg.length());
                    return;
                }
                uie = new UIException(1,msg);
                if( uie.getMessage().compareTo(msg) == 0 ) {
                    showDialog("OK");
                } else {
                    showDialog("NG:msg=" + uie.getMessage());
                }
                break;
        }
    }


    /**
     * behavior in case of the minimum parameter
     */
    public void test2() {
        int idx = menuList2.getSelectedIndex();
        UIException uie;

        /* execute each testing */
        switch( idx ) {
            case 0:
                // J012_4602_0101
                uie = new UIException(0);
                if( uie.getStatus() == 0 ) {
                    showDialog("OK");
                } else {
                    showDialog("NG:status=" + uie.getStatus());
                }
                break;
            case 1:
                // J012_4602_0102
                uie = new UIException(0,"my message");
                if( uie.getStatus() == 0 ) {
                    showDialog("OK");
                } else {
                    showDialog("NG:status=" + uie.getStatus());
                }
                break;
        }
    }


    /**
     * behavior in case of the minimum out of the prescribed
     */
    public void test3() {
        int idx = menuList2.getSelectedIndex();
        UIException uie;

        /* execute each testing */
        switch( idx ) {
            case 0:
                // J012_4602_0301
                uie = new UIException(1,"");
                if( uie.getMessage().compareTo("") == 0 ) {
                    showDialog("OK");
                } else {
                    showDialog("NG:msg=" + uie.getMessage());
                }
                break;
        }
    }


    /**
     * behavior in case of the parameter -1
     */
    public void test4() {
        UIException uie;

        /* execute each testing */
        switch( menuList2.getSelectedIndex() ) {
            case 0:
                // J012_4603_0101
                uie = new UIException(-1);
                if( uie.getStatus() == -1 ) {
                    showDialog("OK");
                } else {
                    showDialog("NG:status=" + uie.getStatus());
                }
                break;
            case 1:
                // J012_4603_0102
                uie = new UIException(-1,"my message");
                if( uie.getStatus() == -1 ) {
                    showDialog("OK");
                } else {
                    showDialog("NG:status=" + uie.getStatus());
                }
                break;
        }
    }


    /**
     * behavior in case of the parameter null
     */
    public void test5() {
        UIException uie;

        /* execute each testing */
        switch( menuList2.getSelectedIndex() ) {
            case 0:
                // J012_4604_0101
                uie = new UIException(1,null);
                if( uie.getMessage() == null ) {
                    showDialog("OK");
                } else {
                    showDialog("NG:msg=" + uie.getMessage());
                }
                break;
        }
    }
}
