/**
 * J012_5101_0101
 * MainPanel
 *
 * Timer class behavior checking (boundary test)
 *
 * $Id: J012_5101_0101.java,v 1.1 2001/12/02 04:38:40 hoshi Exp $
 */
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Timer class behavior checking main class
 * @extends IApplication
 */
public class J012_5101_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * Timer class behavior checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    private final static int    MAX_INTEGER   = 0x7FFFFFFF;
    private final static int    REVERSE_VALUE = -1;

    String[] menuListItem = {
        "0 check the behavior when an argument is the maximum size",
        "1 check the behavior when an argument is the minimum size",
        "2 check the behavior when the argument is null"
    };

    String[] subListItemMax = {
        "setTime"
    };

    String[] subListItemMin = {
        "0 setTime 1",
        "1 setTime 2"
    };

    String[] subListItemNull = {
        "setListener"
    };

    Label   classLabel = new Label("Timer");
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    ListBox subList    = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");
    TextBox resultText = new TextBox("", 20, 1, TextBox.DISPLAY_ANY);

    Timer timer;
    int timerCounter = 0;
    boolean bFlag = false;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    void showMainPanel() {

        /* setting of the display item */
        menuList.setItems(menuListItem);
        subList.setItems(subListItemMax);
        setTitle("API class boundary route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(subList);
        add(execButton);
        add(resultText);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of softkey pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * @param anIndex the value of softkey released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the selection of menu list is changed */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {

            changeSubList(menuList.getSelectedIndex());

            if (bFlag) {
                timer.dispose();
                timerCounter = 0;
                bFlag = false;
            }
            resultText.setText("");
        }

        /* when the selection of menu list is changed */
        if (aComponent == subList
            && aType == ComponentListener.SELECTION_CHANGED) {

            if (bFlag) {
                timer.dispose();
                timerCounter = 0;
                bFlag = false;
            }
            resultText.setText("");
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            if (bFlag) {
                timer.dispose();
                timerCounter = 0;
                bFlag = false;
            }
            resultText.setText("");

            switch (menuList.getSelectedIndex()) {
            case 0:
                confirmMaxArg();
                break;
            case 1:
                confirmMinArg(subList.getSelectedIndex());
                break;
            case 2:
                confirmNullArg();
                break;
            default:
                break;
            }
        }
    }

    /**
     * change the sublist item display by the selection of menu list
     * @param aSelectedMenuIndex the selected value of menu list
     */
    void changeSubList(int aSelectedMenuIndex) {

        switch (aSelectedMenuIndex) {
        case 0:
            subList.setItems(subListItemMax);
            break;
        case 1:
            subList.setItems(subListItemMin);
            break;
        case 2:
            subList.setItems(subListItemNull);
            break;
        default:
            break;
        }
    }

    /**
     * checking behavior of the maximum value of parameter
     */
    void confirmMaxArg() {

        // J012_5101_0101
        try {
            timer = new Timer();
            timer.setTime(MAX_INTEGER);
            timer.setRepeat(true);
            timer.setListener(
                new TimerListener() {
                    public void timerExpired(Timer t) {
                        if (t == timer) {
                            resultText.setText("Timer :" + timerCounter++);
                        }
                    }
                }
            );
            timer.start();
            bFlag = true;
        } catch (Exception e) {
            showDialog("NG:" + e.toString());
        }
    }

    /**
     * checking behavior of the minimum value of parameter
     * @param aSelectedSubIndex the selected value of the sublist
     */
    void confirmMinArg(int aSelectedSubIndex) {

        switch (aSelectedSubIndex) {
        case 0:
            // J012_5102_0101
            // J012_5102_0301
            try {
                timer = new Timer();
                timer.setTime(0);
                timer.setRepeat(true);
                timer.setListener(
                    new TimerListener() {
                        public void timerExpired(Timer t) {
                            if (t == timer) {
                                resultText.setText("Timer :" + timerCounter++);
                            }
                        }
                    }
                );
                timer.start();
                bFlag = true;
            } catch (Exception e) {
                showDialog("NG:" + e.toString());
            }
            break;
        case 1:
            // J012_5102_0201
            try {
                timer = new Timer();
                timer.setTime(-1);
                timer.setRepeat(true);
                timer.start();
                bFlag = true;
                showDialog("NG: enable IllegalArgument setting");
            } catch (IllegalArgumentException iae) {
                if (iae.getMessage().compareTo("Time is negative") == 0) {
                    showDialog("OK");
                } else {
                    showDialog("NG:IllegalArgumentException["
                        + iae.getMessage() + "]");
                }
            } catch (Exception e) {
                showDialog("NG:" + e.toString());
            }
            break;
        default:
            break;
        }
    }

    /**
     * behavior checking in case of parameter Null
     * @param aSelectedSubIndex the selected value of the sublist
     */
    void confirmNullArg() {

        // J012_0203_0101
        try {
            timer = new Timer();
            timer.setListener(null);
            timer.setRepeat(true);
            timer.start();
            bFlag = true;
            resultText.setText("OK");
        } catch (Exception e) {
            showDialog("NG:" + e.toString());
        }
    }

    /**
     * display the dialog in case of Exception catch
     * @param aMessage display message
     */
    void showDialog(String aMessage) {
        Dialog d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aMessage);
        d.show();
    }
}
