/**
 * J013_0301_0101
 *
 * HttpConnection repeat testing
 *
 * $Id: J013_0301_0101.java,v 1.1 2002/01/07 07:30:14 lan Exp $
 */

import java.io.*;
import java.util.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * HttpConnection repeat testing main class
 * @extends IApplication
 */
public class J013_0301_0101 extends IApplication {
    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * HttpConnection repeat testing main screen
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener {
        String[] menulist = {
            "1.close",
            "2.connect",
            "3.getDate",
            "4.getEncoding",
            "5.getExpiration",
            "6.getHeaderField",
            "7.getLastModified",
            "8.getLength",
            "9.getResponseCode",
            "10.getResponseMessage",
            "11.getType",
            "12.getURL",
            "13.openInputStream",
            "14.openOutputStream",
            "15.setIfModifiedSince",
            "16.setRequestMethod",
            "17.setRequestProperty"
        };

        Label title;
        ListBox menu;
        Button exe;

        HttpConnection  con = null;
        InputStream     is = null;
        OutputStream    os = null;
        String          filename = "J013_0301_0101.jam";
        String          url = getSourceURL() + filename;
        int             MaxLoop = 100;
        long            maxLong = 0x7FFFFFFFFFFFFFFFL;

        /**
         * constructor of MainPanel class
         */
        MainPanel() {
            /* create a component */
            setTitle("API class repeatability test");
            title=new Label("HttpConnection");
            title.setSize(getWidth(),title.getHeight());
            add(title);
            menu=new ListBox(ListBox.CHOICE);
            menu.setItems(menulist);
            add(menu);
            exe = new Button("execute");
            add(exe);

            /* setting of the listener */
            setSoftKeyListener(this);
            setSoftLabel(Frame.SOFT_KEY_1, "exit");
            setComponentListener(this);
        }

        /**
         * dialog display method
         * @param   aText chalacter sequence which is displaied
         */
        public void showDialog(String aText) {
            Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
            d.setText(aText);
            d.show();
        }

        /**
         * terminate the application when softkey is pushed
         * @param anIndex Index of the softkey
         */
        public void softKeyPressed(int anIndex) {
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * do nothing when a softkey1 is released
         * @param anIndex Index of the softkey
         */
        public void softKeyReleased(int anIndex) {
        }

        /**
         * get the event on a component
         * @param aComponent The component on which an event occurs
         * @param aType Type of an event.
         * @param aParam Parameter of an event
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* when  the exsecution button is pushed */
            if (aComponent == exe && aType == ComponentListener.BUTTON_PRESSED) {
                /* test the menu which is choiced */
                test();
            }
        }

        /**
         * HttpConnection repeat testing
         */
        public void test() {
            int     i;
            String  s, s1;
            long    d, d1;
            int     n, n1;

            switch( menu.getSelectedIndex() ) {
                // J013_0301_0101
                case 0:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            con.close();
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_0201
                case 1:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    RuntimeException re0 = null;
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            con.connect();
                            if( i > 0 ) {
                                showDialog("NG: no Exception (i=" + i + ")");
                                break;
                            }
                        } catch ( RuntimeException re ) {
                            if( i == 0 ) {
                                showDialog("NG0:RuntimeException" + re.getMessage());
                                break;
                            }
                            re0 = re;
                        } catch (Exception e ) {
                            showDialog(e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop && re0 != null ) {
                        showDialog("NG:RuntimeException:" + re0.getMessage());
                    }
                    break;
                // J013_0301_0301
                case 2:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        d = con.getDate();
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            d1 = con.getDate();
                            if( d1 != d ) {
                                showDialog("NG:d=" + d + " d(" + i + ")=" + d1);
                                break;
                            }
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_0401
                case 3:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        s = con.getEncoding();
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            s1 = con.getEncoding();
                            if( s1==null ) {
                                if( s==null ) {
                                    continue;
                                } else {
                                    showDialog("NG:s=" + s + " s(" + i + ")="
                                            + s1);
                                    break;
                                }
                            }
                            if( s1.compareTo(s) != 0 ) {
                                showDialog("NG:s=" + s + " s(" + i + ")="
                                            + s1);
                                break;
                            }
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_0501
                case 4:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        d = con.getExpiration();
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            d1 = con.getExpiration();
                            if( d1 != d ) {
                                showDialog("NG:d=" + d + " d(" + i + ")=" + d1);
                                break;
                            }
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_0601
                case 5:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        s = con.getHeaderField("Content-Type");
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            s1 = con.getHeaderField("Content-Type");
                            if( s1.compareTo(s) != 0 ) {
                                showDialog("NG:header=" + s + " header(" + i + ")="
                                            + s1);
                                break;
                            }
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_0701
                case 6:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        d = con.getLastModified();
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            d1 = con.getLastModified();
                            if( d1 != d ) {
                                showDialog("NG:d=" + d + " d(" + i + ")=" + d1);
                                break;
                            }
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_0801
                case 7:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        d = con.getLength();
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            d1 = con.getLength();
                            if( d1 != d ) {
                                showDialog("NG:d=" + d + " d(" + i + ")=" + d1);
                                break;
                            }
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_0901
                case 8:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        n = con.getResponseCode();
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            n1 = con.getResponseCode();
                            if( n1 != n ) {
                                showDialog("NG:n=" + n + " n(" + i + ")=" + n1);
                                break;
                            }
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_1001
                case 9:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        s = con.getResponseMessage();
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            s1 = con.getResponseMessage();
                            if( s1.compareTo(s) != 0 ) {
                                showDialog("NG:s=" + s + " s(" + i + ")="
                                            + s1);
                                break;
                            }
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_1101
                case 10:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                        s = con.getType();
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            s1 = con.getType();
                            if( s1.compareTo(s) != 0 ) {
                                showDialog("NG:s=" + s + " s(" + i + ")="
                                            + s1);
                                break;
                            }
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_1201
                case 11:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            s1 = con.getURL();
                            if( s1.compareTo(url) != 0 ) {
                                showDialog("NG:url=" + url + " url(" + i + ")="
                                            + s1);
                                break;
                            }
                        } catch (Exception e ) {
                            showDialog("NG:"+ e.toString());
                            break;
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    if( i == MaxLoop ) {
                        showDialog("OK");
                    }
                    break;
                // J013_0301_1301
                case 12:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                        con.connect();
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    InputStream[] is1 = new InputStream[MaxLoop];
                    n = 0;
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            is1[i] = con.openInputStream();
                            n++;
                        } catch (Exception e ) {
                            break;
                        }
                    }
                    for( i=0; i<n; i++ ) {
                        if( is1[i] != null ) {
                            try {
                                is1[i].close();
                            } catch( Exception e ) {}
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    showDialog("InputStream:open:" + n);
                    break;
                // J013_0301_1401
                case 13:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.WRITE, true);
                        con.setRequestMethod(HttpConnection.POST);
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    OutputStream[] os1 = new OutputStream[MaxLoop];
                    n = 0;
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            os1[i] = con.openOutputStream();
                            n++;
                        } catch (Exception e ) {
                            break;
                        }
                    }
                    for( i=0; i<n; i++ ) {
                        if( os1[i] != null ) {
                            try {
                                os1[i].close();
                            } catch( Exception e ) {}
                        }
                    }
                    try {
                        con.close();
                    } catch( Exception e ) {}
                    showDialog("OutputStream:open:" + n);
                    break;
                // J013_0301_1501
                case 14:
                    Calendar ca = Calendar.getInstance();
                    Date da = ca.getTime();
                    d = da.getTime();
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        d1 = 1000*60*i;
                        try {
                            if( i == MaxLoop-1 ) {
                                con.setIfModifiedSince(0);
                            } else {
                                con.setIfModifiedSince(d-d1);
                            }
                        } catch( Exception e ) {
                            showDialog("NG2:" + e.toString());
                            return;
                        }
                    }
                    try {
                        con.connect();
                        int status = con.getResponseCode();
                        String modified = con.getHeaderField("Last-Modified");
                        con.close();
                        if( status != 200 ) {
                            showDialog("NG" + status + ":Last-Modified:" + modified);
                        } else {
                            showDialog("OK" + status + ":Last-Modified:" + modified);
                        }
                    } catch (Exception e ) {
                        showDialog("NG:"+ +d+e.toString()+":"+e.getMessage());
                    }
                    break;
                // J013_0301_1601
                case 15:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    for( i=0; i<MaxLoop; i++ ) {
                        try {
                            if( i == MaxLoop-1 ) {
                                con.setRequestMethod(HttpConnection.GET);
                            } else {
                                if( (i/2)*2 == i ) {
                                    con.setRequestMethod(HttpConnection.HEAD);
                                } else {
                                    con.setRequestMethod(HttpConnection.POST);
                                }
                            }
                        } catch( IllegalArgumentException iae ) {
                        } catch( Exception e ) {
                            showDialog("NG2:" + e.toString());
                            return;
                        }
                    }
                    try {
                        con.connect();
                        int status = con.getResponseCode();
                        con.close();
                        if( status != 200 ) {
                            showDialog("NG:status=" + status );
                        } else {
                            showDialog("OK");
                        }
                    } catch (Exception e ) {
                        showDialog("NG:"+ e.toString());
                    }
                    break;
                // J013_0301_1701
                case 16:
                    try {
                        con=(HttpConnection) Connector.open(url,
                                            Connector.READ, true);
                        con.setRequestMethod(HttpConnection.GET);
                    } catch (Exception e ) {
                        showDialog("NG1:"+ e.toString());
                        break;
                    }
                    ca = Calendar.getInstance();
                    String value = new String("");;
                    switch( ca.get(Calendar.DAY_OF_WEEK) ) {
                    case Calendar.MONDAY:
                        value += "Mon";
                        break;
                    case Calendar.TUESDAY:
                        value += "Tue";
                        break;
                    case Calendar.WEDNESDAY:
                        value += "Wed";
                        break;
                    case Calendar.THURSDAY:
                        value += "Thu";
                        break;
                    case Calendar.FRIDAY:
                        value += "Fri";
                        break;
                    case Calendar.SATURDAY:
                        value += "Sat";
                        break;
                    case Calendar.SUNDAY:
                        value += "Sun";
                        break;
                    default:
                        value += "Sun";
                        break;
                    }
                    value += ", " + ca.get(Calendar.DAY_OF_MONTH);
                    switch( ca.get(Calendar.MONTH) ) {
                    case Calendar.JANUARY:
                        value += " Jan";
                        break;
                    case Calendar.FEBRUARY:
                        value += " Feb";
                        break;
                    case Calendar.MARCH:
                        value += " Mar";
                        break;
                    case Calendar.APRIL:
                        value += " Apr";
                        break;
                    case Calendar.MAY:
                        value += " May";
                        break;
                    case Calendar.JUNE:
                        value += " Jun";
                        break;
                    case Calendar.JULY:
                        value += " Jul";
                        break;
                    case Calendar.AUGUST:
                        value += " Aug";
                        break;
                    case Calendar.SEPTEMBER:
                        value += " Sep";
                        break;
                    case Calendar.OCTOBER:
                        value += " Oct";
                        break;
                    case Calendar.NOVEMBER:
                        value += " Nov";
                        break;
                    case Calendar.DECEMBER:
                        value += " Dec";
                        break;
                    default:
                        value += " Jan";
                        break;
                    }
                    value += " " + ca.get(Calendar.YEAR);
                    String v = new String("");
                    for( i=0; i<MaxLoop; i++ ) {
                        if( i == MaxLoop-1 ) {
                            v = "Mon,26 Nov 2001 01:01:01 GMT";
                        } else {
                            v = value + " " + (23-i/5) + ":01:01 GMT";
                        }
                        try {
                            con.setRequestProperty("If-Modified-Since",v);
                        } catch( Exception e ) {
                            showDialog("NG2:" + e.toString());
                        }
                    }
                    try {
                        con.connect();
                        int status = con.getResponseCode();
                        String modified = con.getHeaderField("Last-Modified");
                        con.close();
                        if( status != 200 ) {
                            showDialog("NG" + status + ":Last-Modified:" + modified);
                        } else {
                            showDialog("OK" + status + ":Last-Modified:" + modified);
                        }
                    } catch (Exception e ) {
                        showDialog("NG:"+ e.toString());
                    }
                    break;
            }
        }
    }
}
