/** 
 * J013_1101_0101
 * MainPanel
 * 
 * AudioPresenter class behavior checking (repeatability)
 * 
 * $Id: J013_1101_0101.java,v 1.3 2002/05/02 05:37:55 torikatu Exp $
 */

import com.nttdocomo.io.* ;
import com.nttdocomo.ui.* ;

/** 
 * AudioPresenter class action check main class
 * @extends IApplication
 */
public class J013_1101_0101 extends IApplication{
    
    /** 
     * starting method for I-appli
     */
    public void start(){
        Display.setCurrent(new MainPanel());
    }
}

/** 
 * AudioPresenter class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements MediaListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener,MediaListener{
    String[] menuListItem = {
        "1.getAudioPresenter()",
        "2.setSound()",
        "3.setData()",
        "4.MediaResource getMediaResource()",
        "5.play()",
        "6.stop()",
// 2002/08/30 Doja1.5        "7.setAttribute()",
        "8.setMediaListener()"
// 2002/07/25 Doja1.5	  "9.setSyncExent()",	
// 2002/07/25 Doja1.5     "10.getCurrentTime()",
// 2002/07/25 Doja1.5     "11.play(int time)",
// 2002/07/25 Doja1.5     "12.pause()",
// 2002/07/25 Doja1.5     "13.restart()"
    };
    
    Frame subFrame ;
    Label classLabel = new Label("AudioPresenter");
    ListBox menuList = new ListBox(ListBox.CHOICE);
    TextBox resultBox =new TextBox("",20,2,TextBox.DISPLAY_ANY);
    Button execButton = new Button("execute");
    Button stopButton = new Button("stop");
    AudioPresenter ap = null;
    
    /** 
     * constructer of the MainPanel
     */
    public MainPanel(){
        try{
            /* display the MainPanel */
            showMainPanel();
        }catch(Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }
    }
    
    /** 
     * display the main panel
     */
    void showMainPanel(){
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class repeatability test");
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
    
        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);
        add(stopButton);
        add(resultBox);
    
        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }
    
    /** 
     *do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex){}
    
    /** 
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex){
        /* terminate the application when softkey1 is released */
        if(anIndex == Frame.SOFT_KEY_1){
            IApplication.getCurrentApp().terminate();
        }
        
    }

    /** 
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Event type
     * @param aParam  parameter of the event
     */
    public void componentAction(Component aComponent,int aType,int aParam){
        /* processing when the list choice is changed */
        if(aComponent == menuList && aType == ComponentListener.SELECTION_CHANGED){
            resultBox.setText("");
        }
        int index = menuList.getSelectedIndex();
        /* processing when the execution button is pushed */
        if(aComponent == execButton && aType == ComponentListener.BUTTON_PRESSED){
            test();
        }
        
        /* processing when the stop button is pressed */
        if(aComponent == stopButton && aType == ComponentListener.BUTTON_PRESSED){
            ap.stop();
        }
        
    }
        
    /** 
     * create the test method
     * each method when the excecution button is pushed
     */
    public void test(){
        /* takes the figure when choosing from the list box. */
        int index = menuList.getSelectedIndex();
        switch (index) {
            //J013_1101_0101
            case 0:
                for(int i=0;i<=100;i++){
                    try{
                        ap = null;
                        ap = AudioPresenter.getAudioPresenter();
                        if(ap != null){
                            resultBox.setText("OK : " +i+"times");
                        }else{
                            resultBox.setText("NG");
                            break;
                        }
                    }catch(Exception anException){
                        resultBox.setText("NG : " +i+"th time :"+anException.toString());
                        break;
                    }
                }
                break;
                
            //J013_1101_0201
            case 1:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
                    ms.use();
                    for(int i=0;i<=100;i++){
                        ap.setSound(ms);
                        if(i<100){
                            resultBox.setText(i+"times");
                        }else if(i == 100){
                            resultBox.setText("OK : "+i+"times");
                            break;
                        }
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                    break;
                }
                break;
                
            //J013_1101_0301
            case 2:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaData md = MediaManager.getData("resource:///MFi1-1.mld");
                    md.use();
                    for(int i=0;i<=100;i++){
                        ap.setData(md);
                        if(i<100){
                            resultBox.setText(i+"times");
                        }else if(i == 100){
                            resultBox.setText("OK : "+i+"times");
                        }
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                    break;
                }
                break;
                
            //J013_1101_0401
            case 3:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
                    ms.use();
                    ap.setSound(ms);
                    for(int i=0;i<=100;i++){
                        if(i<100){
                            MediaSound s = (MediaSound)ap.getMediaResource();
                            if(ms == s){
                                resultBox.setText(i+"th time");
                            }else{
                                resultBox.setText("NG");
                                break;
                            }
                        }else if(i == 100){
                            MediaSound s = (MediaSound)ap.getMediaResource();
                            if(ms == s){
                                resultBox.setText("OK : "+i+"th time");
                            }else{
                                resultBox.setText("NG");
                                break;
                            }
                        }
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                    break;
                }
                break;
                
            //J013_1101_0501
            case 4:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
                    ms.use();
                    ap.setSound(ms);
                    for(int i=0;i<=100;i++){
                        if(i<100){
                            ap.play();
                            resultBox.setText(i+"th time");
                        }else if(i == 100){
                            ap.play();
                            resultBox.setText("OK : "+i+"th time");
                        }
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                    break;
                }
                break;
                
            //J013_1101_0601
            case 5:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
                    ms.use();
                    ap.setSound(ms);
                    ap.play();
                    for(int i=0;i<=100;i++){
                        if(i<100){
                            ap.stop();
                            resultBox.setText(i+"th time");
                        }else if(i == 100){
                            ap.stop();
                            resultBox.setText("OK : "+i+"th time");
                        }
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : "+anException.toString());
                    break;
                }
                break;
                
            //J013_1101_0701
// 2002/08/30 Doja1.5            case 6:
// 2002/08/30 Doja1.5                try{
// 2002/08/30 Doja1.5                    for(int i=0;i<=100;i++){
// 2002/08/30 Doja1.5                        ap = AudioPresenter.getAudioPresenter();
// 2002/08/30 Doja1.5                        MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
// 2002/08/30 Doja1.5                        ms.use();
// 2002/08/30 Doja1.5                        ap.setSound(ms);
// 2002/08/30 Doja1.5                        if(i<100){
// 2002/08/30 Doja1.5                            ap.setAttribute(AudioPresenter.AUDIO_PLAYING,1);
// 2002/08/30 Doja1.5                            resultBox.setText(i+"");
// 2002/08/30 Doja1.5                        }else if(i == 100){
// 2002/08/30 Doja1.5                            ap.setAttribute(AudioPresenter.AUDIO_PLAYING,1);
// 2002/08/30 Doja1.5                            resultBox.setText("OK : "+i+"");
// 2002/08/30 Doja1.5                        }
// 2002/08/30 Doja1.5                    }
// 2002/08/30 Doja1.5                }catch(Exception anException){
// 2002/08/30 Doja1.5                    resultBox.setText("NG : "+anException.toString());
// 2002/08/30 Doja1.5                    break;
// 2002/08/30 Doja1.5                }
// 2002/08/30 Doja1.5                break;
                
            //J013_1101_0801
// 2002/08/30 Doja1.5            case 7:
            case 6:
                try{
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
                    ms.use();
                    ap.setSound(ms);
                    for(int i = 0;i<=100;i++){
                        if(i<100){
                            ap.setMediaListener(this);
                            resultBox.setText(i+"th time");
                        }else if(i == 100){
                            ap.setMediaListener(this);
                            resultBox.setText("OK : "+i+"th time");
                        }
                    }
                }catch(Exception anException){
                    resultBox.setText("NG : " +anException.toString());
                    break;
                }
                break;
                
//2002/07/25 Doja1.5            //J013_1101_0901
//2002/07/25 Doja1.5            case 8: 
//2002/07/25 Doja1.5              try{
//2002/07/25 Doja1.5                   ap = AudioPresenter.getAudioPresenter();
//2002/07/25 Doja1.5                   MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
//2002/07/25 Doja1.5                   ms.use();
//2002/07/25 Doja1.5                   ap.setSound(ms);
//2002/07/25 Doja1.5                   for(int i = 0;i<=100;i++){
//2002/07/25 Doja1.5                       if(i<100){
//2002/07/25 Doja1.5                           ap.setSyncEvent(AudioPresenter.AUDIO_SYNC,4);
//2002/07/25 Doja1.6                           resultBox.setText(i+"");
//2002/07/25 Doja1.5                       }else if(i == 100){
//2002/07/25 Doja1.5                           ap.setSyncEvent(AudioPresenter.AUDIO_SYNC,4);
//2002/07/25 Doja1.6                           resultBox.setText("OK : "+i+"");
//2002/07/25 Doja1.5                       }
//2002/07/25 Doja1.5                   }
//2002/07/25 Doja1.5               }catch(Exception anException){
//2002/07/25 Doja1.5                   resultBox.setText("NG : " +anException.toString());
//2002/07/25 Doja1.5                   break;
//2002/07/25 Doja1.5               }
//2002/07/25 Doja1.5               break;
                
//2002/07/25 Doja1.5            //J013_1101_1001
//2002/07/25 Doja1.5           case 9:
//2002/07/25 Doja1.5               try{
//2002/07/25 Doja1.5                   ap = AudioPresenter.getAudioPresenter();
//2002/07/25 Doja1.5                   MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
//2002/07/25 Doja1.5                   ms.use();
//2002/07/25 Doja1.5                   ap.setSound(ms);
//2002/07/25 Doja1.5                   ap.play();
//2002/07/25 Doja1.5                  for(int i=0;i<=100;i++){
//2002/07/25 Doja1.5                       if(i<100){
//2002/07/25 Doja1.5                           int msint = ap.getCurrentTime();
//2002/07/25 Doja1.6                           resultBox.setText(i+":"+msint+"ms");
//2002/07/25 Doja1.5                       }else if(i==100){
//2002/07/25 Doja1.5                           int msint = ap.getCurrentTime();
//2002/07/25 Doja1.6                            resultBox.setText("OK : "+i+":"+msint+"ms");
//2002/07/25 Doja1.5                        }
//2002/07/25 Doja1.5                    }
//2002/07/25 Doja1.5               }catch(Exception anException){
//2002/07/25 Doja1.5                   resultBox.setText("NG : " +anException.toString());
//2002/07/25 Doja1.5                    break;
//2002/07/25 Doja1.5                }
//2002/07/25 Doja1.5                break;
            
//2002/07/25 Doja1.5            //J013_1101_1101
//2002/07/25 Doja1.5            case 10:
//2002/07/25 Doja1.5                try{
//2002/07/25 Doja1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 Doja1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
//2002/07/25 Doja1.5                    ms.use();
//2002/07/25 Doja1.5                    ap.setSound(ms);
//2002/07/25 Doja1.5                   for(int i=0;i<=100;i++){
//2002/07/25 Doja1.5                        if(i<100){
//2002/07/25 Doja1.5                            ap.play(10000);
//2002/07/25 Doja1.6                            resultBox.setText(i+"");
//2002/07/25 Doja1.5                        }else if(i == 100){
//2002/07/25 Doja1.5                            ap.play(10000);
//2002/07/25 Doja1.6                            resultBox.setText("OK : "+i+"");
//2002/07/25 Doja1.5                        }
//2002/07/25 Doja1.5                    }
//2002/07/25 Doja1.5               }catch(Exception anException){
//2002/07/25 Doja1.5                    resultBox.setText("NG : " +anException.toString());
//2002/07/25 Doja1.5                    break;
//2002/07/25 Doja1.5                }
//2002/07/25 Doja1.5                break;
                
//2002/07/25 Doja1.5            //J013_1101_1201
//2002/07/25 Doja1.5            case 11:
//2002/07/25 Doja1.5                try{
//2002/07/25 Doja1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 Doja1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
//2002/07/25 Doja1.5                    ms.use();
//2002/07/25 Doja1.5                    ap.setSound(ms);
//2002/07/25 Doja1.5                    ap.play(10000);
//2002/07/25 Doja1.5                    for(int i=0;i<=100;i++){
//2002/07/25 Doja1.5                        if(i<100){
//2002/07/25 Doja1.5                            ap.pause();
//2002/07/25 Doja1.6                            resultBox.setText(i+"");
//2002/07/25 Doja1.5                       }else if(i==100){
//2002/07/25 Doja1.5                            ap.pause();
//2002/07/25 Doja1.6                            resultBox.setText("OK : "+i+"");
//2002/07/25 Doja1.5                        }
//2002/07/25 Doja1.5                    }
//2002/07/25 Doja1.5                }catch(Exception anException){
//2002/07/25 Doja1.5                    resultBox.setText("NG : " +anException.toString());
//2002/07/25 Doja1.5                   break;
//2002/07/25 Doja1.5                }
//2002/07/25 Doja1.5                break;
            
//2002/07/25 Doja1.5            //J013_1101_1301
//2002/07/25 Doja1.5            case 12:
//2002/07/25 Doja1.5                try{
//2002/07/25 Doja1.5                    ap = AudioPresenter.getAudioPresenter();
//2002/07/25 Doja1.5                    MediaSound ms = MediaManager.getSound("resource:///MFi1-1.mld");
//2002/07/25 Doja1.5                    ms.use();
//2002/07/25 Doja1.5                    ap.setSound(ms);
//2002/07/25 Doja1.5                    ap.play(10000);
//2002/07/25 Doja1.5                   ap.pause();
//2002/07/25 Doja1.5                    for(int i=0;i<=100;i++){
//2002/07/25 Doja1.5                        if(i<100){
//2002/07/25 Doja1.5                            ap.restart();
//2002/07/25 Doja1.6                            resultBox.setText(i+"");
//2002/07/25 Doja1.5                       }else if(i == 100){
//2002/07/25 Doja1.5                            ap.restart();
//2002/07/25 Doja1.6                            resultBox.setText("OK : "+i+"");
//2002/07/25 Doja1.5                        }
//2002/07/25 Doja1.5                   }
//2002/07/25 Doja1.5                }catch(Exception anException){
//2002/07/25 Doja1.5                    resultBox.setText("NG : " +anException.toString());
//2002/07/25 Doja1.5                    break;
//2002/07/25 Doja1.5                }
//2002/07/25 Doja1.5                break;
                
            default:
                break;
        }
    }
    
    /**
     * mediaAction behavior of AudioPresenter
     * @param source pass the media presenter
     * @param aType event type
     * @param aParam event parameter
     */
    public void mediaAction(MediaPresenter source,int aType,int aParam){}
}
