/**
 * J013_1201_0101
 * MainPanel
 *
 * Button class repeatability test
 *
 * $Id: J013_1201_0101.java,v 1.1 2001/12/29 02:01:04 ohkoshi Exp $
 */

import com.nttdocomo.ui.*;

/**
 * Button class repeatability test main class
 * @extends IApplication
 */
public class J013_1201_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * Button class repeatability test main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.setEnabled",
        "2.requestFocus",
        "3.setLabel",
        "4.getHeight",
        "5.getWidth",
        "6.getX",
        "7.getY",
        "8.setBackground",
        "9.setForeground",
        "10.setLocation(x)",
        "11.setLocation(y)",
        "12.setSize(w)",
        "13.setSize(h)",
        "14.setVisible(t)",
        "15.setVisible(f)"
    };

    Label        classLabel       = new Label("Button");
    ListBox      menuList         = new ListBox(ListBox.CHOICE);
    Button       execButton       = new Button("execute");
    Button testButton = new Button("button");
    int          sH;
    int          sW;
    int          aH;
    int          aW;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class repeatability test");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        execButton.setSize(getWidth(),execButton.getHeight());
        add(execButton);
        add(testButton);

        /* get the size of the screen */
        sH = getHeight();
        sW = getWidth();

        /* get the component size */
        aH = testButton.getHeight();
        aW = testButton.getWidth();

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList) {
            /* testButton reset */
            testButton.setLabel("button");
            testButton.setEnabled(true);
            testButton.setVisible(true);
            testButton.setBackground(Graphics.getColorOfName(Graphics.WHITE));
            testButton.setForeground(Graphics.getColorOfName(Graphics.BLACK));

        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* execute testing */
            test();
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * repeat testing method
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        int Loop = 100;
        int i;
        int n=0;
        Image   testImage;

        /* execute each testing */
        switch( idx ) {
// J013_1201_0101
            case 0:
                for( i=0; i<Loop; i++ ) {
                    if( n==0 ){
                        testButton.setEnabled(true);
                    } else if( n==1 ){
                        testButton.setEnabled(false);
                    }
                    n = i/2;
                }
                break;
// J013_1201_0201
            case 1:
                for( i=0; i<Loop; i++ ) {
                    testButton.requestFocus();
                }
                break;
// J013_1201_0301
            case 2:
                for( i=0; i<Loop; i++ ) {
                    testButton.setLabel(String.valueOf(i+1)+"times");
                }
                break;
// J013_1201_0401
            case 3:
                int h0 = testButton.getHeight();
                for( i=0; i<Loop; i++ ) {
                    int h = testButton.getHeight();
                    if( h != h0 ) {
                        showDialog("NG:getHeight=" + h + " h0=" + h0);
                        break;
                    }
                }
                if( i == Loop ) {
                    showDialog("OK");
                }
                break;
// J013_1201_0501
            case 4:
                int w0 = testButton.getWidth();
                for( i=0; i<Loop; i++ ) {
                    int w = testButton.getWidth();
                    if( w != w0 ) {
                        showDialog("NG:getWidth=" + w + " w0=" + w0);
                        break;
                    }
                }
                if( i == Loop ) {
                    showDialog("OK");
                }
                break;
// J013_1201_0601
            case 5:
                int x0 = testButton.getX();
                for( i=0; i<Loop; i++ ) {
                    int x = testButton.getX();
                    if( x != x0 ) {
                        showDialog("NG:getX=" + x + " x0=" + x0);
                        break;
                    }
                }
                if( i == Loop ) {
                    showDialog("OK");
                }
                break;
// J013_1201_0701
            case 6:
                int y0 = testButton.getY();
                for( i=0; i<Loop; i++ ) {
                    int y = testButton.getY();
                    if( y != y0 ) {
                        showDialog("NG:getY=" + y + " y0=" + y0);
                        break;
                    }
                }
                if( i == Loop ) {
                    showDialog("OK");
                }
                break;
// J013_1201_0801
            case 7:
                for( i=0; i<Loop; i++ ) {
                    int c;
                    if( i == Loop-1 ) {
                        c = Graphics.getColorOfName(Graphics.YELLOW);
                    } else {
                        c = Graphics.getColorOfRGB(i,i,i);
                    }
                    testButton.setBackground(c);
                }
                break;
// J013_1201_0901
            case 8:
                for( i=0; i<Loop; i++ ) {
                    int c;
                    if( i == Loop-1 ) {
                        c = Graphics.getColorOfName(Graphics.RED);
                    } else {
                        c = Graphics.getColorOfRGB(i,i,i);
                    }
                    testButton.setForeground(c);
                }
                break;
// J013_1201_1001
            case 9:
                setLayoutManager(null);
                //int currentX = testButton.getX();
                for( i=0; i<Loop; i++ ) {
                    testButton.setLocation(Loop-i,testButton.getY());
                }
                //if(i == Loop){
                    showDialog("setLocation(X):loop count 100 OK");
                    //testButton.setLocation(currentX,testButton.getY());
                //}
                break;
// J013_1201_1002
            case 10:
                setLayoutManager(null);
                int currentY = testButton.getY();
                int th = 2*testButton.getHeight();
                for( i=0; i<Loop; i++ ) {
                    testButton.setLocation(testButton.getX(),sH-th-Loop+i);
                }
                if(i == Loop){
                    testButton.setLocation(testButton.getX(),currentY);
                    showDialog("setLocation(Y):loop count 100 OK");
                }
                break;
// J013_1201_1101
            case 11:
                Display.setCurrent(new NextPanel1((Frame) this));
                break;
// J013_1201_1102
            case 12:
                Display.setCurrent(new NextPanel2((Frame) this));
                break;
// J013_1201_1201
            case 13:
                for( i=0; i<Loop; i++ ) {
                    if( n == 0 ) {
                        testButton.setVisible(false);
                    } else if( n == 1){
                        testButton.setVisible(true);
                    }
                n = i/2;
                }
                if( i == Loop){
                    showDialog("setVisible(true):loop count 100 OK");
                }
                break;
// J013_1201_1202
            case 14:
                for( i=0; i<Loop; i++ ) {
                    if( n == 0 ) {
                        testButton.setVisible(true);
                    } else if( n == 1){
                        testButton.setVisible(false);
                    }
                n = i/2;
                }
                if( i == Loop){
                    showDialog("setVisible(false):loop count 100 OK");
                }
                break;
        }
    }
}

/**
 * Button creation checking class1
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel1 extends Panel implements SoftKeyListener,ComponentListener{
    Label        classLabel       = new Label("Button");
    Button       execButton       = new Button("execute");
    Button testButton = new Button("button button button button button button");
    Frame        previousFrame;
    int          aH;
    int          aW;

    /**
     * constructer of NextPanel1 class
     * @param aFrame MainPanel object
     */
    public NextPanel1(Frame aFrame) {

        previousFrame = aFrame;

        /* setting of the display item */
        setTitle("API class repeatability test");
        setSoftLabel(SOFT_KEY_1, "exit");
        setSoftLabel(SOFT_KEY_2, "back");

        /* adding each component on the display */
        add(classLabel);
        execButton.setSize(getWidth(),execButton.getHeight());
        add(execButton);
        add(testButton);

        /* get the component size */
        aH = testButton.getHeight();
        aW = testButton.getWidth();

        testButton.setSize(3,aH);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        int Loop = 100;
        int i;

        /* when the menu is choiced */
        if (aComponent == execButton) {
// J013_1201_1101
            for( i=0; i<Loop; i++ ) {
                testButton.setSize(2+i,aH);
            }
            if( i == Loop ){
                showDialog("setSize(X):loop count 100 OK");
            }
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param aSoftKey Index of the key
     */
    public void softKeyPressed(int anIndex) {}
    
    /**
     * return to the MainPanel screen when the softkey is released
     * @param aSoftKey Index of the key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }else if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Button creation checking class2
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel2 extends Panel implements SoftKeyListener,ComponentListener{
    Label        classLabel       = new Label("Button");
    Button       execButton       = new Button("execute");
    Button testButton = new Button("button button button button button button");
    Frame        previousFrame;
    int          aH;
    int          aW;

    /**
     * constructer of NextPanel1 class
     * @param aFrame MainPanel object
     */
    public NextPanel2(Frame aFrame) {

        previousFrame = aFrame;

        /* setting of the display item */
        setTitle("API class repeatability test");
        setSoftLabel(SOFT_KEY_1, "exit");
        setSoftLabel(SOFT_KEY_2, "back");

        /* adding each component on the display */
        add(classLabel);
        execButton.setSize(getWidth(),execButton.getHeight());
        add(execButton);
        add(testButton);

        /* get the component size */
        aH = testButton.getHeight();
        aW = testButton.getWidth();

        testButton.setSize(aW,2);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        int Loop = 100;
        int i;

        /* when the menu is choiced */
        if (aComponent == execButton) {
// J013_1201_1102
            for( i=0; i<Loop; i++ ) {
                testButton.setSize(aW,3+i);
            }
            if( i == Loop ){
                showDialog("setSize(Y):loop count 100 OK");
            }
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param aSoftKey Index of the key
     */
    public void softKeyPressed(int anIndex) {}
    
    /**
     * return to the MainPanel screen when the softkey is released
     * @param aSoftKey Index of the key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }else if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

