/**
 * J013_1301_0101
 * 
 * MainPanel
 * 
 * Canvas class behavior checking (repeatability)
 * 
 * $ID:$
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;

/**
 * Canvas class action check main class
 * @IApplication
 */
public class J013_1301_0101 extends IApplication{
    /**
     * i-Appli starting method
     */
    public void start(){
        Display.setCurrent(new MainPanel());
    }
}

/**
 * MainPanel class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    String[] menuListItem = {
        "1.getGraphics()",
        "2.paint(Graphics g)",
        "3.repaint()",
        "4.repaint(int x,int y,int width,int height)",
        "5.processEvent(int type,int param)",
        "6.getKeypadState()",
        "7.getWidth()",
        "8.getHeight()",
        "9.setBackground(int c)",
        "10.setSoftLabel()"
    };
    
    Label classLabel = new Label("Canvas");
    ListBox menuList = new ListBox(ListBox.CHOICE);
    Button execButton = new Button("execute");
    Graphics g ;
    
    /**
     * Constructor of MainPanel class
     */
    public MainPanel(){
        try{
            /* display of the main panel */
            showMainPanel();
        }catch(Exception anException){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"error");
        }
    }
    
    void showMainPanel(){
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class repeatability test");
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        
        /* add on each component */
        add(classLabel);
        add(menuList);
        add(execButton);
        
        
        
        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }
    
    /**
     * do nothing when the softkey is pressed
     */
    public void softKeyPressed(int anIndex){}
    
    /**
     * define the action when softkey is released
     */
    public void softKeyReleased(int anIndex){
        IApplication.getCurrentApp().terminate();
    }
    
    /**
     * processing when the execution button is pushed
     */
    public void componentAction(Component aComponent,int aType,int aParam){
        /* processing when the list choice is changed */
        if(aComponent == menuList && aType == ComponentListener.SELECTION_CHANGED){
            
        }
        
        /* processing when the execution button is pushed */
        if(aComponent == execButton && aType == ComponentListener.BUTTON_PRESSED){
            Display.setCurrent(new MainCanvas(this,menuList.getSelectedIndex()));
        }
    }
}

/**
 * screen of MainCanvas class
 * @extends Canvas
 */
class MainCanvas extends Canvas{
    
    Frame previous;
    int flag;
    boolean boolean1 = false;
    Graphics g1;
    String s = "press the execution button";
    String st = "press number key 1";
    String st1 = "press the number button";
    String st2 = "";
//2002/09/06 Doja1.5    int count = 0;
	int count = 1;
    
    int sH = 0;
    int sW = 0;
    
    int dp3 = 10;
    
    /**
     * creating constructor
     */
    public MainCanvas(Frame prevFrame,int aFlag){
        /* get the size of the screen */
        sW = this.getWidth();
        sH = this.getHeight();
        
        previous = prevFrame;
        flag = aFlag;
        setSoftLabel(Canvas.SOFT_KEY_1,"back");
        setSoftLabel(Canvas.SOFT_KEY_2,"execute");
    }
    
    /**
     * event type
     * @param type event type
     * @param param event parameter
     */
    public void processEvent(int type,int param){
        if(type == Display.KEY_RELEASED_EVENT){
            switch(param){
                case Display.KEY_SOFT1:
                    Display.setCurrent(previous);
                    break;
                    
                case Display.KEY_SOFT2:
                    if(flag == 2){
                        for(int i = 0;i<=100;i++){
                            repaint();
                        }
                    }else if(flag == 3){
                    	int sz = Font.getDefaultFont().stringWidth("100th time:OK");
                    	System.out.println("sz:"+sz);
                        for(int i = 0;i<=100;i++){
                            repaint(dp3,0,sz,50);
                        }
                    }
                    break;
                    
                case Display.KEY_1:
                    if(flag == 4){
                        count++;
                        repaint();
                    }
            }
        }else if(type == Display.KEY_PRESSED_EVENT){
            if(Display.KEY_0 <= param && param <= Display.KEY_9 && flag == 5){
                count++;
                int state = getKeypadState();
                st1 = "";
                for(int i = 0;i<10;i++){
                    if((state & 1) ==1){
                        st1 += String.valueOf(i);
                    }
                    state = state >> 1;
                }
                repaint();
            }
        }
    }
    
    /**
     * implementation of paint() method
     */
    public void paint(Graphics g){
        switch(flag){
            //J013_1301_0101
            case 0:
                for(int i = 0;i<=100;i++){
                    g1 = getGraphics();
                    if(i<100){
                        g1.drawString("",10,20);
                    }else if(i == 100){
                        g1.drawString("OK : "+i+"th time",10,20);
                    }
                }
                break;
                
            //J013_1301_0201
            case 1:
                for(int i = 0;i<=100;i++){
                    if(i<100){
                        g.drawString("",10,20);
                    }else if(i == 100){
                        g.drawString("OK : "+i+"th time",10,20);
                    }
                }
                break;
                
            //J013_1301_0301
            case 2:
                g.clearRect(0,0,getWidth(),getHeight());
                g.drawString(s,10,20);
                s = "OK : 100th time";
                break;
                
            //J013_1301_0401
            case 3:
                g.clearRect(0,0,getWidth(),getHeight());
                g.drawString(s,dp3,40);
                dp3 = 35;
                s = "100th time:OK";
                break;
                
            //J013_1301_0501
            case 4:
                g.clearRect(0,0,getWidth(),getHeight());
                g.drawString(st,10,40);
                if(count<100){
                    st = count+"th time";
                }else if(count == 100){
                    st = "OK : "+count+"th time";
                }
                break;
                
            //J013_1301_0601
            case 5:
                g.clearRect(0,0,getWidth(),getHeight());
                g.drawString(st1+st2,10,20);
                if(count<100){
                    st2 = " : "+count+"th time";
                }else if(count == 100){
                    st2 = " : OK : "+count+"th time";
                }
                break;
                
            //J013_1301_0701
            case 6:
                int w0 = this.getWidth();
                int i =0;
                for(i=0;i<=100;i++ ){
                    int w = this.getWidth();
                    if(w != w0){
                        s = "NG : "+i+"th time";
                        g.drawString(s,30,50);
                        break;
                    }
                    if(i == 100){
                        String s = "100th time:OK";
                        g.drawString(s,30,50);
                        String s2 = "width()="+w;
                        g.drawString(s2,30,70);
                    }
                }
                break;
                
            //J013_1301_0801
            case 7:
                int h0 = this.getHeight();
                int k =0;
                for(k=0;k<=100;k++ ){
                    int h = this.getHeight();
                    if(h != h0){
                        s = "NG : "+k+"th time";
                        g.drawString(s,30,50);
                        break;
                    }
                    if(k == 100){
                        String s = "100th time:OK";
                        g.drawString(s,30,50);
                        String s2 = "height()="+h;
                        g.drawString(s2,30,70);
                    }
                }
                break;
                
            //J013_1301_0901
            case 8:
                for(i=0;i<=100;i++){
                    if(i<100){
                        this.setBackground(Graphics.getColorOfName(Graphics.YELLOW));
                        g.clearRect(0,0,getWidth(),getHeight());
                    }else if(i == 100){
                        this.setBackground(Graphics.getColorOfName(Graphics.AQUA));
                        g.clearRect(0,0,getWidth(),getHeight());
                        String s = "100th time:OK";
                        g.drawString(s,30,50); 
                    }
                }
                break;
                
            //J013_1301_1001
            case 9:
                for(i = 0;i<=100;i++){
                    this.setSoftLabel(SOFT_KEY_2," OK ");
                }
                break;
                
                default:
                break;
            
        }
    }
}