/**
 * J013_1701_0101
 * MainPanel
 *
 * Display class repeatability test
 *
 * $Id: J013_1701_0101.java,v 1.1 2001/12/29 02:01:06 ohkoshi Exp $
 */

import com.nttdocomo.ui.*;

/**
 * Display class repeatability test main class
 * @extends IApplication
 */
public class J013_1701_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * Display class repeatability test main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.getWidth",
        "2.getHeight",
        "3.isColor",
        "4.numColor",
        "5.setCurrent",
        "6.getCurrent"
    };

    Label        classLabel       = new Label("Display");
    ListBox      menuList         = new ListBox(ListBox.CHOICE);
    Button       execButton       = new Button("execute");
    int          sH;
    int          sW;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class repeatability test");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        execButton.setSize(getWidth(),execButton.getHeight());
        add(execButton);

        /* get the size of the screen */
        sH = getHeight();
        sW = getWidth();

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex index of the key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     * @param anIndex index of the key
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* execute testing */
            test();
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * repeat testing method
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        int Loop = 100;
        int i;
        int n=0;

        /* execute each testing */
        switch( idx ) {
// J013_1701_0101
            case 0:
                int w0 = Display.getWidth();
                for( i=0; i<Loop; i++ ) {
                    int w = Display.getWidth();
                    if( w != w0 ) {
                        showDialog("NG:getWidth=" + w + " w0=" + w0);
                        break;
                    }
                }
                if( i == Loop ) {
                    showDialog("OK");
                }
                break;
// J013_1701_0102
            case 1:
                int h0 = Display.getHeight();
                for( i=0; i<Loop; i++ ) {
                    int h = Display.getHeight();
                    if( h != h0 ) {
                        showDialog("NG:getHeight=" + h + " h0=" + h0);
                        break;
                    }
                }
                if( i == Loop ) {
                    showDialog("OK");
                }
                break;
// J013_1701_0103
            case 2:
                boolean flag = Display.isColor();
                for( i=0; i<Loop; i++ ) {
                    boolean color = Display.isColor();
                    if( color != flag ) {
                        showDialog("NG:isColor:"+Display.isColor());
                        break;
                    }
                }
                if( i == Loop ){
                    showDialog("OK");
                }
                break;
// J013_1701_0104
            case 3:
                int value = Display.numColors();
                for( i=0; i<Loop; i++ ) {
                    int color = Display.numColors();
                    if( color != value ) {
                        showDialog("NG:isColors:"+Display.numColors());
                        break;
                    }
                }
                if( i == Loop ){
                    showDialog("OK");
                }
                break;
// J013_1701_0105
            case 4:
                for( i=0; i<Loop; i++ ) {
                    try{
                        Display.setCurrent(new NextPanel1((Frame) this));
                    }catch (Exception anExdeption){
                        showDialog("NG:setCurrent"+i+"th time");
                    }
                }
                break;
// J013_1701_0106
            case 5:
                Frame currentFrame = Display.getCurrent();
                for( i=0; i<Loop; i++ ) {
                    try{
                        Frame testFrame = Display.getCurrent();
                    }catch (Exception anExdeption){
                        showDialog("NG:getCurrent"+i+"th time");
                    }
                }
                if( i == Loop ){
                    showDialog("OK");
                }
                break;
        }
    }
}


/**
 * Display creation checking class1
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel1 extends Panel implements SoftKeyListener{
    Label        classLabel       = new Label("if this page is visible, OK");
    Frame        previousFrame;

    /**
     * constructer of NextPanel1 class
     * @param aFrame MainPanel object
     */
    public NextPanel1(Frame aFrame) {

        previousFrame = aFrame;

        /* setting of the display item */
        setTitle("API class repeatability test");
        setSoftLabel(SOFT_KEY_1, "exit");
        setSoftLabel(SOFT_KEY_2, "back");

        /* adding each component on the display */
        add(classLabel);

        /* setting the listener */
        setSoftKeyListener(this);

    }

    /**
     * do nothing when a softkey is pushed
     * @param aSoftKey Index of the key
     */
    public void softKeyPressed(int anIndex) {}
    
    /**
     * return to the MainPanel screen when the softkey is released
     * @param aSoftKey Index of the key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }else if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}



