/**
 * J013_1901_0101
 *
 * Font class behavior checking (repeatability)
 * 
 *
 * $Id: J013_1901_0101.java,v 1.1 2001/12/29 02:00:49 horikoshi Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;


/**
 * Font class behavior checking main class
 * @extends IApplication
 */
public class J013_1901_0101 extends IApplication {

	/**
	 * starting i-Appli start()
	 */
	public void start() {
		Display.setCurrent(new MainPanel());
	}
}


/**
 * Font class behavior checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

	String[] menu1 = {
		"01 getFont",
		"02 getDefaultFont",
		"03 getAscent",
		"04 getDescent",
		"05 getHeight",
		"06 stringWidth",
		"07 getBBoxWidth",
		"08 getBBoxHeight",
		"09 getLineBreak"
	};

	Frame   nextFrame;
	Label   title	  = new Label("Font loop test");
	ListBox menu_Li	= new ListBox(ListBox.CHOICE);
	Button  execButton = new Button("execute");
	int	 firstType;

	/**
	 * MainPanel constructor(initializing)
	 */
	public MainPanel() {
		try {
			/* display of the main panel */
			showMainPanel();
		} catch (Exception e) {
			/* processing when the exception occurs */
			Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
			errDialog.setText("main panel:" + e.toString());
			errDialog.show();
		}
	}

	/**
	 * display the main panel
	 */
	void showMainPanel() {
		menu_Li.setItems(menu1);
		setTitle("API class loop test");
		setSoftLabel(Frame.SOFT_KEY_1, "exit");
		add(title);
		add(menu_Li);
		add(execButton);

		setSoftKeyListener(this);
		setComponentListener(this);
	}

	/**
	 * do nothing when a softkey is pushed
	 * @param anIndex the value of the pushed softkey 
	 */
	public void softKeyPressed(int anIndex) {}

	/**
	 * terminate the application when SOFT_KEY_1 is released
	 * @param anIndex the value of the released softkey 
	 */
	public void softKeyReleased(int anIndex) {

		/* terminate the application when SOFT_KEY_1 is released */
		if (anIndex == Frame.SOFT_KEY_1) {
			IApplication.getCurrentApp().terminate();
		}
	}

	/**
	 * process when the action other than softkey happens
	 * @param source the component on which the event occurs
	 * @param type event type
	 * @param param event parameter
	 */
	public void componentAction(Component source, int type, int param) {

		/* when the fix-key is pushed on the condition the execution button is focused */
		if (source == execButton 
			&& type == ComponentListener.BUTTON_PRESSED) {

			/* get the chosen item */
			firstType = menu_Li.getSelectedIndex();

			switch (firstType) {

				case 0:
					/* to the processing case1 without breaking */
				case 1:
					/* method check is executed on the next screen */
					try {
						nextFrame = new NextPanel(this, firstType);
					} catch (Exception e) {
						showDialog(e.toString());
					}
					/* display screen which have been set */
					Display.setCurrent(nextFrame);
					break;
				case 2:
					/* to the processing case8 without breaking */
				case 3:
					/* to the processing case8 without breaking */
				case 4:
					/* to the processing case8 without breaking */
				case 5:
					/* to the processing case8 without breaking */
				case 6:
					/* to the processing case8 without breaking */
				case 7:
					/* to the processing case8 without breaking */
				case 8:
					test();
					break;
				default:
					break;
			}
		}
	}

	/*
	 * method which display the result
	 */
	public void test() {
		Font	font;
		int	 cont=0;
		int	 num =0;
		int	 num2=0;
		String  str ="loop";
		font = Font.getDefaultFont();

//J013_1901_0301
		/* repeating getAscent */
		if (firstType == 2) {
			num = font.getAscent();
			num2 = num;
			try {
				for (cont=0; cont<100 && num2==num; cont++) {
					num2 = font.getAscent();
				}
			} catch (Exception e) {
				showDialog(e.toString()+":"+cont+"loop");
			}
//J013_1901_0401
		/* repeating getDescent */
		} else if (firstType == 3) {
			num = font.getDescent();
			num2 = num;
			try {
				for (cont=0; cont<100 && num2==num; cont++) {
					num2 = font.getDescent();
				}
			} catch (Exception e) {
				showDialog(e.toString()+":"+cont+"loop");
			}
//J013_1901_0501
		/* repeating getHeight */
		} else if (firstType == 4) {
			num = font.getHeight();
			num2 = num;
			try {
				for (cont=0; cont<100 && num2==num; cont++) {
					num2 = font.getHeight();
				}
			} catch (Exception e) {
				showDialog(e.toString()+":"+cont+"loop");
			}
//J013_1901_0601
		/* repeating stringWidth */
		} else if (firstType == 5) {
			num = font.stringWidth(str);
			num2 = num;
			try {
				for (cont=0; cont<100 && num2==num; cont++) {
					num2 = font.stringWidth(str);
				}
			} catch (Exception e) {
				showDialog(e.toString()+":"+cont+"loop");
			}
//J013_1901_0701
		/* repeating getBBoxWidth */
		} else if (firstType == 6) {
			num = font.getBBoxWidth(str);
			num2 = num;
			try {
				for (cont=0; cont<100 && num2==num; cont++) {
					num2 = font.getBBoxWidth(str);
				}
			} catch (Exception e) {
				showDialog(e.toString()+":"+cont+"loop");
			}
//J013_1901_0801
		/* repeating getBBoxHeight */
		} else if (firstType == 7) {
			num = font.getBBoxHeight(str);
			num2 = num;
			try {
				for (cont=0; cont<100 && num2==num; cont++) {
					num2 = font.getBBoxHeight(str);
				}
			} catch (Exception e) {
				showDialog(e.toString()+":"+cont+"loop");
			}
//J013_1901_0901
		/* repeating getLineBreak */
		} else if (firstType == 8) {
			int len = str.length();
			int w   = this.getWidth();
			num = font.getLineBreak(str, 0, len, w);
			num2 = num;
			try {
				for (cont=0; cont<100 && num2==num; cont++) {
					num = font.getLineBreak(str, 0, len, w);
				}
			} catch (Exception e) {
				showDialog(e.toString()+":"+cont+"loop");
			}
		}

		if (cont == 100) {
			showDialog(cont+" loop OK!:"+num);
		} else {
			showDialog(cont+" loop NG!:"+num);
		}
	}

	/**
	 * setting of the dialog box which is going to be displayed
	 * @param str the message on the dialog
	 */
	public void showDialog(String str) {
		Dialog d = new Dialog(Dialog.BUTTON_OK, "result");
		d.setText(str);
		d.show();
	}
}

/**
 * Font class method action check
 * @extends Panel
 * @implements SoftKeyListener
 */

class NextPanel extends Canvas {

	Frame	  frame;
	Font	   font;
	Font	   font2;
	String	 str = "loop";
	int		firstType;
	int		font_test;
	int		cont=0;
	int		num =0;
	int		num2=0;

	/**
	 * NextPanel constructor(inithializing)
	 * @param f  pass the screen on
	 * @param type the selected value in the listbox1
	 */
	public NextPanel(Frame f, int type) {
		frame = f;
		firstType = type;
		init();
	}

	/**
	 * initializing
	 */
	public void init() {
		setSoftLabel(Frame.SOFT_KEY_2, "back");
	}

	/**
	 * method which display the result
	 */
	public void paint(Graphics grp) {

//J013_1901_0101
		if (firstType == 0) {
			/* repeating getFont */
			/* set the font default */
			font_test = 0x00000000;
			//font = Font.getFont(font_test);
			try {
				for (cont=0; cont<100; cont++) {
					font2 = Font.getFont(font_test);
					//if (!(font.equals(font2))) {
					//	showDialog(cont+" loop NG!");
					//	break;
					//}
				}
			} catch (Exception e) {
				showDialog(e.toString()+":"+cont+"loop");
			}

			if (cont == 100) {
				showDialog(cont+" loop OK!");
			} else {
				showDialog(cont+" loop NG!");
			}

/*			grp.drawString(cont+" loop OK!", 10, 15);

			grp.lock();
			grp.setFont(font);
			grp.drawString(str, 0, 40);
			grp.setFont(font2);
			grp.drawString(str, 0, 40);
			grp.unlock(true);
*/
//J013_1901_0201
		} else if (firstType == 1) {
			/* repeating getDefaultFont */
			font = Font.getDefaultFont();

			try {
				for (cont=0; cont<100; cont++) {
					font2 = Font.getDefaultFont();
					if (!(font.equals(font2))) {
						showDialog(cont+" loop NG!");
						break;
					}
				}
			} catch (Exception e) {
				showDialog(e.toString()+":"+cont+"loop");
			}

			if (cont == 100) {
				showDialog(cont+" loop OK!");
			} else {
				showDialog(cont+" loop NG!");
			}
/*			grp.drawString(cont+" loop OK!", 10, 15);

			grp.lock();
			grp.setFont(font);
			grp.drawString(str, 0, 40);
			grp.setFont(font2);
			grp.drawString(str, 0, 40);
			grp.unlock(true);*/
		}
	}

	/**
	 * processing when the key event occurs
	 * @param type event type
	 * @param param event parameter
	 */
	public void processEvent(int type, int param){
		if (param == Display.KEY_SOFT2) {
			Display.setCurrent(frame);
		}
	}

	/**
	 * setting of the dialog box which is going to be displayed
	 * @param str the message on the dialog
	 */
	public void showDialog(String str) {
		Dialog d = new Dialog(Dialog.BUTTON_OK, "result");
		d.setText(str);
		Display.setCurrent(frame);
		d.show();
	}
}
