/**
 * J013_2101_0101
 * MainPanel
 *
 * Graphics class repeating behavior checking
 *
 * $Id: J013_2101_0101.java,v 1.1 2002/01/07 07:31:13 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Graphics class repeating behavior checking main class
 * @extends IApplication
 */
public class J013_2101_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * Graphics class repeating behavior checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    
    String[] menuItems = {
        "1.copy",
        "2.dispose",
        "3.lock-unlock",
        "4.setOrigin",
        "5.getColorOfRGB",
        "6.getColorOfName",
        "7.setColor",
        "8.setFont",
        "9.clearRect",
        "10.drawLine",
        "11.drawRect",
        "12.fillRect",
        "13.drawImage1",
//2002/08/01 DoJa1.5        "14.drawImage2",
      "15.drawPolyline1",
//2002/07/25 Doja1.5      "16.drawPolyline2",
      "17.fillPolygon1",
//2002/07/25 Doja1.5      "18.fillPolygon2",
        "19.drawString",
        "20.drawChars",
        "21.setPictoColorEnabled"
//2002/07/25 Doja1.5      "21.setPictoColorEnabled",
//2002/07/25 Doja1.5      "22.clearClip",
//2002/07/25 Doja1.5      "23.clipRect",
//2002/07/25 Doja1.5      "24.copyArea",
//2002/07/25 Doja1.5      "25.setClip"
    };

    Label   classLabel       = new Label("Graphics");
    ListBox menu             = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menu.setItems(menuItems);
        setTitle("API class loop test");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menu);
        add(execButton);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "notification");
        d.setText(aText);
        d.show();
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            Display.setCurrent(new GCanvas(this,menu.getSelectedIndex()));
        }
    }
}


/**
 * Canvs implementation class for testing
 * @extends Canvas
 */
class GCanvas extends Canvas {
    Frame   previous;
    int     idx;
    int     sH;     /* screen height */
    int     sW;     /* screen width */
    int     fH;     /* font height */
    int     fD;     /* font decendline */
    int     lH;     /* line height */
    String filename = new String("89aT-8.gif");
    Graphics g;
    MediaImage  mi;
    int     MaxLoop = 100;

    /**
     * constructor
     * @param prevFrame object of previous screen
     * @param anIndex index of the selection menu
     */
    public GCanvas(Frame prevFrame, int anIndex ) {
        previous = prevFrame;
        idx = anIndex;
        setSoftLabel(Canvas.SOFT_KEY_1, "test");
        setSoftLabel(Canvas.SOFT_KEY_2, "back");
        sH = getHeight();
        sW = getWidth();
        fH = Font.getDefaultFont().getHeight();
        fD = Font.getDefaultFont().getDescent();
        lH = fH + fD + 1;
        g = getGraphics();
    }

    /**
     * the implementation of paint() method
     */
    public void paint(Graphics g) {
    }

    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "notification");
        d.setText(aText);
        d.show();
    }

    /**
     * event receive method
     * @param aType event type
     * @param aParam Parameter of an event
     */
    public void processEvent(int type, int param) {
        /* key event */
        if (type == Display.KEY_RELEASED_EVENT) {
            /* when the return key is pushed */
            if( param == Display.KEY_SOFT2 ) {
                /* return to the main menu screen */
                Display.setCurrent(previous);
            }

            /* when the testing key is pressed */
            if( param == Display.KEY_SOFT1 ) {
                /* screen clear */
                g.lock();
                g.setColor(Graphics.getColorOfName(Graphics.WHITE));
                g.fillRect(0,0,sW,sH);
                g.setColor(Graphics.getColorOfName(Graphics.BLACK));
                g.unlock(true);
                setBackground(Graphics.getColorOfName(Graphics.WHITE));

                /* the test starting */
                test();
            }
        }
    }


    /**
     * execute repeating test
     */
    public void test() {
        int i;
        int c;

        g.setColor(Graphics.getColorOfName(Graphics.GREEN));

        switch( idx ) {
        case 0:
            // J013_2101_0101
            g.setColor(Graphics.getColorOfName(Graphics.RED));
            g.drawLine(MaxLoop,0,MaxLoop,sH/2);
            g.setColor(Graphics.getColorOfName(Graphics.GREEN));
            Graphics[] g1 = new Graphics[100];
            for( i=0; i<MaxLoop; i++ ) {
                g1[i] = g.copy();
                if( g1[i] == null ) {
                    break;
                }
                g1[i].drawLine(i,0,i,sH/2);
            }
            if( i != MaxLoop ) {
                showDialog("NG" + i );
            }
            break;
        case 1:
            // J013_2101_0201
            for( i=0; i<MaxLoop; i++ ) {
                g.dispose();
                try {
                    g.drawLine(0,0,sW,sH);
                    showDialog("NG: no Exception");
                    break;
                } catch( UIException uie ) {
                    continue;
                } catch( Exception e ) {
                    showDialog("NG" + i + ":" + e.toString());
                    break;
                }
            }
            if( i == MaxLoop ) {
                showDialog("OK");
            }
            break;
        case 2:
            // J013_2101_0301
            g.setColor(Graphics.getColorOfName(Graphics.RED));
            g.drawLine(MaxLoop,0,MaxLoop,sH/2);
            g.setColor(Graphics.getColorOfName(Graphics.GREEN));
            for( i=0; i<MaxLoop; i++ ) {
                g.lock();
                g.drawLine(i,0,i,sH/2);
            }
            // J013_2101_0401
            for( i=0; i<MaxLoop; i++ ) {
                g.unlock(false);
            }
            break;
        case 3:
            // J013_2101_0501
            for( i=0; i<MaxLoop; i++ ) {
                g.setOrigin(sW/2,sH/2);
            }
            g.drawString("point shown on the left is the origin",0,0+lH/2);
            break;
        case 4:
            // J013_2101_0601
            c = g.getColorOfRGB(125,125,125);
            for( i=0; i<MaxLoop; i++ ) {
                int c1 = g.getColorOfRGB(125,125,125);
                if( c1 != c ) {
                    showDialog("NG" + i + "c1=" + c1 + ",c=" + c);
                    break;
                }
            }
            if( i == MaxLoop ) {
                showDialog("OK");
            }
            break;
        case 5:
            // J013_2101_0701
            c = g.getColorOfName(g.BLUE);
            for( i=0; i<MaxLoop; i++ ) {
                int c1 = g.getColorOfName(g.BLUE);
                if( c1 != c ) {
                    showDialog("NG" + i + "c1=" + c1 + ",c=" + c);
                    break;
                }
            }
            if( i == MaxLoop ) {
                showDialog("OK");
            }
            break;
        case 6:
            // J013_2101_0801
            c = g.getColorOfName(g.BLUE);
            for( i=0; i<MaxLoop; i++ ) {
                g.setColor(c);
            }
            g.fillRect(sW/2-20,sH/2-20,40,40);
            break;
        case 7:
            // J013_2101_0901
            Font f = Font.getFont(Font.FACE_SYSTEM | Font.STYLE_ITALIC | Font.SIZE_LARGE);
            for( i=0; i<MaxLoop; i++ ) {
                g.setFont(f);
            }
            g.drawString("ITALIC_LARGE",1,40);
            break;
        case 8:
            // J013_2101_1001
            c = g.getColorOfName(g.BLUE);
            g.fillRect(0,0,sW,sH);
            for( i=0; i<MaxLoop; i++ ) {
                g.clearRect(sW/2-20,sH/2-20,40,40);
            }
            break;
        case 9:
            // J013_2101_1101
            for( i=0; i<MaxLoop; i++ ) {
                g.drawLine(0,0,sW,sH);
            }
            break;
        case 10:
            // J013_2101_1201
            for( i=0; i<MaxLoop; i++ ) {
                g.drawRect(sW/2-20,sH/2-20,40,40);
            }
            break;
        case 11:
            // J013_2101_1301
            for( i=0; i<MaxLoop; i++ ) {
                g.fillRect(sW/2-20,sH/2-20,40,40);
            }
            break;
        case 12:
            // J013_2101_1401
            /* with no break */
//2002/08/01 DoJa1.5        case 13:
            // J013_2101_1501
            try {
                mi = MediaManager.getImage("resource:///" + filename);
                mi.use();
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
                break;
            }
            for( i=0; i<MaxLoop; i++ ) {
//2002/08/01 DoJa1.5                if( idx == 12 ) {
                    g.drawImage(mi.getImage(),sW/2-mi.getWidth()/2,0);
//2002/08/01 DoJa1.5                } else {
//2002/08/01 DoJa1.5                    g.drawImage(mi.getImage(),sW/2-mi.getWidth()/2,0,10,0,sW,sH);
//2002/08/01 DoJa1.5                }
            }
            break;
        case 13:
//2002/07/25 Doja1.5        case 14:
            // J013_2101_1601
            /* with no break */
//2002/07/25 Doja1.5        case 15:
            // J013_2101_1701
            /* with no break */
//2002/07/25 Doja1.5        case 16:
            // J013_2101_1801
            /* with no break */
        case 14:
//2002/07/25 Doja1.5        case 17:
            // J013_2101_1901
            int[] xP = {-30,0,30,0,-30};
            int[] yP = {0,30,0,-30,0};
            int   nP = 5;
            for( i=0; i<nP; i++ ) {
                xP[i] += sW/2;
                yP[i] += sH/2;
            }
            for( i=0; i<MaxLoop; i++ ) {
                switch( idx ) {
                case 13:
//2002/07/25 Doja1.5                case 14:
                    g.drawPolyline(xP,yP,nP);
                    break;
//2002/07/25 Doja1.5               case 15:
//2002/07/25 Doja1.5                   g.drawPolyline(xP,yP,1,nP-1);
//2002/07/25 Doja1.5                    break;
//2002/07/25 Doja1.5                case 16:
                case 14:
                    g.fillPolygon(xP,yP,nP);
                    break;
//2002/07/25 Doja1.5                case 17:
//2002/07/25 Doja1.5                    g.setColor(g.getColorOfName(g.BLUE));
//2002/07/25 Doja1.5                    g.fillPolygon(xP,yP,1,nP-1);
//2002/07/25 Doja1.5                    break;
                }
            }
            break;
//2002/07/25 Doja1.5      case 18:
        case 15:
            // J013_2101_2001
            for( i=0; i<MaxLoop; i++ ) {
                g.drawString("drawString",1,lH+5);
            }
            break;
//2002/07/25 Doja1.5      case 19:
        case 16:
            // J013_2101_2101
            String str = new String("drawChars");
            char[] chr = str.toCharArray();
            for( i=0; i<MaxLoop; i++ ) {
                g.drawChars(chr,1,lH+5,0,chr.length);
            }
            break;
//2002/07/25 Doja1.5      case 20:
        case 17:
            // J013_2101_2201
            for( i=0; i<MaxLoop; i++ ) {
                g.setPictoColorEnabled(true);
            }
            char[] emoji = {0xE63E, 0xE63F, 0xE640, 0xE641};
            g.drawChars(emoji,0,lH+5,0,emoji.length);
            break;
//2002/07/25 Doja1.5        case 21:
//2002/07/25 Doja1.5            // J013_2101_2301
//2002/07/25 Doja1.5            g.setClip(0,0,sW/2,sH/2);
//2002/07/25 Doja1.5            g.fillRect(0,0,sW,sH);
//2002/07/25 Doja1.5            for( i=0; i<MaxLoop; i++ ) {
//2002/07/25 Doja1.5                g.clearClip();
//2002/07/25 Doja1.5            }
//2002/07/25 Doja1.5            g.setColor(g.getColorOfName(g.BLUE));
//2002/07/25 Doja1.5            g.fillRect(0,0,sW,sH);
//2002/07/25 Doja1.5            break;
//2002/07/25 Doja1.5        case 22:
//2002/07/25 Doja1.5            // J013_2101_2401
//2002/07/25 Doja1.5            for( i=0; i<MaxLoop; i++ ) {
//2002/07/25 Doja1.5                g.clipRect(sW/2-20,sH/2-20,40,40);
//2002/07/25 Doja1.5            }
//2002/07/25 Doja1.5            g.setColor(g.getColorOfName(g.BLUE));
//2002/07/25 Doja1.5            g.fillRect(0,0,sW,sH);
//2002/07/25 Doja1.5            break;
//2002/07/25 Doja1.5        case 23:
//2002/07/25 Doja1.5            // J013_2101_2501
//2002/07/25 Doja1.5            g.fillRect(0,0,sW/2,sH/2);
//2002/07/25 Doja1.5            for( i=0; i<MaxLoop; i++ ) {
//2002/07/25 Doja1.5                g.copyArea(0,0,sW/2,sH/2,sW/2,sH/2);
//2002/07/25 Doja1.5            }
//2002/07/25 Doja1.5            break;
//2002/07/25 Doja1.5        case 24:
//2002/07/25 Doja1.5            // J013_2101_2601
//2002/07/25 Doja1.5            for( i=0; i<MaxLoop; i++ ) {
//2002/07/25 Doja1.5                g.setClip(sW/2-20,sH/2-20,40,40);
//2002/07/25 Doja1.5            }
//2002/07/25 Doja1.5            g.fillRect(0,0,sW,sH);
//2002/07/25 Doja1.5            break;
       }
    }
}
