/**
 * J013_2301_0101
 *
 * Iapplication class behavior checking (repeat)
 *
 * $Id: J013_2301_0101.java,v 1.1 2001/12/29 00:43:25 takanao Exp $
 */

import com.nttdocomo.ui.*;

/**
 * IApplication class action check main class
 * @extends IApplication
 */

public class J013_2301_0101 extends IApplication {

    /* counter of the number of the behavior in case of resuming or launching */
    int resumeCounter = 0;
    /* URL parameter in case of launch */
    String[] launchArgs = null;

    MainPanel testPanel = new MainPanel();

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }

    /**
     * method called by JAM when restarting
     * launch the brouser every time it is called till 100 times restart
     */
    public void resume() {
        resumeCounter ++;
        testPanel.displayResume(resumeCounter);
        if (resumeCounter != 100) {
//2002/07/26 DoJa1.5            launch(IApplication.LAUNCH_BROWSER, launchArgs);
			getCurrentApp();	//2002/07/26 DoJa1.5
        }
    }

    /**
     * setter of launchArgs
     * @param aArgs URL which is called in brouser
     */
    public void setArgs(String[] aArgs) {
        launchArgs = aArgs;
    }
}

/**
 * Iapplication class repeating behavior checking menu screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* application menu item */
    private String[] menuItems = {
        "00 getArgs()",
//2002/07/26 DoJa1.5        "01 getParameter()",
        "02 getSourceURL()",
//2002/07/26 DoJa1.5        "03 getLaunchType()",
//2002/07/26 DoJa1.5        "04 getCurrentApp()",
        "04 getCurrentApp()"	//2002/07/26 DoJa1.5
//2002/07/26 DoJa1.5        "05 launch&resume",
    };

    /* GUI parts definition */
    ListBox menuListBox = new ListBox(ListBox.CHOICE);
    Button processButton = new Button("execute");
    TextBox resultBox = new TextBox(null, 16, 4, TextBox.DISPLAY_ANY);

    /* panel creation */
    public MainPanel() {

        /* GUI setting */
        menuListBox.setItems(menuItems);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("Iapplication loop test");

        /* GUI position */
        add(menuListBox);
        add(processButton);
        add(resultBox);

        /* setting of the listener */
        this.setComponentListener(this);
        this.setSoftKeyListener(this);
    }

    /**
     * component event handler
     * @param aComponent event occurring component
     * @param aParam occurring event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        
        /* when execution button is presed,if the testing is selected, test starts */
        if (ComponentListener.BUTTON_PRESSED == aType && aComponent == processButton) {
            int selectedIndex = menuListBox.getSelectedIndex();
            if (selectedIndex >= 0) {
                try {
                    doTest(selectedIndex);
                } catch (Exception e) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error information");
                    errDialog.setText("an exception occurred out of the test"+e.getClass().getName());
                    errDialog.show();
                }
            }
        }
    }

    /**
     * softkey pressing handler
     * @param aKey pressed key
     */
    public void softKeyPressed(int aKey) {}

    /**
     * softkey released handler
     * @param aKey pressed key
     */
    public void softKeyReleased(int aKey) {
        /* terminate the application when the softkey1 is released */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * add the text to resultBox
     * @param str adding text
     */
    private void addResult(String str) {
        resultBox.setText(resultBox.getText()+str);
    }

    /**
     * checking if the arrays of the string character is same as the other
     * @return true if the array of the string character is equalotherwise false
     * @param src character array1 for comparison
     * @param dst character array2 for comparison
     */
    private boolean matchArgs(String[] src, String[] dst) {

        /* never equal when string length is different */
        if (src.length != dst.length) {
            return false;
        } else {
            /* comparing all the string in the array */
            for (int i=0; i<src.length; i++) {
                if (src[i].compareTo(dst[i]) != 0) {
                    return false;
                }
            }
        }
        return true;
    }

    /**
     * meke the launched type character string
     * @return launched typereturn UNKNOWN when launched type of the parameter doesn't exist
     * @param typeNumber the value of Iapplication.getLaunchType()
     */
//2002/07/26 DoJa1.5    private String getTypeName(int typeNumber) {

//2002/07/26 DoJa1.5        String retValue = "UNKNOWN";
//2002/07/26 DoJa1.5        switch (typeNumber) {
//2002/07/26 DoJa1.5        case IApplication.LAUNCHED_AFTER_DOWNLOAD:
//2002/07/26 DoJa1.5            retValue = "LAUNCHED_AFTER_DOWNLOAD";
//2002/07/26 DoJa1.5            break;
//2002/07/26 DoJa1.5        case IApplication.LAUNCHED_AS_CONCIERGE:
//2002/07/26 DoJa1.5            retValue = "LAUNCHED_AS_CONCIERGE";
//2002/07/26 DoJa1.5            break;
//2002/07/26 DoJa1.5        case IApplication.LAUNCHED_FROM_BROWSER:
//2002/07/26 DoJa1.5            retValue = "LAUNCHED_FROM_BROWSER";
//2002/07/26 DoJa1.5            break;
//2002/07/26 DoJa1.5        case IApplication.LAUNCHED_FROM_EXT:
//2002/07/26 DoJa1.5            retValue = "LAUNCHED_FROM_EXT";
//2002/07/26 DoJa1.5            break;
//2002/07/26 DoJa1.5        case IApplication.LAUNCHED_FROM_MAILER:
//2002/07/26 DoJa1.5            retValue = "LAUNCHED_FROM_MAILER";
//2002/07/26 DoJa1.5            break;
//2002/07/26 DoJa1.5        case IApplication.LAUNCHED_FROM_MENU:
//2002/07/26 DoJa1.5            retValue = "LAUNCHED_FROM_MENU";
//2002/07/26 DoJa1.5            break;
//2002/07/26 DoJa1.5        case IApplication.LAUNCHED_FROM_TIMER:
//2002/07/26 DoJa1.5            retValue = "LAUNCHED_FROM_TIMER";
//2002/07/26 DoJa1.5            break;
//2002/07/26 DoJa1.5        default:
//2002/07/26 DoJa1.5            break;
//2002/07/26 DoJa1.5        }
//2002/07/26 DoJa1.5        return retValue;
//2002/07/26 DoJa1.5    }

    /**
     * display how many times it is resumed when resuming 
     * @param aResume how many times it is resumed
     */
    public void displayResume(int aResume) {
        resultBox.setText("05 resume"+aResume+"th time");
        if (aResume == 100) {
            resultBox.setText("05 OK: resume 100 times");
        }
    }

    /**
     * testing method
     * @param selectedTest execute the prescribed testing
     * @throws Exception thrown when the unexpected exception occurs
     */
    private void doTest(int selectedTest) throws Exception {

        IApplication appli = null;

        switch (selectedTest) {
        case 0:
            // J013_2301_0101
            String[][] testArgs = new String[100][];
            appli = IApplication.getCurrentApp();
            
            /* getArgs 100 times */
            for (int i=0; i<100; i++) {
                testArgs[i] = appli.getArgs();
            }

            /* compare the execution result */
            String[] prevArgs = testArgs[0];
            for (int i=0; i<100; i++) {
                if (! (matchArgs(prevArgs, testArgs[i])) ) {
                    resultBox.setText("00 NG: "+(i+1)+"th time");
                    addResult("\nfailed");
                    for (int j=0; j<prevArgs.length; j++) {
                        addResult("\n"+prevArgs[j]+":"+testArgs[i][j]);
                    }
                    return;
                }
            }
            resultBox.setText("00 OK");
            break;
//2002/07/26 DoJa1.5        case 1:
            // J013_2301_0201
//2002/07/26 DoJa1.5            String[] testParam = new String[100];
//2002/07/26 DoJa1.5            appli = IApplication.getCurrentApp();
        
            /* getParameter 100 times */
//2002/07/26 DoJa1.5            for (int i=0; i<100; i++) {
//2002/07/26 DoJa1.5                testParam[i] = appli.getParameter("test");
//2002/07/26 DoJa1.5            }
//2002/07/26 DoJa1.5            String prevParam = testParam[0];
//2002/07/26 DoJa1.5            if (prevParam == null) {
                /* when the parameter can't be gotten(in case of the application more than two times launching) */
//2002/07/26 DoJa1.5                for (int i=0; i<100; i++) {
//2002/07/26 DoJa1.5                    if (prevParam != testParam[i]) {
//2002/07/26 DoJa1.5                        resultBox.setText("01 NG: "+(i+2)+"");
//2002/07/26 DoJa1.6                        addResult("\n");
//2002/07/26 DoJa1.5                        return;
//2002/07/26 DoJa1.5                    }
//2002/07/26 DoJa1.5                }
//2002/07/26 DoJa1.5                resultBox.setText("OK(null)");
//2002/07/26 DoJa1.5            } else {
                /* when the parameter is gotten */
//2002/07/26 DoJa1.5                for (int i=0; i<100; i++) {
//2002/07/26 DoJa1.5                    if (prevParam.compareTo(testParam[i]) != 0) {
//2002/07/26 DoJa1.5                        resultBox.setText("01 NG: "+(i+2)+"");
//2002/07/26 DoJa1.6                        addResult("\n");
//2002/07/26 DoJa1.5                        addResult("\n"+prevParam+":"+testParam[i]);
//2002/07/26 DoJa1.5                        return;
//2002/07/26 DoJa1.5                    }
//2002/07/26 DoJa1.5                }
//2002/07/26 DoJa1.5                resultBox.setText("01 OK");
//2002/07/26 DoJa1.5            }
//2002/07/26 DoJa1.5            break;

//2002/07/26 DoJa1.5        case 2:
        case 1:		//2002/07/26 DoJa1.5
            // J013_2301_0301
            String[] testUrl = new String[100];
            appli = IApplication.getCurrentApp();

            /* getSourceURL 100 times */
            for (int i=0; i<100; i++) {
                testUrl[i] = appli.getSourceURL();
            }

            /* compare the execution result */
            String prevUrl = testUrl[0];
            for (int i=0; i<100; i++) {
                if (prevUrl.compareTo(testUrl[i]) != 0) {
                    resultBox.setText("02 NG: "+(i+1)+"th time");
                    addResult("\nfailed");
                    addResult("\n"+prevUrl+":"+testUrl[i]);
                    return;
                }
            }
            resultBox.setText("02 OK");
            break;

//2002/07/26 DoJa1.5        case 3:
            // J013_2301_0401
//2002/07/26 DoJa1.5            int[] testType = new int[100];
//2002/07/26 DoJa1.5            appli = IApplication.getCurrentApp();

            /* getLaunchType 100 times */
//2002/07/26 DoJa1.5            for (int i=0; i<100; i++) {
//2002/07/26 DoJa1.5                testType[i] = appli.getLaunchType();
//2002/07/26 DoJa1.5            }

            /* compare the execution result */
//2002/07/26 DoJa1.5            int prevType = testType[0];
//2002/07/26 DoJa1.5            for (int i=0; i<100; i++) {
//2002/07/26 DoJa1.5                if (prevType != testType[i]) {
//2002/07/26 DoJa1.5                    resultBox.setText("03 NG: "+(i+2)+"");
//2002/07/26 DoJa1.6                    addResult("\n");
//2002/07/26 DoJa1.5                    addResult("\n"+getTypeName(prevType)+":"+getTypeName(testType[i]));
//2002/07/26 DoJa1.5                    return;
//2002/07/26 DoJa1.5                }
//2002/07/26 DoJa1.5            }
//2002/07/26 DoJa1.5            resultBox.setText("03 OK");
//2002/07/26 DoJa1.5            break;

//2002/07/26 DoJa1.5        case 4:
        case 2:		//2002/07/26 DoJa1.5
            // J013_2301_0501
            IApplication[] testApp = new IApplication[100];

            /* getCurrentApp 100 times */
            for (int i=0; i<100; i++) {
                testApp[i] = IApplication.getCurrentApp();
            }

            /* compare the execution result */
            IApplication prevApp = testApp[0];
            for (int i=0; i<100; i++) {
                if (prevApp != testApp[0]) {
                    resultBox.setText("04 NG: "+(i+1)+"th time");
                    addResult("\nfailed");
                    return;
                }
            }
            resultBox.setText("04 OK");
            break;

//2002/07/26 DoJa1.5        case 5:
            // J013_2301_0701
            // J013_2301_0901

            /* because URL which is opened in brouser is put in the first parameter of AppParam
             * get and pass to resume testing method
             */
//2002/07/26 DoJa1.5            appli = IApplication.getCurrentApp();
//2002/07/26 DoJa1.5            String[] currentArgs = appli.getArgs();
//2002/07/26 DoJa1.5            String[] args = new String[1];
//2002/07/26 DoJa1.5            args[0] = currentArgs[0];
//2002/07/26 DoJa1.5            ((J013_2301_0101)(appli)).setArgs(args);

            /* launch the first timesfrom now on ,  called 100 times by resume */
//2002/07/26 DoJa1.5            appli.launch(IApplication.LAUNCH_BROWSER, args);
//2002/07/26 DoJa1.5            break;
//2002/07/26 DoJa1.5        default:
//2002/07/26 DoJa1.5            break;
        }
        return;
    }
}


