/**
 * J013_2601_0101
 *
 * ImageLabel class behavior checking (repeating)
 * 
 *
 * $Id: J013_2601_0101.java,v 1.1 2001/12/29 02:00:59 horikoshi Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;


/**
 * ImageLabel class repeating checking main class
 * @extends IApplication
 */
public class J013_2601_0101 extends IApplication {

    /**
     * starting i-Appli start()
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * ImageLabel class repeating checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menu1 = {
        "01 ImageLabel",
        "02 setImage",
        "03 getHeight",
        "04 getWidth",
        "05 getX",
        "06 getY",
        "07 setBackground",
        "08 setForeground",
        "09 setLocation",
        "10 setSize",
        "11 setVisible-true",
        "12 setVisible-false"
    };

    Frame   nextFrame;
    Label   title      = new Label("ImageLabel repeating");
    ListBox menu_Li    = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");
    int     firstType;

    /**
     * MainPanel constructor(initializing)
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "ERROR");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    void showMainPanel() {
        menu_Li.setItems(menu1);
        setTitle("API class loop test");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        add(title);
        add(menu_Li);
        add(execButton);

        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of the pushed softkey 
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when SOFT_KEY_1 is released
     * @param anIndex the value of the released softkey 
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when SOFT_KEY_1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * process when the action other than softkey happens
     * @param source the component on which the event occurs
     * @param type event type
     * @param param event parameter
     */
    public void componentAction(Component source, int type, int param) {

        /* when the fix-key is pushed on the condition the execution button is focused */
        if (source == execButton 
            && type == ComponentListener.BUTTON_PRESSED) {

            firstType = menu_Li.getSelectedIndex();

            /* in case of LayoutManager = OFF */
            if (firstType == 8 || 
                firstType == 4 || firstType == 5) {
                NextPanel2 np2 = new NextPanel2(this);
                Display.setCurrent(np2);
                np2.Resultinit(firstType);

            /* in case of LayoutManager = ON */
            } else {
                nextFrame = new NextPanel1(this, firstType);
                Display.setCurrent(nextFrame);
            }
        }
    }
}


/**
 * NextPanel1 class (LayoutManager=ON)
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel1 extends Panel implements SoftKeyListener {

    Frame      mainFrame;
    Frame      nextFrame;
    int        type;
    MediaImage mi;
    Image      img;
    ImageLabel il_List[] = new ImageLabel[100];
    ImageLabel il;
    TextBox    showText = new TextBox("", 20, 1, TextBox.NUMBER);

    /**
     * NextPanel class constructor(initializing)
     * @param f  pass the screen on
     * @param type listbox selected number
     */
    public NextPanel1(Frame frame, int type) {
        mainFrame = frame;
        this.type = type;
        try {
            Resultinit();
            showResult();
        } catch (Exception e) {
            showDialog("ERROR:NextFrame");
        }
    }

    /**
     * display the testing result on the screen
     */
    public void Resultinit() {
        setSoftLabel(Frame.SOFT_KEY_1, "back");
        setTitle("result");
        setSoftKeyListener(this);
    }

    /**
     * method which display the result
     */
    public void showResult() {
        int cont = 0;
        int num  = 0;
        int num2 = 0;
        int[] color_List    = new int[100];
        boolean[] bool_List = new boolean[102];

        try {
            /* get the image file from JAR */
            mi = MediaManager.getImage("resource:///niko.jpeg");
            mi.use();
        } catch (Exception e) {
            showDialog("loading the image failed.");
        }

//J013_2601_0101
        /* ImageLabel repeating */
        if (type == 0) {
            img = mi.getImage();
            try {
                for (cont=0; cont<100; cont++) {
                    il_List[cont] = new ImageLabel(img);
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }
            add(il_List[cont-1]);

//J013_2601_0201
        /* setImage repeating */
        } else if (type == 1) {
            try {
                for (cont=0; cont<100; cont++) {
                    il_List[cont] = new ImageLabel();
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }
            img = mi.getImage();
            try {
                for (cont=0; cont<100; cont++) {
                    il_List[cont].setImage(img);
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }
            add(il_List[cont-1]);

//J013_2601_0301
        /* getHeight repeating */
        } else if (type == 2) {
            img = mi.getImage();
            il = new ImageLabel(img);
            add(il);
            num = il.getHeight();
            num2 = num;
            try {
                for (cont=0; cont<100 && num2==num; cont++) {
                    num = il.getHeight();
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }


// 2002/08/19 DoJa1.5            showText.setText("Heigth="+num+"\nHeigth="+il.getHeight());
            showText.setText("Heigth="+num+" Heigth="+il.getHeight());
            add(showText);

//J013_2601_0401
        /* getWidth repeating */
        } else if (type == 3) {
            img = mi.getImage();
            il = new ImageLabel(img);
            add(il);
            num = il.getWidth();
            num2 = num;
            try {
                for (cont=0; cont<100 && num2==num; cont++) {
                    num = il.getWidth();
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }

// 2002/08/19 DoJa1.5            showText.setText("Width="+num+"\nWidth="+il.getWidth());
            showText.setText("Width="+num+" Width="+il.getWidth());
            add(showText);

//J013_2601_0701
        /* setBackground repeating */
        } else if (type == 6) {
            /* setting the value for repeating */
            for (cont=0; cont<99; cont++) {
                color_List[cont] = Graphics.getColorOfName(Graphics.GREEN);
            }
            color_List[99] = Graphics.getColorOfName(Graphics.YELLOW);

            img = mi.getImage();
            il = new ImageLabel(img);
            il.setSize(60,60);
            add(il);
            try {
                for (cont=0; cont<100; cont++) {
                    il.setBackground(color_List[cont]);
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }

//J013_2601_0801
        /* setForeground repeating */
        } else if (type == 7) {
            /* setting the value for repeating */
            for (cont=0; cont<99; cont++) {
                color_List[cont] = Graphics.getColorOfName(Graphics.GREEN);
            }
            color_List[99] = Graphics.getColorOfName(Graphics.YELLOW);

            img = mi.getImage();
            il = new ImageLabel(img);
            il.setSize(60,60);
            add(il);
            try {
                for (cont=0; cont<100; cont++) {
                    il.setForeground(color_List[cont]);
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }

//J013_2601_1101
//J013_2601_1201
        /* setSize repeating */
        } else if (type == 9) {
            il = new ImageLabel();
            int x = 0;
            int y = 0;
            il.setSize(x,y);
            add(il);
            try {
                for (cont=0,x=1,y=1; cont<100; cont++,x++,y++) {
                    il.setSize(x,y);
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }

            il.setBackground(Graphics.getColorOfName(Graphics.YELLOW));
            showText.setText("Width="+il.getWidth()+":Height="+il.getHeight());
            add(showText);

//J013_2601_1301
        /* setVisible (true at last) repeating */
        } else if (type == 10) {
            /* setting the value for repeating */
            for (cont=0; cont<100; ) {
                bool_List[cont]=false;
                bool_List[cont+1]=true;
                cont = cont+2;
            }

            img = mi.getImage();
            il = new ImageLabel(img);
            add(il);
            try {
                for (cont=0; cont<100; cont++) {
                    il.setVisible(bool_List[cont]);
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }

//J013_2601_1401
        /* setVisible (false at last) repeating */
        } else if (type == 11) {
            /* setting the value for repeating */
            for (cont=0; cont<100; ) {
                bool_List[cont]=true;
                bool_List[cont+1]=false;
                cont = cont+2;
            }

            img = mi.getImage();
            il = new ImageLabel(img);
            add(il);
            try {
                for (cont=0; cont<100; cont++) {
                    il.setVisible(bool_List[cont]);
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }
        }
        /* display in the dialog how many times loop occurs */
        if (cont == 100) {
            showDialog(cont+" loop OK!");
        } else {
            showDialog(cont+" loop NG!");
        }
    }

    /**
     * setting of the dialog box which is going to be displayed
     * @param str the message on the dialog
     */
    public void showDialog(String str) {
        Dialog d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(str);
        d.show();
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of the pushed softkey 
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * return to the previous screen when SOFT_KEY_1 is released
     * @param anIndex the value of the released softkey 
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            Display.setCurrent(mainFrame);
        }
    }
}

/**
 * NextPanel1 class (LayoutManager=ON)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel2 extends Panel implements SoftKeyListener {

    Frame      mainFrame;
    Frame      nextFrame;
    Label      title      = new Label("result");
    TextBox    showText   = new TextBox("", 20, 1, TextBox.NUMBER);
    int        execFlg = 0;
    Image      img;
    ImageLabel il;
    MediaImage mi;
    int        type;

    /**
     * NextPanelOff class constructor (initializing)
     * @param frame pass the screen
     */
    public NextPanel2(Frame frame) {
        mainFrame = frame;
    }

    /**
     * execute each setting
     * @param type listbox selected number
     */
    public void Resultinit(int type) {
        this.type = type;
        add(title);
        showResult();
        setSoftLabel(Frame.SOFT_KEY_1, "back");
        setSoftKeyListener(this);
    }

    /**
     * method which display the result
     */
    public void showResult() {
        int cont= 0;
        int x   = 0;
        int y   = 0;
        int num = 0;
        int num2= 0;

        /* set layout manager null */
        this.setLayoutManager(null);

        try {
            /* get the image file from JAR */
            mi = MediaManager.getImage("resource:///niko.jpeg");
            mi.use();
        } catch (Exception e) {
            showDialog("loading the image failed.");
        }

//J013_2601_0501
        /* getX repeating */
        if (type == 4) {
            img = mi.getImage();
            il = new ImageLabel(img);
            il.setLocation(20, 20);
            add(il);
            num = il.getX();
            num2 = num;
            try {
                for (cont=0; cont<100 && num2==num; cont++) {
                    num = il.getX();
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }

            showText.setLocation(0, 60);
            showText.setText("X="+num);
            add(showText);

//J013_2601_0601
        /* getY repeating */
        } else if (type == 5) {
            img = mi.getImage();
            il = new ImageLabel(img);
            il.setLocation(20, 20);
            add(il);
            num = il.getY();
            num2 = num;
            try {
                for (cont=0; cont<100 && num2==num; cont++) {
                    num = il.getY();
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }

            showText.setLocation(0, 60);
            showText.setText("Y="+num);
            add(showText);

//J013_2601_0901
//J013_2601_1001
        /* setLocation repeating */
        } else if (type == 8) {

            img = mi.getImage();
            il = new ImageLabel(img);
            try {
                for (cont=0,x=-99,y=-99; cont<100; cont++,x++,y++) {
                    il.setLocation(x,y);
                }
            } catch (Exception e) {
                showDialog(e.toString()+":"+cont+"loop");
            }

            add(il);
            showText.setLocation(0, 50);
            showText.setText("X="+String.valueOf(il.getX())+
                             " : y="+String.valueOf(il.getY()));
            add(showText);
        }
        if (cont == 100) {
            showDialog(cont+" loop OK!");
        } else {
            showDialog(cont+" loop NG!");
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of the pushed softkey 
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * return to the previous screen when SOFT_KEY_1 is released
     * @param anIndex the value of the released softkey 
     */
    public void softKeyReleased(int anIndex) {

        /* return to the previous screen when SOFT_KEY_1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            Display.setCurrent(mainFrame);
        }
    }

    /**
     * setting of the dialog box which is going to be displayed
     * @param str the message on the dialog
     */
    public void showDialog(String str) {
        Dialog d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(str);
        d.show();
    }
}