/**
 * J013_2801_0101
 *
 * KeyListener class behavior checking (repeatability)
 * Constant member definition check
 *
 * $Id: J013_2801_0101.java,v 1.1 2001/12/29 02:01:00 horikoshi Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;


/**
 * KeyListener class action check main class
 * @extends IApplication
 */
public class J013_2801_0101 extends IApplication {

    /**
     * starting i-Appli start()
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * KeyListener class action check main screen
 * @extends Panel
 * @implements KeyListener
 * @implements SoftKeyListener
 */
class MainPanel extends Panel implements KeyListener, SoftKeyListener {

    String[] menu = {
        "01 keyPressed",
        "02 keyReleased"
    };

    /* the max value of key is 0x1F */
    static String[] keys = new String[0x1F];

    static {
        keys[Display.KEY_0] = "0";
        keys[Display.KEY_1] = "1";
        keys[Display.KEY_2] = "2";
        keys[Display.KEY_3] = "3";
        keys[Display.KEY_4] = "4";
        keys[Display.KEY_5] = "5";
        keys[Display.KEY_6] = "6";
        keys[Display.KEY_7] = "7";
        keys[Display.KEY_8] = "8";
        keys[Display.KEY_9] = "9";
        keys[Display.KEY_ASTERISK] = "*";
        keys[Display.KEY_DOWN] = "down arrow key";
        keys[Display.KEY_LEFT] = "left arrow key";
        keys[Display.KEY_UP] = "up arrow key";
        keys[Display.KEY_RIGHT] = "right arrow key";
        keys[Display.KEY_POUND] = "#";
        keys[Display.KEY_SELECT] = "select button";
    }

    int     flg;
    Label   titel = new Label("check the KeyListener");
    Label   label = new Label("please press any button");

    /**
     * MainPanel constructor(normal route)
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            /* processing when the exception occurs */
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    void showMainPanel() {

        /* setting of the display item */
        setTitle("API class normal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(titel);
        add(label);

        /* register the key listener */
        setKeyListener(this);
        /* register the softkey listener */
        setSoftKeyListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     * @param anIndex the value of the pushed softkey 
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when SOFT_KEY_1 is released
     * @param anIndex the value of the released softkey 
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when SOFT_KEY_1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * when the key is pushed , the key is displayed
     * @param p current panel when the key is pushed
     * @param key the value of the pushed key
     */
    public void keyPressed(Panel p, int key) {
//J013_2801_0101
        label.setText(keys[key]+" pressed!");
    }

    /**
     * when the key is released, the key is displayed
     * @param p current panel when the key is released
     * @param key the value of the released key
     */
    public void keyReleased(Panel p, int key) {
//J013_2801_0201
        label.setText(keys[key]+" released!");
    }
}
