/**
 * J013_2901_0101.java
 * 
 * J013_2901_0101
 * MenuPanel
 * TestPanel
 * 
 * ListBox class behavior checking (repeating)
 * 
 * $Id: J013_2901_0101.java,v 1.1 2002/01/07 01:14:34 waka Exp $
 */

import com.nttdocomo.ui.*;

/**
 * ListBox class behavior checking main class
 * @extends IApplication
 */
public class J013_2901_0101 extends IApplication {
    /**
     * starting method for I-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * Label class repeating test menu screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {

    ListBox menuList   = null;    /* selection processing  menu */
    Button  execButton = null;    /* execution button */

    String[] menuItem = {
        "0.setAlignment",
        "1.setText",
        "2.getHeight",
        "3.getWidth",
        "4.getX",
        "5.getY",
        "6.setBackground",
        "7.setForeground",
        "8.setLocation_x",
        "9.setLocation_y",
        "10.setSize_x",
        "11.setSize_y",
        "12.setVisible_t",
        "13.setVisible_f",
    };                            /* menu item */

    /**
     * MenuPanel class constructor
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * display the main panel
     */
    public void showMainPanel() {

        setTitle("API class loop test");
        Label subTitle = new Label("Label");
        menuList       = new ListBox(ListBox.CHOICE, 14);
        execButton     = new Button("execute");
        add(subTitle);
        add(menuList);
        add(execButton);
        subTitle.setSize(getWidth(), subTitle.getHeight());
        menuList.setItems(menuItem);

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * display message dialog
     * @param  aMsg dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }


    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * terminate the application when the softkey1 is released
     * shift to the previous screen in case of softkey2
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {
        if (aAction == ComponentListener.BUTTON_PRESSED) {
            /* shift to the behavior checking Panel */
            Display.setCurrent(new TestPanel(menuList.getSelectedIndex(), this));
        }
    }
}

/**
 * Label class repeat checking screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class TestPanel extends Panel implements SoftKeyListener, ComponentListener {

    private   Frame   previousFrame  = null;      /* store the previous screen */
    private   int     menuIndex      = 0;         /* index of processing selection menu */
    private   Label   subTitle       = null;      /* sub title */
    private   Label   testLabel      = null;      /* for behavior checking */
    private   TextBox resultBox      = null;      /* for display the result */
    private   int     i              = 0;         /* for looping */
    protected int     loopCounter    = 100;       /* the times of looping */

    /**
     * TestPanel class constructor
     * @param  menuIndex index of processing selection menu
     */
    TestPanel(int aMenuIndex, Frame aFrame) {

        previousFrame = aFrame;
        menuIndex     = aMenuIndex;

        try {
            showTestPanel();
            test(menuIndex);
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * behavior checking screen
     */
    void showTestPanel() {

        setTitle("API class loop test");
        subTitle = new Label("");
        add(subTitle);
        resultBox = new TextBox("\"NG\"", getWidth(), 2, TextBox.DISPLAY_ANY);

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        setSoftLabel(Frame.SOFT_KEY_2,"back");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * action checking method
     * @param  menu1Index index of processing selection menu
     */
    void test(int aMenuIndex) {

        int value1 = 0;    /* the value before count up */
        int value2 = 0;    /* the value after count up */

        switch (aMenuIndex) {
// J013_2901_0101
        case 0:
            subTitle.setText("setAlignmentTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /*component(ex,behavior checking) setting*/
                testLabel = new Label("setAlignment:RIGHT");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));

                for (i = 1; i <= loopCounter ; i++) {

                    /* processing in case of 100th (put 2 in alignment) */
                    if (i == loopCounter) {
                        /* alignment setting */
                        testLabel.setAlignment(2);
                        return;
                    }

                    /* alignment setting */
                    testLabel.setAlignment(1);
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }

            break;
// J013_2901_0201
        case 1:
            subTitle.setText("setTextTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /*component(ex,behavior checking) setting*/
                testLabel = new Label("");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));

                for (i = 1; i <= loopCounter; i++) {

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        testLabel.setText("\"OK\":setText");
                        return;
                    }

                    /* label character string setting */
                    testLabel.setText("\"NG\"");
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }

            break;
// J013_2901_0301
        case 2:
            subTitle.setText("getHeightTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("getHeight");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);

                value1 = testLabel.getHeight();

                for (i = 1; i <= loopCounter; i++) {
                    value2 = testLabel.getHeight();

                    /* compare the value before counting up with after */
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    } else {
                        resultBox.setText("\"NG\"");
                    }
                }

            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_0401
        case 3:
            subTitle.setText("getWidthTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("getWidth");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);

                value1 = testLabel.getWidth();
                for (i = 1; i <= loopCounter; i++) {

                    /* compare the value before counting up with after */
                    value2 = testLabel.getWidth();
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    } else {
                        resultBox.setText("\"NG\"");
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_0501
        case 4:
            subTitle.setText("getXTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("getX");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);

                value1 = testLabel.getX();
                for (i = 1; i <= loopCounter; i++) {
                    value2 = testLabel.getX();

                    /* compare the value before counting up with after */
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_0601
        case 5:
            subTitle.setText("getYTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("getY");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);

                value1 = testLabel.getY();
                for (i = 1; i <= loopCounter; i++) {
                    value2 = testLabel.getY();

                    /* compare the value before counting up with after */
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_0701
        case 6:
            subTitle.setText("setBackgroundTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("setBackground");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);
                testLabel = new Label("setBackground");

                for (i = 1; i <= loopCounter ; i++) {

                    /* set the background color 255 in case of 100th loop */
                    if (i == loopCounter) {
                        testLabel.setForeground(0);
                        testLabel.setBackground(255);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to 99th (set the background color 0) */
                    testLabel.setForeground(255);
                    testLabel.setBackground(0);

                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_0801
        case 7:
            subTitle.setText("setForegroundTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("setForeground");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);
                testLabel = new Label("setForeground");

                for (i = 1; i <= loopCounter ; i++) {

                    /* put 255 in the foreground color in case of 100th loop */
                    if (i == loopCounter) {
                        testLabel.setForeground(255);
                        testLabel.setBackground(0);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the 1st to the 99th (set the foreground color 0) */
                    testLabel.setForeground(0);
                    testLabel.setBackground(255);

                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_0901
        case 8:
            setLayoutManager(null);

            subTitle.setText("setLocation_xTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            subTitle.setLocation(0,0);

            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("setLocation_x");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);
                resultBox.setLocation(0,30);

                for (i = 1; i <= loopCounter ; i++) {

                    /* 100th location setting */
                    if (i == loopCounter) {
                        testLabel.setLocation(0,15);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to the 99th (setting the location (1000,i)) */
                    testLabel.setLocation(i,1000);
                }

            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_1001
        case 9:
            setLayoutManager(null);

            subTitle.setText("setLocation_yTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            subTitle.setLocation(0,0);
            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("setLocation_y");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);
                resultBox.setLocation(0,30);

                for (i = 1; i <= loopCounter ; i++) {

                    /* 100th location setting */
                    if (i == loopCounter) {
                        testLabel.setLocation(0,15);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to the 99th (setting the location (1000,i)) */
                    testLabel.setLocation(1000,i);
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_1101
        case 10:
            setLayoutManager(null);

            subTitle.setText("setSize_xTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            subTitle.setLocation(0,0);
            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("setSize_x");
                add(testLabel);
                testLabel.setLocation(0,15);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);
                testLabel.setLocation(0,15);
                resultBox.setLocation(0,30);

                for (i = 1; i <= loopCounter ; i++) {
                    /* processing from the first to the 99th (setting the size (1000,i)) */
                    testLabel.setSize(i,1000);

                    /* 100th size setting */
                    if (i == loopCounter) {
                        testLabel.setSize(getWidth(),15);
                        resultBox.setText("\"OK\"");
                        return;
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_1201
        case 11:
            setLayoutManager(null);

            subTitle.setText("setSize_yTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            subTitle.setLocation(0,0);
            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("setSize_y");
                add(testLabel);
                testLabel.setLocation(0,15);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);
                testLabel.setLocation(0,15);
                resultBox.setLocation(0,30);

                for (i = 1; i <= loopCounter ; i++) {
                    /* processing from the first to the 99th (setting the size (1000,i)) */
                    testLabel.setSize(1000,i);

                    /* 100th size setting */
                    if (i == loopCounter) {
                        testLabel.setSize(getWidth(),15);
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_1301
        case 12:
            subTitle.setText("setVisible_tTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("setVisible_t");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {
                    /* processing from the first to the 99th (setting Visible false) */
                    testLabel.setVisible(false);

                    /* 100th size setting */
                    if (i == loopCounter) {
                        testLabel.setVisible(true);
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_2901_1401
        case 13:
            subTitle.setText("setVisible_fTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            /* repeating */
            try {
                /* component setting */
                testLabel = new Label("setVisible_f");
                add(testLabel);
                testLabel.setSize(getWidth(), subTitle.getHeight());
                testLabel.setForeground(Graphics.getColorOfName(Graphics.WHITE));
                testLabel.setBackground(Graphics.getColorOfName(Graphics.BLACK));
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {
                    /* processing from the first to the 99th (setting Visible false) */
                    testLabel.setVisible(true);

                    /* 100th size setting */
                    if (i == loopCounter) {
                        testLabel.setVisible(false);
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
        default:
            break;
        }
    }

    /**
     * display message dialog
     * @param  aMsg dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * terminate the application when the softkey1 is released
     * shift to the previous screen in case of softkey2
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {}
}
