/**
 * J013_3101_0101.java
 * 
 * J013_3101_0101
 * MenuPanel
 * TestPanel
 * 
 * ListBox class behavior checking (repeating)
 * 
 * $Id: J013_3101_0101.java,v 1.1 2002/01/07 01:14:21 waka Exp $
 */

import com.nttdocomo.ui.*;

/**
 * ListBox class behavior checking main class
 * @extends IApplication
 */
public class J013_3101_0101 extends IApplication {
    /**
     * starting method for I-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * ListBox class repeating test menu screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {

    ListBox menuList   = null;    /* selection processing  menu */
    Button  execButton = null;    /* execution button */

    String[] menuItem = {
        "0.setEnabled_t",
        "1.setEnabled_f",
        "2.requestFocus",
        "3.setItems",
        "4.append",
        "5.removeAll",
        "6.getItemCount",
        "7.getItem",
        "8.select1",
        "9.select2",
        "10.deselect1",
        "11.deselect2",
        "12.isIndexSelected",
        "13.getIndexSelected",
        "14.getHeight",
        "15.getWidth",
        "16.getX",
        "17.getY",
        "18.setBackground",
        "19.setForeground",
        "20.setLocation_x",
        "21.setLocation_y",
        "22.setSize_x",
        "23.setSize_y",
        "24.setVisible_t",
        "25.setVisible_f",
    };                            /* menu item */

    /**
     * MenuPanel class constructor
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * display the main panel
     */
    public void showMainPanel() {

        setTitle("API class loop test");
        Label subTitle = new Label("ListBox");
        menuList       = new ListBox(ListBox.CHOICE, 14);
        execButton     = new Button("execute");
        add(subTitle);
        add(menuList);
        add(execButton);
        subTitle.setSize(getWidth(), subTitle.getHeight());
        menuList.setItems(menuItem);

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * display message dialog
     * @param  aMsg dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * terminate the application when the softkey1 is released
     * shift to the previous screen in case of softkey2
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {
        if (aAction == ComponentListener.BUTTON_PRESSED) {
            /* shift to the behavior checking Panel */
            Display.setCurrent(new TestPanel(menuList.getSelectedIndex(), this));
        }
    }
}

/**
 * ListBox class repeating behavior checking screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class TestPanel extends Panel implements SoftKeyListener, ComponentListener {

    private   Frame    previousFrame  = null;      /* store the previous screen */
    private   int      menuIndex      = 0;         /* index of processing selection menu */
    private   Label    subTitle       = null;      /* sub title */
    private   ListBox  testListBox    = null;      /* for behavior checking */
    private   ListBox  testListBox2   = null;      /* for behavior checking */
    private   ListBox  testListBox3   = null;      /* for behavior checking */
    private   TextBox  resultBox      = null;      /* for display the result */
    private   Button   testButton     = null;      /* execution button */
    private   int      i              = 0;         /* for looping */
    protected int      loopCounter    = 100;       /* the times of looping */

    private   boolean  selectFlag     = false;     /*  */
    private   boolean  deselectFlag   = false;     /*  */



    /**
     * TestPanel class constructor
     * @param  menuIndex index of processing selection menu
     */
    TestPanel(int aMenuIndex, Frame aFrame) {

        previousFrame = aFrame;
        menuIndex     = aMenuIndex;

        try {
            showTestPanel();
            test(menuIndex);
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * behavior checking screen
     */
    void showTestPanel() {

        setTitle("API class loop test");
        subTitle = new Label("");
        add(subTitle);
        resultBox = new TextBox("\"NG\"", getWidth(), 2, TextBox.DISPLAY_ANY);

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        setSoftLabel(Frame.SOFT_KEY_2,"back");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * action checking method
     * @param  menu1Index index of processing selection menu
     */
    void test(int aMenuIndex) {

        int value1 = 0;    /* the value before count up */
        int value2 = 0;    /* the value after count up */
        int aRest  = 0;    /* distinguishe between the even number, the odd number. */

        switch (aMenuIndex) {
//J013_3101_0101
        case 0:
            subTitle.setText("setEnabled_tTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("setEnabled_t");
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* the even number in case of 0, the odd in case of 1 */
                    aRest = i % 2;

                    /* visible setting in case of 100th loop */
                    if (i == loopCounter) {
                        testListBox.setEnabled(true);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to the 99th (aRest=0 invisible, aRest=1 visible) */
                    if (aRest == 0) {
                        testListBox.setEnabled(false);
                    } else {
                        testListBox.setEnabled(true);
                    }


                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_0201
        case 1:
            subTitle.setText("setEnabled_fTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("setEnabled_f");
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* the even number in case of 0, the odd in case of 1 */
                    aRest = i % 2;

                    /* invisible setting in case of 100th loop */
                    if (i == loopCounter) {
                        testListBox.setEnabled(false);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to the 99th (aRest=0 visible, aRest=1 invisible) */
                    if (aRest == 0) {
                        testListBox.setEnabled(true);
                    } else {
                        testListBox.setEnabled(false);
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_0301
        case 2:
            subTitle.setText("requestTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox2 = new ListBox(ListBox.CHOICE, 1);
                testListBox3 = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("request1");
                testListBox2.append("request2");
                testListBox3.append("request3");
                add(testListBox);
                add(testListBox2);
                add(testListBox3);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* the even number in case of 0, the odd in case of 1 */
                    aRest = i % 2;

                    /* set the focus on the second object in case of 100th loop */
                    if (i == loopCounter) {
                        testListBox2.requestFocus();
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to the 99th */
                    if (aRest == 0) {
                        testListBox.requestFocus();
                    } else {
                        testListBox3.requestFocus();
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_0401
        case 3:
            subTitle.setText("setItemsTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            String[] listItem1 = { "OK1","OK2","OK3" };
            String[] listItem2 = { "NG1","NG2","NG3" };
            String[] listItem3 = { "NG1","NG2","NG3" };

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* the even number in case of 0, the odd in case of 1 */
                    aRest = i % 2;

                    /* set listItem1 when the loop count is 100 */
                    if (i == loopCounter) {
                        testListBox.setItems(listItem1);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to the 99th */
                    if (aRest == 0) {
                        testListBox.setItems(listItem2);
                    } else {
                        testListBox.setItems(listItem3);
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_0501
        case 4:
            subTitle.setText("appendTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                add(testListBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* set listItem1 when the loop count is 100 */
                    if (i == loopCounter) {
                        testListBox.append("append:OK");
                        return;
                    }

                    /* processing from the first to the 99th */
                    testListBox.append("Item" + i );
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_0601
        case 5:
            subTitle.setText("removeAllTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHECK_BOX, 2);
                testListBox.append("\"NG\"");
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* operation when the loop count is 100 */
                    if (i == loopCounter) {
                        testListBox.removeAll();
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to the 99th */
                    testListBox.removeAll();
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_0701
        case 6:
            subTitle.setText("getItemCountTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("getItemCount");
                testListBox.append("getItemCount");
                testListBox.append("getItemCount");
                add(testListBox);
                add(resultBox);

                value1 = testListBox.getItemCount();
                for (i = 1; i <= loopCounter; i++) {

                    /* compare the value before counting up with after */
                    value2 = testListBox.getItemCount();
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_0801
        case 7:
            subTitle.setText("getItemsTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("getItem");
                testListBox.append("getItem:NG");
                testListBox.append("getItem:NG");
                testListBox.append("getItem:OK");
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* the even number in case of 0, the odd in case of 1 */
                    aRest = i % 2;

                    /* set listItem1 when the loop count is 100 */
                    if (i == loopCounter) {
                        testListBox.getItem(3);
                        resultBox.setText(testListBox.getItem(3));
                        return;
                    }

                    /* processing from the first to the 99th */
                    if (aRest == 0) {
                        testListBox.getItem(1);
                    } else {
                        testListBox.getItem(2);
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_0901
        case 8:
            subTitle.setText("select1Test");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("select");
                testListBox.append("select:NG");
                testListBox.append("select:NG");
                testListBox.append("select:OK");
                add(testListBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* the even number in case of 0, the odd in case of 1 */
                    aRest = i % 2;

                    /* set listItem1 when the loop count is 100 */
                    if (i == loopCounter) {
                        testListBox.select(3);
                        return;
                    }

                    /* processing from the first to the 99th */
                    if (aRest == 0) {
                        testListBox.select(1);
                    } else {
                        testListBox.select(2);
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_1001
        case 9:
            subTitle.setText("select2Test");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            try {

                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testButton  = new Button("execute");
                testListBox.append("select");
                testListBox.append("select1");
                add(testListBox);
                add(resultBox);
                add(testButton);

                /* setting of the component listener */
                setComponentListener(new ComponentListener() {
                    /**
                     * get the event on a component
                     * @param aComponent The component on which a event occurred
                     * @param aType Type of an event.
                     * @param aParam Parameter of an event
                     */
                    public void componentAction(Component aComponent, int aAction, int aParam) {
                        if (aAction == SELECTION_CHANGED){
                            showMsg("SELECTION_CHANGED");
                        }

                        /* loop processing */
                        if (aAction == ComponentListener.BUTTON_PRESSED) {
                            for (i = 1; i <= loopCounter; i++) {
                                testListBox.select(0);

                            }
                            /* show OK when the loop count is 100 */
                            if (i == loopCounter + 1) {
                                resultBox.setText("\"OK\":" + loopCounter + "th time");
                            }
                        }
                    }
                });

            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_1101
        case 10:
            subTitle.setText("deselect1Test");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            try {
                testListBox = new ListBox(ListBox.SINGLE_SELECT, 2);
                testListBox.append("deselect");
                testListBox.append("deselect");
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {

                    testListBox.deselect(0);

                    /* set listItem1 when the loop count is 100 */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                        return;
                    }
                }

            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_1201
        case 11:
            subTitle.setText("deselect2Test");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            try {

                /* component setting */
                testListBox = new ListBox(ListBox.SINGLE_SELECT, 1);
                testButton  = new Button("execute");
                testListBox.append("select");
                testListBox.append("select1");
                add(testListBox);
                add(resultBox);
                add(testButton);

                /* setting of the component listener */
                setComponentListener(new ComponentListener() {
                    /**
                     * get the event on a component
                     * @param aComponent The component on which a event occurred
                     * @param aType Type of an event.
                     * @param aParam Parameter of an event
                     */
                    public void componentAction(Component aComponent, int aAction, int aParam) {
                        if (aAction == SELECTION_CHANGED && deselectFlag == true
                            && selectFlag == false){
                            showMsg("SELECTION_CHANGED");
                            deselectFlag = false;
                        }

                        /* loop processing */
                        if (aAction == ComponentListener.BUTTON_PRESSED) {
                            for (i = 1; i <= loopCounter; i++) {

                                testListBox.select(0);
                                selectFlag   = true;
                                deselectFlag = false;

                                testListBox.deselect(0);
                                selectFlag   = false;
                                deselectFlag = true;

                            }
                            /* show OK when the loop count is 100 */
                            if (i == loopCounter + 1) {
                                resultBox.setText("\"OK\":" + loopCounter + "th time");
                            }
                        }
                    }
                });

            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_1301
        case 12:
            subTitle.setText("isIndexSelectedTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("isIndexSelected");
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter; i++) {

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    testListBox.isIndexSelected(0);

                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_1401
        case 13:
            subTitle.setText("getSelectedIndexTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("getSelectedIndex");
                testListBox.append("getSelectedIndex");
                add(testListBox);
                add(resultBox);
                testListBox.select(1);

                value1 = testListBox.getSelectedIndex();
                for (i = 1; i <= loopCounter; i++) {
                    value2 = testListBox.getSelectedIndex();

                    /* compare the value before counting up with after */
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_1501
        case 14:
            subTitle.setText("getHeightTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("getHeight");
                add(testListBox);
                add(resultBox);

                value1 = testListBox.getHeight();

                for (i = 1; i <= loopCounter; i++) {
                    value2 = testListBox.getHeight();

                    /* compare the value before counting up with after */
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }

            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_1601
        case 15:
            subTitle.setText("getWidthTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("getWidth");
                add(testListBox);
                add(resultBox);

                value1 = testListBox.getWidth();
                for (i = 1; i <= loopCounter; i++) {

                    /* compare the value before counting up with after */
                    value2 = testListBox.getWidth();
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_1701
        case 16:
            subTitle.setText("getXTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("getX");
                add(testListBox);
                add(resultBox);

                value1 = testListBox.getX();
                for (i = 1; i <= loopCounter; i++) {
                    value2 = testListBox.getX();

                    /* compare the value before counting up with after */
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_1801
        case 17:
            subTitle.setText("getYTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("getY");
                add(testListBox);
                add(resultBox);

                value1 = testListBox.getY();
                for (i = 1; i <= loopCounter; i++) {
                    value2 = testListBox.getY();

                    /* compare the value before counting up with after */
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_1901
        case 18:
            subTitle.setText("setBackgroundTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("setBackground");
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* set the background color 255 in case of 100th loop */
                    if (i == loopCounter) {
                        testListBox.setBackground(255);
                        testListBox.setForeground(0);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to 99th (set the background color 0) */
                    testListBox.setBackground(0);
                    testListBox.setForeground(255);

                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_2001
        case 19:
            subTitle.setText("setForegroundTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("setForeground");
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* put 255 in the foreground color in case of 100th loop */
                    if (i == loopCounter) {
                        testListBox.setForeground(255);
                        testListBox.setBackground(0);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the 1st to the 99th (set the foreground color 0) */
                    testListBox.setForeground(0);
                    testListBox.setBackground(255);

                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_2101
        case 20:
            setLayoutManager(null);

            subTitle.setText("setLocation_xTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            subTitle.setLocation(0,0);

            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("setLocation_x");
                add(testListBox);
                add(resultBox);
                resultBox.setLocation(0,30);

                for (i = 1; i <= loopCounter ; i++) {

                    /* 100th location setting */
                    if (i == loopCounter) {
                        testListBox.setLocation(0,15);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to the 99th (setting the location (1000,i)) */
                    testListBox.setLocation(i,1000);
                }

            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_2201
        case 21:
            setLayoutManager(null);

            subTitle.setText("setLocation_yTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            subTitle.setLocation(0,0);
            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("setLocation_y");
                add(testListBox);
                add(resultBox);
                resultBox.setLocation(0,30);

                for (i = 1; i <= loopCounter ; i++) {

                    /* 100th location setting */
                    if (i == loopCounter) {
                        testListBox.setLocation(0,15);
                        resultBox.setText("\"OK\"");
                        return;
                    }

                    /* processing from the first to the 99th (setting the location (1000,i)) */
                    testListBox.setLocation(1000,i);
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_2301
        case 22:
            setLayoutManager(null);

            subTitle.setText("setSize_xTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            subTitle.setLocation(0,0);
            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("setSize_x");
                add(testListBox);
                add(resultBox);
                testListBox.setLocation(0,15);
                resultBox.setLocation(0,30);

                for (i = 1; i <= loopCounter ; i++) {
                    /* processing from the first to the 99th (setting the size (1000,i)) */
                    testListBox.setSize(i,1000);

                    /* 100th size setting */
                    if (i == loopCounter) {
                        testListBox.setSize(getWidth(),15);
                        resultBox.setText("\"OK\"");
                        return;
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_2401
        case 23:
            setLayoutManager(null);

            subTitle.setText("setSize_yTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            subTitle.setLocation(0,0);
            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("setSize_y");
                add(testListBox);
                add(resultBox);
                testListBox.setLocation(0,15);
                resultBox.setLocation(0,30);

                for (i = 1; i <= loopCounter ; i++) {
                    /* processing from the first to the 99th (setting the size (1000,i)) */
                    testListBox.setSize(1000,i);

                    /* 100th size setting */
                    if (i == loopCounter) {
                        testListBox.setSize(getWidth(),15);
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_2501
        case 24:
            subTitle.setText("setVisible_tTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("setVisible_t");
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {
                    /* processing from the first to the 99th (setting Visible false) */
                    testListBox.setVisible(false);

                    /* 100th size setting */
                    if (i == loopCounter) {
                        testListBox.setVisible(true);
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
//J013_3101_2601
        case 25:
            subTitle.setText("setVisible_fTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            /* repeating */
            try {
                /* component setting */
                testListBox = new ListBox(ListBox.CHOICE, 1);
                testListBox.append("setVisible_f");
                add(testListBox);
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {
                    /* processing from the first to the 99th (setting Visible false) */
                    testListBox.setVisible(true);

                    /* 100th size setting */
                    if (i == loopCounter) {
                        testListBox.setVisible(false);
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
        default:
            break;
        }
    }

    /**
     * display message dialog
     * @param  aMsg dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * terminate the application when the softkey1 is released
     * shift to the previous screen in case of softkey2
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {}
}
