/**
 * J013_3401_0101.java
 * 
 * J013_3401_0101
 * MenuPanel
 * TestPanel
 * 
 * MediaData class behavior checking (repeat)
 * 
 * $Id: J013_3401_0101.java,v 1.1 2002/01/07 01:13:46 waka Exp $
 */

import com.nttdocomo.ui.*;

/**
 * MediaData class behavior checking main class
 * @extends IApplication
 */
public class J013_3401_0101 extends IApplication {
    /**
     * starting method for I-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * MediaData class repeating test menu screen
 * @extends    Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {

    ListBox menuList   = null;    /* selection processing  menu */
    Button  execButton = null;    /* execution button */

    String[] menuItem = {
        "0.getHeight",
        "1.getImage",
        "2.getWidth",
        "3.use",
        "4.unuse",
        "5.dispose",
    };                            /* menu item */

    /**
     * MenuPanel class constructor
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * display the main panel
     */
    public void showMainPanel() {

        /* component setting */
        setTitle("API class loop test");
        Label subTitle = new Label("MediaData");
        menuList       = new ListBox(ListBox.CHOICE, 14);
        execButton     = new Button("execute");
        add(subTitle);
        add(menuList);
        add(execButton);
        subTitle.setSize(getWidth(), subTitle.getHeight());
        menuList.setItems(menuItem);

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * display message dialog
     * @param  aMsg dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * terminate the application when the softkey1 is released
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {
        if (aAction == ComponentListener.BUTTON_PRESSED) {
            /* shift to the behavior checking Panel */
            Display.setCurrent(new TestPanel(menuList.getSelectedIndex(), this));
        }
    }
}

/**
 * MediaData class repeating behavior checking screen
 * @extends    Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class TestPanel
    extends Panel implements SoftKeyListener, ComponentListener ,MediaListener{

    private   Frame    previousFrame  = null;  /* store the previous screen */
    private   int      menuIndex      = 0;     /* index of processing selection menu */
    private   Label    subTitle       = null;  /* sub title */
    private   TextBox  resultBox      = null;  /* for display the result */
    private   int      i              = 0;     /* for looping */
    protected int      loopCounter    = 100;   /* the times of looping */

    /**
     * TestPanel class constructor
     * @param  menuIndex index of processing selection menu
     */
    TestPanel(int aMenuIndex, Frame aFrame) {

        previousFrame = aFrame;
        menuIndex     = aMenuIndex;

        try {
            showTestPanel();
            test(menuIndex);
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * behavior checking screen
     */
    void showTestPanel() {

        setTitle("API class loop test");
        subTitle = new Label("");
        add(subTitle);
        resultBox = new TextBox("\"NG\"", getWidth(), 2, TextBox.DISPLAY_ANY);

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        setSoftLabel(Frame.SOFT_KEY_2,"back");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * action checking method
     * @param  menu1Index index of processing selection menu
     */
    void test(int aMenuIndex) {

        MediaImage      testMediaImage      = null;  /* define media image */
        MediaResource   testMediaResource   = null;  /* media resource data definition */
        VisualPresenter testVisualPresenter = null;  /* define play object of media data */
        int value1                          = 0;     /* the value before count up */
        int value2                          = 0;     /* the value after count up */

        /* create instance */
        testVisualPresenter  = new VisualPresenter();

        switch (aMenuIndex) {
// J013_3401_0201
        case 0:
            /* sub title setting */
            subTitle.setText("getHeightTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            try {
                /* media setting */
                testMediaImage = MediaManager.getImage(
                    ("resource:///J013_3401_0101.gif"));
                testMediaResource = (MediaResource)testMediaImage;
                testMediaResource.use();

                /* component setting */
                add(resultBox);

                value1 = testMediaImage.getHeight();

                for (i = 1; i <= loopCounter; i++) {
                    value2 = testMediaImage.getHeight();

                    /* compare the value before counting up with after */
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_3401_0301
        case 1:
            /* sub title setting */
            subTitle.setText("getImageTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            try {
                for (i = 1; i <= loopCounter ; i++) {

                    /* play the movie at the last loop and display OK */
                    if (i == loopCounter) {
                        testMediaImage = MediaManager.getImage(
                            ("resource:///J013_3401_0101.gif")); 
                        testMediaResource = (MediaResource)testMediaImage;
                        testMediaResource.use();
                        testVisualPresenter.setImage(testMediaImage);
                        testVisualPresenter.setMediaListener(this);
                        add(testVisualPresenter);
                        testVisualPresenter.play();
                        return;
                    }

                    /* calling method which is checked */
                    testMediaImage = MediaManager.getImage(
                        ("resource:///J013_3401_0101.gif")); 
                }

                /* component setting */
                add(resultBox);
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_3401_0101
        case 2:
            /* sub title setting */
            subTitle.setText("getWidthTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            try {
                /* media setting */
                testMediaImage = MediaManager.getImage(
                    ("resource:///J013_3401_0101.gif"));
                testMediaResource = (MediaResource)testMediaImage;
                testMediaResource.use();

                /* component setting */
                add(resultBox);

                value1 = testMediaImage.getWidth();

                for (i = 1; i <= loopCounter; i++) {
                    value2 = testMediaImage.getWidth();

                    /* compare the value before counting up with after */
                    if (value1 != value2) {
                        resultBox.setText("\"NG\"");
                        return;
                    }

                    /* display OK in case of 100th */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_3401_0104
        case 3:
            /* sub title setting */
            subTitle.setText("useTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* media data setting */
            testMediaImage = MediaManager.getImage(
                ("resource:///J013_3401_0101.gif")); 

            /* repeating */
            try {
                /* component setting */
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {
                    /* calling method which is checked */
                    testMediaImage.use();

                    /* display OK in case of the last loop */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                        return;
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_3401_0105
        case 4:
            /* sub title setting */
            subTitle.setText("unuseTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* media data setting */
            testMediaImage = MediaManager.getImage(("resource:///J013_3401_0101.gif")); 

            /* repeating */
            try {
                /* component setting */
                add(resultBox);

                    /* calling method which is checked */
                for (i = 1; i <= loopCounter ; i++) {

                    /* calling method which is checked */
                    testMediaImage.unuse();

                    /* display OK in case of the last loop */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                        return;
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
// J013_3401_0106
        case 5:
            /* sub title setting */
            subTitle.setText("disposeTest");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* media data setting */
            testMediaImage = MediaManager.getImage(("resource:///J013_3401_0101.gif")); 

            /* repeating */
            try {
                /* component setting */
                add(resultBox);

                for (i = 1; i <= loopCounter ; i++) {

                    /* calling method which is checked */
                    testMediaImage.dispose();

                    /* display OK in case of the last loop */
                    if (i == loopCounter) {
                        resultBox.setText("\"OK\"");
                        return;
                    }
                }
            } catch (Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
            break;
        default:
            break;
        }
    }

    /**
     * display message dialog
     * @param  aMsg dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * terminate the application when the softkey1 is released
     * shift to the previous screen in case of softkey2
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {}

    /**
     * get the notice from media presenter
     * @param  aMedia media presenter which is the source of the notice
     * @param  aAction event type
     * @param  aParam event parameter
     */
    public void mediaAction(MediaPresenter aMedia, int aAction, int aParam){}

}