/**
 * J013_3501_0101.java
 * 
 * J013_3501_0101
 * MenuPanel
 * TestPanel
 * 
 * MediaListener class behavior checking (repeat)
 * 
 * $Id: J013_3501_0101.java,v 1.1 2002/01/07 01:13:17 waka Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * MediaData class behavior checking main class
 * @extends IApplication
 */
public class J013_3501_0101 extends IApplication {
    /**
     * starting method for I-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * MediaData class repeating test menu screen
 * @extends    Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener,MediaListener {

    ListBox         menuList            = null;  /* selection processing  menu */
    Button          execButton          = null;  /* execution button */
    TextBox         resultBox           = null;  /* for display the result */
    MediaImage      testMediaImage      = null;  /* define media image */
    MediaResource   testMediaResource   = null;  /* media resource data definition */
    VisualPresenter testVisualPresenter = null;  /* define play object of media data */
    private   int   i                   = 0;     /* for looping */
    protected int   loopCounter         = 10;   /* the times of looping */

    /**
     * MenuPanel class constructor
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * display the main panel
     */
    public void showMainPanel() {

        /* component setting */
        setTitle("API class loop test");
        Label subTitle = new Label("MediaListener");
        execButton     = new Button("execute");
        add(subTitle);
        subTitle.setSize(getWidth(), subTitle.getHeight());

        /* create instance */
        testVisualPresenter  = new VisualPresenter();
        resultBox            = new TextBox("\"NG\"", getWidth(), 2, TextBox.DISPLAY_ANY);

        testMediaImage = MediaManager.getImage(
            ("resource:///J013_3501_0101.gif")); 
        testMediaResource = (MediaResource)testMediaImage;

        try {
            testMediaResource.use();
        } catch (ConnectionException ce) {
            showMsg(ce.toString());
        }

        testVisualPresenter.setImage(testMediaImage);
        testVisualPresenter.setMediaListener(this);
        add(testVisualPresenter);
        add(execButton);
        add(resultBox);
        subTitle.setSize(getWidth(), execButton.getHeight());

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);

    }

// J013_3501_0101
    /**
     * behavior checking (repeating)
     */
    void test() {
        try {
                for (i = 1; i <= loopCounter; i++) {
                    testVisualPresenter.play();
                }
        } catch (Exception e) {
            showMsg(e.toString());
        } catch (Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * display message dialog
     * @param  aMsg dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * terminate the application when the softkey1 is released
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {
        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
    }

// J013_3501_0101
    /**
     * get the notice from media presenter
     * @param  aMedia media presenter which is the source of the notice
     * @param  aAction event type
     * @param  aParam event parameter
     */
    public void mediaAction(MediaPresenter aMedia, int aAction, int aParam){
        if (aAction == VisualPresenter.VISUAL_PLAYING){

            /*  */
            if (i == loopCounter +1 ){
                resultBox.setText("\"OK\":" +loopCounter +1 + "th time");
            }
        }
}

}