/**
 * J013_4001_0101.java
 * 
 * J013_4001_0101
 * MainPanel
 * 
 * Panel class behavior checking (repeat)
 * 
 * $Id: J013_4001_0101.java,v 1.1 2002/01/07 01:46:31 hoshi Exp $
*/

import java.util.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Panel class action check main class
 * @extends IApplication
 */
public class J013_4001_0101 extends IApplication {
    public void start() {
        MainPanel mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Panell class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener {

    /* create message dialog(error/guide) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"error");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "info");

    /* execution button */
    Button execButton = null;
    /* create processing selection menu */
    ListBox mainMenu = new ListBox(ListBox.CHOICE,4);
    /* processing selection menu item */
    String[] mainItem = {
        "0.setBackground()",
        "1.setTitle()",
        "2.add()",
        "3.setComponentListener()",
        "4.setSoftKeyListener()",
        "5.setKeyListener()",
        "6.setFocusManager()",
        "7.getFocusManager()",
        "8.setLayoutManager()",
    };

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {

        try {
            showMainPanel();
        } catch(Exception e) {
            err.setText("Exception:" + e.toString());
        } catch(Error e) {
            err.setText("Error" + e.toString());
        }

    }

    /**
     * displaying Panel class action check main screen 
     */
    public void showMainPanel() {

        /* title displaying */
        setTitle("API class loop test");

        /* sub title displaying */
        Label subTitle = new Label("Panel");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);

        /* testing result display textbox */
        TextBox resultTextBox = new TextBox("", getWidth(), 3, 
                                                TextBox.DISPLAY_ANY);
        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* main menu setting */
        mainMenu.setItems(mainItem);

        /* execution button setting */
        execButton = new Button("execute");

        /* add the component to the screen */
        add(mainMenu);
        add(execButton);
        add(resultTextBox);

    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * softKeyReleased
     * terminate the application when the softkey1 is released
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        /* terminate when the softkey is released */
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aPram) {

        /* shift to the screen of menu when the execution button is pused */
        if ( aComponent == execButton
             && aType == BUTTON_PRESSED ) {
            Display.setCurrent(new testPanel(mainMenu.getSelectedIndex(),
                this));
        }
    }
}               


/**
 * repeating behavior checking screen class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class testPanel extends Panel implements SoftKeyListener, FocusManager,
LayoutManager {

    /* create message dialog(error/guide) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"error");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "info");

    /* the variable for returning to the previous screen */
    Frame previousFrame = null;

    /* testing result display textbox */
    TextBox resultTextBox = new TextBox("", getWidth(), 3, TextBox.DISPLAY_ANY);
    Label subTitle = new Label("");
    Label testLabel[] = new Label[100];
    Button testButton;

    /**
     * testPanel class constructor
     * @param aType the position of menu item
     * @param aFrame the screen
     */
    public testPanel(int aType, Frame aFrame) {

        int i;

        /* put the previous screen in */
        previousFrame = aFrame;

        /* title displaying */
        setTitle("API class loop test");

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        setSoftLabel(Frame.SOFT_KEY_2,"back");

        /* setting of the listener */
        setSoftKeyListener(this);

        /* add the component to the screen */
        add(subTitle);
        add(resultTextBox);

       switch (aType) {
        /* setBackground() */
        // J013_4001_0101
        case 0:
            for ( i = 0; i < 99; i++) {
                try {
                    setBackground(Graphics.getColorOfName(Graphics.RED));
                } catch (IllegalArgumentException ie) {
                    err.setText("NG : " + ie.toString());
                    err.show();
                } catch (Exception e) {
                    err.setText("NG : " + e.toString());
                    err.show();
                    break;
                }
            }
            setBackground(Graphics.getColorOfName(Graphics.BLUE));
            subTitle.setText("setBackground()");
            resultTextBox.setText("if the background color is blue, OK");
            break;
        /* setTitle() */
        // J013_4001_0201
        case 1:
            for ( i = 0; i < 99; i++) {
                try {
                    setTitle("API class loop test");
                } catch (Exception e) {
                    err.setText("NG : " + e.toString());
                    err.show();
                    break;
                }
            }
            setTitle("testPanel");
            resultTextBox.setText("if the title is testPanel, OK");
            break;
        /* add() */
        // J013_4001_0301
        case 2:
            for ( i = 0; i < 100; i++) {
                testLabel[i] = new Label("Label" + i);
            }
            for ( i = 0; i < 100; i++) {
                try {
                    add(testLabel[i]);
                } catch (UIException ue) {
                    err.setText("NG : " + ue.toString());
                    err.show();
                } catch (Exception e) {
                    err.setText("NG : " + e.toString());
                    err.show();
                    break;
                }
            }
            subTitle.setText("add()");
            resultTextBox.setText("check that there are 100 labels");
            break;
        /* setComponentListener() */
        // J013_4001_0401
        case 3:
            testButton = new Button("execute");
            add(testButton);
            subTitle.setText("setComponentListener()");
            for ( i = 0; i < 99; i++) {
                try {
                    setComponentListener(new ComponentListener() {
                        public void componentAction(Component aComponent,
                                                     int aType, int aParam) {
                            if (aComponent == testButton && aType == 
                                    ComponentListener.BUTTON_PRESSED) {
                                resultTextBox.setText("NG");
                            }
                        }
                    });
                } catch (Exception e) {
                    err.setText("NG : " + e.toString());
                    err.show();
                    break;
                }
            }
            setComponentListener(new ComponentListener() {
                public void componentAction(Component aComponent,int aType,
                                                int aParam) {
                    if (aComponent == testButton && aType == 
                        ComponentListener.BUTTON_PRESSED) {
                            resultTextBox.setText("OK");
                    }
                }
            });
            break;
        /* setSoftKeyListener() */
        // J013_4001_0501
        case 4:
            subTitle.setText("setSoftKeyListener()");
            for ( i = 0; i < 99; i++) {
                setSoftKeyListener(new SoftKeyListener() {
                    public void softKeyPressed(int aSoftKey) {
                    }
                    public void softKeyReleased(int aSoftKey) {
                        if (aSoftKey == Frame.SOFT_KEY_2) {
                            resultTextBox.setText("NG");
                        }
                    }
                });
            }
            setSoftKeyListener(this);
            resultTextBox.setText("check that the SoftKey operates normally");
            break;
        /* setKeyListener() */
        // J013_4001_0601
        case 5:
            subTitle.setText("setKeyListener()");
            resultTextBox.setText("press 1");
            for ( i = 0; i < 99; i++) {
                try {
                    setKeyListener(new KeyListener() {
                        public void keyPressed(Panel aPanel, int aKey) {
                        }
                        public void keyReleased(Panel aPanel, int aKey) {
                            if (aKey == Display.KEY_1) {
                                resultTextBox.setText("NG");
                            }
                        }
                    });
                } catch (Exception e) {
                    err.setText("NG : " + e.toString());
                    err.show();
                    break;
                }
            }
            setKeyListener(new KeyListener() {
                public void keyPressed(Panel aPanel, int aKey) {
                }
                public void keyReleased(Panel aPanel, int aKey) {
                    if (aKey == Display.KEY_1) {
                        resultTextBox.setText("OK");
                    }
                }
            });
            break;
        /* setFocusManager() */
        // J013_4001_0701
        case 6:
            subTitle.setText("setFocusManager()");
            for ( i = 0; i < 100; i++) {
                try {
                    setFocusManager(this);
                    err.setText("NG : NoException");
                    err.show();
                    break;

                } catch (IllegalArgumentException ie) {
                    continue;
                } catch (Exception e) {
                    err.setText("NG : " + e.toString());
                    err.show();
                    break;
                }
            }
            if (i == 100) {
                resultTextBox.setText("OK : IllegalArgumentException");
            }
            break;
        /* getFocusManager() */
        // J013_4001_0801
        case 7:
            subTitle.setText("getFocusManager()");
            for ( i = 0; i < 100; i++) {
                try {
                    getFocusManager();
                } catch (Exception e) {
                    err.setText("NG : " + e.toString());
                    err.show();
                    break;
                }
            }
            if (i == 100) {
                resultTextBox.setText("OK : " + getFocusManager().toString());
            }
            break;
        /* setLayoutManager() */
        // J013_4001_0901
        case 8:
            subTitle.setText("setLayoutManager()");
            for ( i = 0; i < 100; i++) {
                try {
                    setLayoutManager(this);
                    err.setText("NG : NoException");
                    err.show();
                    break;
                } catch (IllegalArgumentException ie) {
                    continue;
                } catch (Exception e) {
                    err.setText("NG : " + e.toString());
                    err.show();
                    break;
                }
            }
            if (i == 100) {
                resultTextBox.setText("OK : IllegalArgumentException");
            }
            break;
        }
    }

    /**
     * do nothing when a softkey is pushed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * define the action when softkey is released
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            if ( previousFrame != null ) {
                Display.setCurrent(previousFrame);
            }
        }
    }
}
