/**
 * J013_4201_0101
 * MainPanel
 *
 * ShortTimer class repeating test
 *
 * $Id: J013_4201_0101.java,v 1.1 2002/01/07 07:34:19 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * ShortTimer class repeating test main class
 * @extends IApplication
 */
public class J013_4201_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * ShortTimer class repeating test main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.getResolution",
        "2.start",
        "3.stop",
        "4.dispose"
    };

    Label   classLabel       = new Label("ShorTimer");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class repeatability test");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            test();
        }
    }


    /**
     * testing the selected menu
     */
    public void test() {
        /* create timer canvas */
        STimerCanvas sc = new STimerCanvas(this, menuList.getSelectedIndex());
        /* display timer canvas */
        Display.setCurrent(sc);
        if( sc.st != null ) {
            try {
                sc.st.start();
            } catch( Exception e ) {}
        }
    }
}


/**
 * ShorTimer class action check canvas
 * @extends Canvas
 */
class STimerCanvas extends Canvas {

    int fH, fD;
    int sH, sW;
    ShortTimer st = null;
    int count = 0;
    Frame   previous;
    int     idx1 = 0;
    boolean start = false;
    int     MaxLoop = 100;

    /**
     * STimerCanvas class constructor
     * @param prevFrame  mainPanel
     * @param anIdx1 menu of testing type
     */
    public STimerCanvas(Frame prevFrame, int anIdx1) {
        previous = prevFrame;
        idx1 = anIdx1;
        setSoftLabel(Canvas.SOFT_KEY_1, "start");
        setSoftLabel(Canvas.SOFT_KEY_2, "back");
        fH = Font.getDefaultFont().getHeight();
        fD = Font.getDefaultFont().getDescent();
        sH = getHeight();
        sW = getWidth();

        /* start the timer */
        try {
            st = ShortTimer.getShortTimer(this,0,1000,true);
        } catch( Exception e ) {
            showDialog("cannot be tested:" + e.toString());
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * canvas drawing method
     * @param g Graphics object of canvas
     */
    public void paint(Graphics g) {
        g.lock();
        g.clearRect(0, 0, getWidth(), getHeight());
        g.unlock(true);
        drawText("timer test", 0, 0);
        drawText("timer", 0, 1);
    }

    /**
     * drawing method
     * @param text the character string which is displayed
     * @param x x coordinates of the position which is displayed
     * @param the number of lines from the position where it is drawn
     */
    public synchronized void drawText(String text, int x, int line) {
        Graphics g = getGraphics();
        Font f = Font.getDefaultFont();
        int len = text.length();
        int y = (line+1) * fH;
        int endindex = 0;
        int startindex = 0;
        g.lock();
        while (len > 0) {
            endindex = f.getLineBreak(text, startindex, len, sW-x);
            g.clearRect(x, y-fH, sW, fH);
            g.drawString(text.substring(startindex, endindex), x, y-fD);
            y += fH;
            len -= (endindex-startindex);
            startindex = endindex;
        }
        g.unlock(true);
    }

    /**
     * event receive method
     * @param aType event type
     * @param aParam Parameter of an event
     */
    public void processEvent(int type, int param) {
        /* timer event */
        if (type == Display.TIMER_EXPIRED_EVENT) {
            count++;
            drawText(String.valueOf(count), 50, 1);
        }

        /* key event */
        if (type == Display.KEY_RELEASED_EVENT) {
            switch (param) {
            /* when the start key is pushed */
            case Display.KEY_SOFT1:
                /* start testing */
                test();
                break;

            /* when the return key is pushed */
            case Display.KEY_SOFT2:
                /* destroy short timer */
                if( st != null ) {
                    st.dispose();
                }
                /* return to the main menu screen */
                Display.setCurrent(previous);
                break;
            }
        }
    }

    /**
     * repeating testing method
     */
    public void test() {
        int i;

        if( st == null ) {
            showDialog("NG:timer error");
            return;
        }

        switch( idx1 ) {
        case 0:         /* getResolution() */
            // J013_4201_0101
            int res0 = st.getResolution();
            for( i=0; i<MaxLoop; i++ ) {
                int res = st.getResolution();
                if( res != res0 ) {
                    showDialog("NG:res=" + res + " res0=" + res0);
                    break;
                }
            }
            if( i == MaxLoop ) {
                showDialog("OK");
            }
            break;
        case 1:         /* start() */
            // J013_4201_0201
            for( i=0; i<MaxLoop; i++ ) {
                try {
                    st.start();
                    showDialog("NG" + i + ": no Exception");
                    break;
                } catch( UIException uie ) {
                    if( uie.getStatus() == uie.ILLEGAL_STATE ) {
                        continue;
                    } else {
                        showDialog("NG"+i+":UIException:"+uie.getStatus());
                        break;
                    }
                } catch( Exception e ) {
                    showDialog("NG"+i+":"+e.toString());
                    break;
                }
            }
            if( i == MaxLoop ) {
                showDialog("OK");
            }
            break;
        case 2:         /* stop() */
            // J013_4201_0301
            for( i=0; i<MaxLoop; i++ ) {
                st.stop();
            }
            break;
        case 3:         /* dispose() */
            // J013_4201_0401
            for( i=0; i<MaxLoop; i++ ) {
                st.dispose();
            }
            break;
        }
    }
}
