/**
 * J013_4401_0101
 * MainPanel
 *
 * TextBox class repeatability test
 *
 * $Id: J013_4401_0101.java,v 1.2 2002/02/13 02:37:16 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * TextBox class repeatability test main class
 * @extends IApplication
 */
public class J013_4401_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * TextBox class repeatability test main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.setEnabled",
        "2.requestFocus",
        "3.setText",
        "4.getText",
        "5.setInputMode",
        "6.setEditable",
        "7.getHeight",
        "8.getWidth",
        "9.getX",
        "10.getY",
        "11.setBackground",
        "12.setForeground",
        "13.setLocation(x)",
        "14.setLocation(y)",
        "15.setSize(w)",
        "16.setSize(h)",
        "17.setVisible"
    };

    Label   classLabel       = new Label("TextBox");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");
    TextBox testBox          = new TextBox("TextBox",8,1,TextBox.DISPLAY_ANY);
    int     sH;
    int     sW;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class repeatability test");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        execButton.setSize(getWidth(),execButton.getHeight());
        add(execButton);
        add(testBox);

        /* get the size of the screen */
        /* modified begin 2002.02.13 */
        sH = Display.getHeight();
        sW = Display.getWidth();
        /* modified end 2002.02.13 */

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
            /* testBox reset */
            testBox.setText("TextBox");
            testBox.setEnabled(true);
            testBox.setEditable(true);
            testBox.setVisible(true);
        }

        /* when  the execution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* execute testing */
            test();
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * repeat testing method
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        int MaxLoop = 100;
        int i;

        /* execute each testing */
        switch( idx ) {
            case 0:
                // J013_4401_0101
                for( i=0; i<MaxLoop; i++ ) {
                    testBox.setEnabled(false);
                }
                break;
            case 1:
                // J013_4401_0201
                for( i=0; i<MaxLoop; i++ ) {
                    testBox.requestFocus();
                }
                break;
            case 2:
                // J013_4401_0301
                for( i=0; i<MaxLoop; i++ ) {
                    testBox.setText(String.valueOf(i+1));
                }
                break;
            case 3:
                // J013_4401_0401
                for( i=0; i<MaxLoop; i++ ) {
                    String str = testBox.getText();
                    if( str.compareTo("TextBox") != 0 ) {
                        showDialog("NG:getText=" + str);
                        break;
                    }
                }
                if( i == MaxLoop ) {
                    showDialog("OK");
                }
                break;
            case 4:
                // J013_4401_0501
                for( i=0; i<MaxLoop; i++ ) {
                    try {
                        if( i == MaxLoop-1 ) {
                            testBox.setInputMode(TextBox.NUMBER);
                        } else {
                            testBox.setInputMode(TextBox.ALPHA);
                        }
                    } catch( Exception e ) {
                        showDialog("NG:" + e.toString());
                        break;
                    }
                }
                break;
            case 5:
                // J013_4401_0601
                for( i=0; i<MaxLoop; i++ ) {
                    if( i == MaxLoop-1 ) {
                        testBox.setEditable(false);
                    } else {
                        testBox.setEditable(true);
                    }
                }
                break;
            case 6:
                // J013_4401_0701
                int h0 = testBox.getHeight();
                for( i=0; i<MaxLoop; i++ ) {
                    int h = testBox.getHeight();
                    if( h != h0 ) {
                        showDialog("NG:getHeight=" + h + " h0=" + h0);
                        break;
                    }
                }
                if( i == MaxLoop ) {
                    showDialog("OK");
                }
                break;
            case 7:
                // J013_4401_0801
                int w0 = testBox.getWidth();
                for( i=0; i<MaxLoop; i++ ) {
                    int w = testBox.getWidth();
                    if( w != w0 ) {
                        showDialog("NG:getWidth=" + w + " w0=" + w0);
                        break;
                    }
                }
                if( i == MaxLoop ) {
                    showDialog("OK");
                }
                break;
            case 8:
                // J013_4401_0901
                int x0 = testBox.getX();
                for( i=0; i<MaxLoop; i++ ) {
                    int x = testBox.getX();
                    if( x != x0 ) {
                        showDialog("NG:getX=" + x + " x0=" + x0);
                        break;
                    }
                }
                if( i == MaxLoop ) {
                    showDialog("OK");
                }
                break;
            case 9:
                // J013_4401_1001
                int y0 = testBox.getY();
                for( i=0; i<MaxLoop; i++ ) {
                    int y = testBox.getY();
                    if( y != y0 ) {
                        showDialog("NG:getY=" + y + " y0=" + y0);
                        break;
                    }
                }
                if( i == MaxLoop ) {
                    showDialog("OK");
                }
                break;
            case 10:
                // J013_4401_1101
                for( i=0; i<MaxLoop; i++ ) {
                    int c;
                    if( i == MaxLoop-1 ) {
                        c = Graphics.getColorOfName(Graphics.BLUE);
                    } else {
                        c = Graphics.getColorOfRGB(i,i,i);
                    }
                    testBox.setBackground(c);
                }
                break;
            case 11:
                // J013_4401_1201
                for( i=0; i<MaxLoop; i++ ) {
                    int c;
                    if( i == MaxLoop-1 ) {
                        c = Graphics.getColorOfName(Graphics.RED);
                    } else {
                        c = Graphics.getColorOfRGB(i,i,i);
                    }
                    testBox.setForeground(c);
                }
                break;
            case 12:
                // J013_4401_1301
                setLayoutManager(null);
                for( i=0; i<MaxLoop; i++ ) {
                    testBox.setLocation(MaxLoop-i,testBox.getY());
                }
                break;
            case 13:
                // J013_4401_1302
                setLayoutManager(null);
                int th = 2*testBox.getHeight();
                for( i=0; i<MaxLoop; i++ ) {
                    testBox.setLocation(testBox.getX(),
                                        sH-th-MaxLoop+i);
                }
                break;
            case 14:
                // J013_4401_1401
                for( i=0; i<MaxLoop; i++ ) {
                    /* modified begin 2002.02.13 */
                    int w = sW-MaxLoop+i;
                    if( w < 0 ) {
                        w = 0;
                    }
                    testBox.setSize(w,testBox.getHeight());
                    /* modified end 2002.02.13 */
                }
                break;
            case 15:
                // J013_4401_1402
                for( i=0; i<MaxLoop; i++ ) {
                    /* modified begin 2002.02.13 */
                    int h = sH-MaxLoop+i;
                    if( h < 0 ) {
                        h = 0;
                    }
                    testBox.setSize(testBox.getWidth(),h);
                    /* modified end 2002.02.13 */
                }
                break;
            case 16:
                // J013_4401_1501
                for( i=0; i<MaxLoop; i++ ) {
                    if( i == MaxLoop-1 ) {
                        testBox.setVisible(false);
                    } else {
                        testBox.setVisible(true);
                    }
                }
                break;
        }
    }
}
