/**
 * J013_4501_0101
 * MainPanel
 *
 * Ticker class repeatability test
 *
 * $Id: J013_4501_0101.java,v 1.2 2002/02/13 02:44:35 lan Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Ticker class repeatability test main class
 * @extends IApplication
 */
public class J013_4501_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * Ticker class repeatability test main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.setText",
        "2.getHeight",
        "3.getWidth",
        "4.getX",
        "5.getY",
        "6.setBackground",
        "7.setForeground",
        "8.setLocation(x)",
        "9.setLocation(y)",
        "10.setSize(w)",
        "11.setSize(h)",
        "12.setVisible"
    };

    Label   classLabel       = new Label("Ticker");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");
    Ticker  ticker           = new Ticker("Ticker");
    int     sH;
    int     sW;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class repeatability test");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        execButton.setSize(getWidth(),execButton.getHeight());
        add(execButton);
        add(ticker);

        /* get the size of the screen */
        /* modified begin 2002.02.13 */
        sH = Display.getHeight();
        sW = Display.getWidth();
        /* modified end 2002.02.13 */

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
            /* ticker reset */
            ticker.setText("Ticker");
            ticker.setVisible(true);
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* execute testing */
            test();
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * repeat testing method
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        int MaxLoop = 100;
        int i;

        /* execute each testing */
        switch( idx ) {
            case 0:
                // J013_4501_0101
                for( i=0; i<MaxLoop; i++ ) {
                    ticker.setText(String.valueOf(i+1));
                }
                break;
            case 1:
                // J013_4501_0201
                int h0 = ticker.getHeight();
                for( i=0; i<MaxLoop; i++ ) {
                    int h = ticker.getHeight();
                    if( h != h0 ) {
                        showDialog("NG:getHeight=" + h + " h0=" + h0);
                        break;
                    }
                }
                if( i == MaxLoop ) {
                    showDialog("OK");
                }
                break;
            case 2:
                // J013_4501_0301
                int w0 = ticker.getWidth();
                for( i=0; i<MaxLoop; i++ ) {
                    int w = ticker.getWidth();
                    if( w != w0 ) {
                        showDialog("NG:getWidth=" + w + " w0=" + w0);
                        break;
                    }
                }
                if( i == MaxLoop ) {
                    showDialog("OK");
                }
                break;
            case 3:
                // J013_4501_0401
                int x0 = ticker.getX();
                for( i=0; i<MaxLoop; i++ ) {
                    int x = ticker.getX();
                    if( x != x0 ) {
                        showDialog("NG:getX=" + x + " x0=" + x0);
                        break;
                    }
                }
                if( i == MaxLoop ) {
                    showDialog("OK");
                }
                break;
            case 4:
                // J013_4501_0501
                int y0 = ticker.getY();
                for( i=0; i<MaxLoop; i++ ) {
                    int y = ticker.getY();
                    if( y != y0 ) {
                        showDialog("NG:getY=" + y + " y0=" + y0);
                        break;
                    }
                }
                if( i == MaxLoop ) {
                    showDialog("OK");
                }
                break;
            case 5:
                // J013_4501_0601
                for( i=0; i<MaxLoop; i++ ) {
                    int c;
                    if( i == MaxLoop-1 ) {
                        c = Graphics.getColorOfName(Graphics.BLUE);
                    } else {
                        c = Graphics.getColorOfRGB(i,i,i);
                    }
                    ticker.setBackground(c);
                }
                break;
            case 6:
                // J013_4501_0701
                for( i=0; i<MaxLoop; i++ ) {
                    int c;
                    if( i == MaxLoop-1 ) {
                        c = Graphics.getColorOfName(Graphics.RED);
                    } else {
                        c = Graphics.getColorOfRGB(i,i,i);
                    }
                    ticker.setForeground(c);
                }
                break;
            case 7:
                // J013_4501_0801
                setLayoutManager(null);
                for( i=0; i<MaxLoop; i++ ) {
                    ticker.setLocation(MaxLoop-i,ticker.getY());
                }
                break;
            case 8:
                // J013_4501_0802
                setLayoutManager(null);
                int th = 2*ticker.getHeight();
                for( i=0; i<MaxLoop; i++ ) {
                    ticker.setLocation(ticker.getX(),
                                        sH-th-MaxLoop+i);
                }
                break;
            case 9:
                // J013_4501_0901
                for( i=0; i<MaxLoop; i++ ) {
                    /* modified begin 2002.02.13 */
                    int w = sW-MaxLoop+i;
                    if( w < 0 ) {
                        w = 0;
                    }
                    ticker.setSize(w,ticker.getHeight());
                    /* modified end 2002.02.13 */
                }
                break;
            case 10:
                // J013_4501_0902
                for( i=0; i<MaxLoop; i++ ) {
                    /* modified begin 2002.02.13 */
                    int h = sH-MaxLoop+i;
                    if( h < 0 ) {
                        h = 0;
                    }
                    ticker.setSize(ticker.getWidth(),h);
                    /* modified end 2002.02.13 */
                }
                break;
            case 11:
                // J013_4501_1001
                for( i=0; i<MaxLoop; i++ ) {
                    if( i == MaxLoop-1 ) {
                        ticker.setVisible(false);
                    } else {
                        ticker.setVisible(true);
                    }
                }
                break;
        }
    }
}
