/**
 * J013_4701_0101
 * MainPanel
 *
 * VisualPresenter class repeating test
 *
 * $Id: J013_4701_0101.java,v 1.1 2002/01/07 07:37:51 lan Exp $
 */

import com.nttdocomo.lang.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * VisualPresenter class repeating test main class
 * @extends IApplication
 */
public class J013_4701_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * VisualPresenter class repeating test main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    String[] menuListItem = {
        "1.setImage",
        "2.setData",
        "3.getMediaResource",
        "4.play",
        "5.stop",
        "6.setAttribute",
        "7.setMediaListener",
        "8.getHeight",
        "9.getWidth",
        "10.getX",
        "11.getY",
        "12.setBackground",
        "13.setForeground",
        "14.setLocatin(x)",
        "15.setLocatin(y)",
        "16.setSize(w)",
        "17.setSize(h)",
        "18.setVisible"
    };

    Label   classLabel       = new Label("VisualPresenter");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");
    VisualPresenter vp       = new VisualPresenter();
    MediaImage  mi1          = null;
    MediaImage  mi2          = null;
    String  filename1        = new String("anima.gif");
    String  filename2        = new String("89aT-8.gif");
    int     sH;
    int     sW;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class repeatability test");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* get the size of the screen */
        sH = getHeight();
        sW = getWidth();

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        execButton.setSize(sW,execButton.getHeight());
        add(execButton);
        add(vp);

        /* display initial animation */
        try {
            mi1 = MediaManager.getImage("resource:///"+filename1);
            mi1.use();
            mi2 = MediaManager.getImage("resource:///"+filename2);
            mi2.use();
            vp.setImage(mi1);
            vp.setSize(mi1.getWidth()+10,mi1.getHeight()+10);
            int c = Graphics.getColorOfName(Graphics.GREEN);
            vp.setBackground(c);
        } catch (Exception e) {
            mi1 = null;
            mi2 = null;
            showDialog("VisualPresenter cannot be continued:"+e.toString());
        }

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }


    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
            /* VisualPresenter reset */
            vp.setVisible(true);
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* execute testing */
            test();
        }
    }


    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * test repeating
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        int MaxLoop = 100;
        int i;

        /* execute each testing */
        switch( idx ) {
        case 0:
            // J013_4701_0101
            for( i=0; i<MaxLoop; i++ ) {
                try {
                    if( i == MaxLoop-1 ) {
                        vp.setImage(mi2);
                    } else {
                        vp.setImage(mi1);
                    }
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                    break;
                }
            }
            if( i == MaxLoop ) {
                try {
                    vp.play();
                } catch( Exception e ) {
                    showDialog("NG2:" + e.toString());
                }
            }
            break;
        case 1:
            // J013_4701_0201
            VisualPresenter vp2 = new VisualPresenter();
            int uoeCount=0;
            MediaData md1 = null;
            MediaData md2 = null;
            try {
                md1 = MediaManager.getData("resource:///" + filename1);
                md2 = MediaManager.getData("resource:///" + filename2);
                md1.use();
                md2.use();
            } catch( Exception e ) {
                showDialog("NG1:" + e.toString());
                break;
            }
            add(vp2);
            for( i=0; i<MaxLoop; i++ ) {
                try {
                    if( i == MaxLoop-1 ) {
                        vp2.setData(md2);
                    } else {
                        vp2.setData(md1);
                    }
                } catch( UnsupportedOperationException uoe ) {
                    uoeCount++;
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                    break;
                }
            }
            if( uoeCount == 0 && i == MaxLoop ) {
                try {
                    vp2.play();
                } catch( Exception e ) {
                    showDialog("NG2:" + e.toString());
                }
            } else if( uoeCount == MaxLoop ) {
                showDialog("UnsupportedOperationException");
            }
            break;
        case 2:
            // J013_4701_0301
            MediaResource mr0 = vp.getMediaResource();
            for( i=0; i<MaxLoop; i++ ) {
                MediaResource mr = vp.getMediaResource();
                if( ! mr.equals(mr0) ) {
                    showDialog("NG:not same object");
                    break;
                }
            }
            if( i == MaxLoop ) {
                showDialog("OK");
            }
            break;
        case 3:
            // J013_4701_0401
            try {
                vp.stop();
                vp.setImage(mi1);
            } catch( Exception e ) {
                showDialog("NG1:" + e.toString());
                break;
            }
            for( i=0; i<MaxLoop; i++ ) {
                try {
                    vp.play();
                    Thread.sleep(1000);
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                    break;
                }
            }
            break;
        case 4:
            // J013_4701_0501
            try {
                vp.stop();
                vp.setImage(mi1);
                vp.play();
                Thread.sleep(1000);
            } catch( Exception e ) {
                showDialog("NG1:" + e.toString());
                break;
            }
            for( i=0; i<MaxLoop; i++ ) {
                try {
                    vp.stop();
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                    break;
                }
            }
            break;
        case 5:
            // J013_4701_0601
            int n = 0;
            for( i=0; i<MaxLoop; i++ ) {
                vp.setAttribute(VisualPresenter.IMAGE_XPOS,i/2);
            }
            break;
        case 6:
            // J013_4701_0701
            int turn = 0;
            for( i=0; i<MaxLoop; i++ ) {
                if( i == MaxLoop-1 ) {
                    vp.setMediaListener(new MediaListener() {
                        public void mediaAction(MediaPresenter source,int type,int param) {
                            if( type == VisualPresenter.VISUAL_PLAYING ) {
                                showDialog("Listener100:playing");
                            }
                        }
                    } );
                } else if( turn == 0 ) {
                    vp.setMediaListener(new MediaListener() {
                        public void mediaAction(MediaPresenter source,int type,int param) {
                            if( type == VisualPresenter.VISUAL_PLAYING ) {
                                showDialog("Listener0:playing");
                            }
                        }
                    } );
                    turn = 1;
                } else {
                    vp.setMediaListener(new MediaListener() {
                        public void mediaAction(MediaPresenter source,int type,int param) {
                            if( type == VisualPresenter.VISUAL_PLAYING ) {
                                showDialog("Listener100:playing");
                            }
                        }
                    } );
                    turn = 0;
                }
            }
            try {
                vp.play();
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
            break;
        case 7:
            // J013_4701_0801
            int h0 = vp.getHeight();
            for( i=0; i<MaxLoop; i++ ) {
                int h = vp.getHeight();
                if( h != h0 ) {
                    showDialog("NG:getHeight=" + h + " h0=" + h0);
                    break;
                }
            }
            if( i == MaxLoop ) {
                showDialog("OK");
            }
            break;
        case 8:
            // J013_4701_0901
            int w0 = vp.getWidth();
            for( i=0; i<MaxLoop; i++ ) {
                int w = vp.getWidth();
                if( w != w0 ) {
                    showDialog("NG:getWidth=" + w + " w0=" + w0);
                    break;
                }
            }
            if( i == MaxLoop ) {
                showDialog("OK");
            }
            break;
        case 9:
            // J013_4701_1001
            int x0 = vp.getX();
            for( i=0; i<MaxLoop; i++ ) {
                int x = vp.getX();
                if( x != x0 ) {
                    showDialog("NG:getX=" + x + " x0=" + x0);
                    break;
                }
            }
            if( i == MaxLoop ) {
                showDialog("OK");
            }
            break;
        case 10:
            // J013_4701_1101
            int y0 = vp.getY();
            for( i=0; i<MaxLoop; i++ ) {
                int y = vp.getY();
                if( y != y0 ) {
                    showDialog("NG:getY=" + y + " y0=" + y0);
                    break;
                }
            }
            if( i == MaxLoop ) {
                showDialog("OK");
            }
            break;
        case 11:
            // J013_4701_1201
            for( i=0; i<MaxLoop; i++ ) {
                int c;
                if( i == MaxLoop-1 ) {
                    c = Graphics.getColorOfName(Graphics.BLUE);
                } else {
                    c = Graphics.getColorOfRGB(i,i,i);
                }
                vp.setBackground(c);
            }
            break;
        case 12:
            // J013_4701_1301
            for( i=0; i<MaxLoop; i++ ) {
                int c;
                if( i == MaxLoop-1 ) {
                    c = Graphics.getColorOfName(Graphics.RED);
                } else {
                    c = Graphics.getColorOfRGB(i,i,i);
                }
                vp.setForeground(c);
            }
            break;
        case 13:
            // J013_4701_1401
            setLayoutManager(null);
            for( i=0; i<MaxLoop; i++ ) {
                vp.setLocation(MaxLoop-i,vp.getY());
            }
            break;
        case 14:
            // J013_4701_1402
            setLayoutManager(null);
            int th = vp.getHeight();
            for( i=0; i<MaxLoop; i++ ) {
                vp.setLocation(vp.getX(),sH-th-MaxLoop+i);
            }
            break;
        case 15:
            // J013_4701_1501
            for( i=0; i<MaxLoop; i++ ) {
                vp.setSize(sW-MaxLoop+i,vp.getHeight());
            }
            break;
        case 16:
            // J013_4701_1502
            for( i=0; i<MaxLoop; i++ ) {
                vp.setSize(vp.getWidth(),sH-MaxLoop+i);
            }
            break;
        case 17:
            // J013_4701_1601
            for( i=0; i<MaxLoop; i++ ) {
                if( i == MaxLoop-1 ) {
                    vp.setVisible(false);
                } else {
                    vp.setVisible(true);
                }
            }
            break;
        }
    }
}
