/**
 * J013_5101_0101.java
 * 
 * J013_5101_0101
 * MainPanel
 * 
 * Timer class behavior checking (repeating)
 * 
 * $Id: J013_5101_0101.java,v 1.1 2002/01/07 01:48:56 hoshi Exp $
*/

import java.util.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;
import com.nttdocomo.util.*;

/**
 * Panel class action check main class
 * @extends IApplication
 */
public class J013_5101_0101 extends IApplication {
    public void start() {
        MainPanel mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Timer class behavior checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener {

    /* timer interval */
    static final int TIMER_INTERVAL = 1000;
    Timer timer;
    TimerThread tt;
    int timerCounter = 0;
    boolean aStarted = false;
    boolean threadFlg = false;

    /* create message dialog(error/guide) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"error");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "info");

    /* execution button */
    Button execButton = null;

    /* create processing selection menu */
    ListBox mainMenu = new ListBox(ListBox.CHOICE);

    /* testing result display textbox */
    TextBox resultText = new TextBox("", getWidth(), 3, TextBox.DISPLAY_ANY);

    /* processing selection menu item */
    String[] mainItem = {
        "0.dispose()",
        "1.getResolution()",
        "2.setListener()1",
        "3.setListener()2",
        "4.setRepert()1",
        "5.setRepert()2",
        "6.setTime()",
        "7.start()1",
        "8.start()2",
        "9.start()3",
        "10.stop()",
    };

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {

        try {
            showMainPanel();
        } catch(Exception e) {
            err.setText("Exception:" + e.toString());
            err.show();
        } catch(Error e) {
            err.setText("Error" + e.toString());
            err.show();
        }

    }

    /**
     * display Timer class behavior checking main screen
     */
    public void showMainPanel() {
        
        /* title displaying */
        setTitle("API class loop test");

        /* sub title displaying */
        Label subTitle = new Label("Timer");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);

        /* setting the softkey label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* setting of the listener */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* main menu setting */
        mainMenu.setItems(mainItem);

        /* execution button setting */
        execButton = new Button("execute");

        /* add the component to the screen */
        add(mainMenu);
        add(execButton);
        add(resultText);

    }

    /**
     * do nothing when the softkey is pressed
     * @param aSoftKey softkey type
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * softKeyReleased
     * terminate the application when the softkey1 is released
     * @param aSoftKey softkey type
     */
    public void softKeyReleased(int aSoftKey) {
        /* terminate when the softkey is released */
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }


    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aPram) {

        /* execute testing of menu when the execute button is pressed*/
        if ( aComponent == execButton && aType == BUTTON_PRESSED ) {
            timerCounter = 0;
            if (aStarted) {
                timer.dispose();
                aStarted = false;
            }

            try {
                switch (mainMenu.getSelectedIndex()) {
                case 0:
// J013_5101_0101
                    timer = new Timer();
                    for (int i = 0; i < 100; i++) {
                        timer.dispose();
                    }
                    resultText.setText("dispose the timer : OK");
                    break;
                case 1:
// J013_5101_0201
                    timer = new Timer();
                    for (int i = 0; i < 100; i++) {
                        resultText.setText(
                            "timer's resolution:" + timer.getResolution());
                    }
                    timer.dispose();
                    break;

                case 2:
// J013_5101_0301
                    timer = new Timer();
                    timer.setTime(TIMER_INTERVAL);
                    timer.setRepeat(true);

                    TimerListener tl = new TimerListener() {
                        public void timerExpired(Timer t) {
                            if (t == timer) {
                                resultText.setText("Timer :" + timerCounter++);
                            }
                        }
                    };
                    for (int i = 0; i < 100; i++) {
                        timer.setListener(tl);
                    }
                    timer.start();
                    break;
               case 3:
// J013_5101_0302
                    timer = new Timer();
                    timer.setTime(TIMER_INTERVAL);
                    timer.setRepeat(true);
                    for (int i = 0; i < 100; i++) {
                        timer.setListener(
                            new TimerListener() {
                                public void timerExpired(Timer t) {
                                    if (t == timer) {
                                        resultText.setText(
                                            "Timer :" + timerCounter++);
                                    }
                                }
                            }
                        );
                    }
                    timer.start();
                    aStarted = true;
                    break;
                case 4:
// J013_5101_0401
                    timer = new Timer();
                    timer.setTime(TIMER_INTERVAL);
                    for (int i = 0; i < 50; i++) {
                        timer.setRepeat(true);
                        timer.setRepeat(false);
                    }
                    timer.setListener(
                        new TimerListener() {
                            public void timerExpired(Timer t) {
                                if (t == timer) {
                                    resultText.setText(
                                        "Timer :" + timerCounter++);
                                }
                            }
                        }
                    );
                    timer.start();
                    aStarted = true;
                    break;
                case 5:
// J013_5101_0402
                    timer = new Timer();
                    timer.setTime(TIMER_INTERVAL);
                    for (int i = 0; i < 50; i++) {
                        timer.setRepeat(false);
                        timer.setRepeat(true);
                    }
                    timer.setListener(
                        new TimerListener() {
                            public void timerExpired(Timer t) {
                                if (t == timer) {
                                    resultText.setText(
                                        "Timer :" + timerCounter++);
                                }
                            }
                        }
                    );
                    timer.start();
                    aStarted = true;
                    break;
                case 6:
// J013_5101_0501
                    timer = new Timer();
                    for (int i = 0; i < 100; i++) {
                        timer.setTime(10);
                    }
                    timer.setTime(TIMER_INTERVAL);
                    timer.setRepeat(true);
                    timer.setListener(
                        new TimerListener() {
                            public void timerExpired(Timer t) {
                                if (t == timer) {
                                    resultText.setText(
                                        "Timer :" + timerCounter++);
                                }
                            }
                        }
                    );
                    timer.start();
                    aStarted = true;
                    break;
                case 7:
// J013_5101_0601
                    timer = new Timer();
                    timer.setTime(TIMER_INTERVAL);
                    timer.setRepeat(false);
                    timer.setListener(
                        new TimerListener() {
                            public void timerExpired(Timer t) {
                                if (t == timer) {
                                    resultText.setText(
                                        "Timer :" + timerCounter++);
                                }
                            }
                        }
                    );
                    for (int i = 0; i < 100; i++) {
                        timer.start();
                    }
                    aStarted = true;
                    break;
                case 8:
// J013_5101_0602
                    timer = new Timer();
                    timer.setTime(TIMER_INTERVAL);
                    timer.setRepeat(false);
                    timer.setListener(
                        new TimerListener() {
                            public void timerExpired(Timer t) {
                                if (t == timer) {
                                    resultText.setText(
                                        "Timer :" + timerCounter++);
                                }
                            }
                        }
                    );
                    timer.start();
                    
                    threadFlg = false;
                    tt = new TimerThread(this.timer,threadFlg);
                    tt.start();

                    break;
                case 9:
// J013_5101_0603
                    timer = new Timer();
                    timer.setTime(TIMER_INTERVAL);
                    timer.setRepeat(true);
                    timer.setListener(
                        new TimerListener() {
                            public void timerExpired(Timer t) {
                                if (t == timer) {
                                    resultText.setText(
                                        "Timer :" + timerCounter++);
                                }
                            }
                        }
                    );
                    for (int i = 0; i < 100; i++) {
                        timer.start();
                    }
                    aStarted = true;
                    break;
                case 10:
// J013_5101_0701
                    timer = new Timer();
                    timer.setTime(TIMER_INTERVAL);
                    timer.setRepeat(true);
                    timer.setListener(
                        new TimerListener() {
                            public void timerExpired(Timer t) {
                                if (t == timer) {
                                    resultText.setText(
                                        "Timer :" + timerCounter++);
                                }
                            }
                        }
                    );
                    timer.start();
                    threadFlg = true;
                    tt = new TimerThread(this.timer,threadFlg);
                    tt.start();

                    break;
                }
            } catch (UIException uie) {
                err.setText("Exception:" + uie.toString());
                err.show();
            } catch (Exception e) {
                err.setText("Exception:" + e.toString());
                err.show();
            }
        }
    }
}

/**
 * Timer thread
 * @extends Thread
 */
class TimerThread extends Thread {

    Timer timer;
    boolean threadFlg;

    /* create message dialog(error/guide) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"error");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "info");

    /*
     * Timer thread constructor
     * @param aTimer timer object
     */
    TimerThread(Timer aTimer,boolean Flg) {
        this.timer = aTimer;
        threadFlg = Flg;
    }

    /*
     * Timer thread execution
     */
    public void run() {
        try {
// J013_5101_0701
            if (threadFlg) {
                sleep(3000);
                for (int i = 0; i < 100; i++) {
                    timer.stop();
                }
            } else {
// J013_5101_0602
                for (int i = 0; i < 100; i++) {
                    sleep(3000);
                    timer.start();
                }
            }
        } catch (Exception e) {
                err.setText("Exception:" + e.toString());
                err.show();
        }
    }
}

