/**
 * J014_0901_0101
 * MainPanel
 *
 * URLEncoder class behavior checking (repeat)
 *
 * $Id: J014_0901_0101.java,v 1.1 2002/01/07 01:52:40 hoshi Exp $
 */
import com.nttdocomo.ui.*;
import com.nttdocomo.net.*;


/**
 * URLEncoder class action check main class
 * @extends IApplication
 */
public class J014_0901_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * URLEncoder class action check main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "0 Ascii",
        "1 already encoded",
    };

    Label   classLabel       = new Label("URLEncoder");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");
    Label   inLabel          = new Label("the string to be set");
    Label   outLabel         = new Label("encoding result");
    Label   okLabel          = new Label("normal behavior");
    TextBox inBox            = new TextBox("", 20, 1, TextBox.DISPLAY_ANY);
    TextBox outBox           = new TextBox("", 20, 1, TextBox.DISPLAY_ANY);

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* display of the main panel */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * display the main panel
     */
    void showMainPanel() {

        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class loop test");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(inLabel);
        add(inBox);
        add(execButton);
        add(outLabel);
        add(outBox);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* The conversed character sequence display of an initial menu */
        inBox.setText("\0x8A\0xBF\0x8E\0x9A");

    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when softkey1 is released
     */
    public void softKeyReleased(int anIndex) {

        /* terminate the application when softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* when the menu is choiced */
        if (aComponent == menuList
            && aType == ComponentListener.SELECTION_CHANGED) {
            /* original character sequence display */
            showIn();
        }

        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            test();
        }
    }

    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
      * display original character of choiced variation
      */
    public void showIn() {
        outBox.setText("");
        switch( menuList.getSelectedIndex() ) {
            /* Shift-JIS */
            // J014_0901_0101
            case 0:             
                inBox.setText("\0x8A\0xBF\0x8E\0x9A");
                break;
            /* encoded */
            // J014_0901_0102
            case 1:
                inBox.setText("abc");
// 2002/07/26 Doja1.6                inBox.setText("");
                break;
            default:
                inBox.setText("");

                break;
        }
    }

    /**
     * testing selected Encode
     */
    public void test() {
        showIn();
        outBox.setText("");
        switch( menuList.getSelectedIndex() ) {
            /* Unicode -> urlencode */
            // J014_0901_0101
            case 0:
                try {
                    outBox.setText(URLEncoder.encode(inBox.getText()));
                } catch ( NullPointerException ne ) {
                    showDialog("NullPointerException:"+ne.getMessage());
                } catch ( Exception e ) {
                    showDialog("NG:" + e.toString());
                }
                break;
            /* encoded */
            // J014_0901_0102
            case 1:
                try {
                    outBox.setText(URLEncoder.encode(inBox.getText()));
                    outBox.setText(URLEncoder.encode(outBox.getText()));
                } catch ( NullPointerException ne ) {
                    showDialog("NullPointerException:"+ne.getMessage());
                } catch ( Exception e ) {
                    showDialog("NG:" + e.toString());
                }
                break;
            default:
                break;
        }
    }
}