/**
 * J014_1301_0101
 *
 * Canvas class logical abnormal route
 *
 * $Id: J014_1301_0101.java,v 1.1 2001/12/29 00:48:21 takanao Exp $
 */

import com.nttdocomo.ui.*;

/**
 * Canvas class logical abnormal route main class
 * @extends IApplication
 */

public class J014_1301_0101 extends IApplication {

    /* creating main menu */
    MainPanel testPanel = new MainPanel();

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * Canvas class unexpected behavior checking menu scree
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* application menu item */
    private String[] menuItems = {
        "00 repaint()",
    };

    /* GUI parts definition */
    ListBox menuListBox = new ListBox(ListBox.CHOICE);
    Button processButton = new Button("execute");
    TextBox resultBox = new TextBox(null, 16, 4, TextBox.DISPLAY_ANY);

    /* panel creation */
    public MainPanel() {

        /* GUI setting */
        menuListBox.setItems(menuItems);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("Canvas's behavior for a logical error");

        /* GUI position */
        add(menuListBox);
        add(processButton);
        add(resultBox);

        /* setting of the listener */
        this.setComponentListener(this);
        this.setSoftKeyListener(this);
    }

    /**
     * component event handler
     * @param aComponent event occurring component
     * @param aType event type
     * @param aParam event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        
        /* when execution button is presed,if the testing is selected, test starts */
        if (ComponentListener.BUTTON_PRESSED == aType && aComponent == processButton) {
            int selectedIndex = menuListBox.getSelectedIndex();
            if (selectedIndex >= 0) {
                try {
                    doTest(selectedIndex);
                } catch (Exception e) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "error information");
                    errDialog.setText("an exception occurred out of the test"+e.getClass().getName());
                    errDialog.show();
                }
            }
        }
    }

    /**
     * softkey handler
     * @param aKey pressed key
     */
    public void softKeyPressed(int aKey) {}

    /**
     * softkey handler
     * @param aKey released key
     */
    public void softKeyReleased(int aKey) {
        /* terminate the application when the softkey1 is released */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * testing method
     * @param selectedTest execute the prescribed testing
     * @throws Exception thrown when the unexpected exception occurs
     */
    private void doTest(int selectedTest) throws Exception {

        switch (selectedTest) {
        case 0:
            // J014_1301_0101
            Display.setCurrent(new TestCanvas(this));
            break;
        default:
            break;
        }
        return;
    }
}

/**
 * Canvas class for test operation
 * @extends Canvas
 * @implements SoftKeyListener
 */
class TestCanvas extends Canvas {

    /* previous screen storage object */
    private Frame previousFrame = null;

    /* height of font */
    private int fontHeight = Font.getDefaultFont().getHeight();

    /* create Canvas object which is tested */
    ChildCanvas childCanvas = new ChildCanvas();

    /**
     * constructor of Canvas for testing operation
     * @param Frame previous screen for shifting
     */
    public TestCanvas(Frame aFrame) {
        /* store the previous screen */
        previousFrame = aFrame;

        /* GUI setup */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "test");
    }

    /**
     * Canvas drawing (drawing current frame for comparison)
     * @param aGraphics Graphics object which is passed by system
     */
    public void paint(Graphics aGraphics) {

        /* write the text on the displaying frame */
        aGraphics.lock();
        aGraphics.clearRect(0, 0, getWidth(), getHeight());
        aGraphics.drawString("current frame", 0, fontHeight*2);
        aGraphics.unlock(false);
    }

    /**
     * event handler
     * @param aType event type occurred
     * @param aParameter event parameter
     */
    public void processEvent(int aType, int aParameter) {
        if (aType == Display.KEY_RELEASED_EVENT) {
            switch (aParameter) {
            case Display.KEY_SOFT1:
                IApplication.getCurrentApp().terminate();
                break;
                // J014_1301_0101
            case Display.KEY_SOFT2:
                childCanvas.repaint();
                break;
            default:
                break;
            }
        }
    }
}

/**
 * sub Canvas class for testing
 * @extends Canvas
 */
class ChildCanvas extends Canvas {

    /* height of font */
    private int fontHeight = Font.getDefaultFont().getHeight();

    /**
     * drawing method of sub Canvas
     * @param aGraphics Graphics object which is passed by system
     */
    public void paint(Graphics aGraphics) {

        /* write the text on the invisible frame */
        aGraphics.lock();
        aGraphics.drawString("sub-frame", 0, fontHeight*3);
        aGraphics.unlock(false);

        /* trying to draw from Canvas to Graphics for probation */
        Graphics localGraphics = getGraphics();
        localGraphics.lock();
        localGraphics.drawString("sub-frame", 0, fontHeight*4);
        localGraphics.unlock(false);
    }
}
