/**
 * J014_4701_0101
 * MainPanel
 *
 * VisualPresenter class checking (logical abnormal route)
 *
 * $Id: J014_4701_0101.java,v 1.1 2002/01/07 01:51:00 hoshi Exp $
 */

import com.nttdocomo.lang.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * VisualPresenter class checking main class
 * @extends IApplication
 */
public class J014_4701_0101 extends IApplication {

    /**
     * starting method for I-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}


/**
 * VisualPresenter class checking main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "1.setData1",
        "2.setImage",
        "3.setData2",
    };


    String[]    filename = {
        "anima.gif",
        "error.gif"
    };

    Label   classLabel       = new Label("VisualPresenter");
    ListBox menuList         = new ListBox(ListBox.CHOICE);
    Button  execButton       = new Button("execute");
    VisualPresenter vp      = new VisualPresenter();
    MediaImage mi            = null;

   /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        /* setting of the display item */
        menuList.setItems(menuListItem);
        setTitle("API class abnormal route");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* adding each component on the display */
        add(classLabel);
        add(menuList);
        add(execButton);
        add(vp);

        /* setting the listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * do nothing when a softkey is pushed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * terminate the application when the softkey1 is released
     */
    public void softKeyReleased(int anIndex) {
        /* terminate when the softkey1 is released */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * get the event on a component
     * @param aComponent The component on which a event occurred
     * @param aType Type of an event.
     * @param aParam Parameter of an event
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        /* when  the exsecution button is pushed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            /* execute the selected testing */
            test();
        }
    }

    /**
     * dialog display method
     * @param   aText chalacter sequence which is displaied
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * execute the selected testing
     */
    public void test() {
        int idx1 = menuList.getSelectedIndex();
        MediaData ngData;
        MediaData mData;
        MediaImage mImage;
        String f;

        /* execute each testing */
        switch( idx1 ) {
        case 0:
            /* setData1 */
            // J014_4701_0201
            f = filename[1];
            try {
                ngData = MediaManager.getData("resource:///" + f);
                ngData.use();
            } catch( UIException uie ) {
                showDialog("NG(Data.use):" + uie.getMessage());
                return;
            } catch( Exception e ) {
                showDialog("NG(Data.use):" + e.toString());
                return;
            }

            try {
                vp.setData(ngData);
                showDialog("NG:no Exception");
            } catch( UIException uie ) {
                if( uie.getStatus() == UIException.UNSUPPORTED_FORMAT ) {
                    showDialog("UIException(UNSUPPORTED_FORMAT):"+
                                uie.getMessage());
                } else {
                    showDialog("NG:"+uie.getMessage());
                }
            } catch( UnsupportedOperationException uoe ) {
                showDialog("Exception:" + uoe.toString());
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
            break;

        case 1:
            /* setImage */
            // J014_4702_0101
            f = filename[0];

            try {
                mData = MediaManager.getData("resource:///" + f);
                mData.use();
            } catch( UIException uie ) {
                showDialog("NG(Data.use):" + uie.getMessage());
                return;
            } catch( Exception e ) {
                showDialog("NG(Data.use):" + e.toString());
                return;
            }

            try {
                mImage = MediaManager.getImage("resource:///" + f);
                mImage.use();
            } catch( UIException uie ) {
                showDialog("NG(Image.use):" + uie.getMessage());
                return;
            } catch( Exception e ) {
                showDialog("NG(Image.use):" + e.toString());
                return;
            }

            try {
                vp.setData(mData);
            } catch( UIException uie ) {
                showDialog("NG:"+uie.getMessage());
            } catch( UnsupportedOperationException uoe ) {
                showDialog("Exception:" + uoe.toString());
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }

            try {
                vp.setImage(mImage);
                showDialog("NG:no Exception");
            } catch( UIException uie ) {
                    showDialog("Exception:"+uie.getMessage());
            } catch( Exception e ) {
                showDialog("Exception:" + e.toString());
            }
            break;
        case 2:
            /* setData2 */
// 2002/08/07 DoJa1.5            // J014_4702_0201
			// J014_4702_0102
            f = filename[0];

            try {
                mData = MediaManager.getData("resource:///" + f);
                mData.use();
            } catch( UIException uie ) {
                showDialog("NG(Data.use):" + uie.getMessage());
                return;
            } catch( Exception e ) {
                showDialog("NG(Data.use):" + e.toString());
                return;
            }

            try {
                mImage = MediaManager.getImage("resource:///" + f);
                mImage.use();
            } catch( UIException uie ) {
                showDialog("(Data.use):" + uie.getMessage());
                return;
            } catch( Exception e ) {
                showDialog("(Data.use):" + e.toString());
                return;
            }

            try {
                vp.setImage(mImage);
            } catch( UIException uie ) {
                    showDialog("NG:"+uie.getMessage());
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }

            try {
                vp.setData(mData);
                showDialog("NG:no Exception");
            } catch( UIException uie ) {
                    showDialog("Exception:"+uie.getMessage());
            } catch( Exception e ) {
                showDialog("Exception:" + e.toString());
            }
            break;
        }
    }
}
