/**
 * J111_0101_0108
 * Confirmation of media format read operations (with copyright held)
 * 
 * $Id: J111_0101_0108.java,v 1.1 2002/01/07 07:44:17 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of media format read operations (with copyright held)
 * @extends IApplication
 */
public class J111_0101_0108 extends IApplication {
    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen of confirmation of media format read operations(with copyright held)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuListItem = {
        "GIF89a Normal",
        "GIF89a Interlace",
        "GIF89a Transparent",
        "GIF89a Animation",
        "GIF89a Transparent animation",
        "JFIF   BaseLine"
    };

    Label   classLabel = new Label("Reading normal data-with copyright held");
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");
    TextBox resultText = new TextBox("", 20, 3, TextBox.DISPLAY_ANY);

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        menuList.setItems(menuListItem);
        setTitle("normal route media");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            switch (menuList.getSelectedIndex()) {
//J111_0101_0108 (GIF89a with copyright held Normal)
            case 0:
                GetImage("89a6-1.gif");
                break;

//J111_0101_0109 (GIF89a with copyright held Interlace)
            case 1:
                GetImage("89a7-1.gif");
                break;

//J111_0101_0110 (GIF89a with copyright held Transparent)
            case 2:
                GetImage("89a8-1.gif");
                break;

//J111_0101_0111 (GIF89a with copyright held Animation)
            case 3:
                GetImage("89a9-1.gif");
                break;

//J111_0101_0112 (GIF89a with copyright held Transparent animation)
            case 4:
                GetImage("89a10-1.gif");
                break;

//J111_0101_0114 (JFIF with copyright held BaseLine)
            case 5:
                GetImage("JFIF2-1.jpg");
                break;

//J111_0101_0116 (EXIF with copyright held BaseLine)
//Test cannot be conducted

            default:
                break;
            }
        }
    }
    
    /**
     * Reading media and its determination
     * @param aString Reading file name
     */
    void GetImage(String aString) {

        /* Setting a variable for read purpose */
        MediaImage mediaImage;

        /* Object name setting */
        String mediaPath = "resource:///" + aString;
        
        /* Acquisition of an object of media image */
        mediaImage = MediaManager.getImage(mediaPath);

        /* Reading media */
        try {
            mediaImage.use();
            resultText.setText("OK\nReadingSuccessful\n");
        } catch(Exception e) {
            resultText.setText("NG\nReadingUnsuccessful\n");
            resultText.setText(resultText.getText()+e.toString());
        }
    }
}
