/**
 * J111_0201_0408
 * Confirmation of media format playback operations(with copyright held )
 * Operations of static image media playback - VisualPresenter
 *
 * $Id: J111_0201_0408.java,v 1.1 2002/01/07 07:52:35 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of media format playback operations(with copyright held )
 * Operations of static image media playback
 * @extends IApplication
 */
public class J111_0201_0408 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Confirmation of media format playback operations(with copyright held )
 * Static image media - Main screen for VisualPresenter playback operations
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu1 Selection of display type */
    String[] menuListItem1 = {
        "1.VisualPresenter"
    };

    /* Menu2 Selection of media type */
    String[] menuListItem2 = {
        "1.GIF89a Normal",
        "2.GIF89a Interlace",
        "3.GIF89a Transparent",
        "4.JFIF   BaseLine"
    };

    Label   classLabel1 = new Label("Playback of static image media");
    Label   classLabel2 = new Label("with copyright held ");
    ListBox menuList1   = new ListBox(ListBox.CHOICE);
    ListBox menuList2   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2);
        setTitle("normal route media");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel1);
        add(classLabel2);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            /* Acquisition of selected items */
            int first = menuList1.getSelectedIndex();
            int second = menuList2.getSelectedIndex();
            
            switch (first) {

            /* VisualPresenter Display test */
            case 0:
                switch (second) {
//J111_0201_0408 (GIF89a with copyright held  Normal)
                case 0:
                    Display.setCurrent(new SubPanel(first, this, "89a6-1.gif"));
                    break;

//J111_0201_0409 (GIF89a with copyright held Interlace)
                case 1:
                    Display.setCurrent(new SubPanel(first, this, "89a7-1.gif"));
                    break;

//J111_0201_0410 (GIF89a with copyright held  Transparent)
                case 2:
                    Display.setCurrent(new SubPanel(first, this, "89a8-1.gif"));
                    break;

//J111_0201_0414 (JFIF with copyright held  BaseLine)
                case 3:
                    Display.setCurrent(new SubPanel(first, this, "JFIF2-1.jpg"));
                    break;

//J111_0201_0416 (EXIF with copyright held  BaseLine)
//Test cannot be conducted

                default:
                    break;
                }

            default:
                break;
            }
        }
    }
}

/**
 * Confirmation of media format playback operations(with copyright held )
 * Sub screen of static image media playback operations
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    int   testPattern;
    MediaImage viewImage;
    Frame prevFrame;
    Label classLabel = new Label();
    VisualPresenter visualImage = new VisualPresenter();
    TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);
    
    /**
     * Display a sub screen
     * @param aInt    Test Sub division
     * @param aFrame  Main screen object
     * @param aString Reading file name
     */
    public SubPanel(int aInt, Frame aFrame, String aString) {

        /* Acquisition of test patterns */
        testPattern = aInt;

        /* Object name setting */
        prevFrame = aFrame;
        String mediaPath = "resource:///" + aString;

        /* Acquisition of image objects */
        viewImage = MediaManager.getImage(mediaPath);
        
        /* Reading media */
        try {
            viewImage.use();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Reading unsuccessful" + e.toString());
            errDialog.show();
            IApplication.getCurrentApp().terminate();
        }

        /* Set an image to VisualPresenter */
        visualImage.setImage(viewImage);

        try {
            /* Display sub panels */
            ShowSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Setting an image by test Sub division */
        switch (testPattern) {

        /* VisualPresenter */
        case 0:
            classLabel.setText("Display VisualPresenter");
            add(classLabel);

            /* Display VisualPresenter in yellow for confirmation of transparent */
            visualImage.setBackground(Graphics.getColorOfName(Graphics.YELLOW));

            add(visualImage);
            break;

        default:
            break;

        }

        /* Settings of display items */
        setTitle("normal route media");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        
        /* Add each component to screen */
        add(resultText);

        /* Listener setting */
        setSoftKeyListener(this);

        try {
            /* Playback in VisualPresenter */
            visualImage.play();
            resultText.setText("OK\nDisplaySuccessful\n");
        } catch (Exception e) {
            resultText.setText("NG\nDisplayFailed\n");
            resultText.setText(resultText.getText()+e.toString());
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J111_0201_0408.mainPanel);
        }
    }
}
