/**
 * J111_0201_0501
 * Confirmation of media format playback operations(no copyright held)
 * Operations of static image media playback - Canvas
 *
 * $Id: J111_0201_0501.java,v 1.1 2002/01/07 06:59:37 misato Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of media format playback operations(no copyright held)
 * Operations of static image media playback
 * @extends IApplication
 */
public class J111_0201_0501 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Confirmation of media format playback operations(no copyright held)
 * Static image media - Main screen for Canvas playback operations
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu1 Selection of display type */
    String[] menuListItem1 = {
        "1.GIF87a",
        "2.GIF89a",
        "3.JFIF"
    };

    /* Menu2 Selection of media type */
    String[] menuListItem2_01 = {
        "1.Normal",
        "2.Interlace"
    };

    String[] menuListItem2_02 = {
        "1.Normal",
        "2.Interlace",
        "3.Transparent"
    };

    String[] menuListItem2_03 = {
        "1.BaseLine"
    };

    Label   classLabel1 = new Label("Playback of static image media");
    Label   classLabel2 = new Label("with copyright held ");
    ListBox menuList1   = new ListBox(ListBox.CHOICE);
    ListBox menuList2   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2_01);
        setTitle("normal route media");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel1);
        add(classLabel2);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        /* When one in Menu1 is selected */
        if(aComponent == menuList1 && 
                                aType == ComponentListener.SELECTION_CHANGED){
            /* When acquiring selected items */
            int firstType = menuList1.getSelectedIndex();

            switch(firstType){
                case 0:
                    menuList2.setItems(menuListItem2_01);
                    break;

                case 1:
                    menuList2.setItems(menuListItem2_02);
                    break;

                case 2:
                    menuList2.setItems(menuListItem2_03);
                    break;

                default:
                    break;
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            /* Acquisition of selected items */
            int first = menuList1.getSelectedIndex();
            int second = menuList2.getSelectedIndex();
            
            if (first == 0) {
                switch (second) {
                    //J111_0201_0501
                    case 0:
                        Display.setCurrent(new MainCanvas
                                                    (first, this, "87a-1.gif"));
                        break;

                    //J111_0201_0502
                    case 1:
                        Display.setCurrent(new MainCanvas
                                                (first, this, "87a-7.gif"));
                        break;
                }
            }else if(first == 1){
                switch(second){
                    //J111_0201_0503
                    case 0: 
                        Display.setCurrent(new MainCanvas
                                                (first, this, "89a1-1.gif"));
                        break;

                    //J111_0201_0504
                    case 1:
                        Display.setCurrent(new MainCanvas
                                                (first, this, "89a2-1.gif"));
                        break;
                        
                    //J111_0201_0505
                    case 2:
                        Display.setCurrent(new MainCanvas
                                                (first, this, "89a3-1.gif"));
                        break;
                }
            }else if(first == 2){
                switch(second){
                    //J111_0201_0513
                    case 0:
                        Display.setCurrent(new MainCanvas
                                                (first, this, "jfif1-1.jpg"));
                        break;
                }
            }

            //J111_0201_0514
            //Test cannot be conducted
        }
    }
}

/**
 * Confirmation of media format playback operations(with copyright held )
 * Canvas main screen of static image media playback operations
 * @extends Canvas
 */
class MainCanvas extends Canvas {

    int   testPattern;
    Image viewImage;
    Frame prevFrame;
    String sTitle = "Result of Canvas display";
    String sResult1 = "OK";
    String sResult2 = "Depiction successful";
    
    /**
     * Display a sub screen
     * @param aInt    Test Sub division
     * @param aFrame  Main screen object
     * @param aString Reading file name
     */
    public MainCanvas(int aInt, Frame aFrame, String aString) {

        /* Acquisition of test patterns */
        testPattern = aInt;

        /* Object name setting */
        prevFrame = aFrame;
        String mediaPath = "resource:///" + aString;

        /* Acquisition of image objects */
        MediaImage mi = MediaManager.getImage(mediaPath);
        
        /* Reading media */
        try {
            mi.use();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Reading unsuccessful" + e.toString());
            errDialog.show();
            IApplication.getCurrentApp().terminate();
        }

        /* Copy of an image */
        viewImage = mi.getImage();
        
        /* Settings of display items */
        setSoftLabel(Canvas.SOFT_KEY_1, "exit");
        setSoftLabel(Canvas.SOFT_KEY_2, "back");
    }

    /**
     * Drawing into Canvas
     * @param aGraphics Depiction object
     */
    public void paint(Graphics aGraphics) {

        aGraphics.setColor(Graphics.getColorOfName(Graphics.YELLOW));
        aGraphics.fillRect(0,0,getWidth(),getHeight());
        aGraphics.setColor(Graphics.getColorOfName(Graphics.BLACK));
    
        /* Setting an image by test Sub division */
        switch (testPattern) {

        /* Canvas */
        case 0:
            aGraphics.drawString(sTitle, 10, 20);
            aGraphics.drawImage(viewImage, 10, 30);
            aGraphics.drawString(sResult1, 10, viewImage.getHeight() + 50);
            aGraphics.drawString(sResult2, 10, viewImage.getHeight() + 62);
            break;

        case 1:
            aGraphics.drawString(sTitle, 10, 20);
            aGraphics.drawImage(viewImage, 10, 30);
            aGraphics.drawString(sResult1, 10, viewImage.getHeight() + 50);
            aGraphics.drawString(sResult2, 10, viewImage.getHeight() + 62);
            break;

        case 2:
            aGraphics.drawString(sTitle, 10, 20);
            aGraphics.drawImage(viewImage, 10, 30);
            aGraphics.drawString(sResult1, 10, viewImage.getHeight() + 50);
            aGraphics.drawString(sResult2, 10, viewImage.getHeight() + 62);
            break;

        default:
            break;

        }
    }

    /**
     * Types of events
     * @param type type of an event
     * @param param  parameter of an event
     */
    public void processEvent(int type, int param) {
    
        /* When soft key is released, the application ends */
        if(type == Display.KEY_RELEASED_EVENT) {
            switch(param){

                /* When soft key is released, the application ends */
                case Display.KEY_SOFT1:
                    IApplication.getCurrentApp().terminate();
                    break;

                /* When soft key2 is released, return to the main screen */
                case Display.KEY_SOFT2:
                    Display.setCurrent(J111_0201_0501.mainPanel);
                    break;
            }
        }
    }
}
