/**
 * J111_0201_0508
 * Confirmation of media format playback operations(with copyright held )
 * Operations of static image media playback - Canvas
 *
 * $Id: J111_0201_0508.java,v 1.1 2002/01/07 07:54:03 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of media format playback operations(with copyright held )
 * Operations of static image media playback
 * @extends IApplication
 */
public class J111_0201_0508 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Confirmation of media format playback operations(with copyright held )
 * Static image media - Main screen for Canvas playback operations
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu1 Selection of display type */
    String[] menuListItem1 = {
        "1.Canvas"
    };

    /* Menu2 Selection of media type */
    String[] menuListItem2 = {
        "1.GIF89a Normal",
        "2.GIF89a Interlace",
        "3.GIF89a Transparent",
        "4.JFIF   BaseLine"
    };

    Label   classLabel1 = new Label("Playback of static image media");
    Label   classLabel2 = new Label("with copyright held ");
    ListBox menuList1   = new ListBox(ListBox.CHOICE);
    ListBox menuList2   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2);
        setTitle("normal route media");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel1);
        add(classLabel2);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            /* Acquisition of selected items */
            int first = menuList1.getSelectedIndex();
            int second = menuList2.getSelectedIndex();
            
            switch (first) {

            /* VisualPresenter Display test */
            case 0:
                switch (second) {
//J111_0201_0508 (GIF89a with copyright held  Normal)
                case 0:
                    Display.setCurrent(new MainCanvas(first, this, "89a6-1.gif"));
                    break;

//J111_0201_0509 (GIF89a with copyright held Interlace)
                case 1:
                    Display.setCurrent(new MainCanvas(first, this, "89a7-1.gif"));
                    break;

//J111_0201_0510 (GIF89a with copyright held  Transparent)
                case 2:
                    Display.setCurrent(new MainCanvas(first, this, "89a8-1.gif"));
                    break;

//J111_0201_0514 (JFIF with copyright held  BaseLine)
                case 3:
                    Display.setCurrent(new MainCanvas(first, this, "JFIF2-1.jpg"));
                    break;

//J111_0201_0516 (EXIT with copyright held  BaseLine)
//Test cannot be conducted

                default:
                    break;
                }

            default:
                break;
            }
        }
    }
}

/**
 * Confirmation of media format playback operations(with copyright held )
 * Canvas main screen of static image media playback operations
 * @extends Canvas
 */
class MainCanvas extends Canvas {

    int   testPattern;
    Image viewImage;
    Frame prevFrame;
    String sTitle = "Result of Canvas display";
    String sResult1 = "OK";
    String sResult2 = "Depiction successful";
    
    /**
     * Display a sub screen
     * @param aInt    Test Sub division
     * @param aFrame  Main screen object
     * @param aString Reading file name
     */
    public MainCanvas(int aInt, Frame aFrame, String aString) {

        /* Acquisition of test patterns */
        testPattern = aInt;

        /* Object name setting */
        prevFrame = aFrame;
        String mediaPath = "resource:///" + aString;

        /* Acquisition of image objects */
        MediaImage mi = MediaManager.getImage(mediaPath);
        
        /* Reading media */
        try {
            mi.use();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Reading unsuccessful" + e.toString());
            errDialog.show();
            IApplication.getCurrentApp().terminate();
        }

        /* Copy of an image */
        viewImage = mi.getImage();

        setBackground(Graphics.getColorOfName(Graphics.YELLOW));
        
        /* Settings of display items */
        setSoftLabel(Canvas.SOFT_KEY_1, "exit");
        setSoftLabel(Canvas.SOFT_KEY_2, "back");
    }

    /**
     * Drawing into Canvas
     * @param aGraphics Depiction object
     */
    public void paint(Graphics aGraphics) {

        /* Setting an image by test Sub division */
        switch (testPattern) {

        /* Canvas */
        case 0:
            aGraphics.clearRect(0, 0, 1000, 1000);
            aGraphics.drawString(sTitle, 10, 20);
            aGraphics.drawImage(viewImage, 10, 30);
            aGraphics.drawString(sResult1, 10, viewImage.getHeight() + 50);
            aGraphics.drawString(sResult2, 10, viewImage.getHeight() + 62);
            break;

        default:
            break;

        }
    }

    /**
     * Types of events
     * @param type type of an event
     * @param param  parameter of an event
     */
    public void processEvent(int type, int param) {
    
        /* When soft key is released, the application ends */
        if(type == Display.KEY_RELEASED_EVENT) {
            switch(param){

                /* When soft key is released, the application ends */
                case Display.KEY_SOFT1:
                    IApplication.getCurrentApp().terminate();
                    break;

                /* When soft key2 is released, return to the main screen */
                case Display.KEY_SOFT2:
                    Display.setCurrent(J111_0201_0508.mainPanel);
                    break;
            }
        }
    }
}
