/**
 * J111_02005_0117
 *
 * MainPanel
 * 
 * Confirmation of sound media playback
 * 
 * $Id: J111_0205_0117.java,v 1.1 2002/01/07 07:08:11 misato Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;

/**
 * Main class of confirmation of sound media playback operations
 * @extends IApplication
 */
public class J111_0205_0117 extends IApplication{
    /* Commencing method to i-appli */
    public void start(){
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen of confirmation of playback operations
 * 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListsner
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    String[] menu1 = {
        "1.Copyright-not held",
        "2.Copyright-held"
    };
    
    Frame nextFrame;
    Label classLabel = new Label("Confirmation of AudioPresenter operations");
    ListBox menu_Li = new ListBox(ListBox.CHOICE);
    Button execButton = new Button("execute");
    TextBox resultBox = new TextBox("",20,2,TextBox.DISPLAY_ANY);

    AudioPresenter anAudioPresenter = null;

    /**
     * Constructor of MainPanel class (initialization)
     */
    public MainPanel(){
        /* Settings of display items */
        menu_Li.setItems(menu1);
        setTitle("Media test normal route");
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        setSoftLabel(Frame.SOFT_KEY_2,"STOP");

        /* Locate each component on the screen */
        add(classLabel);
        add(menu_Li);
        add(execButton);
        add(resultBox);
        
        /* Registration of a listener */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, no operations to be done
     */
    public void softKeyPressed(int anIndex){}

    /**
     * Processes when soft key is released
     */
    public void softKeyReleased(int anIndex){
        if(anIndex == Frame.SOFT_KEY_1){
            IApplication.getCurrentApp().terminate();
        }else if(anIndex == Frame.SOFT_KEY_2){
            anAudioPresenter.stop();
        }
    }

    /**
     * Process of the case execute button is pressed
     */
    public void componentAction(Component source,int aType,int param){
        /* In the case one in the Menu1 is selected, */
        if(source == menu_Li && aType == ComponentListener.SELECTION_CHANGED){
            resultBox.setText("");
        }

        /* Process of the case execute button is pressed */
        if(source == execButton && aType == ComponentListener.BUTTON_PRESSED){
            test();
        }
    }

    /**
     * Creation of the test() method
     */
    public void test(){
        int index = menu_Li.getSelectedIndex();

        switch(index){
            //J111_0205_0117
            case 0:
                try{
                    anAudioPresenter = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound
                                                ("resource:///imelody1.mld");
                    ms.use();
                    anAudioPresenter.setSound(ms);
                    anAudioPresenter.play();
                    resultBox.setText("OK");
                }catch(Exception e){
                    resultBox.setText("NG:" +e.toString());
                }
                break;

            //J111_0205_0118
            case 1:
                try{
                    anAudioPresenter = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound
                                                ("resource:///imelody2.mld");
                    ms.use();
                    anAudioPresenter.setSound(ms);
                    anAudioPresenter.play();
                    resultBox.setText("OK");
                }catch(Exception e){
                    resultBox.setText("NG:" +e.toString());
                }
                break;

            default:
                break;
        }
    }
}