/**
 * J111_0301_0101
 * Confirmation of media acquisition operations
 * HTTP communication (no copyright)
 * $Id: J111_0301_0101.java,v 1.1 2002/01/07 07:57:38 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of media acquisition operations - HTTP communication(no copyright)
 * @extends IApplication
 */
public class J111_0301_0101 extends IApplication {
    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
    Display.setCurrent(new MainPanel());
    }

    /**
     * Confirmation of media acquisition operations - Main screen of  HTTP communication(no copyright)
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

        String[] menuListItem = {
            "1.GIF87a Normal",
            "2.GIF87a Interlace",
            "3.GIF89a Normal",
            "4.GIF89a Interlace",
            "5.GIF89a Transparent",
            "6.GIF89a Animation",
            "7.GIF89a Transparent animation",
            "8.JFIF   BaseLine",
            "9.iMelody iMelody1.0"
        };

        Label   classLabel = new Label("Reading HTTP communication-no copyright");
        ListBox menuList   = new ListBox(ListBox.CHOICE);
        Button  execButton = new Button("execute");
        TextBox resultText = new TextBox("", 20, 3, TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            try {
                /* Main panel display */
                showMainPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        /**
         * Display a main panel
         */
        void showMainPanel() {

            /* Settings of display items */
            menuList.setItems(menuListItem);
            setTitle("normal route media");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(classLabel);
            add(menuList);
            add(execButton);
            add(resultText);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                resultText.setText("");
                switch (menuList.getSelectedIndex()) {
//J111_0301_0101 (GIF87a no copyright Normal)
                case 0:
                    GetMediaImage("87a-1.gif");
                    break;

//J111_0301_0102 (GIF87a no copyright held Interlace)
                case 1:
                    GetMediaImage("87a-7.gif");
                    break;

//J111_0301_0103 (GIF89a no copyright Normal)
                case 2:
                    GetMediaImage("89a1-1.gif");
                    break;

//J111_0301_0104 (GIF89a no copyright held Interlace)
                case 3:
                    GetMediaImage("89a2-1.gif");
                    break;

//J111_0301_0105 (GIF89a no copyright Transparent)
                case 4:
                    GetMediaImage("89a3-1.gif");
                    break;

//J111_0301_0106 (GIF89a no copyright Animation)
                case 5:
                    GetMediaImage("89a4-1.gif");
                    break;

//J111_0301_0107 (GIF89a no copyright Transparent animation)
                case 6:
                    GetMediaImage("89a5-1.gif");
                    break;

//J111_0301_0113 (JFIF no copyright BaseLine)
                case 7:
                    GetMediaImage("JFIF1-1.jpg");
                    break;

//J111_0301_0115 (EXIF no copyright BaseLine)
//Test cannot be conducted


//J111_0301_0117 (iMelody no copyright iMelody1.0)
                case 8:
                    GetMediaSound("MFi1-1.mld");
                    break;

                default:
                    break;
                }
            }
        }

        /**
         * Reading and determination of image media
         * @param aString Reading file name
         */
        void GetMediaImage(String aString) {

            /* Setting a variable for read purpose */
            MediaImage imageData;

            /* Object name setting */
            String mediaPath = getSourceURL() + aString;
            
            /* Acquisition of an object of media image */
            imageData = MediaManager.getImage(mediaPath);

            /* Reading media */
            try {
                imageData.use();
                resultText.setText("OK\nReadingSuccessful\n");
            } catch(Exception e) {
                resultText.setText("NG\nReadingUnsuccessful\n");
                resultText.setText(resultText.getText()+e.toString());
            }
        }

        /**
         * Reading and determination of sound media
         * @param aString Reading file name
         */
        void GetMediaSound(String aString) {

            /* Setting a variable for read purpose */
            MediaSound soundData;

            /* Object name setting */
            String mediaPath = getSourceURL() + aString;
            
            /* Acquisition of objects of media sound */
            soundData = MediaManager.getSound(mediaPath);

            /* Reading media */
            try {
                soundData.use();
                resultText.setText("OK\nReadingSuccessful\n");
            } catch(Exception e) {
                resultText.setText("NG\nReadingUnsuccessful\n");
                resultText.setText(resultText.getText()+e.toString());
            }
        }
    }
}
