/**
 * J111_0301_0108
 * Confirmation of media acquisition operations
 * HTTP communication(with copyright held)
 * $Id: J111_0301_0108.java,v 1.1 2002/01/07 07:59:05 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of media acquisition operations - HTTP communication(with copyright held)
 * @extends IApplication
 */
public class J111_0301_0108 extends IApplication {
    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
    Display.setCurrent(new MainPanel());
    }

    /**
     * Confirmation of media acquisition operations - Main screen of HTTP communication(with copyright held)
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

        String[] menuListItem = {
            "1.GIF89a Normal",
            "2.GIF89a Interlace",
            "3.GIF89a Transparent",
            "4.GIF89a Animation",
            "5.GIF89a Transparent animation",
            "6.JFIF   BaseLine",
            "7.iMelody iMelody1.0"
        };

        Label   classLabel = new Label("Reading HTTP communication-with copyright held ");
        ListBox menuList   = new ListBox(ListBox.CHOICE);
        Button  execButton = new Button("execute");
        TextBox resultText = new TextBox("", 20, 3, TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            try {
                /* Main panel display */
                showMainPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        /**
         * Display a main panel
         */
        void showMainPanel() {

            /* Settings of display items */
            menuList.setItems(menuListItem);
            setTitle("normal route media");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(classLabel);
            add(menuList);
            add(execButton);
            add(resultText);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                resultText.setText("");
                switch (menuList.getSelectedIndex()) {
//J111_0301_0108 (GIF89a with copyright held Normal)
                case 0:
                    GetMediaImage("89a6-1.gif");
                    break;

//J111_0301_0109 (GIF89a with copyright held Interlace)
                case 1:
                    GetMediaImage("89a7-1.gif");
                    break;

//J111_0301_0110 (GIF89a with copyright held Transparent)
                case 2:
                    GetMediaImage("89a8-1.gif");
                    break;

//J111_0301_0111 (GIF89a with copyright held Animation)
                case 3:
                    GetMediaImage("89a9-1.gif");
                    break;

//J111_0301_0112 (GIF89a with copyright held Transparent animation)
                case 4:
                    GetMediaImage("89a10-1.gif");
                    break;

//J111_0301_0114 (JFIF with copyright held BaseLine)
                case 5:
                    GetMediaImage("JFIF2-1.jpg");
                    break;

//J111_0301_0116 (EXIF with copyright held BaseLine)
//Test cannot be conducted


//J111_0301_0118 (iMelody with copyright held iMelody1.0)
                case 6:
                    GetMediaSound("MFi2-1.mld");
                    break;

                default:
                    break;
                }
            }
        }
        
        /**
         * Reading and determination of image media
         * @param aString Reading file name
         */
        void GetMediaImage(String aString) {

            /* Setting a variable for read purpose */
            MediaImage imageData;

            /* Object name setting */
            String mediaPath = getSourceURL() + aString;
            
            /* Acquisition of an object of media image */
            imageData = MediaManager.getImage(mediaPath);

            /* Reading media */
            try {
                imageData.use();
                resultText.setText("OK\nReadingSuccessful\n");
            } catch(Exception e) {
                resultText.setText("NG\nReadingUnsuccessful\n");
                resultText.setText(resultText.getText()+e.toString());
            }
        }

        /**
         * Reading and determination of sound media
         * @param aString Reading file name
         */
        void GetMediaSound(String aString) {

            /* Setting a variable for read purpose */
            MediaSound soundData;

            /* Object name setting */
            String mediaPath = getSourceURL() + aString;
            
            /* Acquisition of objects of media sound */
            soundData = MediaManager.getSound(mediaPath);

            /* Reading media */
            try {
                soundData.use();
                resultText.setText("OK\nReadingSuccessful\n");
            } catch(Exception e) {
                resultText.setText("NG\nReadingUnsuccessful\n");
                resultText.setText(resultText.getText()+e.toString());
            }
        }

    }
}
