/**
 * J111_0301_0401
 * MainPanel
 *
 * Confirmation of Scratchpad read operations of media test
 *
 * $Id: J111_0301_0401.java,v 1.1 2002/01/07 07:28:40 misato Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of Scratchpad read operations of media test
 * @extends IApplication
 */
public class J111_0301_0401 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of Scratchpad read operations of media test
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menuItems = {
            "1.GIF87aNormal",
            "2.GIF87aInterlace",
            "3.GIF89aNormal",
            "4.GIF89aInterlace",
            "5.GIF89aTransparent",
            "6.GIF89aAnimation",
            "7.GIF89aTransparent animation",
            "8.GIF89aNormalC",
            "9.GIF89aInterlaceC",
            "10.GIF89aTransparentC",
            "11.GIF89aAnimationC",
            "12.GIF89aTransparentAnimationC",
            "13.JFIF",
            "14.JFIF-C",
            "15.iMelody",
            "16.iMelody-C"
        };
        String[] filenames = {
            "87a-1.gif",
            "87a-7.gif",
            "89a1-1.gif",
            "89a2-1.gif",
            "89a3-1.gif",
            "89a4-1.gif",
            "89a5-1.gif",
            "89a6-1.gif",
            "89a7-1.gif",
            "89a8-1.gif",
            "89a9-1.gif",
            "89a10-1.gif",
            "jfif1-1.jpg",
            "jfif2-1.jpg",
            "MFi1-1.mld",
            "MFi2-1.mld",
        };
        boolean readyFlag = false;

        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  writeButton      = new Button("Write");
        Button  readButton       = new Button("Read");
        Label   label            = new Label("Reading Scratchpad");
        TextBox statusBox        = new TextBox("",20,2,TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media test");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu.setItems(menuItems);
            add(menu);
            writeButton.setSize(getWidth(),writeButton.getHeight());
            add(writeButton);
            readButton.setSize(getWidth(),readButton.getHeight());
            add(readButton);
            add(statusBox);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* When Menu is selected, */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* Flag setting */
                readyFlag = false;
                statusBox.setText("");
            }

            /* When "Write" button is pressed */
            if (aComponent == writeButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Write media data in the Scratchpad */
                statusBox.setText("");
                writeSP();
            }

            /* When "Read" button is pressed, */
            if (aComponent == readButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                statusBox.setText("");
                if( ! readyFlag ) {
                    /* Inexecutable */
                    showDialog("Press \"Read\" after executing \"Write\"");
                    return;
                }
                // J111_0301_0401
                // J111_0301_0402
                // J111_0301_0403
                // J111_0301_0404
                // J111_0301_0405
                // J111_0301_0406
                // J111_0301_0407
                // J111_0301_0408
                // J111_0301_0409
                // J111_0301_0410
                // J111_0301_0411
                // J111_0301_0412
                // J111_0301_0413
                // J111_0301_0414
                // J111_0301_0417
                // J111_0301_0418

                // Test cannot be conducted
                // J111_0301_0415
                // J111_0301_0416

                /* Read media data from Scratchpad */
                readSP();
            }
        }

        /**
         * The method to write media data into Scratchpad
         */
        public void writeSP() {
            /* Flag reset */
            readyFlag = false;

            /* Acquire the menu index */
            int idx = menu.getSelectedIndex();

            /* Definition of URL of communication destination */
            String url = getSourceURL();
            url += "../media/" + filenames[idx];

            /* Acquire media data by HttpConnection */
            HttpConnection con = null;
            InputStream is = null;
            int spSize = 10240;
            byte[] data = new byte[spSize];
            int dataSize = 0;
            try {
                con = (HttpConnection) Connector.open(url,Connector.READ,true);
                con.setRequestMethod(con.GET);
                con.connect();
                is = con.openInputStream();
                dataSize = is.read(data,0,spSize);
                is.close();
                con.close();
            } catch( Exception e ) {
                if( is != null ) {
                    try {
                        is.close();
                    } catch( Exception e1 ) {}
                }
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e2 ) {}
                }
                showDialog("Http error:" + e.toString());
                return;
            }
            if( dataSize == 0 ) {
                showDialog("NG: dataSize=0");
                return;
            }

            /* Write media data into SP */
            DataOutputStream dos = null;
            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                dos.write(data,0,spSize);
                dos.close();
            } catch( Exception e ) {
                if( dos != null ) {
                    try {
                        dos.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("scratchpad write error:" + e.toString());
                return;
            }

            /* Writing in SP successful */
            readyFlag = true;
            statusBox.setText("Writing SP completed");
        }


        /**
         * The method to read media data from Scratchpad
         */
        public void readSP() {
            /* Acquire the menu index */
            int idx = menu.getSelectedIndex();

            /* Load media from Scratchpad in MediaManager */
            MediaImage mi = null;
            MediaSound ms = null;
            try {
                if( idx <= 13 ) {
                    mi = MediaManager.getImage("scratchpad:///0");
                    mi.use();
                } else {
                    ms = MediaManager.getSound("scratchpad:///0");
                    ms.use();
                }
                statusBox.setText("Reading SP successful");
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }

            /* Abandon media resource */
            try {
                if( mi != null ) {
                    mi.dispose();
                }
                if( ms != null ) {
                    ms.dispose();
                }
            } catch( Exception e ) {}
        }
    }
}
