/**
 * J111_0301_0440
 * Confirmation of media acquisition operations
 * Direct reading - Specification of Scratchpad location 
 *
 * $Id: J111_0301_0440.java,v 1.1 2002/01/07 08:03:04 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Confirmation of media acquisition operations
 * Direct reading - Specification of Scratchpad location 
 * @extends IApplication
 */
public class J111_0301_0440 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Confirmation of media acquisition operations
 * Direct reading -Main screen of specification of Scratchpad location
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Selection of Menu Media type */
    String[] menuListItem = {
        "1.GIF87aNormal",
        "2.GIF87aInterlace",
        "3.GIF89aNormal",
        "4.GIF89aInterlace",
        "5.GIF89aTransparent",
        "6.GIF89aAnimation",
        "7.GIF89aTransparent animation",
        "8.GIF89aNormalC",
        "9.GIF89aInterlaceC",
        "10.GIF89aTransparentC",
        "11.GIF89aAnimationC",
        "12.GIF89aTransparentAnimationC",
        "13.JFIF",
        "14.JFIF C",
        "15.iMelody",
        "16.iMelody C"

    };

    Label   classLabel1 = new Label("Operations of direct writing");
    Label   classLabel2 = new Label("Confirmation of writing location-specified SP");
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  writeButton = new Button("Write");
    
    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        menuList.setItems(menuListItem);
        setTitle("normal route media");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel1);
        add(classLabel2);
        add(menuList);
        add(writeButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When "Write" button is pressed */
        if (aComponent == writeButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            switch (menuList.getSelectedIndex()) {

//J111_0301_0440 (GIF87a Normal)
            case 0:
                Display.setCurrent(new SubPanel(this, "87a-1.gif"));
                break;

//J111_0301_0441 (GIF87a Interlace)
            case 1:
                Display.setCurrent(new SubPanel(this, "87a-7.gif"));
                break;

//J111_0301_0442 (GIF89a Normal no copyright)
            case 2:
                Display.setCurrent(new SubPanel(this, "89a1-1.gif"));
                break;

//J111_0301_0443 (GIF89a Interlace no copyright held)
            case 3:
                Display.setCurrent(new SubPanel(this, "89a2-1.gif"));
                break;

//J111_0301_0444 (GIF89a Transparent no copyright)
            case 4:
                Display.setCurrent(new SubPanel(this, "89a3-1.gif"));
                break;

//J111_0301_0445 (GIF89a Animation no copyright)
            case 5:
                Display.setCurrent(new SubPanel(this, "89a4-1.gif"));
                break;

//J111_0301_0446 (GIF89a Transparent animation no copyright)
            case 6:
                Display.setCurrent(new SubPanel(this, "89a5-1.gif"));
                break;

//J111_0301_0447 (GIF89a Normal with copyright held)
            case 7:
                Display.setCurrent(new SubPanel(this, "89a6-1.gif"));
                break;

//J111_0301_0448 (GIF89a Interlace with copyright held)
            case 8:
                Display.setCurrent(new SubPanel(this, "89a7-1.gif"));
                break;

//J111_0301_0449 (GIF89a Transparent with copyright held)
            case 9:
                Display.setCurrent(new SubPanel(this, "89a8-1.gif"));
                break;

//J111_0301_0450 (GIF89a Animation with copyright held)
            case 10:
                Display.setCurrent(new SubPanel(this, "89a9-1.gif"));
                break;

//J111_0301_0451 (GIF89a Transparent animation with copyright held)
            case 11:
                Display.setCurrent(new SubPanel(this, "89a10-1.gif"));
                break;

//J111_0301_0452 (JFIF no copyright BaseLine)
            case 12:
                Display.setCurrent(new SubPanel(this, "JFIF1-1.jpg"));
                break;

//J111_0301_0453 (JFIF no copyright BaseLine)
            case 13:
                Display.setCurrent(new SubPanel(this, "JFIF2-1.jpg"));
                break;

//J111_0301_0454 (EXIF no copyright BaseLine)
//Test cannot be conducted

//J111_0301_0455 (EXIF with copyright held BaseLine)
//Test cannot be conducted


//J111_0301_0456 (iMelody no copyright iMelody1.0) 
            case 14:
                Display.setCurrent(new SubPanel(this, "MFi1-1.mld"));
                break;

//J111_0301_0457 (iMelody with copyright held iMelody1.0) 
            case 15:
                Display.setCurrent(new SubPanel(this, "MFi2-1.mld"));
                break;

            default:
                break;
            }
        }
    }

    /**
     * Confirmation of media format playback operations(with copyright held )
     * Sub screen of static image media playback operations
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

        Frame prevFrame;
        Label classLabel = new Label("Confirmation of reading location-specified SP");
        Button execButton = new Button("execute");
        TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);

        /**
         * Display a sub screen
         * @param aFrame  Main screen object
         * @param aString Reading file name
         */
        public SubPanel(Frame aFrame, String aString) {

            /* Object name setting */
            prevFrame = aFrame;
            String mediaPath = "resource:///" + aString;

            /* Acquisition of data */
            byte bData[] = loadData(mediaPath);
            
            /* Writing into Scratchpad */
            writeScratchpad(bData);

            try {
                /* Display sub panels */
                ShowSubPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        void ShowSubPanel() {

            /* Settings of display items */
            setTitle("normal route media");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");
            setSoftLabel(Frame.SOFT_KEY_2, "back");
            
            /* Add each component to screen */
            add(classLabel);
            add(execButton);
            add(resultText);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);

        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }

            /* When soft key2 is released, return to the main screen */
            if (anIndex == Frame.SOFT_KEY_2) {
                Display.setCurrent(J111_0301_0440.mainPanel);
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                /**
                 * Acquisition and determination of data objects
                 * Separate determination in the case of "sound"
                 */
                if (menuList.getSelectedIndex() == 14
                    || menuList.getSelectedIndex() == 15) {
                    GetMediaSound();
                } else {
                    GetMediaImage();
                }
            }
        }

        /**
        * Acquisition of data
        */
        private byte[] loadData(String aString) {
            DataInputStream dis = null;
            byte[] bData = new byte[7168];

            try {
                dis = Connector.openDataInputStream(aString);
                int iCheck = dis.read(bData);
                if  (iCheck == -1) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Read NG: No data");
                    errDialog.show();
                    dis.close();
                }
            } catch (IOException e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Reading SP:NG(IOException)");
                errDialog.show();
                IApplication.getCurrentApp().terminate();
            } finally {
                try {
                    if (dis != null) {
                        dis.close();
                    }
                } catch (IOException ie) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Connection Close:NG" + ie.toString());
                    errDialog.show();
                }
            }
            
            return bData;
        }

        /**
        * Write into Scratchpad
        * @param anImage Data written
        */
        private void writeScratchpad(byte[] aByte) {
            DataOutputStream dos = null;
            
            try {
                /* Specify the location as 512byte*/
                dos = Connector.openDataOutputStream("scratchpad:///0;pos=512");
                dos.write(aByte);
                resultText.setText("Writing SP completed");
            } catch (IOException e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Writing SP:NG" + e.toString());
                errDialog.show();
                resultText.setText("Writing SP:NG");
            } finally {
                try {
                    if (dos != null) {
                        dos.close();
                    }
                } catch (IOException ie) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Connection Close:NG" + ie.toString());
                    errDialog.show();
                    resultText.setText("Writing SP:NG");
                }
            }
        }

        /**
         * Reading and determination of image media
         */
        void GetMediaImage() {

            /* Setting a variable for read purpose */
            MediaImage imageData;

            /* Acquisition of objects of media data */
            imageData = MediaManager.getImage("scratchpad:///0;pos=512");

            /* Reading media */
            try {
                imageData.use();
                resultText.setText("OK\nReadingSuccessful\n");
            } catch(Exception e) {
                resultText.setText("NG\nReadingUnsuccessful\n");
                resultText.setText(resultText.getText()+e.toString());
            }
        }

        /**
         * Reading and determination of sound media
         */
        void GetMediaSound() {

            /* Setting a variable for read purpose */
            MediaSound soundData;

            /* Acquisition of objects of media data */
            soundData = MediaManager.getSound("scratchpad:///0;pos=512");

            /* Reading media */
            try {
                soundData.use();
                resultText.setText("OK\nReadingSuccessful\n");
            } catch(Exception e) {
                resultText.setText("NG\nReadingUnsuccessful\n");
                resultText.setText(resultText.getText()+e.toString());
            }
        }
    }
}
