/**
 * J111_0302_0101
 * Confirmation of media acquisition operations
 * Read transferred data - HTTP -> Scratchpad
 *
 * $Id: J111_0302_0101.java,v 1.1 2002/01/07 08:08:30 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Confirmation of media acquisition operations
 * Read transferred data - HTTP -> Scratchpad
 * @extends IApplication
 */
public class J111_0302_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }

    /**
     * Confirmation of media acquisition operations
     * Read transferred data - HTTP -> Main screen of Scratchpad
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

        /* Selection of Menu Media type */
        String[] menuListItem = {
            "1.GIF87a Normal",
            "2.GIF89a Normal",
            "3.JFIF   BaseLine",
            "4.iMelody iMelody1.0"
        };

        Label   classLabel1 = new Label("Operations of reading transferred data");
        Label   classLabel2 = new Label("HTTP->Scratchpad");
        ListBox menuList   = new ListBox(ListBox.CHOICE);
        Button  execButton = new Button("execute");
        TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            try {
                /* Main panel display */
                showMainPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        /**
         * Display a main panel
         */
        void showMainPanel() {

            /* Settings of display items */
            menuList.setItems(menuListItem);
            setTitle("normal route media");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(classLabel1);
            add(classLabel2);
            add(menuList);
            add(execButton);
            add(resultText);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                resultText.setText("");
                switch (menuList.getSelectedIndex()) {

//J111_0302_0101 (GIF87a Normal)
                case 0:
                    test("87a-1.gif");
                    break;

//J111_0302_0108 (GIF89a with copyright held Normal)
                case 1:
                    test("89a6-1.gif");
                    break;

//J111_0302_0114 (JFIF with copyright held BaseLine)
                case 2:
                    test("JFIF2-1.jpg");
                    break;

//J111_0302_0115 (EXIF no copyright BaseLine)
//Test cannot be conducted


//J111_0302_0117 (iMelody no copyright iMelody1.0) 
                case 3:
                    test("MFi1-1.mld");
                    break;

                default:
                    break;
                }
            }
        }

        /**
         * Execution of a test
         * @param aString Reading file name
         */
        void test(String aString) {

            /* Object name setting */
            String mediaPath = aString;

            /* Acquisition of data */
            byte bData[] = loadData(mediaPath);

            /* Writing into Scratchpad */
            writeScratchpad(bData);

            /**
             * Acquisition and determination of data objects
             * Separate determination in the case of "sound"
             */
            if (menuList.getSelectedIndex() == 3) {
                GetMediaSound();
            } else {
                GetMediaImage();
            }

        }

        /**
        * Acquire data via HTTP
        */
        private byte[] loadData(String aString) {
            HttpConnection  con = null;
            DataInputStream dis = null;
            byte[] bData = new byte[7168];
            String url = getSourceURL() + aString;

            try {
                con = (HttpConnection) Connector.open(url, Connector.READ, true);
                con.setRequestMethod(HttpConnection.GET);
                con.connect();
                dis = con.openDataInputStream();

                /* Acquisition of data */
                int iCheck = dis.read(bData);
                if  (iCheck == -1) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Read NG: No data");
                    errDialog.show();
                    dis.close();
                }
            } catch (IOException ioe) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Read:NG(IOException)");
                errDialog.show();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Read:NG(Exception)" + e.toString());
                errDialog.show();
            } finally {
                try {
                    if (dis != null) {
                        dis.close();
                    }
                    if (con != null) {
                        con.close();
                    }
                } catch (IOException ie) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Connection Close:NG" + ie.toString());
                    errDialog.show();
                }
            }
            
            return bData;
        }


        /**
        * Write into Scratchpad
        * @param aByte Writing data
        */
        private void writeScratchpad(byte[] aByte) {
            DataOutputStream dos = null;

            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                dos.write(aByte);
            } catch (IOException e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Writing SP:NG" + e.toString());
                errDialog.show();
            } finally {
                try {
                    if (dos != null) {
                        dos.close();
                    }
                } catch (IOException ie) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Connection Close:NG" + ie.toString());
                    errDialog.show();
                }
            }
        }

        /**
         * Reading and determination of image media
         */
        void GetMediaImage() {

            /* Setting a variable for read purpose */
            MediaImage imageData;

            /* Acquisition of objects of media data */
            imageData = MediaManager.getImage("scratchpad:///0");

            /* Reading media */
            try {
                imageData.use();
                resultText.setText("OK\nReadingSuccessful\n");
            } catch(Exception e) {
                resultText.setText("NG\nReadingUnsuccessful\n");
                resultText.setText(resultText.getText()+e.toString());
            }
        }

        /**
         * Reading and determination of sound media
         */
        void GetMediaSound() {

            /* Setting a variable for read purpose */
            MediaSound soundData;

            /* Acquisition of objects of media data */
            soundData = MediaManager.getSound("scratchpad:///0");

            /* Reading media */
            try {
                soundData.use();
                resultText.setText("OK\nReadingSuccessful\n");
            } catch(Exception e) {
                resultText.setText("NG\nReadingUnsuccessful\n");
                resultText.setText(resultText.getText()+e.toString());
            }
        }
    }
}