/**
 * J111_0401_0101
 * MainPanel
 *
 * Confirmation of communication method variations of media test 
 *
 * $Id: J111_0401_0101.java,v 1.1 2002/01/07 06:58:04 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of communication method variations of media test
 * @extends IApplication
 */
public class J111_0401_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of communication method variations of media test
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menu1Items = {
            "1 With parameter",
            "2 Without parameter",
            "3 No Content-Length"
        };
        String[] menu2Items = {
            "1 GIF87a",
            "2 GIF89a",
            "3 JFIF",
            "4 MFi"
        };
        String[] filenames = {
            "87a-1.gif",
            "89a6-1.gif",
            "jfif2-1.jpg",
            "MFi1-1.mld"
        };
        String[] cgifiles = {
            "getgif87a.cgi",
            "getgif89a.cgi",
            "getjfif.cgi",
            "getmld.cgi",
            "getmedia.cgi",
            "getmedia2.cgi"
        };

        ListBox menu1            = new ListBox(ListBox.CHOICE);
        ListBox menu2            = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");
        Label   label            = new Label("Variations of communication methods");
        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media test");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu1.setItems(menu1Items);
            menu2.setItems(menu2Items);
            add(menu1);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* When Menu is selected, */
            if (aComponent == menu1
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* Configuration of sub menu */
                menu2.setItems(menu2Items);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Call a test method */
                test();
            }
        }

        /**
         * The method a test is implemented
         */
        public void test() {
            /* Acquire the menu index */
            int idx1 = menu1.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();

            /* Definition of URL of communication destination */
            String url = getSourceURL();
            switch( idx1 ) {
            case 0:
                url += "../cgi-bin/" + cgifiles[4] + "?" + filenames[idx2];
                break;
            case 1:
                url += "../cgi-bin/" + cgifiles[idx2];
                break;
            case 2:
                url += "../cgi-bin/" + cgifiles[5] + "?" + filenames[idx2];
                break;
            }

            /* Communicate with the communication destination in MediaManager */
            // J111_0401_0101
            // J111_0401_0108
            // J111_0401_0114
            // J111_0401_0115
            // J111_0401_0117
            // J111_0401_0201
            // J111_0401_0208
            // J111_0401_0214
            // J111_0401_0215
            // J111_0401_0217
            // J111_0401_0301
            // J111_0401_0308
            // J111_0401_0314
            // J111_0401_0315
            // J111_0401_0317
            // J111_0401_0401
            // J111_0401_0408
            // J111_0401_0414
            // J111_0401_0415
            // J111_0401_0417
            MediaImage mi = null;
            MediaSound ms = null;
            try {
                if( idx2 <= 2 ) {
                    mi = MediaManager.getImage(url);
                    mi.use();
                } else {
                    ms = MediaManager.getSound(url);
                    ms.use();
                }
                showDialog("OK");
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }

            /* Abandon media resource */
            try {
                if( mi != null ) {
                    mi.dispose();
                }
                if( ms != null ) {
                    ms.dispose();
                }
            } catch( Exception e ) {}
        }
    }
}
