/**
 * J111_0403_0101
 * MainPanel
 *
 * Confirmation of HTTP status code of media test
 *
 * $Id: J111_0403_0101.java,v 1.1 2002/01/07 07:01:47 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of HTTP status code of media test
 * @extends IApplication
 */
public class J111_0403_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of HTTP status code of media test
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menu1Items = {
            "1 200",
            "2 201",
            "3 202",
            "4 203",
            "5 204",
            "6 205",
            "7 206",
            "8 300",
            "9 301",
            "10 302",
            "11 303",
            "12 304",
            "13 400",
            "14 401",
            "15 402",
            "16 403",
            "17 404",
            "18 405",
            "19 406",
            "20 407",
            "21 408",
            "22 500",
            "23 501",
            "24 502",
            "25 503",
            "26 504"
        };
        String[] menu2Items = {
            "1 getImage",
            "2 getSound",
            "3 getData"
        };
        String[] filenames = {
            "200",
            "201",
            "202",
            "203",
            "204",
            "205",
            "206",
            "300",
            "301",
            "302",
            "303",
            "304",
            "400",
            "401",
            "402",
            "403",
            "404",
            "405",
            "406",
            "407",
            "408",
            "500",
            "501",
            "502",
            "503",
            "504"
        };

        ListBox menu1            = new ListBox(ListBox.CHOICE);
        ListBox menu2            = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");
        Label   label            = new Label("Confirmation of HTTP status code");
        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media test");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu1.setItems(menu1Items);
            menu2.setItems(menu2Items);
            add(menu1);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* When Menu is selected, */
            if (aComponent == menu1
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* Configuration of sub menu */
                menu2.setItems(menu2Items);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Call a test method */
                test();
            }
        }

        /**
         * The method a test is implemented
         */
        public void test() {
            /* Acquire the menu index */
            int idx1 = menu1.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();

            /* Definition of URL of communication destination */
            String url = getSourceURL();
            if( idx1 <= 6 ) {
                url += "../status/" + filenames[idx1];
                if( idx2 == 1 ) {
                    url += "-2.asis";
                } else {
                    url += "-1.asis";
                }
            } else if( idx1 == 13 ) {
                if( idx2 == 1 ) {
                    url += "../sec/MFi1-1.mld";
                } else {
                    url += "../sec/89a6-1.gif";
                }
            } else {
                url += "../status/" + filenames[idx1] + ".asis";
            }

            /* Communicate with the communication destination in MediaManager */
            MediaImage mi = null;
            MediaSound ms = null;
            MediaData  md = null;
            try {
                switch( idx2 ) {
                case 0:
                    mi = MediaManager.getImage(url);
                    mi.use();
                    break;
                case 1:
                    ms = MediaManager.getSound(url);
                    ms.use();
                    break;
                case 2:
                    md = MediaManager.getData(url);
                	if(md == null){
                		showDialog("MediaData : Null");
                		return;
                	}
                	
                    md.use();
                    break;
                }
                // J111_0403_0101
                // J111_0403_0102
                // J111_0403_0103
                // J111_0403_0201
                // J111_0403_0202
                // J111_0403_0203
                // J111_0403_0301
                // J111_0403_0302
                // J111_0403_0303
                // J111_0403_0401
                // J111_0403_0402
                // J111_0403_0403
                // J111_0403_0501
                // J111_0403_0502
                // J111_0403_0503
                // J111_0403_0601
                // J111_0403_0602
                // J111_0403_0603
                // J111_0403_0701
                // J111_0403_0702
                // J111_0403_0703
                // J111_0403_1401
                // J111_0403_1402
                // J111_0403_1403
                showDialog("OK");
            } catch( ConnectionException ce ) {
                // J111_0403_0801
                // J111_0403_0802
                // J111_0403_0803
                // J111_0403_0901
                // J111_0403_0902
                // J111_0403_0903
                // J111_0403_1001
                // J111_0403_1002
                // J111_0403_1003
                // J111_0403_1101
                // J111_0403_1102
                // J111_0403_1103
                // J111_0403_1201
                // J111_0403_1202
                // J111_0403_1203
                // J111_0403_1301
                // J111_0403_1302
                // J111_0403_1303
                // J111_0403_1501
                // J111_0403_1502
                // J111_0403_1503
                // J111_0403_1601
                // J111_0403_1602
                // J111_0403_1603
                // J111_0403_1701
                // J111_0403_1702
                // J111_0403_1703
                // J111_0403_1801
                // J111_0403_1802
                // J111_0403_1803
                // J111_0403_1901
                // J111_0403_1902
                // J111_0403_1903
                // J111_0403_2001
                // J111_0403_2002
                // J111_0403_2003
                // J111_0403_2101
                // J111_0403_2102
                // J111_0403_2103
                // J111_0403_2201
                // J111_0403_2202
                // J111_0403_2203
                // J111_0403_2301
                // J111_0403_2302
                // J111_0403_2303
                // J111_0403_2401
                // J111_0403_2402
                // J111_0403_2403
                // J111_0403_2501
                // J111_0403_2502
                // J111_0403_2503
                // J111_0403_2601
                // J111_0403_2602
                // J111_0403_2603
                showDialog("ConnectionException");
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }

            /* Abandon media resource */
            try {
                if( mi != null ) {
                    mi.dispose();
                }
                if( ms != null ) {
                    ms.dispose();
                }
                if( md != null ) {
                    md.dispose();
                }
            } catch( Exception e ) {}
        }
    }
}
