/**
 * J111_0405_0101
 * MainPanel
 *
 * Confirmation of Resource lock operations of media testing
 *
 * $Id: J111_0405_0101.java,v 1.1 2002/01/07 07:03:42 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of Resource lock operations of media testing
 * @extends IApplication
 */
public class J111_0405_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of Resource lock operations of media testing
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menuItems = {
            "1 GIF87a",
            "2 GIF89a",
            "3 JFIF",
            "4 MFi"
        };
        String[] filenames = {
            "87a-1.gif",
            "89a6-1.gif",
            "jfif2-1.jpg",
            "MFi1-1.mld"
        };

        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton      = new Button("execute");
        Label   label            = new Label("Resource lock");
        TextBox statusBox        = new TextBox("",20,2,TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media test");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu.setItems(menuItems);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);
            add(statusBox);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* When Menu is selected, */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* Clear text */
                statusBox.setText("");
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                statusBox.setText("");
                // J111_0405_0101
                // J111_0405_0108
                // J111_0405_0114
                // J111_0405_0117
                /* Startup of threads by Resource read */
                ReadResThread readResT = new ReadResThread();
                readResT.start();
                /* Delay by 1 second */
                try {
                    Thread.sleep(1000);
                } catch( Exception e ) {}
                /* Read media data from Resource */
                readRes();
            }
        }


        /**
         * Method to read media data from Resource
         */
        public void readRes() {
            /* Acquire the menu index */
            int idx = menu.getSelectedIndex();

            /* Load media from Resource by MediaManager */
            MediaImage mi = null;
            MediaSound ms = null;
            try {
                if( idx <= 2 ) {
                    mi = MediaManager.getImage("resource:///"+filenames[idx]);
                    mi.use();
                } else {
                    ms = MediaManager.getSound("resource:///"+filenames[idx]);
                    ms.use();
                }
                statusBox.setText("Reading successful");
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }

            /* Abandon media resource */
            try {
                if( mi != null ) {
                    mi.dispose();
                }
                if( ms != null ) {
                    ms.dispose();
                }
            } catch( Exception e ) {}
        }


        /**
         * Resource reading threads
         * @extends Thread
         */
        class ReadResThread extends Thread {
            /**
             * ReadResThread constructor
             */
            public ReadResThread() {}

            /**
             * run method
             */
            public void run() {
                statusBox.setText("ReadThread:Start");
                /* Resource open */
                DataInputStream dis = null;
                try {
                    dis = Connector.openDataInputStream("resource:///"+
                                    filenames[menu.getSelectedIndex()]);
                } catch( Exception e ) {
                    showDialog("ReadThread:open error:" + e.toString());
                    statusBox.setText("ReadThread:Abnormal termination");
                    return;
                }
                /* Read for about 10 seconds */
                try {
                    for( int i=0; i<10; i++ ) {
                        int c = dis.read();
                        Thread.sleep(1000);
                    }
                } catch( Exception e ) {
                    showDialog("ReadThread:read error:" + e.toString());
                    statusBox.setText("ReadThread:Abnormal termination");
                }
                /* Resource close */
                try {
                    dis.close();
                } catch( Exception e ) {
                    showDialog("ReadThread:close error:" + e.toString());
                    statusBox.setText("ReadThread:Abnormal termination");
                }
                statusBox.setText("ReadThread:Completed");
            }
        }
    }
}
