/**
 * J111_0601_0201
 * Confirmation of operations of when movie is replayed
 * Confirmation of operations of delay in Animation GIF
 *
 * $Id: J111_0601_0201.java,v 1.1 2002/01/07 08:14:54 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of operations of when movie is replayed
 * Confirmation of operations of delay in Animation GIF
 * @extends IApplication
 */
public class J111_0601_0201 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Confirmation of operations of when movie is replayed
 * Confirmation of operations of delay in animation GIF - Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, selection of movie type */
    String[] menuListItem = {
        "1.Minimum delay operations",
        "2.Delay  0 display",
        "3.delays between segments inconsistent"
    };

    Label   classLabel1 = new Label("Operations of animation GIF playback");
    Label   classLabel2 = new Label("Confirmation of delay operations ");
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        menuList.setItems(menuListItem);
        setTitle("normal route media");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel1);
        add(classLabel2);
        add(menuList);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            switch (menuList.getSelectedIndex()) {

//J111_0601_0201 (Confirmation of operations of minimum delay)
            case 0:
                Display.setCurrent(new SubPanel(this, "89a4-1-1.gif"));
                break;

//J111_0201_0409 (Confirmation of display of the case delay is 0)
            case 1:
                Display.setCurrent(new SubPanel(this, "89a4-1-2.gif"));
                break;

//J111_0201_0410 (Confirmation of operations of the case delays between segments are inconsistent)
            case 2:
                Display.setCurrent(new SubPanel(this, "89a4-1-3.gif"));
                break;

            default:
                break;
            }
        }
    }
}

/**
 * Confirmation of operations of when movie is replayed
 * Confirmation of operations of delay in animation GIF - sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    MediaImage viewImage;
    Frame prevFrame;
    VisualPresenter visualImage = new VisualPresenter();
    TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);

    /**
     * Display a sub screen
     * @param aFrame  Main screen object
     * @param aString Reading file name
     */
    public SubPanel(Frame aFrame, String aString) {

        /* Object name setting */
        prevFrame = aFrame;
        String mediaPath = "resource:///" + aString;

        /* Acquisition of image objects */
        viewImage = MediaManager.getImage(mediaPath);
        
        /* Reading media */
        try {
            viewImage.use();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Reading unsuccessful" + e.toString());
            errDialog.show();
            IApplication.getCurrentApp().terminate();
        }

        /* Set an image to VisualPresenter */
        visualImage.setImage(viewImage);

        try {
            /* Display sub panels */
            ShowSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* VisualPresenter */
        add(visualImage);

        /* Settings of display items */
        setTitle("normal route media");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Add each component to screen */
        add(resultText);

        /* Listener setting */
        setSoftKeyListener(this);

        try {
            /* Playback in VisualPresenter */
            visualImage.play();
            resultText.setText("OK\nDisplaySuccessful\n");
        } catch (Exception e) {
            resultText.setText("NG\nDisplayFailed\n");
            resultText.setText(resultText.getText()+e.toString());
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J111_0601_0201.mainPanel);
        }
    }
}
