/**
 * J112_0101_0101
 * Confirmation of minimum read operations by scheme
 * HTTP communication
 * $Id: J112_0101_0101.java,v 1.2 2002/02/26 07:28:34 takanao Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of minimum read operations by scheme - HTTP communication
 * @extends IApplication
 */
public class J112_0101_0101 extends IApplication {
    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
    Display.setCurrent(new MainPanel());
    }

    /**
     * Confirmation of minimum read operations by scheme - Main screen of HTTP communication
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

        String[] menuListItem = {
            "1.GIF87a 0Byte",
            "2.GIF89a 0Byte",
            "3.JFIF   0Byte",
            "4.EXIF   0Byte",
            "5.iMelody 0Byte"
        };

        Label   classLabel = new Label("Minimum read operations of HTTP communication");
        ListBox menuList   = new ListBox(ListBox.CHOICE);
        Button  execButton = new Button("execute");
        TextBox resultText = new TextBox("", 20, 3, TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            try {
                /* Main panel display */
                showMainPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        /**
         * Display a main panel
         */
        void showMainPanel() {

            /* Settings of display items */
            menuList.setItems(menuListItem);
            setTitle("Media boundary type");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(classLabel);
            add(menuList);
            add(execButton);
            add(resultText);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                resultText.setText("");
                switch (menuList.getSelectedIndex()) {
//J112_0101_0101 (GIF87a Size 0Byte)
                case 0:
                    GetMediaImage("87a_J-1.gif");
                    break;

//J112_0101_0103 (GIF89a Size 0Byte)
                case 1:
                    GetMediaImage("89a_J-3.gif");
                    break;

//J112_0101_0113 (JFIF Size 0Byte)
                case 2:
                    GetMediaImage("JFIF_J-13.jpg");
                    break;

//J112_0101_0115 (EXIF Size 0Byte)
                case 3:
                    GetMediaImage("EXIF_J-15.jpg");
                    break;

//J112_0101_0117 (iMelody Size 0Byte)
                case 4:
                    GetMediaSound("MFi_J-17.mld");
                    break;

                default:
                    break;
                }
            }
        }
        
        /**
         * Reading and determination of image media
         * @param aString Reading file name
         */
        void GetMediaImage(String aString) {

            /* Setting a variable for read purpose */
            MediaImage imageData;

            /* Object name setting */
            String mediaPath = getSourceURL() + aString;
            
            /* Acquisition of an object of media image */
            imageData = MediaManager.getImage(mediaPath);

            /* Reading media */
            try {
                imageData.use();
                resultText.setText("NG\nReadSuccessful\n");
            } catch (IOException ioe){
                resultText.setText("OK\nReadFailed\n");
                resultText.setText(resultText.getText()+ioe.toString());
            } catch (Exception e) {
                resultText.setText("OK\nReadFailed\n");
            }
        }

        /**
         * Reading and determination of sound media
         * @param aString Reading file name
         */
        void GetMediaSound(String aString) {

            /* Setting a variable for read purpose */
            MediaSound soundData;

            /* Object name setting */
            String mediaPath = getSourceURL() + aString;
            
            /* Acquisition of objects of media sound */
            soundData = MediaManager.getSound(mediaPath);

            /* Reading media */
            try {
                soundData.use();
                resultText.setText("NG\nReadSuccessful\n");
            } catch (IOException ioe){
                resultText.setText("OK\nReadFailed\n");
                resultText.setText(resultText.getText()+ioe.toString());
            } catch (Exception e) {
                resultText.setText("OK\nReadFailed\n");
            }
        }
    }
}
