/**
 * J112_0101_0401
 * Confirmation of minimum read operations by scheme
 * Scratchpad specification
 *
 * $Id: J112_0101_0401.java,v 1.2 2002/02/26 07:28:54 takanao Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Confirmation of minimum read operations by scheme - Scratchpad specification
 * @extends IApplication
 */
public class J112_0101_0401 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Confirmation of minimum read operations by scheme - Main screen of Scratchpad specification
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Selection of Menu Media type */
        String[] menuListItem = {
            "1.GIF87a 0Byte",
            "2.GIF89a 0Byte",
            "3.JFIF   0Byte",
            "4.EXIF   0Byte",
            "5.iMelody 0Byte"
        };

    Label   classLabel1 = new Label("Scratchpad Specification");
    Label   classLabel2 = new Label("Minimum read");
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  writeButton = new Button("Write");
    
    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        menuList.setItems(menuListItem);
        setTitle("Media boundary type");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel1);
        add(classLabel2);
        add(menuList);
        add(writeButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When "Write" button is pressed */
        if (aComponent == writeButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            switch (menuList.getSelectedIndex()) {

//J112_0101_0401 (GIF87a Size 0Byte)
            case 0:
                Display.setCurrent(new SubPanel(this, "87a_J-1.gif"));
                break;

//J112_0101_0403 (GIF89a Size 0Byte)
            case 1:
                Display.setCurrent(new SubPanel(this, "89a_J-3.gif"));
                break;

//J112_0101_0413 (JFIF Size 0Byte)
            case 2:
                Display.setCurrent(new SubPanel(this, "JFIF_J-13.jpg"));
                break;

//J112_0101_0415 (EXIF Size 0Byte)
            case 3:
                Display.setCurrent(new SubPanel(this, "EXIF_J-15.jpg"));
                break;

//J112_0101_0417 (iMelody Size 0Byte)
            case 4:
                Display.setCurrent(new SubPanel(this, "MFi_J-17.mld"));
                break;

            default:
                break;
            }
        }
    }

    /**
     * Confirmation of minimum read operations by scheme - Sub screen of Scratchpad specification
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

        Frame prevFrame;
        Label classLabel = new Label("Confirmation of reading Scratchpad specification");
        Button execButton = new Button("execute");
        TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);

        /**
         * Display a sub screen
         * @param aFrame  Main screen object
         * @param aString Reading file name
         */
        public SubPanel(Frame aFrame, String aString) {

            /* Object name setting */
            prevFrame = aFrame;
            String mediaPath = "resource:///" + aString;

            /* Acquisition of data */
            byte bData[] = loadData(mediaPath);
            
            /* Writing into Scratchpad */
            writeScratchpad(bData);

            try {
                /* Display sub panels */
                ShowSubPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        void ShowSubPanel() {

            /* Settings of display items */
            setTitle("Media boundary type");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");
            setSoftLabel(Frame.SOFT_KEY_2, "back");
            
            /* Add each component to screen */
            add(classLabel);
            add(execButton);
            add(resultText);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);

        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }

            /* When soft key2 is released, return to the main screen */
            if (anIndex == Frame.SOFT_KEY_2) {
                Display.setCurrent(J112_0101_0401.mainPanel);
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                /**
                 * Acquisition and determination of data objects
                 * Separate determination in the case of "sound"
                 */
                if (menuList.getSelectedIndex() == 4) {
                    GetMediaSound();
                } else {
                    GetMediaImage();
                }
            }
        }

        /**
        * Acquisition of data
        */
        private byte[] loadData(String aString) {
            DataInputStream dis = null;
            byte[] bData = new byte[1024];

            try {
                dis = Connector.openDataInputStream(aString);
                int iCheck = dis.read(bData);
            } catch (IOException e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Reading SP:NG(IOException)");
                errDialog.show();
                IApplication.getCurrentApp().terminate();
            } finally {
                try {
                    if (dis != null) {
                        dis.close();
                    }
                } catch (IOException ie) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Connection Close:NG" + ie.toString());
                    errDialog.show();
                }
            }
            
            return bData;
        }

        /**
        * Write into Scratchpad
        * @param anImage Data written
        */
        private void writeScratchpad(byte[] aByte) {
            DataOutputStream dos = null;
            
            try {
                /* Specify the location as 512byte*/
                dos = Connector.openDataOutputStream("scratchpad:///0");
                dos.write(aByte);
                resultText.setText("Writing SP completed");
            } catch (IOException e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Writing SP:NG" + e.toString());
                errDialog.show();
                resultText.setText("Writing SP:NG");
            } finally {
                try {
                    if (dos != null) {
                        dos.close();
                    }
                } catch (IOException ie) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Connection Close:NG" + ie.toString());
                    errDialog.show();
                    resultText.setText("Writing SP:NG");
                }
            }
        }

        /**
         * Reading and determination of image media
         */
        void GetMediaImage() {

            /* Setting a variable for read purpose */
            MediaImage imageData;

            /* Acquisition of objects of media data */
            imageData = MediaManager.getImage("scratchpad:///0");

            /* Reading media */
            try {
                imageData.use();
                resultText.setText("NG\nReadSuccessful\n");
            } catch (IOException ioe){
                resultText.setText("OK\nReadFailed\n");
                resultText.setText(resultText.getText()+ioe.toString());
            } catch (Exception e) {
                resultText.setText("OK\nReadFailed\n");
            }
        }

        /**
         * Reading and determination of sound media
         */
        void GetMediaSound() {

            /* Setting a variable for read purpose */
            MediaSound soundData;

            /* Acquisition of objects of media data */
            soundData = MediaManager.getSound("scratchpad:///0");

            /* Reading media */
            try {
                soundData.use();
                resultText.setText("NG\nReadSuccessful\n");
            } catch (IOException ioe){
                resultText.setText("OK\nReadFailed\n");
                resultText.setText(resultText.getText()+ioe.toString());
            } catch (Exception e) {
                resultText.setText("OK\nReadFailed\n");
            }
        }
    }
}
