/**
 * J112_0102_0401
 * Confirmation of maximum read operations by scheme
 * Scratchpad specification
 *
 * $Id: J112_0102_0401.java,v 1.1 2002/02/01 06:16:34 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Confirmation of maximum read operations by scheme - Scratchpad specification
 * @extends IApplication
 */
public class J112_0102_0401 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }


    /**
     * Confirmation of maximum read operations by scheme - Main screen of Scratchpad specification
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

        /* Selection of Menu Media type */
            String[] menuListItem = {
                "1.GIF87aNormal",
                "2.GIF87aInterlace",
                "3.GIF89aNormal",
                "4.GIF89aInterlace",
                "5.GIF89aTransparent",
                "6.GIF89aAnimation",
                "7.GIF89aTransparent animation",
                "8.GIF89aNormalC",
                "9.GIF89aInterlaceC",
                "10.GIF89aTransparentC",
                "11.GIF89aAnimationC",
                "12.GIF89aTransparentAnimationC",
                "13.JFIF",
                "14.JFIF C"
            };

        Label   classLabel1 = new Label("Scratchpad Specification");
        Label   classLabel2 = new Label("Maximum read");
        ListBox menuList   = new ListBox(ListBox.CHOICE);
        Button  writeButton = new Button("Write");
        TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);
        
        /* URI for testing */
        String spName = "scratchpad:///0";

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            try {
                /* Main panel display */
                showMainPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        /**
         * Display a main panel
         */
        void showMainPanel() {

            /* Settings of display items */
            menuList.setItems(menuListItem);
            setTitle("Media boundary type");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(classLabel1);
            add(classLabel2);
            add(menuList);
            add(writeButton);
            add(resultText);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* When "Write" button is pressed */
            if (aComponent == writeButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                resultText.setText("SP being written..");
                switch (menuList.getSelectedIndex()) {

//J112_0102_0401 (GIF87a Normal)
                case 0:
                    Display.setCurrent(new SubPanel(this, "87a-5"));
                    break;

//J112_0102_0402 (GIF87a Interlace)
                case 1:
                    Display.setCurrent(new SubPanel(this, "87a-11"));
                    break;

//J112_0102_0403 (GIF89a Normal no copyright held)
                case 2:
                    Display.setCurrent(new SubPanel(this, "89a1-5"));
                    break;

//J112_0102_0404 (GIF89a Interlace no copyright held)
                case 3:
                    Display.setCurrent(new SubPanel(this, "89a2-5"));
                    break;

//J112_0102_0405 (GIF89a Transparent no copyright held)
                case 4:
                    Display.setCurrent(new SubPanel(this, "89a3-5"));
                    break;

//J112_0102_0406 (GIF89a Animation no copyright held)
                case 5:
                    Display.setCurrent(new SubPanel(this, "89a4-5"));
                    break;

//J112_0102_0407 (GIF89a TransparentAnimation no copyright held)
                case 6:
                    Display.setCurrent(new SubPanel(this, "89a5-5"));
                    break;

//J112_0102_0408 (GIF89a Normal with copyright held)
                case 7:
                    Display.setCurrent(new SubPanel(this, "89a6-5"));
                    break;

//J112_0102_0409 (GIF89a Interlace with copyright held)
                case 8:
                    Display.setCurrent(new SubPanel(this, "89a7-5"));
                    break;

//J112_0102_0410 (GIF89a Transparent with copyright held)
                case 9:
                    Display.setCurrent(new SubPanel(this, "89a8-5"));
                    break;

//J112_0102_0411 (GIF89a Animation with copyright held)
                case 10:
                    Display.setCurrent(new SubPanel(this, "89a9-5"));
                    break;

//J112_0102_0412 (GIF89a TransparentAnimation with copyright held)
                case 11:
                    Display.setCurrent(new SubPanel(this, "89a10-5"));
                    break;

//J112_0102_0413 (JFIF no copyright held BaseLine)
                case 12:
                    Display.setCurrent(new SubPanel(this, "JFIF1-5"));
                    break;

//J112_0102_0414 (JFIF with copyright held BaseLine)
                case 13:
                    Display.setCurrent(new SubPanel(this, "JFIF2-5"));
                    break;

//J112_0102_0415 (EXIF no copyright held BaseLine)
//Test cannot be conducted

//J112_0102_0416 (EXIF with copyright held BaseLine)
//Test cannot be conducted

//J112_0102_0417 (iMelody no copyright held iMelody1.0) 
//Test cannot be conducted

//J112_0102_0418 (iMelody with copyright held iMelody1.0) 
    //Test cannot be conducted

                default:
                    break;
                }
            }
        }

        /**
         * Confirmation of maximum read operations by scheme - Sub screen of Scratchpad specification
         * @extends Panel
         * @implements SoftKeyListener
         * @implements ComponentListener
         */
        class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

            Frame prevFrame;
            Label classLabel = new Label("Confirmation of reading Scratchpad specification");
            Button execButton = new Button("execute");
            TextBox textBox = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);

            /**
             * Display a sub screen
             * @param aFrame  Main screen object
             * @param aString Reading file name
             */
            public SubPanel(Frame aFrame, String aString) {

                /* Object name setting */
                prevFrame = aFrame;

                try {
                    /**
                     * Acquisition of data
                     * Acquire data of 100k in ten times by dividing it
                     */
                    setupScratchpad(aString);
                    textBox.setText("Writing SP completed");

                    /* Display sub panels */
                    ShowSubPanel();
                } catch (Exception e) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Error:" + e.toString());
                    errDialog.show();
                    textBox.setText("NG:SP writing failed");
                }
            }

            void ShowSubPanel() {

                /* Settings of display items */
                setTitle("Media boundary type");
                setSoftLabel(Frame.SOFT_KEY_1, "exit");
                setSoftLabel(Frame.SOFT_KEY_2, "back");
                
                /* Add each component to screen */
                add(classLabel);
                add(execButton);
                add(textBox);

                /* Listener setting */
                setSoftKeyListener(this);
                setComponentListener(this);

            }

            /**
             * When soft key is pressed, it does not operate
             * @param anIndex  The value of the soft key pressed
             */
            public void softKeyPressed(int anIndex) {}

            /**
             * When soft key1 is released, the application ends
             * @param anIndex  The value of released soft key
             */
            public void softKeyReleased(int anIndex) {

                /* When soft key is released, the application ends */
                if (anIndex == Frame.SOFT_KEY_1) {
                    IApplication.getCurrentApp().terminate();
                }

                /* When soft key2 is released, return to the main screen */
                if (anIndex == Frame.SOFT_KEY_2) {
                    Display.setCurrent(J112_0102_0401.mainPanel);
                }
            }

            /**
             * Receive events occurred in components
             * @param aComponent  Component where an event occurred
             * @param aType  Type of events
             * @param aParam  Parameter of events
             */
            public void componentAction(Component aComponent, int aType, int aParam) {

                /* In the case execute button is pressed */
                if (aComponent == execButton
                    && aType == ComponentListener.BUTTON_PRESSED) {
                    try {
                        GetMediaImage();
                        textBox.setText("OK\nReadingSuccessful\n");
                    } catch (Exception e) {
                        textBox.setText("NG\nReadingUnsuccessful\n");
                        textBox.setText(resultText.getText()+e.toString());
                    }
                }
            }

            /**
             * Copy specified media to Scratchpad
             * @param aNames Media list
             * @throws Exception In the case unexpected exceptions occur
             */
            public void setupScratchpad(String aString) throws Exception {

                HttpConnection  con = null;
                InputStream in = null;
                OutputStream out = null;
                int byteCounter = 0;
                String url = getSourceURL() + aString + "/" + aString + ".00";

                /* Scratchpad Clear*/
                try {
                    out = Connector.openOutputStream(spName);
                    for (int i=0; i<102400;i++) {
                        out.write(0);
                    }
                } catch (Exception ioe) {
                } finally {
                    out.close();
                    out = null;
                }

                /* Media Copy */
                out = Connector.openOutputStream(spName);
                for (int i=0; i<10; i++) {
                    resultText.setText("SP being written.." + (i + 1) + "File name");
                    con = (HttpConnection) Connector.open(url + i, Connector.READ, true);
                    con.setRequestMethod(HttpConnection.GET);
                    con.connect();
                    in = con.openInputStream();
                    int inData;
                    while ((inData = in.read()) != -1) {
                        byteCounter++;
                        out.write(inData);
                    }
                    in.close();
                    con.close();
                }
                out.close();
            }

            /**
             * Reading and determination of image media
             */
            void GetMediaImage() throws Exception {
                /* Setting a variable for read purpose */
                MediaImage imageData;

                /* Reading media */
                imageData = MediaManager.getImage(spName);
                imageData.use();
            }
        }
    }
}
