/**
 * J112_0103_0201
 * Confirmation of maximum read operations by scheme
 * SSL Communication
 * $Id: J112_0103_0201.java,v 1.1 2002/01/07 07:59:34 misato Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of maximum read operations by scheme - SSL communication
 * @extends IApplication
 */
public class J112_0103_0201 extends IApplication {
    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
    Display.setCurrent(new MainPanel());
    }

    /**
     * Confirmation of maximum read operations by scheme - Main screen of SSL communication
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

        String[] menuListItem = {
            "1.GIF87a Normal",
            "2.GIF87a Interlace",
            "3.GIF89a Normal",
            "4.GIF89a Interlace",
            "5.GIF89a Transparent",
            "6.GIF89a Animation",
            "7.GIF89a Transparent animation",
            "8.GIF89a Normal-C",
            "9.GIF89a Interlace-C",
            "10.GIF89a Transparent-C",
            "11.GIF89a Animation-C",
            "12.GIF89a Transparent animation-C",
            "13.JFIF",
            "14.JFIF-C",
            "15.iMelody",
            "16.iMelody-C"
        };

        Label   classLabel = new Label("Maximum read operations of SSL communication");
        ListBox menuList   = new ListBox(ListBox.CHOICE);
        Button  execButton = new Button("execute");
        TextBox resultText = new TextBox("", 20, 3, TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            try {
                /* Main panel display */
                showMainPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        /**
         * Display a main panel
         */
        void showMainPanel() {

            /* Settings of display items */
            menuList.setItems(menuListItem);
            setTitle("Media boundary type");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(classLabel);
            add(menuList);
            add(execButton);
            add(resultText);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                resultText.setText("");
                switch (menuList.getSelectedIndex()) {
//J112_0103_0201
                case 0:
                    GetMediaImage("87a-3.gif");
                    break;

//J112_0103_0202
                case 1:
                    GetMediaImage("87a-9.gif");
                    break;

//J112_0103_0203
                case 2:
                    GetMediaImage("89a1-3.gif");
                    break;

//J112_0103_0204
                case 3:
                    GetMediaImage("89a2-3.gif");
                    break;

//J112_0103_0205
                case 4:
                    GetMediaImage("89a3-3.gif");
                    break;

//J112_0103_0206
                case 5:
                    GetMediaImage("89a4-3.gif");
                    break;

//J112_0103_0207
                case 6:
                    GetMediaImage("89a5-3.gif");
                    break;

//J112_0103_0208
                case 7:
                    GetMediaImage("89a6-3.gif");
                    break;

//J112_0103_0209
                case 8:
                    GetMediaImage("89a7-3.gif");
                    break;

//J112_0103_0210
                case 9:
                    GetMediaImage("89a8-3.gif");
                    break;

//J112_0103_0211
                case 10:
                    GetMediaImage("89a9-3.gif");
                    break;

//J112_0103_0212
                case 11:
                    GetMediaImage("89a10-3.gif");
                    break;

//J112_0103_0213
                case 12:
                    GetMediaImage("JFIF1-3.jpg");
                    break;

//J112_0103_0214
                case 13:
                    GetMediaImage("JFIF2-3.jpg");
                    break;

//J112_0103_0217
                case 14:
                    GetMediaSound("MFi30k.mld");
                    break;

//J112_0103_0218
                case 15:
                    GetMediaSound("MFi30k-C.mld");
                    break;

                default:
                    break;
                }
            }
        }
        
        /**
         * Reading and determination of image media
         * @param aString Reading file name
         */
        void GetMediaImage(String aString) {

            /* Setting a variable for read purpose */
            MediaImage imageData;

            /* Object name setting */
            String mediaPath = getSourceURL() + "../media/" +aString;
            
            /* Acquisition of an object of media image */
            imageData = MediaManager.getImage(mediaPath);

            /* Reading media */
            try {
                imageData.use();
                resultText.setText("NG\nReadSuccessful\n");
            }catch (ConnectionException ce) {
                resultText.setText("OK\nReadFailed");
            }catch (Exception e) {
                resultText.setText("NG\nReadingUnsuccessful\n"+e.toString());
            }
        }

        /**
         * Reading and determination of sound media
         * @param aString Reading file name
         */
        void GetMediaSound(String aString) {

            /* Setting a variable for read purpose */
            MediaSound soundData;

            /* Object name setting */
            String mediaPath = getSourceURL() +"../media/"+ aString;
            
            /* Acquisition of objects of media sound */
            soundData = MediaManager.getSound(mediaPath);

            /* Reading media */
            try {
                soundData.use();
                resultText.setText("NG\nReadSuccessful\n");
            }catch (ConnectionException ce) {
                resultText.setText("OK\nReadFailed");
            }catch (Exception e) {
                resultText.setText("NG\nReadingUnsuccessful\n"+e.toString());
            }
        }
    }
}
