/**
 * J112_0202_0201
 * Confirmation of read operations of over maximum length by scheme
 * SSL Communication
 * $Id: J112_0202_0201.java,v 1.2 2002/01/18 05:03:18 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of read operations of over maximum length by scheme - SSL communication
 * @extends IApplication
 */
public class J112_0202_0201 extends IApplication {
    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
    Display.setCurrent(new MainPanel());
    }

    /**
     * Confirmation of read operations of over maximum length by scheme - Main screen of SSL communication
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

        String[] menuListItem = {
            "1.GIF87a ",
            "2.GIF89a with copyright held",
            "3.JFIF   with copyright held",
            "4.iMelody"
        };

        Label   classLabel = new Label("SSL communication reading exceeding maximum length");
        ListBox menuList   = new ListBox(ListBox.CHOICE);
        Button  execButton = new Button("execute");
        TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);
        int testType;
        
        /**
         * getSourceURL() -> 68 characters
         * 180 characters out of 188 in a file name to be omitted 
         */
        String URL = getSourceURL();
        String GIF87a  = "g87a.gif";  /* GIF87a    */
        String GIF89a  = "g89a.gif";  /* GIF89a    */
        String JFIF    = "jpeg.jpg";  /* JFIF      */
        String iMelody = "midi.mld";  /* iMelody   */

        
        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            try {
                /* Main panel display */
                showMainPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        /**
         * Display a main panel
         */
        void showMainPanel() {

            /* Settings of display items */
            menuList.setItems(menuListItem);
            setTitle("Media boundary type");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(classLabel);
            add(menuList);
            add(execButton);
            add(resultText);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                resultText.setText("");
                
                switch (menuList.getSelectedIndex()) {
//J112_0202_0201 (GIF87a)
                case 0:
                    GetMediaImage(GIF87a);
                    break;

//J112_0202_0208 (GIF89a)
                case 1:
                    GetMediaImage(GIF89a);
                    break;

//J112_0202_0214 (JFIF)
                case 2:
                    GetMediaImage(JFIF);
                    break;

//J112_0202_0215 (EXIF)
//Test cannot be conducted

//J112_0202_0217 (iMelody)
                case 3:
                    GetMediaSound(iMelody);
                    break;

                default:
                    break;
                }
            }
        }
        
        /**
         * Reading and determination of image media
         * @param aString Reading file name
         */
        void GetMediaImage(String aString) {

            /* Setting a variable for read purpose */
            MediaImage imageData;

            /* Supplement 180 characters of file names */
            String mediaPath = URL;
            for (int i=0; i<18; i++) {
                mediaPath = mediaPath + "1234567890";
            }

            mediaPath = mediaPath + aString;

            /* Reading media */
            try {
                imageData = MediaManager.getImage(mediaPath);
                imageData.use();
                resultText.setText("NG\nReadSuccessful\n");
            } catch (Exception e){
                Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
                msgDialog.setText("OK ->" + e.toString());
                msgDialog.show();
            }
        }

        /**
         * Reading and determination of sound media
         * @param aString Reading file name
         */
        void GetMediaSound(String aString) {

            /* Setting a variable for read purpose */
            MediaSound soundData;

            /* Supplement 180 characters of file names */
            String mediaPath = URL;
            for (int i=0; i<18; i++) {
                mediaPath = mediaPath + "1234567890";
            }

            mediaPath = mediaPath + aString;

            /* Reading media */
            try {
                soundData = MediaManager.getSound(mediaPath);
                soundData.use();
                resultText.setText("NG\nReadSuccessful\n");
            } catch (Exception e){
                Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
                msgDialog.setText("OK ->" + e.toString());
                msgDialog.show();
            }
        }
    }
}
