/**
 * J112_0401_0101
 * Confirmation of animation operations
 * Confirmation of loop operations
 *
 * $Id: J112_0401_0101.java,v 1.1 2002/01/07 08:27:17 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Confirmation of animation operations
 * Confirmation of loop operations
 * @extends IApplication
 */
public class J112_0401_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Confirmation of animation operations
 * Confirmation of loop operations - Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, selection of movie type */
    String[] menuListItem = {
        "1.Loop maximum operations",
        "2.Loop operations exceeding the maximum",
        "3.Loop infinite operations"
    };

    Label   classLabel1 = new Label("Animation operations");
    Label   classLabel2 = new Label("Confirmation of loop operations");
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");
    int testType = 0;
    
    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        menuList.setItems(menuListItem);
        setTitle("Media boundary type");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel1);
        add(classLabel2);
        add(menuList);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            testType = menuList.getSelectedIndex();
            switch (testType) {

//J112_0401_0101 (Confirmation of loop minimum operations)
//Evaluation cannot be implemented

//J112_0401_0201 (Confirmation of loop maximum operations)
            case 0:
                Display.setCurrent(new SubPanel(testType, this, "89a5-17.gif"));
                break;

//J112_0401_0301 (Confirmation of look operations exceeding maximum)
            case 1:
                Display.setCurrent(new SubPanel(testType, this, "89a5-16.gif"));
                break;

//J112_0401_0401 (Confirmation of loop infinite operations)
            case 2:
                Display.setCurrent(new SubPanel(testType, this, "89a5-i.gif"));
                break;

            default:
                break;
            }
        }
    }
}

/**
 * Confirmation of animation operations
 * Confirmation of loop operations - Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    MediaImage viewImage;
    Frame prevFrame;
    VisualPresenter visualImage = new VisualPresenter();
    TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);
    int testTyep = 0;

    /**
     * Display a sub screen
     * @param aFrame  Main screen object
     * @param aString Reading file name
     * @param anInt   Test pattern
     */
    public SubPanel(int anInt, Frame aFrame, String aString) {

        /* Object name setting */
        testTyep = anInt;
        prevFrame = aFrame;
        String mediaPath = "resource:///" + aString;

        /* Acquisition of image objects */
        viewImage = MediaManager.getImage(mediaPath);
        
        /* Reading media */
        try {
            viewImage.use();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Reading unsuccessful" + e.toString());
            errDialog.show();
            IApplication.getCurrentApp().terminate();
        }

        /* Set an image to VisualPresenter */
        visualImage.setImage(viewImage);

        try {
            /* Display sub panels */
            ShowSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* VisualPresenter */
        add(visualImage);

        /* Settings of display items */
        setTitle("Media boundary type");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Add each component to screen */
        add(resultText);

        /* Listener setting */
        setSoftKeyListener(this);

        try {
            /* Playback in VisualPresenter */
            visualImage.play();
            resultText.setText("OK\nDisplaySuccessful\n");
        } catch (Exception e) {
            resultText.setText("NG\nDisplayFailed\n");
            resultText.setText(resultText.getText()+e.toString());
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J112_0401_0101.mainPanel);
        }
    }
}
