/**
 * J112_0601_0101
 * Confirmation of read operations of Scratchpad location specification
 *
 * $Id: J112_0601_0101.java,v 1.1 2002/01/07 08:32:04 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Confirmation of read operations of Scratchpad location specification
 * @extends IApplication
 */
public class J112_0601_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Confirmation of read operations of Scratchpad location specification
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu Selection of the location to be read into */
    String[] menuListItem1 = {
        "1.Position -1",
        "2.Position 100k",
        "3.Position 100k+1"
    };

    String[] menuListItem2 = {
        "1.GIF87aNormal",
        "2.GIF89aNormalC",
        "3.JFIF C",
        "4.iMelody",
    };

    Label   classLabel = new Label("Confirmation of writing location-specified SP");
    ListBox menuList1   = new ListBox(ListBox.CHOICE);
    ListBox menuList2   = new ListBox(ListBox.CHOICE);
    Button  writeButton = new Button("Write");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2);
        setTitle("Media boundary type");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(writeButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When "Write" button is pressed */
        if (aComponent == writeButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int testType = menuList1.getSelectedIndex();
            switch (menuList2.getSelectedIndex()) {

//J112_0601_0101 (GIF87a Normal)
//J112_0601_0201
//J112_0601_0301

            case 0:
                Display.setCurrent(new SubPanel(this, testType, "87a-1.gif"));
                break;

//J112_0601_0108 (GIF89a with copyright held Normal)
//J112_0601_0208
//J112_0601_0308
            case 1:
                Display.setCurrent(new SubPanel(this, testType, "89a6-1.gif"));
                break;

//J112_0601_0114 (JFIF with copyright held BaseLine)
//J112_0601_0214
//J112_0601_0314
            case 2:
                Display.setCurrent(new SubPanel(this, testType, "JFIF2-1.jpg"));
                break;

//J112_0601_0115 (EXIF no copyright held BaseLine)
//Test cannot be conducted
//J112_0601_0215
//Test cannot be conducted
//J112_0601_0315
//Test cannot be conducted


//J112_0601_0117 (iMelody no copyright held iMelody1.0) 
//J112_0601_0217
//J112_0601_0317
            case 3:
                Display.setCurrent(new SubPanel(this, testType, "MFi1-1.mld"));
                break;

            default:
                break;
            }
        }
    }

    /**
     * Confirmation of read operations of Scratchpad location specification
     * Sub screen
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

        Frame prevFrame;
        Label classLabel = new Label("Confirmation of reading location-specified SP");
        Button execButton = new Button("execute");
        TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);
        String readPos;
        /**
         * Display a sub screen
         * @param aFrame  Main screen object
         * @param aString Reading file name
         */
        public SubPanel(Frame aFrame, int anInt, String aString) {

            /* Object name setting */
            prevFrame = aFrame;
            String mediaPath = "resource:///" + aString;

            switch (anInt) {
            case 0:
                readPos = "scratchpad:///0;pos=-1";
                break;
                
            case 1:
//2002/09/03 DoJa1.5                readPos = "scratchpad:///0;pos=102399";
                readPos = "scratchpad:///0;pos=102400";
                break;

            case 2:
//2002/09/03 DoJa1.5                readPos = "scratchpad:///0;pos=102400";
                readPos = "scratchpad:///0;pos=102401";
                break;
            
            }

            /* Acquisition of data */
            byte bData[] = loadData(mediaPath);
            
            /* Writing into Scratchpad */
            writeScratchpad(bData);

            try {
                /* Display sub panels */
                ShowSubPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        void ShowSubPanel() {

            /* Settings of display items */
            setTitle("Media boundary type");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");
            setSoftLabel(Frame.SOFT_KEY_2, "back");
            
            /* Add each component to screen */
            add(classLabel);
            add(execButton);
            add(resultText);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);

        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }

            /* When soft key2 is released, return to the main screen */
            if (anIndex == Frame.SOFT_KEY_2) {
                Display.setCurrent(J112_0601_0101.mainPanel);
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                /**
                 * Acquisition and determination of data objects
                 * Separate determination in the case of "sound"
                 */
                if (menuList2.getSelectedIndex() == 3) {
                    GetMediaSound(readPos);
                } else {
                    GetMediaImage(readPos);
                }
            }
        }

        /**
        * Acquisition of data
        */
        private byte[] loadData(String aString) {
            DataInputStream dis = null;
            byte[] bData = new byte[8192];

            try {
                dis = Connector.openDataInputStream(aString);
                int iCheck = dis.read(bData);
                if  (iCheck == -1) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Read NG: No data");
                    errDialog.show();
                    dis.close();
                }
            } catch (IOException e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Read:NG(IOException)");
                errDialog.show();
                IApplication.getCurrentApp().terminate();
            } finally {
                try {
                    if (dis != null) {
                        dis.close();
                    }
                } catch (IOException ie) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Connection Close:NG" + ie.toString());
                    errDialog.show();
                }
            }
            
            return bData;
        }

        /**
        * Write into Scratchpad
        * @param anImage Data written
        */
        private void writeScratchpad(byte[] aByte) {
            DataOutputStream dos = null;
            
            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                dos.write(aByte);
                resultText.setText("Writing SP completed");
            } catch (IOException e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Writing SP:NG" + e.toString());
                errDialog.show();
                resultText.setText("Writing SP:NG");
            } finally {
                try {
                    if (dos != null) {
                        dos.close();
                    }
                } catch (IOException ie) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Connection Close:NG" + ie.toString());
                    errDialog.show();
                    resultText.setText("Writing SP:NG");
                }
            }
        }

        /**
         * Reading and determination of image media
         */
        void GetMediaImage(String aString) {

            /* Setting a variable for read purpose */
            MediaImage imageData;

            /* Reading media */
            try {
                imageData = MediaManager.getImage(aString);
                imageData.use();
                resultText.setText("NG\nReadSuccessful\n");
            } catch(Exception e) {
                    Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
                    msgDialog.setText("OK ->" + e.toString());
                    msgDialog.show();
            }
        }

        /**
         * Reading and determination of sound media
         */
        void GetMediaSound(String aString) {

            /* Setting a variable for read purpose */
            MediaSound soundData;

            /* Reading media */
            try {
                soundData = MediaManager.getSound(aString);
                soundData.use();
                resultText.setText("NG\nReadSuccessful\n");
            } catch(Exception e) {
                    Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
                    msgDialog.setText("OK ->" + e.toString());
                    msgDialog.show();
            }
        }
    }
}
