/**
 * J113_0101_0101
 *
 * Operations of media acquisition(Scratchpad)
 *
 * $Id: J113_0101_0101.java,v 1.1 2002/01/07 08:34:14 uruno Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Operations of media acquisition(Scratchpad)
 * @extends IApplication
 */
public class J113_0101_0101 extends IApplication {

    MainPanel testPanel = new MainPanel();

    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * Menu of media acquiring operations (Scratchpad)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu */
    String[] menuItem = {
        "00 SP Loading", 
        "01 SP(0) Separation",
    };

    /* A list of media names */
    String[] mediaList = {
        "87a-1.gif",
        "89a6-1.gif",
        "jfif2-1.jpg",
        "MFi1-1.mld",
        /* "smf.mid", */
    };

    /* A list of SP points */
    int[] mediaPos;

    /* URI for testing */
    String rsName = "resource:///";
    String spName = "scratchpad:///0";

    boolean isReady = false;


    /* Definition of GUI components */
    TextBox resultBox = new TextBox(null, 16, 16, TextBox.DISPLAY_ANY);
    ListBox menuList = new ListBox(ListBox.CHOICE);
    Button  setupButton = new Button("Test preparation");
    Button  testButton = new Button("Test conduction");

    AudioPresenter testAP;
    VisualPresenter testVP1 = new VisualPresenter();
    VisualPresenter testVP2 = new VisualPresenter();
    VisualPresenter testVP3 = new VisualPresenter();

    MediaImage mi1;
    MediaImage mi2;
    MediaImage mi3;
    MediaSound ms;


    /**
     * Panel generation
     */
    public MainPanel() {

        /* GUI settings */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("Media acquisition(Scratchpad)");
        menuList.setItems(menuItem);

        testAP = AudioPresenter.getAudioPresenter();
        
        testVP1.setSize(32,32);
        testVP2.setSize(32,32);
        testVP3.setSize(32,32);

        /* GUI location */
        add(menuList);
        add(setupButton);
        add(testButton);
        add(testVP1);
        add(testVP2);
        add(testVP3);

        add(resultBox);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

    }

    /** 
     * Soft key handler
     * @param aKey Pressed key
     */
    public void softKeyPressed(int aKey) {}

    /** 
     * Soft key handler
     * @param aKey Released key
     */
    public void softKeyReleased(int aKey) {
        /* When soft key1 is released, end the application */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Component event handler
     * @param aComponent Event occurrence component
     * @param aType Event type
     * @param aParam Event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if (aType == ComponentListener.BUTTON_PRESSED) {
            int index = menuList.getSelectedIndex();
            if (index < 0) {
                return;
            }
            if (aComponent == testButton) {
                if (!isReady) {
                    resultBox.setText("Get test preparation ready first");
                } else {
                    resultBox.setText("Commence testing:");
                    try {
                        doTest();
                    } catch (Exception e) {
                        addResult("\nNG:"+e.getClass().getName());
                    } finally {
                        isReady = false;
                    }
                }
            } else if (aComponent == setupButton) {
                if (isReady) {
                    resultBox.setText("Test preparation is already ready.");
                    isReady = false;
                } else {
                    resultBox.setText("Test preparation:");
                    try {
                        doSetup(index);
                    } catch (Exception e) {
                        addResult("\nNG:"+e.getClass().getName());
                    } finally {
                        isReady = true;
                    }
                }
            }
        }
    }

    /**
     * Add output to resultBox
     * @param aMessage Output character strings
     */
    public void addResult(String aMessage) {
        resultBox.setText(resultBox.getText()+aMessage);
    }

    /**
     * Vary the state of Scratchpad to the testing state
     * @param aTestNumber Test number
     * @throws Exception Thrown when unexpected exceptions occur
     */
    public void doSetup(int aTestNumber) throws Exception {

        switch (aTestNumber) {

        case 0:
            mediaPos = setupScratchpad(false);
            addResult("OK");
            break;

        case 1:
            mediaPos = setupScratchpad(true);
            addResult("OK");
            break;

        default:
            break;
        }
    }

    /**
     * Execute specified test
     * @throws Exception In the case unexpected exceptions occur
     */
    public void doTest() throws Exception {

        addResult("[Location specification]");
        mi1 = MediaManager.getImage(spName+";pos="+mediaPos[0]);
        mi2 = MediaManager.getImage(spName+";pos="+mediaPos[1]);
        mi3 = MediaManager.getImage(spName+";pos="+mediaPos[2]);
        ms  = MediaManager.getSound(spName+";pos="+mediaPos[3]);

        addResult("[use]");
        mi1.use();
        mi2.use();
        mi3.use();
        ms.use();

        addResult("[bind]");
        testVP1.setImage(mi1);
        testVP2.setImage(mi2);
        testVP3.setImage(mi3);
        
        testAP.setSound(ms);

        addResult("[play]");
        testVP1.play();
        testVP2.play();
        testVP3.play();
        testAP.play();

        addResult("OK");
    }

    /**
     * Copy specified media to Scratchpad
     * @param aNames Media list
     * @param aGap Specification whether a gap (0) is placed between media In the case of true a gap exists
     * @return A sequence displaying the location of media on the Scratchpad
     * @throws Exception In the case unexpected exceptions occur
     */
    public int[] setupScratchpad(boolean aGap) throws Exception {

        InputStream in = null;
        OutputStream out = null;
        int byteCounter = 0;
        
        int[] workPos = new int[mediaList.length];
        /* Scratchpad Clear*/
        try {
            out = Connector.openOutputStream(spName);
            for (int i=0; i<10240;i++) {
                out.write(0);
            }
        } catch (Exception ioe) {
        } finally {
            out.close();
            out = null;
        }

        /* Media Copy */
        out = Connector.openOutputStream(spName);
        for (int i=0; i<mediaList.length; i++) {
            in = Connector.openInputStream(rsName+mediaList[i]);
            workPos[i] = byteCounter;
            int inData;
            while ((inData = in.read()) != -1) {
                byteCounter++;
                out.write(inData);
            }
            if (aGap) {
                byteCounter++;
                out.write(0);
            }
            in.close();
        }

        out.close();
        return workPos;
    }
}

