/**
 * J114_0101_0101
 * MainPanel
 *
 * Confirmation of lost media read operations of Media Abnormal route test
 *
 * $Id: J114_0101_0101.java,v 1.1 2002/01/07 07:10:51 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of lost media read operations of Media Abnormal route test
 * @extends IApplication
 */
public class J114_0101_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of lost media read operations of Media Abnormal route test 2
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menuItems = {
            "1 GIF87a",
            "2 GIF87a-I",
            "3 GIF89a",
            "4 GIF89a-I",
            "5 GIF89a-T",
            "6 GIF89a-A",
            "7 GIF89a-TA",
            "8 GIF89a-C",
            "9 GIF89a-CI",
            "10 GIF89a-CT",
            "11 GIF89a-CA",
            "12 GIF89a-CTA",
            "13 JFIF-B",
            "14 JFIF-CB",
            "15 MFi",
            "16 MFi-C"
        };
        String[] filenames = {
            "87a-6.gif",
            "87a-12.gif",
            "89a1-6.gif",
            "89a2-6.gif",
            "89a3-6.gif",
            "89a4-6.gif",
            "89a5-6.gif",
            "89a6-6.gif",
            "89a7-6.gif",
            "89a8-6.gif",
            "89a9-6.gif",
            "89a10-6.gif",
            "JFIF1-6.jpg",
            "JFIF2-6.jpg",
            "mfi1-6.mld",
            "mfi2-6.mld"
        };

        Button  execButton      = new Button("execute");
        Label   label           = new Label("Reading lost media HTTP");
        ListBox menu            = new ListBox(ListBox.CHOICE);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media abnormal route");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu.setItems(menuItems);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Call a method for test implementation */
                test();
            }
        }


        /**
         * Method for test implementation
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();

            /* Generation of URL of the read-end */
            String url = getSourceURL() + "../media/" + filenames[idx];

            /* Acquisition of media data */
            // J114_0101_0101
            // J114_0101_0102
            // J114_0101_0103
            // J114_0101_0104
            // J114_0101_0105
            // J114_0101_0106
            // J114_0101_0107
            // J114_0101_0108
            // J114_0101_0109
            // J114_0101_0110
            // J114_0101_0111
            // J114_0101_0112
            // J114_0101_0113
            // J114_0101_0114
            // J114_0101_0117
            // J114_0101_0118
            // J114_0101_0140
            // J114_0101_0141
            // J114_0101_0142
            // J114_0101_0143
            // J114_0101_0144
            // J114_0101_0145
            // J114_0101_0146
            // J114_0101_0147
            // J114_0101_0148
            // J114_0101_0149
            // J114_0101_0150
            // J114_0101_0151
            // J114_0101_0152
            // J114_0101_0153
            // J114_0101_0156
            // J114_0101_0157
            MediaImage mi = null;
            MediaSound ms = null;
            try {
                if( idx < 14 ) {
                    mi = MediaManager.getImage(url);
                } else {
                    ms = MediaManager.getSound(url);
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
                return;
            }
            try {
                if( idx < 14 ) {
                    mi.use();
                } else {
                    ms.use();
                }
                showDialog("NG: no Exception");
            } catch( UIException uie ) {
                if( uie.getStatus() == uie.UNSUPPORTED_FORMAT ) {
                    showDialog("UIException:UNSUPPORTED_FORMAT");
                } else {
                    showDialog("UIException:" + uie.getStatus());
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
        }
    }
}
