/**
 * J114_0101_0103
 * MainPanel
 *
 * Confirmation of lost media read operations of Media Abnormal route test 3
 *
 * $Id: J114_0101_0103.java,v 1.1 2002/01/07 07:12:51 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of lost media read operations of Media Abnormal route test 3
 * @extends IApplication
 */
public class J114_0101_0103 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of lost media read operations of Media Abnormal route test 2
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menuItems = {
            "1 GIF89a-TA",
            "2 GIF89a-C",
            "3 GIF89a-CI",
            "4 GIF89a-CT",
            "5 GIF89a-CA",
            "6 GIF89a-CTA",
        };
        String[] filenames = {
            "89a5-6.gif",
            "89a6-6.gif",
            "89a7-6.gif",
            "89a8-6.gif",
            "89a9-6.gif",
            "89a10-6.gif"
        };

        Button  execButton      = new Button("execute");
        Label   label           = new Label("Reading lost media RES2");
        ListBox menu            = new ListBox(ListBox.CHOICE);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media abnormal route");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu.setItems(menuItems);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Call a method for test implementation */
                test();
            }
        }


        /**
         * Method for test implementation
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();

            /* Generation of URL of the read-end */
            String url = "resource:///" + filenames[idx];

            /* Acquisition of media data */
            // J114_0101_0185
            // J114_0101_0186
            // J114_0101_0187
            // J114_0101_0188
            // J114_0101_0189
            // J114_0101_0190
            MediaImage mi = null;
            try {
                mi = MediaManager.getImage(url);
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
                return;
            }
            try {
                mi.use();
                showDialog("NG: no Exception");
            } catch( UIException uie ) {
                if( uie.getStatus() == uie.UNSUPPORTED_FORMAT ) {
                    showDialog("UIException:UNSUPPORTED_FORMAT");
                } else {
                    showDialog("UIException:" + uie.getStatus());
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
        }
    }
}
