/**
 * J114_0101_0104
 * MainPanel
 *
 * Confirmation of lost media read operations of Media Abnormal route test 4
 *
 * $Id: J114_0101_0104.java,v 1.1 2002/01/07 07:14:22 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of lost media read operations of Media Abnormal route test 4
 * @extends IApplication
 */
public class J114_0101_0104 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of lost media read operations of Media Abnormal route test  4
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menuItems = {
            "1 JFIF-B",
            "2 JFIF-CB",
            "3 MFi",
            "4 MFi-C"
        };
        String[] filenames = {
            "JFIF1-6.jpg",
            "JFIF2-6.jpg",
            "mfi1-6.mld",
            "mfi2-6.mld"
        };

        Button  execButton      = new Button("execute");
        Label   label           = new Label("Reading lost media RES3");
        ListBox menu            = new ListBox(ListBox.CHOICE);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media abnormal route");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu.setItems(menuItems);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Call a method for test implementation */
                test();
            }
        }


        /**
         * Method for test implementation
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();

            /* Generation of URL of the read-end */
            String url = "resource:///" + filenames[idx];

            /* Acquisition of media data */
            // J114_0101_0191
            // J114_0101_0192
            // J114_0101_0195
            // J114_0101_0196
            MediaImage mi = null;
            MediaSound ms = null;
            try {
                if( idx < 2 ) {
                    mi = MediaManager.getImage(url);
                } else {
                    ms = MediaManager.getSound(url);
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
                return;
            }
            try {
                if( idx < 2 ) {
                    mi.use();
                } else {
                    ms.use();
                }
                showDialog("NG: no Exception");
            } catch( UIException uie ) {
                if( uie.getStatus() == uie.UNSUPPORTED_FORMAT ) {
                    showDialog("UIException:UNSUPPORTED_FORMAT");
                } else {
                    showDialog("UIException:" + uie.getStatus());
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
        }
    }
}
