/**
 * J114_0101_0105
 * MainPanel
 *
 * Confirmation of lost media read operations of Media Abnormal route test 5
 *
 * $Id: J114_0101_0105.java,v 1.1 2002/01/07 07:15:28 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of lost media read operations of Media Abnormal route test
 * @extends IApplication
 */
public class J114_0101_0105 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main class of confirmation of lost media read operations of Media Abnormal route test 5
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menuItems = {
            "1 GIF87a",
            "2 GIF87a-I",
            "3 GIF89a",
            "4 GIF89a-I",
            "5 GIF89a-T",
            "6 GIF89a-A",
            "7 GIF89a-TA",
            "8 GIF89a-C",
            "9 GIF89a-CI",
            "10 GIF89a-CT",
            "11 GIF89a-CA",
            "12 GIF89a-CTA",
            "13 JFIF-B",
            "14 JFIF-CB",
            "15 MFi",
            "16 MFi-C"
        };
        String[] filenames = {
            "87a-6.gif",
            "87a-12.gif",
            "89a1-6.gif",
            "89a2-6.gif",
            "89a3-6.gif",
            "89a4-6.gif",
            "89a5-6.gif",
            "89a6-6.gif",
            "89a7-6.gif",
            "89a8-6.gif",
            "89a9-6.gif",
            "89a10-6.gif",
            "JFIF1-6.jpg",
            "JFIF2-6.jpg",
            "mfi1-6.mld",
            "mfi2-6.mld"
        };
        boolean readyFlag = false;

        Label   label           = new Label("Reading lost media SP");
        ListBox menu            = new ListBox(ListBox.CHOICE);
        Button  writeButton     = new Button("Write");
        Button  readButton      = new Button("Read");
        TextBox statusBox       = new TextBox("",20,2,TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media abnormal route");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu.setItems(menuItems);
            add(menu);
            writeButton.setSize(getWidth(),writeButton.getHeight());
            add(writeButton);
            readButton.setSize(getWidth(),readButton.getHeight());
            add(readButton);
            add(statusBox);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* When Menu is selected, */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* Flag setting */
                readyFlag = false;
                statusBox.setText("");
            }

            /* When "Write" button is pressed */
            if (aComponent == writeButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Write media data in the Scratchpad */
                statusBox.setText("");
                writeSP();
            }

            /* When "Read" button is pressed, */
            if (aComponent == readButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                statusBox.setText("");
                if( ! readyFlag ) {
                    /* Inexecutable */
                    showDialog("Press \"Read\" after executing \"Write\"");
                    return;
                }
                /* Read media data from Scratchpad */
                readSP();
            }
        }

        /**
         * The method to write media data into Scratchpad
         */
        public void writeSP() {
            /* Flag reset */
            readyFlag = false;

            /* Acquire the menu index */
            int idx = menu.getSelectedIndex();

            /* Definition of URL of communication destination */
            String url = getSourceURL();
            url += "../media/" + filenames[idx];

            /* Acquire media data by HttpConnection */
            HttpConnection con = null;
            InputStream is = null;
            int spSize = 10240;
            byte[] data = new byte[spSize];
            int dataSize = 0;
            try {
                con = (HttpConnection) Connector.open(url,Connector.READ,true);
                con.setRequestMethod(con.GET);
                con.connect();
                is = con.openInputStream();
                dataSize = is.read(data,0,spSize);
                is.close();
                con.close();
            } catch( Exception e ) {
                if( is != null ) {
                    try {
                        is.close();
                    } catch( Exception e1 ) {}
                }
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e2 ) {}
                }
                showDialog("Http error:" + e.toString());
                return;
            }
            if( dataSize == 0 ) {
                showDialog("NG: dataSize=0");
                return;
            }

            /* Write media data into SP */
            DataOutputStream dos = null;
            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                dos.write(data,0,spSize);
                dos.close();
            } catch( Exception e ) {
                if( dos != null ) {
                    try {
                        dos.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("scratchpad write error:" + e.toString());
                return;
            }

            /* Writing in SP successful */
            readyFlag = true;
            statusBox.setText("Writing SP completed");
        }


        /**
         * The method to read media data from Scratchpad
         */
        public void readSP() {
            /* Acquire the menu index */
            int idx = menu.getSelectedIndex();

            /* Load media from Scratchpad in MediaManager */
            // J114_0101_01118
            // J114_0101_01119
            // J114_0101_01120
            // J114_0101_01121
            // J114_0101_01122
            // J114_0101_01123
            // J114_0101_01124
            // J114_0101_01125
            // J114_0101_01126
            // J114_0101_01127
            // J114_0101_01128
            // J114_0101_01129
            // J114_0101_01130
            // J114_0101_01131
            // J114_0101_01134
            // J114_0101_01135
            MediaImage mi = null;
            MediaSound ms = null;
            try {
                if( idx <= 14 ) {
                    mi = MediaManager.getImage("scratchpad:///0");
                    mi.use();
                } else {
                    ms = MediaManager.getSound("scratchpad:///0");
                    ms.use();
                }
                statusBox.setText("Reading SP normally completed");
                showDialog("NG: no Exception");
            } catch( UIException uie ) {
                if( uie.getStatus() == uie.UNSUPPORTED_FORMAT ) {
                    showDialog("UIException:UNSUPPORTED_FORMAT");
                } else {
                    showDialog("UIException:" + uie.getStatus());
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }

            /* Abandon media resource */
            try {
                if( mi != null ) {
                    mi.dispose();
                }
                if( ms != null ) {
                    ms.dispose();
                }
            } catch( Exception e ) {}
        }
    }
}
