/**
 * J114_0102_0101
 * MainPanel
 *
 * Confirmation of read operations of media that is incompliant with Media Abnormal route test
 *
 * $Id: J114_0102_0101.java,v 1.1 2002/01/07 07:18:32 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of read operations of media that is incompliant with Media Abnormal route test
 * @extends IApplication
 */
public class J114_0102_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of read operations of media that is incompliant with Media Abnormal route test 2
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menu1Items = {
            "1 HTTP(S)",
            "2 Resource",
            "3 Scratchpad"
        };
        String[] menu2Items = {
            "1 PNG-8",
            "2 PNG-24",
            "3 ASF",
            "4 XBM",
            "5 JPEG2000",
            "6 SMF",
            "7 SMF-C"
        };
        String[] filenames = {
            "png-8.png",
            "png-24.png",
            "asf1.asf",
            "xbm1.xbm",
            "jpeg2000.j2k",
            "smf.mid",
            "smf-c.mid"
        };

        Button  execButton      = new Button("execute");
        Label   label           = new Label("Incompliant media");
        ListBox menu1           = new ListBox(ListBox.CHOICE);
        ListBox menu2           = new ListBox(ListBox.CHOICE);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media abnormal route");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu1.setItems(menu1Items);
            menu2.setItems(menu2Items);
            add(menu1);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* In the case menu1 is selected, */
            if (aComponent == menu1 &&
                aType == ComponentListener.SELECTION_CHANGED ) {
                /* Reset menu2 */
                menu2.setItems(menu2Items);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Call a method for test implementation */
                test();
            }
        }


        /**
         * Method for test implementation
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx1 = menu1.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();

            /* Generation of URL of the read-end */
            String url;
            if( idx1 == 1 ) {
                url = "resource:///";
            } else {
                url = getSourceURL() + "../res/";
            }
            url += filenames[idx2];

            /* In the case of Scratchpad, write data from a server by HTTP first */
            if( idx1 == 2 ) {
                if( writeSP(url) != 0 ) {
                    /* Testing cannot be continued */
                    return;
                } else {
                    url = "scratchpad:///0";
                }
            }

            /* Acquisition of media data */
            // J114_0102_0133
            // J114_0102_0134
            // J114_0102_0135
            // J114_0102_0136
            // J114_0102_0137
            // J114_0102_0138
            // J114_0102_0139
            // J114_0102_0172
            // J114_0102_0173
            // J114_0102_0174
            // J114_0102_0175
            // J114_0102_0176
            // J114_0102_0177
            // J114_0102_0178
            // J114_0102_01111
            // J114_0102_01112
            // J114_0102_01113
            // J114_0102_01114
            // J114_0102_01115
            // J114_0102_01116
            // J114_0102_01117
            // J114_0102_01150
            // J114_0102_01151
            // J114_0102_01152
            // J114_0102_01153
            // J114_0102_01154
            // J114_0102_01155
            // J114_0102_01156
            MediaImage mi = null;
            MediaSound ms = null;
            try {
                if( idx1 < 6 ) {
                    mi = MediaManager.getImage(url);
                } else {
                    ms = MediaManager.getSound(url);
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
                return;
            }
            try {
                if( idx1 < 6 ) {
                    mi.use();
                } else {
                    ms.use();
                }
                showDialog("NG: no Exception");
            } catch( UIException uie ) {
                if( uie.getStatus() == uie.UNSUPPORTED_FORMAT ) {
                    showDialog("UIException:UNSUPPORTED_FORMAT");
                } else {
                    showDialog("UIException:" + uie.getStatus());
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
        }


        /**
         * The method to write media data into Scratchpad
         * @param url   URL of media data
         * @return  int - Return 0 when normal and other than 0 when abnormal
         */
        public int writeSP(String url) {
            /* Acquire media data by HttpConnection */
            HttpConnection con = null;
            InputStream is = null;
            int spSize = 10240;
            byte[] data = new byte[spSize];
            int dataSize = 0;
            try {
                con = (HttpConnection) Connector.open(url,Connector.READ,true);
                con.setRequestMethod(con.GET);
                con.connect();
                is = con.openInputStream();
                dataSize = is.read(data,0,spSize);
                is.close();
                con.close();
            } catch( Exception e ) {
                if( is != null ) {
                    try {
                        is.close();
                    } catch( Exception e1 ) {}
                }
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e2 ) {}
                }
                showDialog("Http error:" + e.toString());
                return -1;
            }
            if( dataSize == 0 ) {
                showDialog("NG: dataSize=0");
                return -2;
            }

            /* Write media data into SP */
            DataOutputStream dos = null;
            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                dos.write(data,0,spSize);
                dos.close();
            } catch( Exception e ) {
                if( dos != null ) {
                    try {
                        dos.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("scratchpad write error:" + e.toString());
                return -3;
            }

            /* Writing in SP successful */
            return 0;
        }
    }
}
