/**
 * J114_0103_0201
 * MainPanel
 *
 * Confirmation of operations of protocols that are incompliant with Media Abnormal route test 2
 *
 * $Id: J114_0103_0201.java,v 1.1 2002/01/07 07:19:59 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of operations of protocols that are incompliant with Media Abnormal route test 2
 * @extends IApplication
 */
public class J114_0103_0201 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of operations of protocols that are incompliant with Media Abnormal route test 2
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menu1Items = {
            "1 tel",
            "2 mailto",
            "3 ftp"
        };
        String[] menu2Items = {
            "1 getImage",
            "2 getSound",
            "3 getData"
        };

        Button  execButton      = new Button("execute");
        Label   label           = new Label("Illegal protocol");
        ListBox menu1           = new ListBox(ListBox.CHOICE);
        ListBox menu2           = new ListBox(ListBox.CHOICE);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media abnormal route");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu1.setItems(menu1Items);
            menu2.setItems(menu2Items);
            add(menu1);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* In the case menu1 is selected, */
            if (aComponent == menu1 &&
                aType == ComponentListener.SELECTION_CHANGED ) {
                /* Reset menu2 */
                menu2.setItems(menu2Items);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Call a method for test implementation */
                test();
            }
        }


        /**
         * Method for test implementation
         */
        public void test() {
            String url = new String("");
            switch( menu1.getSelectedIndex() ) {
            case 0:
                url = "tel:117";
                break;
            case 1:
                url = "mailto:foo@hotmail.com";
                break;
            case 2:
                url = "ftp://www.yahoo.com";
                break;
            }
            try {
                switch( menu2.getSelectedIndex() ) {
                case 0:
                    // J114_0103_0201
                    // J114_0103_0204
                    // J114_0103_0207
                    MediaImage mi = MediaManager.getImage(url);
                    break;
                case 1:
                    // J114_0103_0202
                    // J114_0103_0205
                    // J114_0103_0208
                    MediaSound ms = MediaManager.getSound(url);
                    break;
                case 2:
                    // J114_0103_0201
                    // J114_0103_0206
                    // J114_0103_0209
                    MediaData md = MediaManager.getData(url);
                	if(md == null){
                		showDialog("MediaData: Null");
                		return;
                	}
                    break;
                }
                showDialog("NG: no Exception");
            } catch( IllegalArgumentException iae ) {
                showDialog("IllegalArgumentException");
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
        }
    }
}
