/**
 * J114_0104_0101
 * MainPanel
 *
 * Confirmation of communication error of Media Abnormal route test
 *
 * $Id: J114_0104_0101.java,v 1.1 2002/01/07 07:21:01 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of communication error of Media Abnormal route test
 * @extends IApplication
 */
public class J114_0104_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of communication error of Media Abnormal route test
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menu1Items = {
            "1 HTTP_ERROR",
            "2 IMODE_LOCKED",
            "3 NO_USE",
            "4 OUT_OF_SERVICE",
            "5 Interruption"
        };
        String[] menu2Items = {
            "1 getImage",
            "2 getSound",
            "3 getData"
        };
        boolean readyFlag = false;
        String  url;

        Button  readyButton     = new Button("Condition determination");
        Button  execButton      = new Button("execute");
        Label   label           = new Label("Communication error");
        ListBox menu1           = new ListBox(ListBox.CHOICE);
        ListBox menu2           = new ListBox(ListBox.CHOICE);
        TextBox statusBox       = new TextBox("",20,2,TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media abnormal route");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu1.setItems(menu1Items);
            menu2.setItems(menu2Items);
            add(menu1);
            add(menu2);
            readyButton.setSize(getWidth(),readyButton.getHeight());
            add(readyButton);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);
            add(statusBox);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* In the case menu1 is selected, */
            if (aComponent == menu1 &&
                aType == ComponentListener.SELECTION_CHANGED ) {
                /* Reset menu2 */
                menu2.setItems(menu2Items);
                readyFlag = false;
                statusBox.setText("");
                return;
            }

            /* In the case menu2 is selected */
            if (aComponent == menu2 &&
                aType == ComponentListener.SELECTION_CHANGED ) {
                /* Reset the text box */
                readyFlag = false;
                statusBox.setText("");
                return;
            }

            /* When condition determination button is pressed */
            if (aComponent == readyButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Check the preconditions of the test */
                condition();
                return;
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                if( !readyFlag ) {
                    showDialog("Test incapability error:Test conditions are not met");
                    return;
                }
                /* Call a method for test implementation */
                test();
            }
        }


        /**
         * The method to check preconditions of the test
         */
        public void condition() {
            readyFlag = false;
            url = getSourceURL();
            int idx1 = menu1.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();
            if( idx1 == 0 ) {
                url += "../media/xxx.gif";
            } else {
                if( idx2 == 1 ) {
                    url += "../media/imelody1.mld";
                } else {
                    url += "../media/89a1-2.gif";
                }
            }
            /* Confirmation of exceptions of HttpConnection */
            HttpConnection con = null;
            try {
                con = (HttpConnection) Connector.open(url,
                            Connector.READ,true);
                con.setRequestMethod(HttpConnection.GET);
                con.connect();
                con.close();
                if( idx1 == 4 ) {
                    showDialog("Connection OK");
                    readyFlag = true;
                    return;
                }
            } catch( ConnectionException ce ) {
                switch(ce.getStatus()) {
                case ConnectionException.HTTP_ERROR:
//2002/08/13 Doja1.5                case ce.HTTP_ERROR:
                    showDialog("ConnectionException(HTTP_ERROR)");
                    if( idx1 == 0 ) {
                        readyFlag = true;
                    }
                    break;
                case ConnectionException.IMODE_LOCKED:
//2002/08/13 Doja1.5                case ce.IMODE_LOCKED:
                    showDialog("ConnectionException(IMODE_LOCKED)");
                    if( idx1 == 1 ) {
                        readyFlag = true;
                    }
                    break;
                case ConnectionException.NO_USE:
//2002/08/13 Doja1.5                case ce.NO_USE:
                    showDialog("ConnectionException(NO_USE)");
                    if( idx1 == 2 ) {
                        readyFlag = true;
                    }
                    break;
                case ConnectionException.OUT_OF_SERVICE:
//2002/08/13 Doja1.5                case ce.OUT_OF_SERVICE:
                    showDialog("ConnectionException(OUT_OF_SERVICE)");
                    if( idx1 == 1 ) {
                        readyFlag = true;
                    }
                    break;
                default:
                    showDialog("ConnectionException(status=" + ce.getStatus()+")");
                    break;
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e ) {}
                }
            }
        }


        /**
         * Method for test implementation
         */
        public void test() {
            statusBox.setText("Start acquisition");
            MediaImage mi = null;
            MediaSound ms = null;
            MediaData  md = null;
            try {
                switch( menu2.getSelectedIndex() ) {
                case 0:
                    // J114_0104_0101
                    // J114_0104_0104
                    // J114_0104_0107
                    // J114_0104_0110
                    // J114_0104_0113
                    // J114_0104_0116
                    mi = MediaManager.getImage(url);
                    mi.use();
                    break;
                case 1:
                    // J114_0104_0102
                    // J114_0104_0105
                    // J114_0104_0108
                    // J114_0104_0111
                    // J114_0104_0114
                    // J114_0104_0117
                    ms = MediaManager.getSound(url);
                    ms.use();
                    break;
                case 2:
                    // J114_0104_0103
                    // J114_0104_0106
                    // J114_0104_0109
                    // J114_0104_0112
                    // J114_0104_0115
                    // J114_0104_0118
                    md = MediaManager.getData(url);
                    md.use();
                    break;
                }
                showDialog("no Exception");
                statusBox.setText("Acquisition successful");
            } catch( UIException uie ) {
                statusBox.setText("UIException");
            } catch( ConnectionException ce ) {
                statusBox.setText("ConnectionException");
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
                statusBox.setText("Acquisition failed");
            } finally {
                /* Abandon memory */
                try {
                    if( mi != null ) {
                        mi.dispose();
                    }
                    if( ms != null ) {
                        ms.dispose();
                    }
                    if( md != null ) {
                        md.dispose();
                    }
                } catch( Exception e ) {}
            }
        }
    }
}
