/**
 * J114_0202_0101
 * MainPanel
 *
 * Confirmation of operations of Scratchpad lock of Media Abnormal route test
 *
 * $Id: J114_0202_0101.java,v 1.1 2002/01/07 07:25:53 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * Main class of confirmation of operations of Scratchpad lock of Media Abnormal route test
 * @extends IApplication
 */
public class J114_0202_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }


    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * Main screen of confirmation of operations of Scratchpad lock of Media Abnormal route test
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menuItems = {
            "1 GIF87a",
            "2 GIF89a",
            "3 JFIF",
            "4 MFi"
        };
        String[] filenames = {
            "87a-1.gif",
            "89a6-1.gif",
            "jfif2-1.jpg",
            "MFi1-1.mld"
        };

        Button  execButton      = new Button("execute");
        Label   label           = new Label("Lock Scratchpad");
        ListBox menu            = new ListBox(ListBox.CHOICE);
        TextBox statusBox        = new TextBox("",20,2,TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("Media abnormal route");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(label);
            menu.setItems(menuItems);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);
            add(statusBox);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* When Menu is selected, */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* Clear text box */
                statusBox.setText("");
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* Call a method for test implementation */
                test();
            }
        }


        /**
         * Method for test implementation
         */
        public void test() {
            /* Acquire media data from a server and write it into SP */
            statusBox.setText("Under download");
            if( writeSP() != 0 ) {
                statusBox.setText("Abnormal download");
                showDialog("Abnormal termination of media data acquisition");
                return;
            }

            /* Thread startup by a read of Scratchpad */
            WriteSPThread writeSPT = new WriteSPThread();
            writeSPT.start();
            /* Delay by 2 seconds */
            try {
                Thread.sleep(2000);
            } catch( Exception e ) {}
            /* Read media data from Scratchpad */
            readSP();
        }


        /**
         * The method to read media data from Scratchpad
         */
        public void readSP() {
            /* Acquire the menu index */
            int idx = menu.getSelectedIndex();

            /* Load media from Scratchpad in MediaManager */
            // J114_0202_0101
            // J114_0202_0108
            // J114_0202_0114
            // J114_0202_0117
            MediaImage mi = null;
            MediaSound ms = null;
            String url = "scratchpad:///0";
            try {
                if( idx == 3 ) {
                    ms = MediaManager.getSound(url);
                    ms.use();
                } else {
                    mi = MediaManager.getImage(url);
                    mi.use();
                }
                showDialog("NG: no Exception");
            } catch( ConnectionException ce ) {
                showDialog("ConnectionException");
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
            /* Abandon media resource */
            try {
                if( mi != null ) {
                    mi.dispose();
                }
                if( ms != null ) {
                    ms.dispose();
                }
            } catch( Exception e ) {}
        }


        /**
         * The method to write media data into Scratchpad
         * @return  int - Normal termination 0, other than 0 with abnormal termination
         */
        public int writeSP() {
            /* Acquire the menu index */
            int idx = menu.getSelectedIndex();

            /* Definition of URL of communication destination */
            String url = getSourceURL();
            url += "../media/" + filenames[idx];

            /* Acquire media data by HttpConnection */
            HttpConnection con = null;
            InputStream is = null;
            int spSize = 10240;
            byte[] data = new byte[spSize];
            int dataSize = 0;
            try {
                con = (HttpConnection) Connector.open(url,Connector.READ,true);
                con.setRequestMethod(con.GET);
                con.connect();
                is = con.openInputStream();
                dataSize = is.read(data,0,spSize);
                is.close();
                con.close();
            } catch( Exception e ) {
                if( is != null ) {
                    try {
                        is.close();
                    } catch( Exception e1 ) {}
                }
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e2 ) {}
                }
                showDialog("Http error:" + e.toString());
                return -1;
            }
            if( dataSize == 0 ) {
                showDialog("NG: dataSize=0");
                return -2;
            }

            /* Write media data into SP */
            DataOutputStream dos = null;
            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                dos.write(data,0,spSize);
                dos.close();
            } catch( Exception e ) {
                if( dos != null ) {
                    try {
                        dos.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("scratchpad write error:" + e.toString());
                return -3;
            }

            /* Writing in SP successful */
            return 0;
        }


        /**
         * scratchpad writing threads
         * @extends Thread
         */
        class WriteSPThread extends Thread {
            /**
             * WriteSPThread constructor
             */
            public WriteSPThread() {}

            /**
             * run method
             */
            public void run() {
                /* Scratchpad "open" */
                statusBox.setText("WriteThread:Under execution");
                DataOutputStream dos = null;
                try {
                    dos = Connector.openDataOutputStream("scratchpad:///0");
                } catch( Exception e ) {
                    showDialog("WriteThread:open error:" + e.toString());
                    statusBox.setText("WriteThread:Abnormal");
                    return;
                }
                /* Conduct a read operation for about ten seconds */
                try {
                    for( int i=0; i<10; i++ ) {
                        dos.write(0);
                        Thread.sleep(1000);
                    }
                } catch( Exception e ) {
                    showDialog("WriteThread:write error:" + e.toString());
                    statusBox.setText("WriteThread:Abnormal");
                }
                /* Scratchpad "close" */
                try {
                    dos.close();
                } catch( Exception e ) {
                    showDialog("WriteThread:close error:" + e.toString());
                    statusBox.setText("WriteThread:Abnormal");
                    return;
                }
                statusBox.setText("WriteThread:Completed");
            }
        }
    }
}
