/**
 * J211_0204_0101
 * MainPanel
 *
 * Class operational test(AudioPresenter)
 *
 * $Id: J211_0204_0101.java,v 1.1 2002/02/01 06:33:03 hoshi Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/** 
 * Main class of class's operational test(AudioPresenter)
 * @extends IApplication
 */
public class J211_0204_0101 extends IApplication{

    MainPanel testPanel = new MainPanel();

    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * Main screen of class's operational test(AudioPresenter)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements MediaListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener, 
MediaListener {

    /* Menu */
    String[] menuItem = {
    "00 Initial state 1",
    "01 Initial state 2",
    "02 Initial state 3",
//2002/10/01 Doja1.5    "03 Initial state 4",
    "04 Initial state 5",
    "05 Available 1",
    "06 Replaying state 1",
    "07 Replaying state 2",
    "08 Replaying state 3",
    "09 Replaying state 4",
//2002/10/01 Doja1.5    "10 Replaying state 5",
    "11 Replaying state 6",
    };

    boolean isReady = false;
    MediaSound ms;
    MediaData md;
    AudioPresenter ap = null;
    MediaResource mr;

    /* Definition of GUI components */
    TextBox resultBox = new TextBox(null, 16, 16, TextBox.DISPLAY_ANY);
    Label classLabel = new Label("AudioPresenter6");
    ListBox menuList = new ListBox(ListBox.CHOICE);
    Button  setupButton = new Button("Test preparation");
    Button  testButton = new Button("Test conduction");

    /* Panel generation */
    public MainPanel() {

        /* GUI settings */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("Class's operational test");
        menuList.setItems(menuItem);

        /* GUI location */
        add(classLabel);
        add(menuList);
        add(setupButton);
        add(testButton);
        add(resultBox);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /** 
     * Soft key handler
     * @param aKey Pressed key
     */
    public void softKeyPressed(int aKey) {}

    /** 
     * Soft key handler
     * @param aKey Released key
     */
    public void softKeyReleased(int aKey) {
        /* When soft key1 is released, end the application */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Component event handler
     * @param aComponent Event occurrence component
     * @param aType Event type
     * @param aParam Event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if (aType == ComponentListener.BUTTON_PRESSED) {
            int index = menuList.getSelectedIndex();
            if (index < 0) {
                return;
            }
            if (aComponent == testButton) {
                if (!isReady) {
                    resultBox.setText("Get test preparation ready first");
                } else {
                    resultBox.setText("Commence testing:");
                    try {
                        doTest(index);
                    } catch (Exception e) {
                        addResult("\nNG:"+e.getClass().getName());
                    } finally {
                        isReady = false;
                    }
                }
            } else if (aComponent == setupButton) {
                resultBox.setText("Test preparation:");
                try {
                    doSetup(index);
                } catch (Exception e) {
                    addResult("\nNG:"+e.getClass().getName());
                } finally {
                    isReady = true;
                }
            }
        }
    }

    /**
     * Add output to resultBox
     * @param message Output strings
     */
    public void addResult(String message) {
        resultBox.setText(resultBox.getText()+message);
    }

    /**
     * Vary the state to testing condition
     * @param testNumber Test Number
     * @exception Exception Thrown when unexpected exceptions occur
     */
    public void doSetup(int testNumber) throws Exception {

        ap = AudioPresenter.getAudioPresenter();
        ms = MediaManager.getSound("resource:///imelody1.mld");
		//2003/03/04 Doja1.5 DELETE
        //md = MediaManager.getData("resource:///imelody1.mld");
        ms.use();
		//2003/03/04 Doja1.5 DELETE
        // md.use();

        switch (testNumber) {
        case 0:
        /* Create initial condition */

			//2003/03/04 Doja1.5 INSERT
			addResult("OK");
            break;

            /* No break */
        case 1:
        /* Create initial condition */

			//2003/03/04 Doja1.5 INSERT
    	    md = MediaManager.getData("resource:///imelody1.mld");
			//md.use();
			addResult("OK");
			break;
            /* No break */
        case 2:
        /* Create initial condition */

			//2003/03/04 Doja1.5 INSERT
			addResult("OK");
            break;

            /* No break */
//2002/10/01 Doja1.5        case 3:
        /* Create initial condition */

            /* No break */
//2002/10/01 Doja1.5        case 4:
        case 3:
        /* Create initial condition */
            addResult("OK");
            break;
//2002/10/01 Doja1.5        case 5:
        case 4:
        /* Create visible condition */
            ap.setSound(ms);
            ap.setMediaListener(this);
            addResult("OK");
            break;

//2002/10/01 Doja1.5        case 6:
        case 5:
        /* Create replaying condition */

			//2003/03/04 Doja1.5 INSERT
			ap.setSound(ms);
            ap.setMediaListener(this);
            ap.play();
			addResult("OK");
            break;

            /* No break */
//2002/10/01 Doja1.5        case 7:
        case 6:
        /* Create replaying condition */
            ap.setSound(ms);
            ap.setMediaListener(this);
            ap.play();
            addResult("OK");
            break;

//2002/10/01 Doja1.5        case 8:
        case 7:
        /* Create replaying condition */

			//2003/03/04 Doja1.5 INSERT
	        //md = MediaManager.getData("resource:///imelody1.mld");
			//md.use();

            //ap.setData(md);
			ap.setSound(ms);
            ap.setMediaListener(this);
            ap.play();
            addResult("OK");
            break;
//2002/10/01 Doja1.5        case 9:
        case 8:
        /* Create replaying condition */

			//2003/03/04 Doja1.5 INSERT
			ap.setSound(ms);
            ap.setMediaListener(this);
            ap.play();
			addResult("OK");
            break;

            /* No break */
//2002/10/01 Doja1.5        case 10:
        /* Create replaying condition */

            /* No break */
//2002/10/01 Doja1.5        case 11:
        case 9:
        /* Create replaying condition */
            ap.setSound(ms);
            ap.setMediaListener(this);
            ap.play();
            addResult("OK");
            break;
        default:
            break;
        }
    }

    /**
     * Execute specified test
     * @param testNumber Test Number
     * @exception In case of unscripted exceptions
     */
    public void doTest(int testNumber) throws Exception {

        switch (testNumber) {

        case 0:
//J211_0204_0103
            ap.setSound(ms);
            addResult("\nOK : setSound()");
            break;
        case 1:
//J211_0204_0104
			ap.setData(md);
            addResult("\nOK : setData()");
            break;

        case 2:
//J211_0204_0105
            mr = ap.getMediaResource();
            addResult("\nOK : getMediaResource()");
            break;

//2002/10/01 Doja1.5        case 3:
//J211_0204_0106
//2002/10/01 Doja1.5            ap.setAttribute(5,10);
//2002/10/01 Doja1.5            addResult("\nOK : setAttribute()");
//2002/10/01 Doja1.5            break;

//2002/10/01 Doja1.5        case 4:
        case 3:
//J211_0204_0107
            ap.setMediaListener(this);
            addResult("\nOK : setMediaListener()");
            break;

//2002/10/01 Doja1.5        case 5:
        case 4:
//J211_0204_0202
            ap.stop();
            addResult("\nOK : stop()");
            break;

//2002/10/01 Doja1.5        case 6:
        case 5:
//J211_0204_0301
            ap.play();
            addResult("\nOK : play()");
            break;

//2002/10/01 Doja1.5        case 7:
        case 6:
//J211_0204_0303
            try {
                ap.setSound(ms);
                addResult("\nNG : setSound()");
            } catch (UIException uie) {
                addResult("\nStatus;"+uie.getStatus());
            }
            break;

//2002/10/01 Doja1.5        case 8:
        case 7:
//J211_0204_0304
            try {
				ap.setData(md);
                addResult("\nNG : setData()");
            } catch (UIException uie) {
                addResult("\nStatus;"+uie.getStatus());
            }
            break;

//2002/10/01 Doja1.5        case 9:
        case 8:
//J211_0204_0305
            mr = ap.getMediaResource();
            addResult("\nOK : getMediaResource()");
            break;

//2002/10/01 Doja1.5        case 10:
//J211_0204_0306
//2002/10/01 Doja1.5            ap.setAttribute(5,10);
//2002/10/01 Doja1.5            addResult("\nOK : setAttribute()");
//2002/10/01 Doja1.5            break;

//2002/10/01 Doja1.5        case 11:
        case 9:
//J211_0204_0307
            ap.setMediaListener(this);
            addResult("\nOK : setMediaListener()");
            break;
        }
    }

    /**
     * Event process of MediaAction
     * @source  MediaPresenter of the notification-origin is to be passed
     * @type Types of events
     * @param Parameter of event
     */
    public void mediaAction(MediaPresenter source,int type,int param){}

}