/**
 * J211_0501_0101.java
 * 
 * J211_0501_0101
 * MenuPanel
 * TestPanel
 * 
 * Class's operational test (Dialog)
 * 
 * $Id: J211_0501_0101.java,v 1.1 2002/02/01 06:33:05 hoshi Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;

/**
 * Main class for class's operational test(Dialog)
 * @extends IApplication
 */
public class J211_0501_0101 extends IApplication {

    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * Menu screen for class's operational (Dialog) test
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {

    ListBox menu1 = null;
    ListBox menu2 = null;                    /* Process selection menu */
    Button execButton = null;                /* execute button */

    /* Items in process selection menu(menu1menu2) */
    String[] menu1Item = {
        "0.Checking basic operations",
        "1.Check the behavior of display",
        "2. Check the behavior of the event",
    };

    String[][] menu2Item = {
        /* Menu for check basic operations */
        {
            "0.DAILOG_ERROR",
            "1.DAILOG_WARNING",
            "2.DAILOG_INFO",
            "3.DAILOG_YESNO1",
            "4.DAILOG_YESNO2",
            "5.DAILOG_YESNOCANCEL1",
            "6.DAILOG_YESNOCANCEL2",
            "7.DAILOG_YESNOCANCEL3",
            "8.Forbidden operations",
        },
        /* Menu for checking display operations */
        {
            "0. Dialog display 1",
            "1. Dialog display 2",
            "2. In case of the character being specified 1",
            "3. In case of the character being specified 2",
            "4. In case of the character being specified 3",
            "5. Character type of the title 1",
            "6. Character type of the title 2",
            "7. Character type of the message 1",
            "8. Character type of the message 2",
        },
        /* Menu for checking behavior of the event */
        {
            "0. Event block 1",
            "1. Event block 2",
            "2. Behavior of the event 1",
            "3. Behavior of the event 2",
            "4. Behavior of the event 3",
        },
    };

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.getMessage());
        } catch(Error e) {
            showMsg(e.getMessage());
        }
    }

    /**
     * Display menu screen
     */
    public void showMainPanel() {
        /* Display title/sub title */
        setTitle("Class behavior's test");
        Label subTitle = new Label("Dialog");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);

        /* Add creation of components */
        menu1 = new ListBox(ListBox.CHOICE, 3);
        menu2 = new ListBox(ListBox.CHOICE, 10);
        execButton = new Button("execute");
        menu1.setItems(menu1Item);
        menu2.setItems(menu2Item[0]);
        add(menu1);
        add(menu2);
        add(execButton);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * When soft key 1 is released, end the application
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }


    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* Set an item (menu2) when menu list (menu1) is selected */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menu1 ) {
                menu2.setItems(menu2Item[menu1.getSelectedIndex()]);
            }
        }
        /* When execute button is pressed store menu index into a variable and evoke a method for checking behavior*/
        if ( aType == ComponentListener.BUTTON_PRESSED ) {
            try {
                int menu1Index = menu1.getSelectedIndex();
                int menu2Index = menu2.getSelectedIndex();

                /* Transit to Panel for checking behavior */
                Display.setCurrent(new TestPanel(menu1Index, menu2Index, this));
            } catch(Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
        }
    }
}

/**
 * Confirmation screen for class's operational (Dialog) test
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class TestPanel extends Panel implements SoftKeyListener,ComponentListener,
    KeyListener, MediaListener {

    Frame previousFrame = null;         /* Store the previous screen */
    int menu1Index = 0;
    int menu2Index = 0;                 /* Index of the menu of previous screen */
    Label subTitle = null;              /* Sub title */
    Button testButton;                  /* Test button */
    TextBox textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);
    int testIndex = 0;
    String s =  null;
    Timer timer;
    ListBox menu1 = null;
    AudioPresenter ap1 = null;

    String[] menu1Item = {
        "0.aaa",
        "1.bbb",
        "2.ccc",
    };

    /**
     * Constructor of TestPanel class
     * @param  menu1Index  Index of menu1
     * @param  menu2Index  Index of menu2
     */
    TestPanel(int menu1Index, int menu2Index, Frame aFrame) {
        previousFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;
        showTestPanel(menu1Index,menu2Index);
    }
    TestPanel() {
        
    }
    /**
     * Panel for checking operations
     */
    void showTestPanel(int menu1Index,int menu2Index) {
        /* Display title/sub title */
        setTitle("Class behavior's test");
        subTitle = new Label("");
        testButton = new Button("execute");
        menu1 = new ListBox(ListBox.CHOICE, 3);
        menu1.setItems(menu1Item);

        switch ( menu1Index ) {
            case 0:
                switch ( menu2Index ) {
                    case 0:
                        subTitle.setText("DAILOG_ERROR");
                        testIndex =1;
                        break;
                    case 1:
                        subTitle.setText("DAILOG_WARNING");
                        testIndex =2;
                        break;
                    case 2:
                        subTitle.setText("DAILOG_INFO");
                        testIndex =3;
                        break;
                    case 3:
                        subTitle.setText("DAILOG_YESNO1");
                        testIndex =4;
                        break;
                    case 4:
                        subTitle.setText("DAILOG_YESNO2");
                        testIndex =5;
                        break;
                    case 5:
                        subTitle.setText("DAILOG_YESNOCANCEL1");
                        testIndex =6;
                        break;
                    case 6:
                        subTitle.setText("DAILOG_YESNOCANCEL2");
                        testIndex =7;
                        break;
                    case 7:
                        subTitle.setText("DAILOG_YESNOCANCEL3");
                        testIndex =8;
                        break;
                    case 8:
                        subTitle.setText("DAILOG_Forbidded operations");
                        testIndex =9;
                        break;
                }
                break;
            case 1:
                switch ( menu2Index ) {
                    case 0:
                        subTitle.setText("Dialog display 1");
                        testIndex =10;
                        break;
                    case 1:
                        subTitle.setText("Dialog display 2");
                        testIndex =11;
                        break;
                    case 2:
                        subTitle.setText("In case of the character being specified 1");
                        testIndex =12;
                        break;
                    case 3:
                        subTitle.setText("In case of the character being specified 2");
                        testIndex =13;
                        break;
                    case 4:
                        subTitle.setText("In case of the character being specified 3");
                        testIndex =14;
                        break;
                    case 5:
                        subTitle.setText("Character type of the title 1");
                        testIndex =15;
                        break;
                    case 6:
                        subTitle.setText("Character type of the title 2");
                        testIndex =16;
                        break;
                    case 7:
                        subTitle.setText("Character type of the message 1");
                        testIndex =17;
                        break;
                    case 8:
                        subTitle.setText("Character type of the message 2");
                        testIndex =18;
                        break;
                }
                break;
            case 2:
                switch ( menu2Index ) {
                    case 0:
                        subTitle.setText("Event block 1");
                        testIndex =19;
                        break;
                    case 1:
                        subTitle.setText("Event block 2");
                        testIndex =20;
                        break;
                    case 2:
                        subTitle.setText("Behavior of the event 1");
                        testIndex =21;
                        break;
                    case 3:
                        subTitle.setText("Behavior of the event 2");
                        testIndex =22;
                        break;
                    case 4:
                        subTitle.setText("Behavior of the event 3");
                        testIndex =23;
                        break;
                }
                break;
        }

        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);
        if (testIndex == 22) {
            add(menu1);
        }
        add(testButton);
        add(textBox);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        setSoftLabel(Frame.SOFT_KEY_2,"back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
        setKeyListener(this);
    }

    /**
     * The method of confirming operations
     */
    public void test() {

//J211_0501_0301
        if (testIndex == 1) {
            showMsg(testIndex);
//J211_0501_0302
        } if (testIndex == 2) {
            showMsg(testIndex);
//J211_0501_0303
        } if (testIndex == 3) {
            showMsg(testIndex);
//J211_0501_0304
        } if (testIndex == 4) {
            showMsg(testIndex);
//J211_0501_0305
        } if (testIndex == 5) {
            showMsg(testIndex);
//J211_0501_0306
        } if (testIndex == 6) {
            showMsg(testIndex);
//J211_0501_0307
        } if (testIndex == 7) {
            showMsg(testIndex);
//J211_0501_0308
        } if (testIndex == 8) {
            showMsg(testIndex);
//J211_0501_0401
        } if (testIndex == 9) {
            try {
                Display.setCurrent(new Dialog(Dialog.BUTTON_OK, "NG"));
            } catch (IllegalArgumentException iae) {
                textBox.setText("OK:IllegalArgumentException");
            } catch (Exception e) {
                textBox.setText("NG:Exception");
            }
//J211_0502_0102
        } if (testIndex == 10) {
             Display.setCurrent(new TestCanvas(this));
//J211_0502_0103
        } if (testIndex == 11) {
            showMsg(testIndex);
//J211_0502_0201
        } if (testIndex == 12) {
            showMsg(testIndex);
//J211_0502_0202
        } if (testIndex == 13) {
            showMsg(testIndex);
//J211_0502_0203
        } if (testIndex == 14) {
            showMsg(testIndex);
//J211_0502_0305
        } if (testIndex == 15) {
            showMsg(testIndex);
//J211_0502_0306
        } if (testIndex == 16) {
            showMsg(testIndex);
//J211_0502_0405
        } if (testIndex == 17) {
            showMsg(testIndex);
//J211_0502_0406
        } if (testIndex == 18) {
            showMsg(testIndex);
//J211_0503_0101
        } if (testIndex == 19) {
            Display.setCurrent(new STimerCanvas(this));
//J211_0503_0102
        } if (testIndex == 20) {
            showMsg(testIndex);
//J211_0503_0201
        } if (testIndex == 21) {
            timer = new Timer();
            timer.setTime(5000);
            timer.setRepeat(false);
            TimerListener tl = new TimerListener() {
                public void timerExpired(Timer t) {
                    if (t == timer) {
                        textBox.setText("OK");
                    }
                }
            };
            timer.setListener(tl);
            timer.start();
            showMsg(testIndex);
//J211_0503_0202
        } if (testIndex == 22) {
            threadClass tc1 = new threadClass(1);
            Thread t1 = new Thread(tc1);
            t1.start();
            showMsg(testIndex);
//J211_0503_0203
        } if (testIndex == 23) {
            try {
                ap1 = AudioPresenter.getAudioPresenter();
                MediaSound ms = MediaManager.getSound(
                    "resource:///imelody1.mld");
                ms.use();
                ap1.setSound(ms);
                ap1.setMediaListener(this);
            } catch (Exception e) {}
            threadClass tc2 = new threadClass(2);
            Thread t2 = new Thread(tc2);
            t2.start();
            showMsg(testIndex);
        } if (testIndex == 25) {
            menu1.select(2);
        } if (testIndex == 26) {
            ap1.play();
        }
    }


    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(int testIndex) {
//J211_0501_0301
        if (testIndex == 1) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_ERROR, "test");
            msgDialog.setText(" Press OK and 1 is displayed in the text box.");
            s = Integer.toString(msgDialog.show());
            textBox.setText(s);
//J211_0501_0302
        } if (testIndex == 2) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_WARNING, "test");
            msgDialog.setText(" Press OK and 1 is displayed in the text box.");
            s = Integer.toString(msgDialog.show());
            textBox.setText(s);
//J211_0501_0303
        } if (testIndex == 3) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "test");
            msgDialog.setText(" Press OK and 1 is displayed in the text box.");
            s = Integer.toString(msgDialog.show());
            textBox.setText(s);
//J211_0501_0304
        } if (testIndex == 4) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_YESNO,"test");
            msgDialog.setText(" Press YES and 4is displayed in the text box.");
            s = Integer.toString(msgDialog.show());
            textBox.setText(s);
//J211_0501_0305
        } if (testIndex == 5) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_YESNO, "test");
            msgDialog.setText(" Press NO and 8 is displayed in the text box.");
            s = Integer.toString(msgDialog.show());
            textBox.setText(s);
//J211_0501_0306
        } if (testIndex == 6) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_YESNOCANCEL, "test");
            msgDialog.setText(" Press YES and 4is displayed in the text box.");
            s = Integer.toString(msgDialog.show());
            textBox.setText(s);
//J211_0501_0307
        } if (testIndex == 7) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_YESNOCANCEL, "test");
            msgDialog.setText(" Press NO and 8 is displayed in the text box.");
            s = Integer.toString(msgDialog.show());
            textBox.setText(s);
//J211_0501_0308
        } if (testIndex == 8) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_YESNOCANCEL, "test");
            msgDialog.setText(" Press CANCEL and 2 is displayed in the text box.");
            s = Integer.toString(msgDialog.show());
            textBox.setText(s);
//J211_0502_0103
        } if (testIndex == 11) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "test");
            msgDialog.setText("OK");
            msgDialog.show();
//J211_0502_0201
        } if (testIndex == 12) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "test");
            msgDialog.setText("The title to be center-justified.");
            msgDialog.show();
//J211_0502_0202
        } if (testIndex == 13) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "");
            msgDialog.setText("No title");
            msgDialog.show();
//J211_0502_0203
        } if (testIndex == 14) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "test");
            msgDialog.setText("This message displays");
            msgDialog.show();
//J211_0502_0305
        } if (testIndex == 15) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "t\ne\ns\nt");
            msgDialog.setText("There are one byte space in the title as t e s t");
            msgDialog.show();
//J211_0502_0306
        } if (testIndex == 16) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "A1a\n\uE681");
            msgDialog.setText("Title is displayed in mixed characters. (\"A1a\"+Space+Pictograph)");
            msgDialog.show();
//J211_0502_0405
        } if (testIndex == 17) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "test");
            msgDialog.setText("S\nP\nA\nC\nE\n");
            msgDialog.show();
//J211_0502_0406
        } if (testIndex == 18) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "test");
            msgDialog.setText("A1a\n\uE681(\"A1a\"+Space+Pictograph)");
            msgDialog.show();
//J211_0503_0102
        } if (testIndex == 20) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "test");
            msgDialog.setText("Press 1");
            msgDialog.show();
//J211_0503_0201
        } if (testIndex == 21) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "test");
            msgDialog.setText("Timer event occurs after 5 seconds");
            msgDialog.show();
//J211_0503_0202
        } if (testIndex == 22) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "test");
            msgDialog.setText("UI event occurs after 5 seconds");
            msgDialog.show();
//J211_0503_0203
        } if (testIndex == 23) {
            Dialog msgDialog = new Dialog(Dialog.DIALOG_INFO, "test");
            msgDialog.setText("Media event occurs after 5 seconds");
            msgDialog.show();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == testButton ) {
            test();
        }
        if ( aComponent == menu1) {
            if (aType == ComponentListener.SELECTION_CHANGED) {
                textBox.setText("OK");
            }
        }
    }

    /** 
     * Process that is responsible for event registration
     */
    public void mediaAction(MediaPresenter source,int aType,int aParam){
        if( aType == AudioPresenter.AUDIO_PLAYING ) {
            textBox.setText("OK");
        }
    }


    /**
     *  Key event process (When pressed)
     */
    public void keyPressed(Panel panel, int key) {
//J211_0503_0102
        if (key == 1) {
            if (testIndex == 20) {
               textBox.setText("NG");
            }
        }
    }

    /**
     *  Key event process(When released)
     */
    public void keyReleased(Panel panel, int key) {}

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application if soft key1 is released
     * Transit to the whole screen in the event of soft key2
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }

    /**
     * Class for execution of Threads
     * @implements Runnable
     */
    class threadClass implements Runnable {
        int flg;

        /**
         * Constructor of threadClass
         * @param aflg Judgement of threads
         */
        public threadClass(int aflg){
            flg = aflg;
        }
        /**
         * Thread execution method
         */
        public void run() {
            try {
                Thread.sleep(5000);
            } catch (Exception e) {
            }
            if (flg == 1) {
                testIndex = 25;
            } if (flg == 2) {
                testIndex = 26;
            }
            test();
        }
    }
}


//J211_0502_0102
/**
 * Screen for checking class's operational (Canvas) test,
 * @extends Canvas
 */
class TestCanvas extends Canvas {
    Frame previousFrame;         /* Store the previous screen */
    boolean flg = true;

    /**
     * Constructor of TestPanel class
     */
    public TestCanvas(Frame aFrame) {
        previousFrame = aFrame;
        setSoftLabel(Canvas.SOFT_KEY_1,"back");
        setSoftLabel(Canvas.SOFT_KEY_2,"execute");
    }

    /**
     *  Key event process
     */
    public void processEvent(int type,int param){
        /* Key event, */
        if(type == Display.KEY_RELEASED_EVENT){
            switch(param){
                /* Process of when Return key is pressed, */
                case Display.KEY_SOFT1:
                    Display.setCurrent(previousFrame);
                    break;
                case Display.KEY_SOFT2:
                    Dialog dialog = new Dialog(1,"test");
                    dialog.setText("OK");
                    try {
                        dialog.show();
                    } catch(Exception e) {
                        flg = false;
                        repaint();
                    }
                    break;
            }
        }
    }

    /**
     * Implement of paint() method,
     */
    public void paint(Graphics g){
        if (flg) {
            g.clearRect(0, 0, getWidth(), getHeight());
            g.drawString("Canvas",10,20);
            g.drawString("Press Enter button",10,40);
        }else{
            g.clearRect(0, 0, getWidth(), getHeight());
            g.drawString("Canvas",10,20);
            g.drawString("NG",10,40);
        }
    }
}

//J211_0503_0101
/**
 * Canvas for checking behavior of ShortTimer class
 * @extends Canvas
 */
class STimerCanvas extends Canvas {

    ShortTimer st = null;
    Frame   previous;
    int count = 0;
    Graphics g;
    boolean start = false;

   /**
     * Constructor of STimerCanvas class
     * @param prevFrame  mainPanel
     */
    public STimerCanvas(Frame prevFrame) {
        previous = prevFrame;
        /* Creation of interval timer */
        st = ShortTimer.getShortTimer(this, 0, 1000, true);
        setSoftLabel(Canvas.SOFT_KEY_1,"Start");
        setSoftLabel(Canvas.SOFT_KEY_2,"back");
    }


   /**
     * Canvas drawing method
     * @param g     Graphics objects of Canvas
     */
    public void paint(Graphics g) {
        g.lock();
            g.clearRect(0, 0, getWidth(), getHeight());
            g.drawString("ShortTimer",10,20);
            g.drawString("Press Start button",10,40);
            g.drawString("Press Enter key.",10,60);
            g.drawString("Timer : " + Integer.toString(count), 10, 80);
        g.unlock(true);
    }

    /**
     * Drawing method
     */
    public synchronized void drawText() {
        g = getGraphics();
        g.lock();
        g.clearRect(0,62,getWidth(),80);
        g.drawString("Timer : " + Integer.toString(count), 10, 80);
        g.unlock(true);
    }

    /**
     * Event acceptance method
     * @param aType  Event type
     * @param aParam  Parameter of events
     */
    public void processEvent(int type, int param) {
        /* Timer event */
        if (type == Display.TIMER_EXPIRED_EVENT) {
            count++;
            drawText();
        }

        /* Key event, */
        if (type == Display.KEY_RELEASED_EVENT) {
            switch (param) {
            /* In case of Start key being pressed */
            case Display.KEY_SOFT1:
                if( st == null ) {
                    break;
                }
                if( start == false ) {
                    st.start();
                    start = true;
                }

                break;

            /* In case of Return key being pressed */
            case Display.KEY_SOFT2:
                /* Dispose short timer */
                if( st != null ) {
                    st.dispose();
                }
                /* Return to Main menu screen */
                Display.setCurrent(previous);
                break;
            case Display.KEY_SELECT:
                Dialog dialog = new Dialog(1,"test");
                dialog.setText("Timer starts with the value before display");
                try {
                    dialog.show();
                } catch(Exception e) {
                }
                break;
            }
        }
    }
}