/**
 * J211_0601_0101.java
 * 
 * J211_0601_0101
 * MenuPanel
 * TestPanel
 * TestCanvas
 *
 * Class's operational test(Display)
 * 
 * $Id: J211_0601_0101.java,v 1.2 2002/05/02 06:22:38 torikatu Exp $
 */

import com.nttdocomo.ui.*;

/**
 * Main class of class's operational (Display) test
 * @extends IApplication
 */
public class J211_0601_0101 extends IApplication {

    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * Main screen of class's operational (Display) test
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {

    ListBox menu1 = null;
    ListBox menu2 = null;                    /* Process selection menu */
    Button execButton = null;                /* execute button */

    TestCanvas tc;
    TestPanel tp;
    TestPanel2 tp2 = new TestPanel2(this);

    /* Items in process selection menu(menu1menu2) */
    String[] menu1Item = {
        "0.Check synchronous execution",
        "1.Check behavior of the key event",
        "2.Release high level->low level",
    };

    String[][] menu2Item = {
        /* Menu for checking synchronous execution */
        {
            "0.Panel->Panel",
            "1.Panel->Canvas",
            "2.Canvas->Canvas",
            "3.Canvas->Panel",
        },
        /* Menu for checking behavior of the key event */
        {
            "0.Panel->Panel",
            "1.Panel->Canvas",
        },
        /* Release high level->Low level menu */
        {
            "0.TextBox",
            "1.ListBox",
//2002/08/06 Doja1.5            "2.AnchorButton",
            "3.Button",
//2002/08/06 Doja1.5            "4.ImageButton",
        },

    };

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.getMessage());
        } catch(Error e) {
            showMsg(e.getMessage());
        }
    }

    /**
     * Display menu screen
     */
    public void showMainPanel() {
        /* Display title/sub title */
        setTitle("Class behavior's test");
        Label subTitle = new Label("Display");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);

        /* Add creation of components */
        menu1 = new ListBox(ListBox.CHOICE, 5);
        menu2 = new ListBox(ListBox.CHOICE, 5);
        execButton = new Button("execute");
        menu1.setItems(menu1Item);
        menu2.setItems(menu2Item[0]);
        add(menu1);
        add(menu2);
        add(execButton);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * When soft key 1 is released, end the application
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }


    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* Set an item (menu2) when menu list (menu1) is selected */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menu1 ) {
                menu2.setItems(menu2Item[menu1.getSelectedIndex()]);
            }
        }
        /* When execute button is pressed store menu index into a variable and evoke a method for checking behavior*/
        if ( aType == ComponentListener.BUTTON_PRESSED ) {
            try {
                int menu1Index = menu1.getSelectedIndex();
                int menu2Index = menu2.getSelectedIndex();
                tc = new TestCanvas(menu1Index,menu2Index, this);
                tp = new TestPanel(menu1Index,menu2Index, this);

                switch ( menu1Index ) {
                    case 0:
                        switch ( menu2Index ) {
                            case 0:
                                /* No break */
                            case 1:
                                Display.setCurrent(tp);
                                break;
                            case 2:
                                /* No break */
                            case 3:
                                Display.setCurrent(tc);
                                break;
                        }
                        break;
                    case 1:
                        switch ( menu2Index ) {
                            case 0:
                                /* No break */
                            case 1:
                                Display.setCurrent(tp);
                                break;
                        }
                        break;
                    case 2:
                        switch ( menu2Index ) {
                            case 0:
                                /* No break */
                            case 1:
                                /* No break */
                            case 2:
                                /* No break */
                            case 3:
                                /* No break */
                            case 4:
                                Display.setCurrent(tp);
                                break;
                        }
                        break;
                }
            } catch(Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
        }
    }


/**
 * Confirmation screen for class's operational (Display) test
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class TestPanel extends Panel implements SoftKeyListener,ComponentListener,
    KeyListener {

    Frame previousFrame = null;         /* Store the previous screen */
    int menu1 = 0;
    int menu2 = 0;
    Label subTitle;
    int ButtonIndex = 0;
    TextBox testTextBox = null;         /* Text box */
    ListBox testListBox;                /* List box */
//2002/08/06 Doja1.5    AnchorButton testAnchorButton;      /* Anchor Button */
    Button testButton;                  /* Button */
//2002/08/06 Doja1.5    ImageButton testImageButton;        /* Image button */
    MediaImage mi;                      /* Media image */
    Image img;                          /* Image */
    String fileName;                    /* File name */

    String[] testListBoxItem = {
        "0.aaa",
        "1.bbb",
        "2.ccc",
        "3.ddd",
        "4.eee",
    };

    /**
     * Constructor of TestPanel class
     * @param  menu1Index  Index of menu1
     * @param  menu2Index  Index of menu2
     */
    TestPanel(int menu1Index, int menu2Index, Frame aFrame) {
        previousFrame = aFrame;
        menu1 = menu1Index;
        menu2 = menu2Index;

        try {

            /* Setting of the soft key label */
            setSoftLabel(Frame.SOFT_KEY_1,"exit");
            setSoftLabel(Frame.SOFT_KEY_2,"back");

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
            setKeyListener(this);

            subTitle = new Label("");
            testButton = new Button("execute");
            testTextBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);
            fileName = new String("java1.gif");
//2002/08/06 Doja1.5            testAnchorButton = new AnchorButton(
//2002/08/06 Doja1.5                changeImage(fileName),"Text");
//2002/08/06 Doja1.5            testImageButton = new ImageButton(changeImage(fileName));
            testListBox = new ListBox(ListBox.CHOICE,5);
            testListBox.setItems(testListBoxItem);

            showPanel(menu1, menu2);
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * The method of confirming operations
     * @param  menu1Index  Index of menu1 of menu screen
     * @param  menu2Index  Index of menu2 of menu screen
     */
    void showPanel(int menu1, int menu2) {

        switch ( menu1 ) {
            case 0:
                switch ( menu2 ) {
                    case 0:
                        setTitle("Class behavior's test");
                        subTitle.setText("Panel->Panel");
                        subTitle.setSize(getWidth(), subTitle.getHeight());
                        add(subTitle);
                        add(testButton);
                        ButtonIndex = 1;
                        break;
                    case 1:
                        setTitle("Class behavior's test");
                        subTitle.setText("Panel->Canvas");
                        subTitle.setSize(getWidth(), subTitle.getHeight());
                        add(subTitle);
                        add(testButton);
                        ButtonIndex = 2;
                        break;
                    case 2:
                        break;
                    case 3:
                        setTitle("Class behavior's test");
                        subTitle.setText("Canvas->Panel");
                        subTitle.setSize(getWidth(), subTitle.getHeight());
                        add(subTitle);
                        testTextBox.setText("OK");
                        add(testTextBox);
                        break;
                }
                break;
            case 1:
                switch ( menu2 ) {
                    case 0:
                        setTitle("Class behavior's test");
                        subTitle.setText("Panel->Panel");
                        subTitle.setSize(getWidth(), subTitle.getHeight());
                        add(subTitle);
                        testTextBox.setText("Press Enter key.");
                        testTextBox.setEnabled(false);
                        add(testTextBox);
                        ButtonIndex = 3;
                        break;
                    case 1:
                        setTitle("Class behavior's test");
                        subTitle.setText("Panel->Canvas");
                        subTitle.setSize(getWidth(), subTitle.getHeight());
                        add(subTitle);
                        testTextBox.setText("Press Enter key.");
                        testTextBox.setEnabled(false);
                        add(testTextBox);
                        ButtonIndex = 4;
                        break;
                }
                break;
            case 2:
                switch ( menu2 ) {
                    case 0:
                        setTitle("Class behavior's test");
                        subTitle.setText("TextBox");
                        subTitle.setSize(getWidth(), subTitle.getHeight());
                        add(subTitle);
                        add(testTextBox);
                        ButtonIndex = 5;
                        break;
                    case 1:
                        setTitle("Class behavior's test");
                        subTitle.setText("ListBox");
                        subTitle.setSize(getWidth(), subTitle.getHeight());
                        add(subTitle);
                        add(testListBox);
                        break;
//2002/08/06 Doja1.5                    case 2:
//2002/08/06 Doja1.5                        setTitle("Class behavior's test");
//2002/08/06 Doja1.5                        subTitle.setText("AnchorButton");
//2002/08/06 Doja1.5                        subTitle.setSize(getWidth(), subTitle.getHeight());
//2002/08/06 Doja1.5                        add(subTitle);
//2002/08/06 Doja1.5                        add(testAnchorButton);
//2002/08/06 Doja1.5                        break;
                    case 2:
//2002/08/06 Doja1.5                    case 3:
                        setTitle("Class behavior's test");
                        subTitle.setText("Button");
                        subTitle.setSize(getWidth(), subTitle.getHeight());
                        add(subTitle);
                        ButtonIndex = 8;
                        add(testButton);
                        break;
//2002/08/06 Doja1.5                    case 4:
//2002/08/06 Doja1.5                        setTitle("Class behavior's test");
//2002/08/06 Doja1.5                        subTitle.setText("ImageButton");
//2002/08/06 Doja1.5                        subTitle.setSize(getWidth(), subTitle.getHeight());
//2002/08/06 Doja1.5                        add(subTitle);
//2002/08/06 Doja1.5                        add(testImageButton);
//2002/08/06 Doja1.5                        break;
                }
                break;
            case 3:
                switch ( menu2 ) {
                    case 0:
                        setTitle("Class behavior's test");
                        subTitle.setText("OK!");
                        subTitle.setSize(getWidth(), subTitle.getHeight());
                        add(subTitle);
                        break;
                }
                break;
            
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == testButton ) {
            if (aType == BUTTON_PRESSED) {
//J211_0601_0101
                if (ButtonIndex == 1) {
                    menu1 = 3;
                    menu2 = 0;
                    for (int i = 0; i < 10; i++) {
                        Display.setCurrent(new TestPanel(menu1,
                            menu2, this));
                    }
//J211_0601_0102
                } if (ButtonIndex == 2) {
                    for (int i = 0; i < 10; i++) {
                        Display.setCurrent(new TestCanvas(menu1,
                            menu2, this));
                    }
//J211_0601_0314
                } if (ButtonIndex == 8) {
                    Display.setCurrent(new TestCanvas(menu1,menu2, this));
                }
            }
//J211_0601_0311
        } if (aComponent == testTextBox) {
            if (aType == TEXT_CHANGED) {
                if (ButtonIndex == 5) {
                    Display.setCurrent(new TestCanvas(menu1,
                        menu2, this));
                }
            }
//J211_0601_0312
        } if (aComponent == testListBox) {
            if (aType == SELECTION_CHANGED) {
                Display.setCurrent(new TestCanvas(menu1,
                    menu2, this));
            }
//J211_0601_0313
//2002/08/06 Doja1.5        } if (aComponent == testAnchorButton) {
//2002/08/06 Doja1.5            if (aType == BUTTON_PRESSED) {
//2002/08/06 Doja1.5                Display.setCurrent(new TestCanvas(menu1,
//2002/08/06 Doja1.5                    menu2, this));
//2002/08/06 Doja1.5            }
//J211_0601_0315
//2002/08/06 Doja1.5        } if (aComponent == testImageButton) {
//2002/08/06 Doja1.5            if (aType == BUTTON_PRESSED) {
//2002/08/06 Doja1.5                Display.setCurrent(new TestCanvas(menu1,
//2002/08/06 Doja1.5                    menu2, this));
//2002/08/06 Doja1.5            }
        }
    }

    /**
     * Key event process (When pressed)
     * @param panel
     * @param key
     */
    public void keyPressed(Panel panel, int key) {
        if (key == Display.KEY_SELECT) {
//J211_0601_0201
            if (ButtonIndex == 3) {
                Display.setCurrent(new TestPanel(menu1, menu2, this));
//J211_0601_0202
            } if (ButtonIndex == 4) {
                Display.setCurrent(new TestCanvas(menu1, menu2, this));
            }
        }
    }

    /**
     * Key event process (When released)
     * @param panel
     * @param key
     */
    public void keyReleased(Panel panel, int key) {
        if (key == Display.KEY_SELECT) {
            if (ButtonIndex == 3) {
                testTextBox.setText("OK");
            }
            if (menu1 == 1 && menu2 == 3) {
                testTextBox.setText("OK");
                testTextBox.setEnabled(false);
                add(testTextBox);
            }
        }
    }


    /**
     *Convert image into Image type 
     */
    public Image changeImage(String fileName){
        mi = MediaManager.getImage("resource:///" + fileName);

        try {
            mi.use();
        } catch (Exception e) {
            Dialog d = new Dialog(Dialog.DIALOG_INFO, "App");
            d.setText(e.toString());
            d.show();
        }
        img = mi.getImage();
        return img;
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application if soft key1 is released
     * Transit to the whole screen in the event of soft key2
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Confirmation screen for class's operational (Display) test
 * @extends Canvas
 */
class TestCanvas extends Canvas {
    Frame previousFrame;         /* Store the previous screen */
    int Index1;
    int Index2;

    public TestCanvas(int menu1Index, int menu2Index, Frame aFrame) {
        previousFrame = aFrame;
        Index1 = menu1Index;
        Index2 = menu2Index;

        if (Index1 != 2) {
            setSoftLabel(Canvas.SOFT_KEY_2,"back");
        }
    }

    /**
     *  Key event process(processEvent)
     */
    public void processEvent(int type,int param){

        if (Index1 == 2) {
            Dialog dialog = new Dialog(Dialog.BUTTON_OK, "error");
            dialog.setText("NG");
            dialog.show();
        }

        /* Key event, */
        if(type == Display.KEY_PRESSED_EVENT){
            switch(param){
                /* Process of when Return key is pressed, */
                case Display.KEY_SOFT2:
                    Display.setCurrent(previousFrame);
                    break;
                case Display.KEY_SELECT:
//J211_0601_0103
                    if (Index1 == 0 && Index2 == 2) {
                        Index1 = 3;
                        Index2 = 0;
                        for (int i = 0; i < 10; i++) {
                            Display.setCurrent(new TestCanvas(
                                Index1, Index2,this));
                        }
                    }
//J211_0601_0104
                    if (Index1 == 0 && Index2 == 3) {
                        for (int i = 0; i < 10; i++) {
                            Display.setCurrent(tp2);
                        }
                    }
                    if (Index1 == 1 && Index2 == 1) {
                        Index1 = 3;
                        Index2 = 1;
                        repaint();
                    }
                    break;
            }
        }
        if(type == Display.KEY_RELEASED_EVENT){
            switch(param){
                case Display.KEY_SELECT:

					// 2003/03/25 ->
                    //if (Index1 == 1 && Index2 == 2) {
					if (Index1 == 1 && Index2 == 1) {
					// 2003/03/25 <-
                        Index1 = 3;
                        Index2 = 2;
                        repaint();
                    }
                    break;
            }
        }
    }

    /**
     * Implement of paint() method,
     */
    public void paint(Graphics g){
        switch ( Index1 ) {
            case 0:
                switch ( Index2 ) {
                    case 0:
                        break;
                    case 1:
                        g.clearRect(0, 0, getWidth(), getHeight());
                        g.drawString("Panel->Canvas",10,20);
                        g.drawString("OK",10,40);
                        break;
                    case 2:
                        g.clearRect(0, 0, getWidth(), getHeight());
                        g.drawString("Canvas->Canvas",10,20);
                        g.drawString("Press Enter key.",10,40);
                        break;
                    case 3:
                        g.clearRect(0, 0, getWidth(), getHeight());
                        g.drawString("Canvas->Panel",10,20);
                        g.drawString("Press Enter key.",10,40);
                        break;
                }
                break;
            case 1:
                switch ( Index2 ) {
                    case 0:
                        break;
                    case 1:
                        g.clearRect(0, 0, getWidth(), getHeight());
                        g.drawString("Panel->Canvas",10,20);
						// 2003/03/25 ->
                        //g.drawString("OK",10,40);
						// 2003/03/25 <-
                        break;
                }
                break;
            case 2:
                switch ( Index2 ) {
                    case 0:
                        g.clearRect(0, 0, getWidth(), getHeight());
                        g.drawString("TextBox",10,20);
                        g.drawString("OK",10,40);
                        break;
                    case 1:
                        g.clearRect(0, 0, getWidth(), getHeight());
                        g.drawString("ListBox",10,20);
                        g.drawString("OK",10,40);
                        break;
//2002/08/06 Doja1.5                    case 2:
//2002/08/06 Doja1.5                        g.clearRect(0, 0, getWidth(), getHeight());
//2002/08/06 Doja1.5                        g.drawString("AnchorButton",10,20);
//2002/08/06 Doja1.5                        g.drawString("OK",10,40);
//2002/08/06 Doja1.5                        break;
                    case 2:
//2002/08/06 Doja1.5                    case 3:
                        g.clearRect(0, 0, getWidth(), getHeight());
                        g.drawString("Button",10,20);
                        g.drawString("OK",10,40);
                        break;
//2002/08/06 Doja1.5                    case 4:
//2002/08/06 Doja1.5                        g.clearRect(0, 0, getWidth(), getHeight());
//2002/08/06 Doja1.5                        g.drawString("ImageButton",10,20);
//2002/08/06 Doja1.5                        g.drawString("OK",10,40);
//2002/08/06 Doja1.5                        break;
                }
                break;
            case 3:
                switch ( Index2 ) {
                    case 0:
                        g.clearRect(0, 0, getWidth(), getHeight());
                        g.drawString("Canvas->Canvas",10,20);
                        g.drawString("OK",10,40);
                        break;
                    case 1:
                        g.clearRect(0, 0, getWidth(), getHeight());
                        g.drawString("Panel->Canvas",10,20);
                        g.drawString("Ok",10,40);
                        break;
                    case 2:
                        g.clearRect(0, 0, getWidth(), getHeight());
                        g.drawString("Panel->Canvas",10,20);
                        g.drawString("OK",10,40);
                        break;
                }
                break;
        }

    }
}

/**
 * Confirmation screen for class's operational (Display) test
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class TestPanel2 extends Panel implements SoftKeyListener {

    Frame previousFrame = null;         /* Store the previous screen */
    Label aLabel;

    /**
     * Constructor of TestPanel class
     * @param  menu1Index  Index of menu1
     * @param  menu2Index  Index of menu2
     */
    TestPanel2(Frame aFrame) {
        previousFrame = aFrame;
        try {
            aLabel = new Label("OK");
            add(aLabel);

            /* Setting of the soft key label */
            setSoftLabel(Frame.SOFT_KEY_1,"exit");
            setSoftLabel(Frame.SOFT_KEY_2,"back");
            /* Listener setting */
            setSoftKeyListener(this);

        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }


    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application if soft key1 is released
     * Transit to the whole screen in the event of soft key2
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}
}