
/**
 * J211_0703_0201.java
 * 
 * J211_0703_0201
 * MenuPanel
 * TestPanel
 * 
 * Class's operational test (FocusManager)
 * 
 * $Id: J211_0703_0201.java,v 1.1 2002/02/01 06:33:08 hoshi Exp $
 */

import com.nttdocomo.ui.*;

/**
 * Main class of class's operational test (FocusManager)
 * @extends IApplication
 */
public class J211_0703_0201 extends IApplication {

    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * Menu screen for class's operational (FocusManager) test
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {

    ListBox menu1 = null;                    /* Process selection menu */
    Button execButton = null;                /* execute button */
    int index = 0;

    /* Items in process selection menu(menu1menu2) */
    String[] menu1Item = {
        "0.Test 1",
        "1.Test 2",
    };

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.getMessage());
        } catch(Error e) {
            showMsg(e.getMessage());
        }
    }

    /**
     * Display menu screen
     */
    public void showMainPanel() {
        /* Display title/sub title */
        setTitle("Class behavior's test");
        Label subTitle = new Label("FocusManager5");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);

        /* Add creation of components */
        menu1 = new ListBox(ListBox.CHOICE, 4);
        execButton = new Button("execute");
        menu1.setItems(menu1Item);
        add(menu1);
        add(execButton);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * When soft key 1 is released, end the application
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }


    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When execute button is pressed store menu index into a variable and evoke a method for checking behavior*/
        if ( aType == ComponentListener.BUTTON_PRESSED ) {
            try {
                int menu1Index = menu1.getSelectedIndex();
                Display.setCurrent(new TestPanel(menu1Index, this));
            } catch(Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
        }
    }
}

/**
 * Confirmation screen for class's operational (FocusManager)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements KeyListener
 */
class TestPanel extends Panel implements SoftKeyListener, KeyListener {

    Frame previousFrame = null;         /* Store the previous screen */
    int buttonIndex;                    /* Test index */
    Label subTitle = null;              /* Sub title */
    Button button;                      /* Button */
    TextBox textBox;                    /* Text box */

    /**
     * Constructor of TestPanel class
     * @param  index  Test index
     */
    TestPanel(int index, Frame aFrame) {
        previousFrame = aFrame;
        buttonIndex = index;

        try {
            /* Display title/sub title */
            setTitle("Class behavior's test");
            subTitle = new Label("");
            subTitle.setText("Event block");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* Setting of the soft key label */
            setSoftLabel(Frame.SOFT_KEY_1,"exit");
            setSoftLabel(Frame.SOFT_KEY_2,"back");

            /* Listener setting */
            setSoftKeyListener(this);
            setKeyListener(this);

            button = new Button("Button");
            textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);
            if (index == 1) {
                button.setEnabled(false);
                textBox.setEnabled(false);
            }
            add(subTitle);
            add(button);
            add(textBox);

        } catch(Exception e) {
            showMsg(e.getMessage());
        } catch(Error e) {
            showMsg(e.getMessage());
        }
    }


    /**
     * Key event process (When pressed)
     * @param panel
     * @param key
     */
    public void keyPressed(Panel panel, int key) {}

    /**
     * Key event process (When released)
     * @param panel
     * @param key
     */
    public void keyReleased(Panel panel, int key) {
       switch (key) {
//J211_0703_0201
//J211_0703_0202
//J211_0703_0203
//J211_0703_0204
//J211_0703_0205
//J211_0703_0206
            case Display.KEY_SELECT:
                /* No break */
            case Display.KEY_UP:
                /* No break */
            case Display.KEY_RIGHT:
                /* No break */
            case Display.KEY_LEFT:
                /* No break */
            case Display.KEY_DOWN:
                /* No break */
            case Display.KEY_0:
                /* No break */
            case Display.KEY_1:
                /* No break */
            case Display.KEY_2:
                /* No break */
            case Display.KEY_3:
                /* No break */
            case Display.KEY_4:
                /* No break */
            case Display.KEY_5:
                /* No break */
            case Display.KEY_6:
                /* No break */
            case Display.KEY_7:
                /* No break */
            case Display.KEY_8:
                /* No break */
            case Display.KEY_9:
                /* No break */
            case Display.KEY_ASTERISK:
                /* No break */
            case Display.KEY_POUND:
                showMsg("Occurrence of the key event");
                break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application if soft key1 is released
     * Transit to the whole screen in the event of soft key2
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}
