
/**
 * J211_0901_0101.java
 * 
 * J211_0901_0101
 * MenuPanel
 * TestPanel
 * 
 * Class's operational test(Graphics)
 * 
 * $Id: J211_0901_0101.java,v 1.1 2002/02/01 06:33:08 hoshi Exp $
 */

import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;

/**
 * Main class for class's operational test (Graphics)
 * @extends IApplication
 */
public class J211_0901_0101 extends IApplication {

    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * Menu screen for class's operational (Graphics) test
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {

    ListBox menu1 = null;                    /* Process selection menu */
    Button execButton = null;                /* execute button */
    int index = 0;

    /* Items in process selection menu(menu1menu2) */
    String[] menu1Item = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
//2002/08/07 Doja1.5        "3.Test 4",
//2002/08/07 Doja1.5        "4.Test 5",
        "5.Test 6",
        "6.Test 7",
//2002/08/07 Doja1.5        "7.Test 8",
    };

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.getMessage());
        } catch(Error e) {
            showMsg(e.getMessage());
        }
    }

    /**
     * Display menu screen
     */
    public void showMainPanel() {
        /* Display title/sub title */
        setTitle("Class behavior's test");
        Label subTitle = new Label("Graphics");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);

        /* Add creation of components */
        menu1 = new ListBox(ListBox.CHOICE, 4);
        execButton = new Button("execute");
        menu1.setItems(menu1Item);
        add(menu1);
        add(execButton);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * When soft key 1 is released, end the application
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }


    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When execute button is pressed store menu index into a variable and evoke a method for checking behavior*/
        if ( aType == ComponentListener.BUTTON_PRESSED ) {
            try {
                int menu1Index = menu1.getSelectedIndex();
                Display.setCurrent(new testCanvas(menu1Index, this));
            } catch(Exception e) {
                showMsg(e.toString());
            } catch (Error e) {
                showMsg(e.toString());
            }
        }
    }
}

/**
 * Confirmation screen class
 * @extends Canvas
 */
class testCanvas extends Canvas {

    /* Variable in order to return to the previous screen */
    Frame previousFrame = null;

    int index;
    Graphics g1;
    Graphics g2;
    Image img;
    MediaImage mi;
    ImageLabel il;
    int flg;

    /* Creation of message dialog (error/Information) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"error");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "info");

    /**
     * Constructor of testCanvas class
     * @param aType  Location of items of Menu
     * @param aFrame  Screen
     */
    public testCanvas(int aType, Frame aFrame) {

        /* Assign the previous screen */
        previousFrame = aFrame;
        index = aType;
        
        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        setSoftLabel(Frame.SOFT_KEY_2,"back");

    }

    /**
     * test method
     */
     void test() {
        switch (index) {
//J211_0901_0101
            case 0:
                g1 = getGraphics();
                g1.setColor(Graphics.getColorOfName(Graphics.BLUE));
                g2 = g1.copy();
                g2.drawString("BLUE",0,50);
                break;
//J211_0901_0102
            case 1:
                g1 = getGraphics();
                g1.setColor(Graphics.getColorOfName(Graphics.BLUE));
                g2 = g1.copy();
                g1.dispose();
                g2.drawString("BLUE",0,50);
                break;
//J211_0901_0202
            case 2:
                g1 = getGraphics();
                g1.drawString("Display in the default font",0,50);
                break;
//J211_0901_0203
//2002/08/07 Doja1.5            case 3:
//2002/08/07 Doja1.5                img = Image.createImage(50, 50);
//2002/08/07 Doja1.5                g1 = img.getGraphics();
//2002/08/07 Doja1.5                g2 = img.getGraphics();
//2002/08/07 Doja1.5                if (g1 == g2) {
//2002/08/07 Doja1.5                    flg = 1;
//2002/08/07 Doja1.5                } else {
//2002/08/07 Doja1.5                    flg = 2;
//2002/08/07 Doja1.5                }
//2002/08/07 Doja1.5                repaint();
//2002/08/07 Doja1.5                break;
//J211_0901_0204
//2002/08/07 Doja1.5            case 4:
//2002/08/07 Doja1.5                img = Image.createImage(getWidth(), 50);
//2002/08/07 Doja1.5                g1 = img.getGraphics();
//2002/08/07 Doja1.5                g1.drawString("Display in the default font",10,10);
//2002/08/07 Doja1.5                flg = 3;
//2002/08/07 Doja1.5                repaint();
//2002/08/07 Doja1.5                break;
//J211_0901_0304
            case 3:
//2002/08/07 Doja1.5            case 5:
                g1 = getGraphics();
                g2 = getGraphics();
                g1.lock();
                g2.lock();
                g1.drawString("g1Drawing",0,50);
//2002/10/02 DoJa1.5                g2.drawString("g2Drawing",0,70);
                g1.unlock(true);
                try {
                    Thread.sleep(3000);
                } catch (Exception e) {
                    err.setText(e.toString());
                    err.show();
                }
                g2.drawString("g2Drawing",0,70);
                g2.unlock(true);
                break;
//J211_0901_0403
            case 4:
//2002/08/07 Doja1.5            case 6:
                g1 = getGraphics();
                g1.dispose();
                try {
                    g1.setColor(Graphics.getColorOfName(Graphics.BLUE));
                } catch (Exception e) {
                    err.setText(e.toString());
                    err.show();
                }
                try {
                    g1.dispose();
                    info.setText("OK");
                    info.show();
                } catch (Exception e) {
                    err.setText(e.toString());
                    err.show();
                }
                break;
//J211_0901_0502
//2002/08/07 Doja1.5            case 7:
//2002/08/07 Doja1.5                img = Image.createImage(35, 50);
//2002/08/07 Doja1.5                g1 = img.getGraphics();
//2002/08/07 Doja1.5                g1.setColor(Graphics.getColorOfName(Graphics.BLUE));
//2002/08/07 Doja1.5                g1.drawRect(0,0,34,49);
//2002/08/07 Doja1.5                flg = 5;
//2002/08/07 Doja1.5                repaint();
//2002/08/07 Doja1.5                break;
        }
    }

    /**
     * Screen depiction
     */
    public void paint(Graphics g) {

        g.lock();
        int y = 45;
        int x = 0;
        g.drawString("Check behavior of the class",0,10);
        g.drawLine(0,15,getWidth(),15);
        g.drawString("Press Enter key",0,30);

        switch (index) {
            case 0:
                break;
            case 1:
                break;
            case 2:
                break;
//2002/08/07 Doja1.5            case 3:
//2002/08/07 Doja1.5                if (flg == 1) {
//2002/08/07 Doja1.5                    g.drawString("NG",0,50);
//2002/08/07 Doja1.5                } if (flg == 2) {
//2002/08/07 Doja1.5                    g.drawString("OK",0,50);
//2002/08/07 Doja1.5                }
//2002/08/07 Doja1.5                break;
//2002/08/07 Doja1.5            case 4:
//2002/08/07 Doja1.5                if (flg == 3) {
//2002/08/07 Doja1.5                    g.drawImage(img,0,50);
//2002/08/07 Doja1.5                }
//2002/08/07 Doja1.5                break;
            case 3:
//2002/08/07 Doja1.5            case 5:
                break;
            case 4:
//2002/08/07 Doja1.5            case 6:
                break;
//2002/08/07 Doja1.5            case 7:
//2002/08/07 Doja1.5                if (flg == 5) {
//2002/08/07 Doja1.5                    g.drawImage(img,5,50);
//2002/08/07 Doja1.5                }
//2002/08/07 Doja1.5                break;
        }
        g.unlock(true);
    }

    /**
     * Define the behavior in the case key being pressed
     * @param aSoftKey  Type of soft key
     */
    public void processEvent(int type,int param) {
        if(type == Display.KEY_RELEASED_EVENT) {
            switch(param) {
                case Display.KEY_SOFT1:
                    IApplication.getCurrentApp().terminate();
                    break;
                case Display.KEY_SOFT2:
                    if(previousFrame != null) {
                        Display.setCurrent(previousFrame);
                    }
                    break;
                case Display.KEY_SELECT:
                    test();
                    break;
                default:
            }
        }
    }
}
