/**
 * J211_1401_0201
 * Check behavior of the class
 * ImageLabel - Check display operations
 *
 * $Id: J211_1401_0201.java,v 1.2 2002/05/23 10:17:46 torikatu Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ImageLabel - Check display operations
 * @extends IApplication
 */
public class J211_1401_0201 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ImageLabel - Check display operations
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem = {
        "1.Check focus acquisition",
        "2.Check behavior when colors are specified"
    };
    
    Label classLabel = new Label();
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Operation check of ImageLabel");
        setTitle("Behavior of the class");
        menuList.setItems(menuListItem);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int testType = menuList.getSelectedIndex();
            Display.setCurrent(new SubPanel(testType, this));
        }
    }
}

/**
 * Check behavior of the class
 * ImageLabel - Check display operations
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

    Image imageObj;
    Frame prevFrame;
    Label subTitle = null;     
    Button button;
    int count=0;
    int testType;
    MakeImage getImageObj = new MakeImage();
    ImageLabel imageLabelObj = new ImageLabel();
    TextBox textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        testType = anInt;

        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(testType);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    void testPanel(int anInt) {

        switch(anInt) {
//J211_1401_0201
        case 0:
            /* Create ImageLabel of 60*16 */
            imageObj = getImageObj.create();
            imageLabelObj.setImage(imageObj);

            /* Allocate buttons before and after the ImageLabel */
            Button buttonObj1 = new Button("Button 1");
            Button buttonObj2 = new Button("Button 2");
            buttonObj1.setSize(getWidth(), buttonObj1.getHeight());
            buttonObj2.setSize(getWidth(), buttonObj2.getHeight());

            /* Setting of the obj */
            subTitle.setText("Check focus acquisition");
            add(buttonObj1);
            add(imageLabelObj);
            add(buttonObj2);
            break;

//J212_1401_0403
        case 1:
            subTitle.setText("Specify both the foreground and the background");
            /* Create ImageLabel of 60*16 */
            imageObj = getImageObj.create();
            imageLabelObj.setImage(imageObj);

            /* Change the size of label */
            imageLabelObj.setSize(80,32);

            imageLabelObj.setForeground(ColorBox.colors[count]);
            imageLabelObj.setBackground(ColorBox.colors[count]);
            textBox.setText("Colors of foreground and background of the graphic image "
                            + ColorBox.names[count] + " To be displayed by -");
            count++;
            button = new Button("execute");
            add(imageLabelObj);
            add(button);
            add(textBox);
            button.requestFocus();
            break;
        default:
        
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1401_0201.mainPanel);
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button ) {
             imageLabelObj.setForeground(ColorBox.colors[count]);
             imageLabelObj.setBackground(ColorBox.colors[count]);
             textBox.setText("Colors of foreground and background of the graphic image " + ColorBox.names[count] +
                             " To be displayed by -");
            count++;
            if ( count > 15 ) {
                count = 0;
            }
        }
    }
}


/**
 * Acquisition of graphical contents in Image format
 * @extends Panel
 */
class MakeImage extends Panel {

    Image makeImage;
	MediaImage aMediaImage;

    /**
     * Creation of image objects
     */
    MakeImage() {
    }

    /**
     * Creation of images
     */
    public Image create() {

        /* Image of 60*16 */
//2002/08/07 DoJa1.5        makeImage = Image.createImage(60, 16);
        try {
            aMediaImage = MediaManager.getImage
                                     ("resource:///java1.gif");
            aMediaImage.use();
            makeImage = aMediaImage.getImage();
        } catch (Exception e) {
        }

//2002/08/07 DoJa1.5        Graphics g = makeImage.getGraphics();
//2002/08/07 DoJa1.5        g.setColor(Graphics.getColorOfRGB(0x00, 0xff, 0xff)); /* Set to sky blue */
//2002/08/07 DoJa1.5        g.fillRect(0, 0, 59, 15);                /* Paint in the rectangle      */
//2002/08/07 DoJa1.5        g.setColor(Graphics.getColorOfRGB(0xff, 0x00, 0x00)); /* Set to red */
//2002/08/07 DoJa1.5        g.drawString("ImageLabel", 0, 12);       /* Write ImageLabel */
        return makeImage;
    }
}

/**
 * Color setting for checking behavior of the class
 */
class ColorBox {
    static int[] colors = {
        Graphics.getColorOfName(Graphics.BLACK),
        Graphics.getColorOfName(Graphics.BLUE),
        Graphics.getColorOfName(Graphics.LIME),
        Graphics.getColorOfName(Graphics.AQUA),
        Graphics.getColorOfName(Graphics.RED),
        Graphics.getColorOfName(Graphics.FUCHSIA),
        Graphics.getColorOfName(Graphics.YELLOW),
        Graphics.getColorOfName(Graphics.WHITE),
        Graphics.getColorOfName(Graphics.GRAY),
        Graphics.getColorOfName(Graphics.NAVY),
        Graphics.getColorOfName(Graphics.GREEN),
        Graphics.getColorOfName(Graphics.TEAL),
        Graphics.getColorOfName(Graphics.MAROON),
        Graphics.getColorOfName(Graphics.PURPLE),
        Graphics.getColorOfName(Graphics.OLIVE),
        Graphics.getColorOfName(Graphics.SILVER),
    };
    static String[] names = {
    "BLACK",
    "BLUE",
    "LIME",
    "AQUA",
    "RED",
    "FUCHSIA",
    "YELLOW",
    "WHITE",
    "GRAY",
    "NAVY",
    "GREEN",
    "TEAL",
    "MAROON",
    "PURPLE",
    "OLIVE",
    "SILVER",
    };
}

