/**
 * J211_1402_0102
 * Check behavior of the class
 * ImageLabel - Check behavior of the size
 *
 * $Id: J211_1402_0102.java,v 1.2 2002/05/23 10:18:10 torikatu Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ImageLabel - Check behavior of the size
 * @extends IApplication
 */
public class J211_1402_0102 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ImageLabel - Check behavior of the size
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Check the default size",
        "2.Check behavior when size is specified"
    };

    String[][] menuListItem2 = {
        /* Menu for checking default size */
        {
            
            "2.With graphic image",
        },
        /* Menu for checking behavior of the case size being specified */
        {
            "1.Vertical graphic image > Vertical label",
            "2.Vertical graphic image = Vertical label",
            "3.Vertical graphic image < Vertical label",
            "4.Horizontal graphic image > Horizontal label",
            "5.Horizontal graphic image = Horizontal label",
            "6.Horizontal graphic image < Horizontal label",
            "7.Graphic image > label",
            "8.Graphic image = label",
            "9.Graphic image < label",
        }
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Operation check of ImageLabel");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * ImageLabel - Check behavior of the size
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Image imageObj;
    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;
    int menu1Index;
    int menu2Index;
    MakeImage getImageObj = new MakeImage();
    ImageLabel imageLabelObj = new ImageLabel();
    TextBox textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);

    /**
     * Display a sub screen
     * @param anInt1  Sub division of test
     * @param anInt2  Detail items of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt1, int anInt2, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = anInt1;
        menu2Index = anInt2;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    void testPanel() {

        switch(menu1Index) {

        /* Check default size */
        case 0:
            subTitle.setText("Default");

            switch(menu2Index) {


//J211_1402_0102
            case 0:
                sizeTitle.setText("Graphic image of 60*16");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                /* Create ImageLabel of 60*16 */
                imageObj = getImageObj.create();
                imageLabelObj.setImage(imageObj);
                add(imageLabelObj);

                /* For displaying the original graphic image */
                Label label = new Label("Original graphic image");
                label.setSize(getWidth(), label.getHeight());
                ImageLabel imageLabel = new ImageLabel(imageObj); 

                /* Make the size be the same as the original graphic image */
                imageLabel.setSize(60,16);
                add(label);
                add(imageLabel);
                break;

            default:
                break;
            }

            break;

        case 1:
            subTitle.setText("Specify the size");

            /* Create ImageLabel of 24*24 */
            imageObj = getImageObj.create2();

            switch(menu2Index) {
//J211_1402_0201
            case 0:
                sizeTitle.setText("Vertical graphic image > Vertical label");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                /* Set the size of label */
                imageLabelObj.setSize(18,12);
                break;

//J211_1402_0202
            case 1:
                sizeTitle.setText("Vertical graphic image = Vertical label");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
                /* Set the size of label */
                imageLabelObj.setSize(18,24);
                break;

//J211_1402_0203
            case 2:
                sizeTitle.setText("Vertical graphic image < Vertical label");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
                /* Set the size of label */
                imageLabelObj.setSize(18,36);
                break;

//J211_1402_0204
            case 3:
                sizeTitle.setText("Horizontal graphic image > Horizontal label");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                /* Set the size of label */
                imageLabelObj.setSize(12,18);
                break;

//J211_1402_0205
            case 4:
                sizeTitle.setText("Horizontal graphic image = Horizontal label");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                /* Set the size of the label before setting image */
                imageLabelObj.setSize(24,18);
                break;

//J211_1402_0206
            case 5:
                sizeTitle.setText("Horizontal graphic image < Horizontal label");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                /* Set the size of label */
                imageLabelObj.setSize(36,18);
                break;

//J211_1402_0207
            case 6:
                sizeTitle.setText("Graphic image > label");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                /* Set the size of label */
                imageLabelObj.setSize(12,12);
                break;

//J211_1402_0208
            case 7:
                sizeTitle.setText("Graphic image = label");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                /* Set the size of label */
                imageLabelObj.setSize(24,24);
                break;

//J211_1402_0209
            case 8:
                sizeTitle.setText("Graphic image < label");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
                /* Set the size of the label before setting image */
                imageLabelObj.setSize(36,36);
                break;

            default:
            
            }

            /* Set image */
            imageLabelObj.setImage(imageObj);

            /* Turn the background into GRAY to check the size */
            imageLabelObj.setBackground(
                Graphics.getColorOfName(Graphics.GRAY));

            add(imageLabelObj);

            Label resultLabel = new Label("Original graphic image");
            resultLabel.setSize(getWidth(), resultLabel.getHeight());
            add(resultLabel);
            ImageLabel resultImageLabel = new ImageLabel();
            resultImageLabel.setImage(imageObj);
            add(resultImageLabel);

            break;
        default:
        
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1402_0102.mainPanel);
        }
    }
}


/**
 * Acquisition of graphical contents in Image format
 * @extends Panel
 */
class MakeImage extends Panel {

    Image makeImage;
	MediaImage aMediaImage;

    /**
     * Creation of image objects
     */
    MakeImage() {
    }

    /**
     * Creation of images
     */
    public Image create() {

        /* Image of 60*16 */
//2002/08/07 DoJa1.5        makeImage = Image.createImage(60, 16);

//2002/08/07 DoJa1.5        Graphics g = makeImage.getGraphics();
//2002/08/07 DoJa1.5        g.setColor(Graphics.getColorOfRGB(0x00, 0xff, 0xff)); /* Set to sky blue */
//2002/08/07 DoJa1.5        g.fillRect(0, 0, 59, 15);                  /* Paint in the rectangle      */
//2002/08/07 DoJa1.5        g.setColor(Graphics.getColorOfRGB(0xff, 0x00, 0x00)); /* Set to red */
//2002/08/07 DoJa1.5        g.drawString("ImageLabel", 0, 12);         /* Write ImageLabel */
        try {
            aMediaImage = MediaManager.getImage
                                     ("resource:///java2.gif");
            aMediaImage.use();
            makeImage = aMediaImage.getImage();
        } catch (Exception e) {
        }

        return makeImage;
    }

    public Image create2() {

        /* Image by 24*24 */
//2002/08/07 DoJa1.5        makeImage = Image.createImage(24, 24);

//2002/08/07 DoJa1.5        Graphics g = makeImage.getGraphics();
//2002/08/07 DoJa1.5        g.setColor(0x0000ffff);                    /* Set to sky blue     */
//2002/08/07 DoJa1.5        g.fillRect(0, 0, 23, 23);                  /* Paint in the rectangle */
//2002/08/07 DoJa1.5        g.setColor(0x00ff0000);                    /* Set to red     */
//2002/08/07 DoJa1.5        g.drawString("**", 0, 11);                 /* Write **     */
//2002/08/07 DoJa1.5        g.setColor(0x00ff00ff);                    /* Set to FUCHSIA     */
//2002/08/07 DoJa1.5        g.drawString("**", 12,11);                 /* Write **     */
//2002/08/07 DoJa1.5        g.setColor(0x000000ff);                    /* Set to BLUE     */
//2002/08/07 DoJa1.5        g.drawString("**", 0, 22);                 /* Write **     */
//2002/08/07 DoJa1.5        g.setColor(0x00ffff00);                    /* Set to YELLOW     */
//2002/08/07 DoJa1.5        g.drawString("**", 12,22);                 /* Write **     */
        try {
            aMediaImage = MediaManager.getImage
                                     ("resource:///java1.gif");
            aMediaImage.use();
            makeImage = aMediaImage.getImage();
        } catch (Exception e) {
        }
        return makeImage;
    }

}
