/**
 * J211_1403_0101
 * Check behavior of the class
 * ImageLabel - Check behavior of scrolling
 *
 * $Id: J211_1403_0101.java,v 1.3 2002/05/15 09:03:40 torikatu Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ImageLabel - Check behavior of scrolling
 * @extends IApplication
 */
public class J211_1403_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ImageLabel - Check behavior of scrolling
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Operation check of smooth scrolling",
        "2.Operation check of scrolling"
    };

    String[][] menuListItem2 = {
        /* Menu for checking default size */
        {
            "1.Default - Normal",
            "2.Default - Screen's height",
            "3.Default - Invisible",
//2002/08/07 DoJa1.5            "4.HTML - Normal",
//2002/08/07 DoJa1.5            "5.HTML - Screen's height",
//2002/08/07 DoJa1.5            "6.HTML - Invisible",
        },
        /* Menu for checking behavior of the case size being specified */
        {
            "1.Outside the graphic image - Normal",
            "2.Outside the graphic image - Screen's height",
            "3.Outside the graphic image - Invisible",
        }
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Operation check of ImageLabel");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(
                    menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * ImageLabel - Check behavior of scrolling
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Image imageObj;
    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;
    int menu1Index;
    int menu2Index;
    MakeImage getImageObj = new MakeImage();
    ImageLabel imageLabelObj = new ImageLabel();
    TextBox textBox = new TextBox("", 16, 20, TextBox.DISPLAY_ANY);
//2002/08/07 DoJa1.5    HTMLLayout htmlLayout = new HTMLLayout();

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int menu1Index, int menu2Index, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(menu1Index, menu2Index);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    void testPanel(int menu1Index, int menu2Index) {

        /* Label for checking the invisible state */
        Label resultLabel = new Label();
        resultLabel.setSize(getWidth(), resultLabel.getHeight());

        switch(menu1Index) {

        /* Check default size */
        case 0:
            subTitle.setText("Check smooth scrolling");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            imageObj = getImageObj.create();
            imageLabelObj.setImage(imageObj);
            

            switch(menu2Index) {
//J211_1403_0101
            case 0:
                sizeTitle.setText("Default - Normal");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                add(imageLabelObj);
                
                break;

//J211_1403_0102
            case 1:
                sizeTitle.setText("Default - Screen's height");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                imageLabelObj.setSize(Display.getWidth(), Display.getHeight());
//2002/09/12 Doja1.5                imageLabelObj.setSize(getWidth(), getHeight());

                /* Turn the background into GRAY to check the size */
                imageLabelObj.setBackground(
                    Graphics.getColorOfName(Graphics.GRAY));
                add(imageLabelObj);

                break;

//J211_1403_0104
            case 2:
                sizeTitle.setText("Default - Invisible");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
                imageLabelObj.setVisible(false);
                add(imageLabelObj);
                resultLabel.setText("Empty line exists above");
                add(resultLabel);
                break;

//J211_1403_0105
//2002/08/07 DoJa1.5            case 3:
                /* Set Panel layout to HTMLayoutL */
//2002/08/07 DoJa1.5                setLayoutManager(htmlLayout);

//2002/08/07 DoJa1.5                sizeTitle.setText("HTML - Normal");
//2002/08/07 DoJa1.5                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//2002/08/07 DoJa1.5                imageObj = getImageObj.create();
//2002/08/07 DoJa1.5                imageLabelObj.setImage(imageObj);
//2002/08/07 DoJa1.5                add(imageLabelObj);

//2002/08/07 DoJa1.5                break;

//J211_1403_0106
//2002/08/07 DoJa1.5            case 4:
                /* Set Panel layout to HTMLayoutL */
//2002/08/07 DoJa1.5                setLayoutManager(htmlLayout);

//2002/08/07 DoJa1.5                sizeTitle.setText("HTML - Screen's height");
//2002/08/07 DoJa1.5                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
//2002/08/07 DoJa1.5                imageLabelObj.setSize(getWidth(), getHeight());

                /* Turn the background into GRAY to check the size */
//2002/08/07 DoJa1.5                imageLabelObj.setBackground(
//2002/08/07 DoJa1.5                    Graphics.getColorOfName(Graphics.GRAY));
//2002/08/07 DoJa1.5                add(imageLabelObj);
//2002/08/07 DoJa1.5                break;

//J211_1403_0108
//2002/08/07 DoJa1.5            case 5:
                /* Set Panel layout to HTMLayoutL */
//2002/08/07 DoJa1.5                setLayoutManager(htmlLayout);

//2002/08/07 DoJa1.5                sizeTitle.setText("HTML - Invisible");
//2002/08/07 DoJa1.5                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//2002/08/07 DoJa1.5                imageLabelObj.setVisible(false);
//2002/08/07 DoJa1.5                resultLabel.setText("Empty line exists above");
//2002/08/07 DoJa1.5                add(imageLabelObj);
//2002/08/07 DoJa1.5                add(resultLabel);
//2002/08/07 DoJa1.5                break;

            default:
                break;
            }

            textBox.setText("Allocate a relatively large text box for checking scrolling");
            add(textBox);
            break;

        case 1:
            /* Set Panel layout to null */
            setLayoutManager(null);

            subTitle.setText("NULL layout");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            imageObj = getImageObj.create();
            imageLabelObj.setImage(imageObj);

            subTitle.setLocation(0,0);
            sizeTitle.setLocation(0,13);


            switch(menu2Index) {
//J211_1403_0201
            case 0:
                sizeTitle.setText("Outside the screen - Normal");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                imageLabelObj.setLocation(0,Display.getHeight()-15);
//2002/09/12 Doja1.5                imageLabelObj.setLocation(0,111);
                add(imageLabelObj);

                break;

//J211_1403_0202
            case 1:
                sizeTitle.setText("Outside the screen - Screen's height");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                imageLabelObj.setSize(getWidth(), Display.getHeight());
//2002/09/12 Doja1.5                imageLabelObj.setSize(getWidth(), getHeight());
                imageLabelObj.setLocation(0,Display.getHeight()-15);
//2002/09/12 Doja1.5                imageLabelObj.setLocation(0,110);
                imageLabelObj.setBackground(
                    Graphics.getColorOfName(Graphics.GRAY));
                add(imageLabelObj);
                break;

//J211_1403_0204
            case 2:
                sizeTitle.setText("Outside the screen - invisible");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                /* Label for checking the invisible state */
                resultLabel.setText("Empty line exists below");
                resultLabel.setSize(getWidth(), resultLabel.getHeight());
                resultLabel.setLocation(0,99);
                add(resultLabel);
                imageLabelObj.setVisible(false);
                imageLabelObj.setLocation(0,Display.getHeight()-15);
//2002/09/12 Doja1.5                imageLabelObj.setLocation(0,110);
                add(imageLabelObj);
                break;

            default:
                break;
            }
        default:
            break;
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1403_0101.mainPanel);
        }
    }
}


/**
 * Acquisition of graphical contents in Image format
 * @extends Panel
 */
class MakeImage extends Panel {

    Image makeImage;
	MediaImage aMediaImage;

    /**
     * Creation of image objects
     */
    MakeImage() {
    }

    /**
     * Creation of images
     */
    public Image create() {

        /* Image of 60*16 */
//2002/08/07 DoJa1.5        makeImage = Image.createImage(60, 16);

//2002/08/07 DoJa1.5        Graphics g = makeImage.getGraphics();
//2002/08/07 DoJa1.5        g.setColor(g.getColorOfName(Graphics.AQUA)); /* Set to sky blue          */
//2002/08/07 DoJa1.5        g.fillRect(0, 0, 59, 15);                    /* Paint in the rectangle      */
//2002/08/07 DoJa1.5        g.setColor(g.getColorOfName(Graphics.RED));  /* Set to red          */
//2002/08/07 DoJa1.5        g.drawString("ImageLabel", 0, 12);           /* Write ImageLabel */
        try {
            aMediaImage = MediaManager.getImage
                                     ("resource:///java1.jpg");
//2002/09/12 Doja1.5                                     ("resource:///java1.gif");
            aMediaImage.use();
            makeImage = aMediaImage.getImage();
        } catch (Exception e) {
        }

        return makeImage;
    }
}
