/**
 * J211_1501_0101
 * Check behavior of the class
 * KeyListener - Check behavior of the key event
 *
 * $Id: J211_1501_0101.java,v 1.1 2002/02/01 06:56:08 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * KeyListener - Check behavior of the key event
 * @extends IApplication
 */
public class J211_1501_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * KeyListener - Check behavior of the key event
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem = {
        "1. Check key event range",
        "2. Check up/down/left/right key events",
        "3. Check the selected key event 1",
        "4. Check the selected key event 2",
    };

    Label classLabel = new Label();
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Check the KeyListener event");
        setTitle("Behavior of the class");
        menuList.setItems(menuListItem);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int testType = menuList.getSelectedIndex();
            Display.setCurrent(new SubPanel(testType, this));
        }
    }
}

/**
 * Check behavior of the class
 * KeyListener - Check behavior of the key event
 * Sub screen
 * @extends Panel
 * @implements KeyListener
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements KeyListener, SoftKeyListener {

    String[] menu = {
        "01 keyPressed",
        "02 keyReleased"
    };

    /* Maximum value of the key is 0x1F */
    static String[] keys = new String[0x1F];

    static {
        keys[Display.KEY_0] = "0";
        keys[Display.KEY_1] = "1";
        keys[Display.KEY_2] = "2";
        keys[Display.KEY_3] = "3";
        keys[Display.KEY_4] = "4";
        keys[Display.KEY_5] = "5";
        keys[Display.KEY_6] = "6";
        keys[Display.KEY_7] = "7";
        keys[Display.KEY_8] = "8";
        keys[Display.KEY_9] = "9";
        keys[Display.KEY_ASTERISK] = "*";
        keys[Display.KEY_DOWN] = "down arrow key";
        keys[Display.KEY_LEFT] = "left arrow key";
        keys[Display.KEY_UP] = "up arrow key";
        keys[Display.KEY_RIGHT] = "->";
        keys[Display.KEY_POUND] = "#";
        keys[Display.KEY_SELECT] = "Select key";
    }

    int     testType;
    int     flg;
    Frame   prevFrame;
    Label   titel = new Label("Check KeyListener");
    Label   label = new Label("Press any keys");
    Button  button = new Button("Button");

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt, Frame aFrame) {
        
        /* obj of the whole screen */
        prevFrame = aFrame;
        
        /* Acquisition of test patterns */
        testType = anInt;
        
        try {
            /* Display sub panels */
            showSubPanel();
        } catch (Exception e) {
            /* Process for thrown exceptions */
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showSubPanel() {

        /* Settings of display items */
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Add each component to screen */
        add(titel);
        add(label);
        
        if(testType==3) {
            add(button);
        }

        /* Register key listener */
        setKeyListener(this);
        /* Register soft key listener */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex  Value of the pressed soft key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When SOFT_KEY_1 is released terminate the application
     * @param anIndex  Value of the released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When SOFT_KEY_1 is released terminate the application */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1501_0101.mainPanel);
        }
    }

    /**
     * When a key is pressed display that key
     * @param p  Current panel of when key is pressed
     * @param key  Value of the pressed key
     */
//J211_1501_0101
//J211_1501_0201
//J211_1501_0202
//J211_1501_0203
    public void keyPressed(Panel p, int key) {
        flg = 1;
        key_show(flg, key);
    }

    /**
     * When a key is released display that key
     * @param p  Current panel of the case when a key is released
     * @param key  The value of the released key
     */
    public void keyReleased(Panel p, int key) {
        flg = 0;
        key_show(flg, key);
    }

    /**
     * Display key status
     * @param flg  Flag to determine whether pressed(=1) or released(=0)
     * @param key  Value of the key an action was taken
     */
    public void key_show(int flg, int key) {
        if (flg == 1) {
            label.setText(keys[key]+" Pressed!");
            label.setSize(getWidth(), label.getHeight());
        } else {
            label.setText(keys[key]+" Released!");
            label.setSize(getWidth(), label.getHeight());
        }
    }
}
