/**
 * J211_1601_0101
 * Check behavior of the class
 * Label - Check behavior of the display
 *
 * $Id: J211_1601_0101.java,v 1.1 2002/02/01 06:56:08 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * Label - Check behavior of the display
 * @extends IApplication
 */
public class J211_1601_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * Label - Check behavior of the display
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Check the behavior of display",
        "2.Check the alignment",
        "3.Get the focus",
        "4.Check the display of invisible state",
        "5.Check behavior of character types",
        "6.Check behavior of color specification",
    };

    String[][] menuListItem2 = {
        /* Menu for checking display operations */
        {
            "1.No character",
            "2.one byte character",
//2002/08/07 DoJa1.5            "3.two byte character",
            "4.String",
        },
        /* Menu for checking the alignment */
        {
            "1.Default"
        },
        /* Menu for checking the focus */
        {
            "1.Check the focus"
        },
        /* Menu for checking the invisible state */
        {
            "1.Check invisibility"
        },
        /* Menu for checking the character type */
        {
            "1.Linefeed",
            "2.All types mixed"
        },
        /* Menu for checking behavior of color-specification */
        {
            "1.When the foreground is specified",
            "2.When both the foreground and background are specified"
        }
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Operation check of Label");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * Label - Check behavior of the display
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;
    Button button;

    int ButtonIndex = 0;
    int menu1Index;
    int menu2Index;
    int backCount=0;
    int foreCount=0;
    Label LabelObj = new Label();
    TextBox textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);

    /* Character code for pictograph */
    char[] emoji = {0xE63E, 0xE63F};

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int menu1Index, int menu2Index, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(menu1Index, menu2Index);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    void testPanel(int menu1Index, int menu2Index) {

        switch(menu1Index) {

        /* Check display operations */
        case 0:
            subTitle.setText("Check display operations");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            switch(menu2Index) {
//J211_1601_0101
            case 0:
                sizeTitle.setText("No character exists below");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
                /* Turn the background into AQUA to confirm the size */
                LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
                break;

//J211_1601_0102
            case 1:
                sizeTitle.setText("1 one byte character below");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
                LabelObj.setText("a");

                /* Turn the background into AQUA to confirm the size */
                LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
                break;

//J211_1601_0103
//2002/08/07 DoJa1.5            case 2:
//2002/08/07 DoJa1.5                sizeTitle.setText("1 two byte character below");
//2002/08/07 DoJa1.5                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
//2002/08/07 DoJa1.5                LabelObj.setText("a");

                /* Turn the background into AQUA to confirm the size */
//2002/08/07 DoJa1.5                LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
//2002/08/07 DoJa1.5                break;

//J211_1601_0104
//2002/08/07 DoJa1.5            case 3:
            case 2:
                sizeTitle.setText("String below");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
                LabelObj.setText("Character strings");

                /* Turn the background into AQUA to confirm the size */
                LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
                break;

            default:
                break;
            }

            add(LabelObj);
            
            break;

//J211_1601_0201
        /* Check alignment */
        case 1:
            subTitle.setText("Check the alignment");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            sizeTitle.setText("Displayed in the center below");
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
            LabelObj.setText("Label");
            LabelObj.setSize(50,12);

            /* Turn the background into AQUA to confirm the size */
            LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));

            add(LabelObj);
            break;

//J211_1601_0301
        /* Check focus */
        case 2:
            subTitle.setText("Check the focus");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            LabelObj.setText("Label");

            /* Turn the background into AQUA to confirm the size */
            LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));

            /* Allocate buttons before and after the Label */
            Button buttonObj1 = new Button("Button 1");
            Button buttonObj2 = new Button("Button 2");
            buttonObj1.setSize(getWidth(), buttonObj1.getHeight());
            buttonObj2.setSize(getWidth(), buttonObj2.getHeight());

            /* Setting of the obj */
            add(buttonObj1);
            add(LabelObj);
            add(buttonObj2);
            break;

//J211_1601_0401
        /* Check the invisible state */
        case 3:
            subTitle.setText("Check the invisible state");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            sizeTitle.setText("Empty line exists below");
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            LabelObj.setText("Label");

            /* Turn the background into AQUA to confirm the size */
            LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
            
            /* Make it invisible */
            LabelObj.setVisible(false);
            
            /* For checking display of the Label result */
            Label resultLabel = new Label("Empty line exists above");
            resultLabel.setSize(getWidth(), resultLabel.getHeight());

            /* Setting of the obj */
            add(LabelObj);
            add(resultLabel);
            break;

        /* Check behavior of character types */
        case 4:
            subTitle.setText("Check behavior of character types");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            switch(menu2Index) {
//J211_1601_0505
            case 0:
                sizeTitle.setText("Linefeed down below");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                LabelObj.setText("\n");

                /* Turn the background into AQUA to confirm the size */
                LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));

                /* Setting of the obj */
                add(LabelObj);

                break;

//J211_1601_0506
            case 1:
                sizeTitle.setText("All the types mixed below");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                
//2002/08/07 DoJa1.5                LabelObj.setText("Tow bytes kana characters,One byte kana character\nAb" + String.valueOf(emoji));
                LabelObj.setText("abc\nAb" + String.valueOf(emoji));                LabelObj.setText("123\nAb" + String.valueOf(emoji));

                /* Turn the background into AQUA to confirm the size */
                LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));

                /* Setting of the obj */
                add(LabelObj);

                break;

            default:
                break;
            }
            
            break;
            
        /* Check behavior in case of colors being specified */
        case 5:
            subTitle.setText("Check behavior in case of colors being specified");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            switch(menu2Index) {
//J211_1601_0602
            case 0:
                sizeTitle.setText("Specify the foreground color");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                LabelObj.setText(String.valueOf(emoji));

                /* Turn the background into AQUA to confirm the size */
                LabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
                LabelObj.setForeground(ColorBox.colors[foreCount]);

                textBox.setText("The foreground color of the label "
                    + ColorBox.names[foreCount] + " Display by ");

                foreCount++;
                button = new Button("execute");
                ButtonIndex = 0;
                add(LabelObj);
                add(button);
                add(textBox);
                button.requestFocus();
                break;

//J211_1601_0604
            case 1:
                sizeTitle.setText("Specify both the foreground and background colors");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                LabelObj.setText("Label");

                /* Setting of colors for foreground/ background */
                LabelObj.setForeground(ColorBox.colors[foreCount]);
                LabelObj.setBackground(ColorBox.colors[backCount]);

                textBox.setText("The foreground color of the label " + ColorBox.names[foreCount] +
                              "\nBackground color of the label " + ColorBox.names[backCount] +
                              " Display by ");

                foreCount++;
                button = new Button("execute");
                ButtonIndex = 1;
                add(LabelObj);
                add(button);
                add(textBox);
                button.requestFocus();
                break;

            default:
                break;
            }
            break;
        default:
            break;
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1601_0101.mainPanel);
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button ) {
            if ( ButtonIndex == 0) {
                LabelObj.setForeground(ColorBox.colors[foreCount]);
                textBox.setText("By the foreground color of the label " + ColorBox.names[foreCount] +
                    " To be displayed by and no influence in the pictographs");
            } if ( ButtonIndex == 1) {
                LabelObj.setForeground(ColorBox.colors[foreCount]);
                LabelObj.setBackground(ColorBox.colors[backCount]);
                textBox.setText("By the foreground color of the label " + ColorBox.names[foreCount] +
                              "\nBackground color of the label " + ColorBox.names[backCount] +
                              " To be displayed by ");
            }
            foreCount++;
            if ( foreCount > 15 ) {
                foreCount = 0;
                backCount++;
                if ( backCount > 15 ) {
                    backCount = 0;
                    
                }
            }
        }
    }
}

/**
 * Color setting for checking behavior of the class
 */
class ColorBox {
    static int[] colors = {
        Graphics.getColorOfName(Graphics.BLACK),
        Graphics.getColorOfName(Graphics.BLUE),
        Graphics.getColorOfName(Graphics.LIME),
        Graphics.getColorOfName(Graphics.AQUA),
        Graphics.getColorOfName(Graphics.RED),
        Graphics.getColorOfName(Graphics.FUCHSIA),
        Graphics.getColorOfName(Graphics.YELLOW),
        Graphics.getColorOfName(Graphics.WHITE),
        Graphics.getColorOfName(Graphics.GRAY),
        Graphics.getColorOfName(Graphics.NAVY),
        Graphics.getColorOfName(Graphics.GREEN),
        Graphics.getColorOfName(Graphics.TEAL),
        Graphics.getColorOfName(Graphics.MAROON),
        Graphics.getColorOfName(Graphics.PURPLE),
        Graphics.getColorOfName(Graphics.OLIVE),
        Graphics.getColorOfName(Graphics.SILVER),
    };
    static String[] names = {
    "BLACK",
    "BLUE",
    "LIME",
    "AQUA",
    "RED",
    "FUCHSIA",
    "YELLOW",
    "WHITE",
    "GRAY",
    "NAVY",
    "GREEN",
    "TEAL",
    "MAROON",
    "PURPLE",
    "OLIVE",
    "SILVER",
    };
}
