/**
 * J211_1701_0101
 * Check behavior of the class
 * LayoutManager(Default) - Check basic operations
 *
 * $Id: J211_1701_0101.java,v 1.1 2002/02/01 06:56:09 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * LayoutManager(Default) - Check basic operations
 * @extends IApplication
 */
public class J211_1701_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * LayoutManager(Default) - Check basic operations
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Behavior of component's alignment",
        "2.Behavior of the alignment",
    };

    String[][] menuListItem2 = {
        /* Menu for checking component alignment */
        {
            "1.Default  the same line",
            "2.Default Vertical location",
            "3.Default Horizontal width",
            "4.Default is invisible",
            "5.Component's Vertical intervals",
            "6.Component's horizontal intervals",
        },
        /* Menu for checking behavior of the alignment */
        {
            "1.Check center-justification",
//2002/08/07 Doja1.5            "2.Vertical location",
        }
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("LayoutManager");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * LayoutManager(Default) - Check basic operations
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;

    /* Create each component */
//2002/08/07 Doja1.5    AnchorButton anchorObj = new AnchorButton("An");
    Button  buttonObj = new Button("B"); 
//2002/08/07 Doja1.5    ImageButton imageButtonObj = new ImageButton();
    ImageLabel imageLabelObj = new ImageLabel();
    Label labelObj = new Label("L");
    ListBox listBoxObj = new ListBox(ListBox.CHOICE);
    String[] menuListItem = {"re"};
    TextBox textBoxObj = new TextBox("T", 1, 1, TextBox.DISPLAY_ANY);
    Ticker tickerObj = new Ticker("te");
    VisualPresenter vPresenterObj = new VisualPresenter();

    int menu1Index;
    int menu2Index;
    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int menu1Index, int menu2Index, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;

        /* Get image from resource */
        MediaImage imageObj;
        imageObj = MediaManager.getImage("resource:///java2.gif");

        /* Reading media */
        try {
            imageObj.use();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Image read error" + e.toString());
            errDialog.show();
        }

//2002/08/07 Doja1.5        anchorObj.setImage(imageObj.getImage());
//2002/08/07 Doja1.5        imageButtonObj.setImage(imageObj.getImage());
        imageLabelObj.setImage(imageObj.getImage());
        vPresenterObj.setImage(imageObj);
        listBoxObj.setItems(menuListItem);
        imageLabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
        vPresenterObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
        labelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));

        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(menu1Index, menu2Index);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    void testPanel(int menu1Index, int menu2Index) {

        switch(menu1Index) {

        /* Check display operations */
        case 0:
            subTitle.setText("Check the behavior of the alignment");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            switch(menu2Index) {
//J211_1701_0101
            case 0:
                sizeTitle.setText("Allocate the same line");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(imageLabelObj);
                add(labelObj);
                listBoxObj.setSize(12, listBoxObj.getHeight());
                add(listBoxObj);
                add(textBoxObj);
                tickerObj.setSize(10, tickerObj.getHeight());
                add(tickerObj);
                add(vPresenterObj);

                break;

//J211_1701_0102
//J211_1701_0202
            case 1:
                sizeTitle.setText("Center of vertical location");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(imageLabelObj);
                labelObj.setSize(labelObj.getWidth(), labelObj.getHeight()*2);
                add(labelObj);
                listBoxObj.setSize(12, listBoxObj.getHeight());
                add(listBoxObj);
                add(textBoxObj);
                tickerObj.setSize(10, tickerObj.getHeight());
                add(tickerObj);
                add(vPresenterObj);

                break;

//J211_1701_0103
            case 2:
                sizeTitle.setText("Layout in the next line");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(imageLabelObj);
                labelObj.setSize(labelObj.getWidth()*3, labelObj.getHeight());
                add(labelObj);
                listBoxObj.setSize(24*3, listBoxObj.getHeight());
                add(listBoxObj);
                add(textBoxObj);
                tickerObj.setSize(12*3, tickerObj.getHeight());
                add(tickerObj);
                add(vPresenterObj);

                break;

//J211_1701_0104
            case 3:
                sizeTitle.setText("Add the invisible");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                imageLabelObj.setVisible(false);
                add(imageLabelObj);
                labelObj.setSize(labelObj.getWidth(), labelObj.getHeight());
                add(labelObj);
                listBoxObj.setSize(12, listBoxObj.getHeight());
                listBoxObj.setVisible(false);
                add(listBoxObj);
                add(textBoxObj);
                tickerObj.setSize(10, tickerObj.getHeight());
                add(tickerObj);
                add(vPresenterObj);

                break;

//J211_1701_0105
            case 4:
                sizeTitle.setText("Each interval - Vertical");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//2002/08/07 Doja1.5                anchorObj.setSize(getWidth(), anchorObj.getHeight());
//2002/08/07 Doja1.5                add(anchorObj);
                buttonObj.setSize(getWidth(), buttonObj.getHeight());
                add(buttonObj);
//2002/08/07 Doja1.5                imageButtonObj.setSize(getWidth(), imageButtonObj.getHeight());
//2002/08/07 Doja1.5                add(imageButtonObj);
                imageLabelObj.setSize(getWidth(), imageLabelObj.getHeight());
                add(imageLabelObj);
                labelObj.setSize(getWidth(), 4);
                add(labelObj);
                listBoxObj.setSize(getWidth(), listBoxObj.getHeight());
                add(listBoxObj);
                textBoxObj.setSize(getWidth(), textBoxObj.getHeight());
                add(textBoxObj);
                tickerObj.setSize(getWidth(), tickerObj.getHeight());
                add(tickerObj);
                vPresenterObj.setSize(getWidth(), vPresenterObj.getHeight());
                add(vPresenterObj);
                break;

//J211_1701_0106
            case 5:

                sizeTitle.setText("Each interval - Horizontal");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//2002/08/07 Doja1.5                add(anchorObj);
                buttonObj.setSize(buttonObj.getWidth(), getHeight()/2);
                add(buttonObj);
//2002/08/07 Doja1.5                imageButtonObj.setSize(imageButtonObj.getWidth(), getHeight()/2);
//2002/08/07 Doja1.5                add(imageButtonObj);
                imageLabelObj.setSize(imageLabelObj.getWidth(), getHeight()/2);
                add(imageLabelObj);
                labelObj.setSize(4, getHeight()/2);
                add(labelObj);
                listBoxObj.setSize(12, getHeight()/2);
                add(listBoxObj);
                textBoxObj.setSize(12, getHeight()/2);
                add(textBoxObj);
                tickerObj.setSize(10, getHeight()/2);
                add(tickerObj);
                vPresenterObj.setSize(vPresenterObj.getWidth(), getHeight()/2);
                add(vPresenterObj);
                break;

            default:
                break;
            }

            break;

        /* Check alignment */
        case 1:
            subTitle.setText("Check the alignment");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            switch(menu2Index) {
//J211_1701_0201
            case 0:
                sizeTitle.setText("Center justify");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(imageLabelObj);
                add(labelObj);
                listBoxObj.setSize(getWidth()/2, listBoxObj.getHeight());
                add(listBoxObj);
                textBoxObj.setSize(getWidth()/2+24, textBoxObj.getHeight());
                add(textBoxObj);
                tickerObj.setSize(getWidth()/2+48, tickerObj.getHeight());
                add(tickerObj);
                vPresenterObj.setSize(getWidth()/2+72, vPresenterObj.getHeight());
                add(vPresenterObj);

                break;

//J211_1701_0203
//2002/08/07 Doja1.5            case 1:
//2002/08/07 Doja1.5                sizeTitle.setText("Vertical location");
//2002/08/07 Doja1.5                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//2002/08/07 Doja1.5                anchorObj.setSize(anchorObj.getWidth(), getHeight()+10);
//2002/08/07 Doja1.5                add(anchorObj);
//2002/08/07 Doja1.5                add(buttonObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
//2002/08/07 Doja1.5                add(imageLabelObj);
//2002/08/07 Doja1.5                add(labelObj);
//2002/08/07 Doja1.5                listBoxObj.setSize(12, listBoxObj.getHeight());
//2002/08/07 Doja1.5                add(listBoxObj);
//2002/08/07 Doja1.5                add(textBoxObj);
//2002/08/07 Doja1.5                tickerObj.setSize(10, tickerObj.getHeight());
//2002/08/07 Doja1.5                add(tickerObj);
//2002/08/07 Doja1.5                add(vPresenterObj);

//2002/08/07 Doja1.5                break;

            default:
                break;
            }
            
            break;
            
        default:
            break;
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1701_0101.mainPanel);
        }
    }
}
