/**
 * J211_1801_0101
 * Check behavior of the class
 * LayoutManager(null) - Check basic operations
 *
 * $Id: J211_1801_0101.java,v 1.1 2002/02/01 06:56:09 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * LayoutManager(null) - Check basic operations
 * @extends IApplication
 */
public class J211_1801_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * LayoutManager(null) - Check basic operations
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Specify the Location",
        "2.Cascade alignment",
        "3.Focus of the cascade alignment",
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("LayoutManager");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * LayoutManager(null) - Check basic operations
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;

    /* Create each component */
//2002/08/07 Doja1.5    AnchorButton anchorObj = new AnchorButton("Anchor");
    Button  buttonObj = new Button("Button"); 
//2002/08/07 Doja1.5    ImageButton imageButtonObj = new ImageButton();
    ImageLabel imageLabelObj = new ImageLabel();
    Label labelObj = new Label("Label");
    ListBox listBoxObj = new ListBox(ListBox.CHOICE);
    String[] menuListItem = {"List"};
    TextBox textBoxObj = new TextBox("Text", 4, 1, TextBox.DISPLAY_ANY);
    Ticker tickerObj = new Ticker("Ticker");
    VisualPresenter vPresenterObj = new VisualPresenter();

    int menu1Index;
    TextBox textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);
    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int menu1Index, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = menu1Index;

        /* Get image from resource */
        MediaImage imageObj;
        imageObj = MediaManager.getImage("resource:///java2.gif");

        /* Reading media */
        try {
            imageObj.use();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Image read error" + e.toString());
            errDialog.show();
        }

//2002/08/07 Doja1.5        anchorObj.setImage(imageObj.getImage());
//2002/08/07 Doja1.5        imageButtonObj.setImage(imageObj.getImage());
        imageLabelObj.setImage(imageObj.getImage());
        vPresenterObj.setImage(imageObj);
        listBoxObj.setItems(menuListItem);
        imageLabelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
        vPresenterObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));
        labelObj.setBackground(Graphics.getColorOfName(Graphics.AQUA));

        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(menu1Index);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Set Panel layout to null */
        setLayoutManager(null);

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        subTitle.setLocation(0,0);
        sizeTitle.setLocation(0,13);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    void testPanel(int menu1Index) {

        subTitle.setText("Check basic operations");
        subTitle.setSize(getWidth(), subTitle.getHeight());

        switch(menu1Index) {
//J211_1801_0101
        case 0:
            sizeTitle.setText("Specify the Location");
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
            
            /* Specify the location */
//2002/08/07 Doja1.5            anchorObj.setLocation(0,28);
            buttonObj.setLocation(getWidth()/2,28);
//2002/08/07 Doja1.5            imageButtonObj.setLocation(0,44);
            imageLabelObj.setLocation(getWidth()/3,44);
            labelObj.setLocation(getWidth()/3*2,44);
            listBoxObj.setSize(listBoxObj.getWidth()/2, listBoxObj.getHeight());
            listBoxObj.setLocation(0,60);
            textBoxObj.setLocation(getWidth()/2+10,60);
            tickerObj.setSize(tickerObj.getWidth()/2, tickerObj.getHeight());
            tickerObj.setLocation(0,80);
            vPresenterObj.setLocation(getWidth()/2+10,80);
            
//2002/08/07 Doja1.5            add(anchorObj);
            add(buttonObj);
//2002/08/07 Doja1.5            add(imageButtonObj);
            add(imageLabelObj);
            add(labelObj);
            add(listBoxObj);
            add(textBoxObj);
            add(tickerObj);
            add(vPresenterObj);

            break;

//J211_1801_0102
        case 1:
            sizeTitle.setText("Cascade display");
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            /* Specify the location */
//2002/08/07 Doja1.5            anchorObj.setLocation(0,28);
            buttonObj.setLocation(0,28);
//2002/08/07 Doja1.5            imageButtonObj.setLocation(0,28);
            imageLabelObj.setLocation(0,28);
            labelObj.setLocation(0,28);
            listBoxObj.setLocation(0,28);
            textBoxObj.setLocation(0,28);
            tickerObj.setLocation(0,28);
            vPresenterObj.setLocation(0,28);

//2002/08/07 Doja1.5            add(anchorObj);
            add(buttonObj);
//2002/08/07 Doja1.5            add(imageButtonObj);
            add(imageLabelObj);
            add(labelObj);
            add(listBoxObj);
            add(textBoxObj);
            add(tickerObj);
            add(vPresenterObj);

            break;

//J211_1801_0103
        case 2:
            sizeTitle.setText("Focus of the cascade display");
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            /* Specify the location */
//2002/08/07 Doja1.5            anchorObj.setLocation(0,28);
            buttonObj.setLocation(0,28);
//2002/08/07 Doja1.5            imageButtonObj.setLocation(0,28);
            listBoxObj.setLocation(0,28);
            textBoxObj.setLocation(0,28);

//2002/08/07 Doja1.5            add(anchorObj);
            add(buttonObj);
//2002/08/07 Doja1.5            add(imageButtonObj);
            add(listBoxObj);
            add(textBoxObj);
            break;

        default:
            break;
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1801_0101.mainPanel);
        }
    }
}
