/**
 * J211_1901_0201
 * Check behavior of the class
 * ListBox - Check behavior of the display
 *
 * $Id: J211_1901_0201.java,v 1.1 2002/02/01 06:56:09 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ListBox - Check behavior of the display
 * @extends IApplication
 */
public class J211_1901_0201 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ListBox - Check behavior of the display
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Behavior of omission",
        "2.Check the invisible state",
        "3.Check the behavior of character types",
        "4.Check the behavior of color specification",
    };

    String[][] menuListItem2 = {
        /* Menu for checking discarding operations */
        {
            "1.CHOICE",
            "2.SINGLE_SELECT",
            "3.MULTIPLE_SELECT",
            "4.NUMBERED_LIST",
            "5.RADIO_BUTTON",
            "6.CHECK_BOX"
        },
        /* Menu for checking the invisible state */
        {
            "1.Check invisibility"
        },
        /* Menu for checking the character type */
        {
            "1.Linefeed",
            "2.All types mixed"
        },
        /* Menu for checking behavior of color-specification */
        {
            "1.When the foreground is specified",
            "2.When both the foreground and background are specified"
        }
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Operation check of ListBox");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * ListBox - Check behavior of the display
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;
    Button button;

    int ButtonIndex = 0;
    int menu1Index;
    int menu2Index;
    int backCount=0;
    int foreCount=0;

    int[] listType = {
        ListBox.CHOICE,
        ListBox.SINGLE_SELECT,
        ListBox.MULTIPLE_SELECT,
        ListBox.NUMBERED_LIST,
        ListBox.RADIO_BUTTON,
        ListBox.CHECK_BOX,
    };

    String[] listTypeName = {
        "CHOICE",
        "SINGLE",
        "MULTIPLE",
        "NUMBERED",
        "RADIO",
        "CHECKBOX"
    };

    /* Create ListBox for foreground and background */
    ListBox ListBoxObj5 = new ListBox(listType[0]);
    ListBox ListBoxObj6 = new ListBox(listType[1]);
    ListBox ListBoxObj7 = new ListBox(listType[2]);
    ListBox ListBoxObj8 = new ListBox(listType[3]);
    ListBox ListBoxObj9 = new ListBox(listType[4]);
    ListBox ListBoxObj10 = new ListBox(listType[5]);

    TextBox textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);

    /* Character code for pictograph */
    char[] emoji = {0xE63E, 0xE63F};

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int menu1Index, int menu2Index, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(menu1Index, menu2Index);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    void testPanel(int menu1Index, int menu2Index) {

        switch(menu1Index) {

//J211_1901_0201
//J211_1901_0202
//J211_1901_0203
//J211_1901_0204
//J211_1901_0205
//J211_1901_0206
        /* Check display operations */
        case 0:
            subTitle.setText("Check behavior for omission");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* String for menu display (30 one byte characters/20 two byte characters) */
            String[] menuListItem1 = {
                "123456789012345678901234567890",
				"ABCDEFGHIJKLMNOPQRSTUVWXYZ0123"
//2002/08/07 Doja1.5                "123456789012345678901234567890",
//2002/08/07 Doja1.5                "12345678901234567890"
            };

            sizeTitle.setText(listTypeName[menu2Index]);
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            ListBox ListBoxObj1 = new ListBox(listType[menu2Index]);
            ListBoxObj1.setItems(menuListItem1);
            add(ListBoxObj1);
            
            break;

//J211_1901_0301
        /* Check the invisible state */
        case 1:
            subTitle.setText("Check the invisible state");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            sizeTitle.setText("");
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            /* String for menu display */
            String[] menuListItem2 = {"1.test"};

            for(int i=0; i<6; i++) {
                ListBox ListBoxObj2 = new ListBox(listType[i]);
                ListBoxObj2.setItems(menuListItem2);
                ListBoxObj2.setVisible(false);
                Label resultLabel = new Label();
                resultLabel.setText("Empty line exists below "+ listTypeName[i]);
                resultLabel.setSize(getWidth(), resultLabel.getHeight());
                add(resultLabel);
                add(ListBoxObj2);
            }

            break;

        /* Check behavior of character types */
        case 2:
            subTitle.setText("Check behavior of character types");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            switch(menu2Index) {
//J211_1901_0505
            case 0:
                sizeTitle.setText("Display linefeed");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                /* String for menu display */
                String[] menuListItem3 = {"->\n<-"};

                for(int i=0; i<6; i++) {
                    ListBox ListBoxObj3 = new ListBox(listType[i]);
                    ListBoxObj3.setItems(menuListItem3);
                    add(ListBoxObj3);
                }

                break;

//J211_1901_0506
            case 1:
                sizeTitle.setText("All types mixed");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                /* String for menu display */
                String[] menuListItem4 = {"\nAb" + String.valueOf(emoji)};
//2002/08/07 Doja1.5                String[] menuListItem4 = {"Tow bytes kana characters,One byte kana character\nAb" + String.valueOf(emoji)};

                for(int i=0; i<6; i++) {
                    ListBox ListBoxObj4 = new ListBox(listType[i]);
                    ListBoxObj4.setItems(menuListItem4);
                    add(ListBoxObj4);
                }

                break;

            default:
                break;
            }
            
            break;
            
        /* Check behavior in case of colors being specified */
        case 3:
            subTitle.setText("Check behavior in case of colors being specified");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* String for menu display */
            String[] menuListItem5 = {String.valueOf(emoji[0])};
            String[] menuListItem6 = {"List"};

            ListBoxObj5.setItems(menuListItem5);
            ListBoxObj5.setSize(getWidth()/3-4, ListBoxObj5.getHeight());
            ListBoxObj6.setItems(menuListItem5);
            ListBoxObj6.setSize(getWidth()/3-4, ListBoxObj6.getHeight());
            ListBoxObj7.setItems(menuListItem5);
            ListBoxObj7.setSize(getWidth()/3-4, ListBoxObj7.getHeight());
            ListBoxObj8.setItems(menuListItem5);
            ListBoxObj8.setSize(getWidth()/3-4, ListBoxObj8.getHeight());
            ListBoxObj9.setItems(menuListItem5);
            ListBoxObj9.setSize(getWidth()/3-4, ListBoxObj9.getHeight());
            ListBoxObj10.setItems(menuListItem5);
            ListBoxObj10.setSize(getWidth()/3-4, ListBoxObj10.getHeight());

            ListBoxObj5.setForeground(ColorBox.colors[foreCount]);
            ListBoxObj6.setForeground(ColorBox.colors[foreCount]);
            ListBoxObj7.setForeground(ColorBox.colors[foreCount]);
            ListBoxObj8.setForeground(ColorBox.colors[foreCount]);
            ListBoxObj9.setForeground(ColorBox.colors[foreCount]);
            ListBoxObj10.setForeground(ColorBox.colors[foreCount]);

            add(ListBoxObj5);
            add(ListBoxObj6);
            add(ListBoxObj7);
            add(ListBoxObj8);
            add(ListBoxObj9);
            add(ListBoxObj10);

            switch(menu2Index) {
//J211_1901_0602
            case 0:
                sizeTitle.setText("Specify the foreground color");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                textBox.setText("The color of foreground "
                    + ColorBox.names[foreCount] + " Display by ");

                foreCount++;
                button = new Button("execute");
                ButtonIndex = 0;
                add(button);
                add(textBox);
                button.requestFocus();
                break;

//J211_1901_0604
            case 1:
                sizeTitle.setText("Specify both the foreground and background colors");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                ListBoxObj5.setItems(menuListItem6);
                ListBoxObj6.setItems(menuListItem6);
                ListBoxObj7.setItems(menuListItem6);
                ListBoxObj8.setItems(menuListItem6);
                ListBoxObj9.setItems(menuListItem6);
                ListBoxObj10.setItems(menuListItem6);


                /* Setting of the view */
                ListBoxObj5.setBackground(ColorBox.colors[foreCount]);
                ListBoxObj6.setBackground(ColorBox.colors[foreCount]);
                ListBoxObj7.setBackground(ColorBox.colors[foreCount]);
                ListBoxObj8.setBackground(ColorBox.colors[foreCount]);
                ListBoxObj9.setBackground(ColorBox.colors[foreCount]);
                ListBoxObj10.setBackground(ColorBox.colors[foreCount]);

                textBox.setText("The color of foreground " + ColorBox.names[foreCount] +
                              "\nColor of background " + ColorBox.names[backCount] +
                              " Display by ");

                foreCount++;
                button = new Button("execute");
                ButtonIndex = 1;
                add(button);
                add(textBox);
                button.requestFocus();
                break;

            default:
                break;
            }
            break;
        default:
            break;
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1901_0201.mainPanel);
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button ) {
            if ( ButtonIndex == 0) {
                ListBoxObj5.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj6.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj7.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj8.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj9.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj10.setForeground(ColorBox.colors[foreCount]);
                textBox.setText("Color of the foreground " + ColorBox.names[foreCount] +
                    " To be displayed by and no influence in the pictographs");
            } if ( ButtonIndex == 1) {
                ListBoxObj5.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj6.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj7.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj8.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj9.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj10.setForeground(ColorBox.colors[foreCount]);
                ListBoxObj5.setBackground(ColorBox.colors[backCount]);
                ListBoxObj6.setBackground(ColorBox.colors[backCount]);
                ListBoxObj7.setBackground(ColorBox.colors[backCount]);
                ListBoxObj8.setBackground(ColorBox.colors[backCount]);
                ListBoxObj9.setBackground(ColorBox.colors[backCount]);
                ListBoxObj10.setBackground(ColorBox.colors[backCount]);
                textBox.setText("Color of the foreground " + ColorBox.names[foreCount] +
                              "\nColor of the background " + ColorBox.names[backCount] +
                              " To be displayed");
            }
            foreCount++;
            if ( foreCount > 15 ) {
                foreCount = 0;
                backCount++;
                if ( backCount > 15 ) {
                    backCount = 0;
                    
                }
            }
        }
    }
}

/**
 * Color setting for checking behavior of the class
 */
class ColorBox {
    static int[] colors = {
        Graphics.getColorOfName(Graphics.BLACK),
        Graphics.getColorOfName(Graphics.BLUE),
        Graphics.getColorOfName(Graphics.LIME),
        Graphics.getColorOfName(Graphics.AQUA),
        Graphics.getColorOfName(Graphics.RED),
        Graphics.getColorOfName(Graphics.FUCHSIA),
        Graphics.getColorOfName(Graphics.YELLOW),
        Graphics.getColorOfName(Graphics.WHITE),
        Graphics.getColorOfName(Graphics.GRAY),
        Graphics.getColorOfName(Graphics.NAVY),
        Graphics.getColorOfName(Graphics.GREEN),
        Graphics.getColorOfName(Graphics.TEAL),
        Graphics.getColorOfName(Graphics.MAROON),
        Graphics.getColorOfName(Graphics.PURPLE),
        Graphics.getColorOfName(Graphics.OLIVE),
        Graphics.getColorOfName(Graphics.SILVER),
    };
    static String[] names = {
    "BLACK",
    "BLUE",
    "LIME",
    "AQUA",
    "RED",
    "FUCHSIA",
    "YELLOW",
    "WHITE",
    "GRAY",
    "NAVY",
    "GREEN",
    "TEAL",
    "MAROON",
    "PURPLE",
    "OLIVE",
    "SILVER",
    };
}
