/**
 * J211_1902_0101
 * Check behavior of the class
 * ListBox - Check behavior of the size (Specify the default item)
 *
 * $Id: J211_1902_0101.java,v 1.1 2002/02/01 06:56:10 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ListBox - Check behavior of the size (Specify the default item)
 * @extends IApplication
 */
public class J211_1902_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ListBox - Check behavior of the size (Specify the default item)
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Check the default size",
        "2.Behavior in case of item being specified",
    };

    String[][] menuListItem2 = {
        /* Menu for checking default size */
        {
            "1.CHOICE",
            "2.SINGLE_SELECT",
            "3.MULTIPLE_SELECT",
            "4.NUMBERED_LIST",
            "5.RADIO_BUTTON",
            "6.CHECK_BOX"
        },
        /* Menu for operational confirmation in the event of item specification */
        {
            "1.CHOICE",
            "2.SINGLE_SELECT",
            "3.MULTIPLE_SELECT",
            "4.NUMBERED_LIST",
            "5.RADIO_BUTTON",
            "6.CHECK_BOX"
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Operation check of ListBox");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * ListBox - Check behavior of the size (Specify the default item)
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;

    int menu1Index;
    int menu2Index;

    int[] listType = {
        ListBox.CHOICE,
        ListBox.SINGLE_SELECT,
        ListBox.MULTIPLE_SELECT,
        ListBox.NUMBERED_LIST,
        ListBox.RADIO_BUTTON,
        ListBox.CHECK_BOX,
    };

    String[] listTypeName = {
        "CHOICE",
        "SINGLE_SELECT",
        "MULTIPLE_SELECT",
        "NUMBERED_LIST",
        "RADIO_BUTTON",
        "CHECK_BOX"
    };

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int menu1Index, int menu2Index, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(menu1Index, menu2Index);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    void testPanel(int menu1Index, int menu2Index) {

        switch(menu1Index) {

//J211_1902_0101
//J211_1902_0102
//J211_1902_0103
//J211_1902_0104
//J211_1902_0105
//J211_1902_0106
        /* Check default size */
        case 0:
            subTitle.setText("Default size");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            sizeTitle.setText(listTypeName[menu2Index]);
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
            Label resultLabel = new Label("Display the frame in the string above");

            ListBox ListBoxObj1 = new ListBox(listType[menu2Index]);
            add(ListBoxObj1);
            add(resultLabel);
            break;

//J211_1902_0201
//J211_1902_0202
//J211_1902_0203
//J211_1902_0204
//J211_1902_0205
//J211_1902_0206
        /* Check item specification operations */
        case 1:
            subTitle.setText("Behavior of item specification");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            sizeTitle.setText(listTypeName[menu2Index]);
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            String[] menuListItem = {listTypeName[menu2Index]};

            ListBox ListBoxObj2 = new ListBox(listType[menu2Index]);
            ListBoxObj2.setItems(menuListItem);
            add(ListBoxObj2);
            
            break;

        default:
            break;
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1902_0101.mainPanel);
        }
    }
}
