/**
 * J211_1902_0301
 * Check behavior of the class
 * ListBox - Check behavior of the size(Specify the size)
 *
 * $Id: J211_1902_0301.java,v 1.1 2002/02/01 06:56:10 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ListBox - Check behavior of the size(Specify the size)
 * @extends IApplication
 */
public class J211_1902_0301 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ListBox - Check behavior of the size(Specify the size)
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Select the display type */
    String[] menuListItem1 = {
        "1.Horizontal > Character",
        "2.Horizontal = Character",
        "3.Horizontal < Character",
        "4.Vertical > Item",
        "5.Vertical = Item",
        "6.Vertical < Item",
    };

    String[][] menuListItem2 = {
        /* Confirmation menu */
        {
            "1.CHOICE",
            "2.SINGLE_SELECT",
            "3.MULTIPLE_SELECT",
            "4.NUMBERED_LIST",
            "5.RADIO_BUTTON",
            "6.CHECK_BOX"
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Operation check of ListBox");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[0]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * ListBox - Check behavior of the size(Specify the size)
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;

    int menu1Index;
    int menu2Index;

    /* ListBox type */
    int[] listType = {
        ListBox.CHOICE,
        ListBox.SINGLE_SELECT,
        ListBox.MULTIPLE_SELECT,
        ListBox.NUMBERED_LIST,
        ListBox.RADIO_BUTTON,
        ListBox.CHECK_BOX,
    };

    /* ListBox type name */
    String[] listTypeName = {
        "CHOICE",
        "SINGLE_SELECT",
        "MULTIPLE_SELECT",
        "NUMBERED_LIST",
        "RADIO_BUTTON",
        "CHECK_BOX"
    };

    /* Menu list */
    String[] menuListItem = {
        "Character strings",
    };

    TextBox textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int menu1Index, int menu2Index, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(menu1Index, menu2Index);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    void testPanel(int menu1Index, int menu2Index) {
		// 2003/03/19 ->
		Font	font;
		String	str;
		int		m_CharSize;
		int		m_Horizontal;
		int		m_Vertical;

		font = Font.getDefaultFont();
		str = menuListItem[0];
		m_CharSize = font.stringWidth(str);
		m_Vertical = font.getHeight();
		// 2003/03/19 <-
        switch(menu1Index) {

//J211_1902_0301
//J211_1902_0302
//J211_1902_0303
//J211_1902_0304
//J211_1902_0305
//J211_1902_0306
        /* Horizontal > Character */
        case 0:
            subTitle.setText("Horizontal > Character");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            sizeTitle.setText(listTypeName[menu2Index]);
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            ListBox ListBoxObj1 = new ListBox(listType[menu2Index]);
            ListBoxObj1.setItems(menuListItem);
			// 2003/03/19 ->
            /*ListBoxObj1.setSize(64, ListBoxObj1.getHeight());

            textBox.setText("Character size\n Horizontal=36 Vertical=12\nListBoxsize\n Horizontal="
                + ListBoxObj1.getWidth() + " Vertical=" +ListBoxObj1.getHeight());
			*/
			m_Horizontal = m_CharSize * 2;
			ListBoxObj1.setSize(m_Horizontal, ListBoxObj1.getHeight());

			textBox.setText("Character size\n Horizontal=" + m_CharSize 
				+ " Vertical=" + m_Vertical + "\nListBoxsize\n Horizontal="
				+ ListBoxObj1.getWidth() + " Vertical=" +ListBoxObj1.getHeight());
			// 2003/03/19 <-

            add(ListBoxObj1);
            break;

//J211_1902_0307
//J211_1902_0308
//J211_1902_0309
//J211_1902_0310
//J211_1902_0311
//J211_1902_0312
        /* Horizontal = Character */
        case 1:
            subTitle.setText("Horizontal = Character");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            sizeTitle.setText(listTypeName[menu2Index]);
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            ListBox ListBoxObj2 = new ListBox(listType[menu2Index]);
            ListBoxObj2.setItems(menuListItem);
			// 2003/03/19 ->
            /*ListBoxObj2.setSize(36, ListBoxObj2.getHeight());

            textBox.setText("Character size\n Horizontal=36 Vertical=12\nListBoxsize\n Horizontal="
                + ListBoxObj2.getWidth() + " Vertical=" +ListBoxObj2.getHeight());
			*/
			m_Horizontal = font.stringWidth(str);
			ListBoxObj2.setSize(m_Horizontal, ListBoxObj2.getHeight());

			textBox.setText("Character size\n Horizontal=" + m_CharSize 
				+ " Vertical=" + m_Vertical + "\nListBoxsize\n Horizontal="
				+ ListBoxObj2.getWidth() + " Vertical=" +ListBoxObj2.getHeight());
			// 2003/03/19 <-

            add(ListBoxObj2);
            
            break;

//J211_1902_0313
//J211_1902_0314
//J211_1902_0315
//J211_1902_0316
//J211_1902_0317
//J211_1902_0318
        /* Horizontal < Character */
        case 2:
            subTitle.setText("Horizontal<Character");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            sizeTitle.setText(listTypeName[menu2Index]);
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            ListBox ListBoxObj3 = new ListBox(listType[menu2Index]);
            ListBoxObj3.setItems(menuListItem);
			// 2003/03/19 ->
            /*ListBoxObj3.setSize(24, ListBoxObj3.getHeight());

            textBox.setText("Character size\n Horizontal=36 Vertical=12\nListBoxsize\n Horizontal="
                + ListBoxObj3.getWidth() + " Vertical=" +ListBoxObj3.getHeight());
			*/
			m_Horizontal = font.stringWidth(str) / 2;
			ListBoxObj3.setSize(m_Horizontal, ListBoxObj3.getHeight());

			textBox.setText("Character size\n Horizontal=" + m_CharSize 
				+ " Vertical=" + m_Vertical + "\nListBoxsize\n Horizontal="
				+ ListBoxObj3.getWidth() + " Vertical=" +ListBoxObj3.getHeight());
			// 2003/03/19 <-

            add(ListBoxObj3);
            
            break;

//J211_1902_0319
//J211_1902_0320
//J211_1902_0321
//J211_1902_0322
//J211_1902_0323
//J211_1902_0324
        /* Vertical > Item */
        case 3:
            subTitle.setText("Vertical > Item");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            sizeTitle.setText(listTypeName[menu2Index]);
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            ListBox ListBoxObj4 = new ListBox(listType[menu2Index]);
            ListBoxObj4.setItems(menuListItem);
            
            /* Double the vertical width */
            ListBoxObj4.setSize(ListBoxObj4.getWidth(), ListBoxObj4.getHeight() * 2);

            textBox.setText("Frame Size\n Horizontal=" + ListBoxObj4.getWidth() +
                            " Vertical=" + ListBoxObj4.getHeight() * 2 +
                            "\nListBoxSize\n Horizontal=" + ListBoxObj4.getWidth() +
                            " Vertical=" +ListBoxObj4.getHeight());

            add(ListBoxObj4);
            
            break;

//J211_1902_0325
//J211_1902_0326
//J211_1902_0327
//J211_1902_0328
//J211_1902_0329
//J211_1902_0330
        /* Vertical = Item */
        case 4:
            subTitle.setText("Vertical = Item");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            sizeTitle.setText(listTypeName[menu2Index]);
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            ListBox ListBoxObj5 = new ListBox(listType[menu2Index]);
            ListBoxObj5.setItems(menuListItem);

            /* Keep the vertical width as it is */
            ListBoxObj5.setSize(ListBoxObj5.getWidth(), ListBoxObj5.getHeight());

            textBox.setText("Frame Size\n Horizontal=" + ListBoxObj5.getWidth() +
                            " Vertical=" + ListBoxObj5.getHeight() +
                            "\nListBoxSize\n Horizontal=" + ListBoxObj5.getWidth() +
                            " Vertical=" +ListBoxObj5.getHeight());

            add(ListBoxObj5);
            
            break;

//J211_1902_0331
//J211_1902_0332
//J211_1902_0333
//J211_1902_0334
//J211_1902_0335
//J211_1902_0336
        /* Vertical > Item */
        case 5:
            subTitle.setText("Vertical < Item");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            sizeTitle.setText(listTypeName[menu2Index]);
            sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

            ListBox ListBoxObj6 = new ListBox(listType[menu2Index]);
            ListBoxObj6.setItems(menuListItem);

            /* Vertical width is 2/3 */
            ListBoxObj6.setSize(ListBoxObj6.getWidth(), ListBoxObj6.getHeight()*2/3);

            textBox.setText("Frame Size\n Horizontal=" + ListBoxObj6.getWidth() +
                            " Vertical=" + ListBoxObj6.getHeight()*2/3 +
                            "\nListBoxSize\n Horizontal=" + ListBoxObj6.getWidth() +
                            " Vertical=" +ListBoxObj6.getHeight());

            add(ListBoxObj6);
            
            break;

        default:
            break;
        }

        add(textBox);



    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1902_0301.mainPanel);
        }
    }
}
