/**
 * J211_1903_0101
 * Check behavior of the class
 * ListBox - Focus operations
 *
 * $Id: J211_1903_0101.java,v 1.1 2002/02/01 06:56:11 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ListBox - Focus operations
 * @extends IApplication
 */
public class J211_1903_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ListBox - Focus operations
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Select the display type */
    String[] menuListItem1 = {
        "1.With or without the focus",
    };

    String[][] menuListItem2 = {
        /* Menu for checking default size */
        {
            "1.CHOICE",
            "2.SINGLE_SELECT",
            "3.MULTIPLE_SELECT",
            "4.NUMBERED_LIST",
            "5.RADIO_BUTTON",
            "6.CHECK_BOX"
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        setTitle("Behavior of the class");
        classLabel.setText("Operation check of ListBox");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[0]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * ListBox - Focus operations
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;

    int menu1Index;
    int menu2Index;

    /* ListBox type */
    int[] listType = {
        ListBox.CHOICE,
        ListBox.SINGLE_SELECT,
        ListBox.MULTIPLE_SELECT,
        ListBox.NUMBERED_LIST,
        ListBox.RADIO_BUTTON,
        ListBox.CHECK_BOX,
    };

    /* ListBox type name */
    String[] listTypeName = {
        "CHOICE",
        "SINGLE_SELECT",
        "MULTIPLE_SELECT",
        "NUMBERED_LIST",
        "RADIO_BUTTON",
        "CHECK_BOX"
    };

    /* Menu list */
    String[] menuListItem = {
        "1.String"
    };

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int menu1Index, int menu2Index, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(menu1Index, menu2Index);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    void testPanel(int menu1Index, int menu2Index) {

        subTitle.setText("With or without focus");
        subTitle.setSize(getWidth(), subTitle.getHeight());

        sizeTitle.setText(listTypeName[menu2Index]);
        sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

        /* Create ListBox */
//J211_1903_0101
//J211_1903_0102
//J211_1903_0103
//J211_1903_0104
//J211_1903_0105
//J211_1903_0106
        Label resultLabel1 = new Label("Down below is focused", Label.LEFT);
        resultLabel1.setSize(getWidth(), resultLabel1.getHeight());
        ListBox ListBoxObj1 = new ListBox(listType[menu2Index]);
        ListBoxObj1.setItems(menuListItem);

//J211_1903_0201
//J211_1903_0202
//J211_1903_0203
//J211_1903_0204
//J211_1903_0205
//J211_1903_0206
        Label resultLabel2 = new Label("below is not focused", Label.LEFT);
        resultLabel2.setSize(getWidth(), resultLabel2.getHeight());
        ListBox ListBoxObj2 = new ListBox(listType[menu2Index]);
        ListBoxObj2.setItems(menuListItem);

        /* Add components*/
        add(resultLabel1);
        add(ListBoxObj1);
        ListBoxObj1.requestFocus();
        add(resultLabel2);
        add(ListBoxObj2);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1903_0101.mainPanel);
        }
    }
}
