/**
 * J211_1904_0101
 * Check behavior of the class
 * ListBox - Checking behavior of scrolling
 *
 * $Id: J211_1904_0101.java,v 1.1 2002/02/01 06:56:11 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ListBox - Checking behavior of scrolling
 * @extends IApplication
 */
public class J211_1904_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ListBox - Checking behavior of scrolling
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Operation check of smooth scrolling",
        "2.Operation check of scrolling"
    };

    String[][] menuListItem2 = {
        /* Menu for checking default size */
        {
            "1.Default - Normal",
            "2.Default - Screen's height",
            "3.Default - Invalid state",
            "4.Default - Invisible",
//2002/08/07 Doja1.5            "5.HTML - Normal",
//2002/08/07 Doja1.5            "6.HTML - Screen's height",
//2002/08/07 Doja1.5            "7.HTML - Invalid state",
//2002/08/07 Doja1.5            "8.HTML - Invisible",
        },
        /* Menu for checking behavior of the case size being specified */
        {
            "1.NULL - Normal",
            "2.NULL - Screen's height",
            "3.NULL - Invalid state",
            "4.NULL - Invisible",
        }
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Operation check of ListBox");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(
                    menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * ListBox - Checking behavior of scrolling
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;
    int menu1Index;
    int menu2Index;
//2002/08/07 Doja1.5    HTMLLayout htmlLayout = new HTMLLayout();

    /* Menu list */
    String[] menuListItem = {
        "1.String"
    };

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int menu1Index, int menu2Index, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = menu1Index;
        menu2Index = menu2Index;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(menu1Index, menu2Index);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    void testPanel(int menu1Index, int menu2Index) {

        /* Label for checking the invisible state */
        Label resultLabel = new Label();

        /* Create all types of ListBox */
        ListBox ListBoxObj1 = new ListBox(ListBox.CHOICE);
        ListBox ListBoxObj2 = new ListBox(ListBox.SINGLE_SELECT);
        ListBox ListBoxObj3 = new ListBox(ListBox.MULTIPLE_SELECT);
        ListBox ListBoxObj4 = new ListBox(ListBox.NUMBERED_LIST);
        ListBox ListBoxObj5 = new ListBox(ListBox.RADIO_BUTTON);
        ListBox ListBoxObj6 = new ListBox(ListBox.CHECK_BOX);
        ListBoxObj1.setItems(menuListItem);
        ListBoxObj2.setItems(menuListItem);
        ListBoxObj3.setItems(menuListItem);
        ListBoxObj4.setItems(menuListItem);
        ListBoxObj5.setItems(menuListItem);
        ListBoxObj6.setItems(menuListItem);
        
        /* Add components */
        add(ListBoxObj1);
        add(ListBoxObj2);
        add(ListBoxObj3);
        add(ListBoxObj4);
        add(ListBoxObj5);
        add(ListBoxObj6);

//2002/009/12 Doja1.5
        ListBoxObj1.setSize(getWidth(), ListBoxObj1.getHeight()*2);
        ListBoxObj2.setSize(getWidth(), ListBoxObj2.getHeight()*2);
        ListBoxObj3.setSize(getWidth(), ListBoxObj3.getHeight()*2);
        ListBoxObj4.setSize(getWidth(), ListBoxObj4.getHeight()*2);
        ListBoxObj5.setSize(getWidth(), ListBoxObj5.getHeight()*2);
        ListBoxObj6.setSize(getWidth(), ListBoxObj6.getHeight()*2);

        switch(menu1Index) {

        /* Check default size */
        case 0:
            subTitle.setText("Check smooth scrolling");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            switch(menu2Index) {
//J211_1904_0101
            case 0:
                sizeTitle.setText("Default - Normal");

                break;

//J211_1904_0102
            case 1:
                sizeTitle.setText("Default - Screen's height");

                /* Change the size of ListBox  */
                ListBoxObj1.setSize(getWidth(), getHeight());

                break;

//J211_1904_0103
            case 2:
                sizeTitle.setText("Default - Invalid state");

                /* Change the state of ListBox to invalid state */
                ListBoxObj1.setEnabled(false);
                ListBoxObj2.setEnabled(false);
                ListBoxObj3.setEnabled(false);
                ListBoxObj4.setEnabled(false);
                ListBoxObj5.setEnabled(false);
                ListBoxObj6.setEnabled(false);

                break;

//J211_1904_0104
            case 3:
                sizeTitle.setText("Default - Invisible");

                /* Change ListBox to invisible */
                ListBoxObj1.setVisible(false);
                ListBoxObj2.setVisible(false);
                ListBoxObj3.setVisible(false);
                ListBoxObj4.setVisible(false);
                ListBoxObj5.setVisible(false);
                ListBoxObj6.setVisible(false);
                resultLabel.setText("Empty line exists above");
                resultLabel.setSize(getWidth(), resultLabel.getHeight());
                add(resultLabel);

                break;

//J211_1904_0105
//2002/08/07 Doja1.5            case 4:
                /* Set Panel layout to HTMLayoutL */
//2002/08/07 Doja1.5                setLayoutManager(htmlLayout);

//2002/08/07 Doja1.5                sizeTitle.setText("HTML - Normal");

//2002/08/07 Doja1.5                break;

//J211_1904_0106
//2002/08/07 Doja1.5            case 5:
                /* Set Panel layout to HTMLayoutL */
//2002/08/07 Doja1.5                setLayoutManager(htmlLayout);

//2002/08/07 Doja1.5                sizeTitle.setText("HTML - Screen's height");

                /* Change the size of ListBox  */
//2002/08/07 Doja1.5                ListBoxObj1.setSize(getWidth(), getHeight());

//2002/08/07 Doja1.5                break;

//J211_1904_0107
//2002/08/07 Doja1.5            case 6:
                /* Set Panel layout to HTMLayoutL */
//2002/08/07 Doja1.5                setLayoutManager(htmlLayout);

//2002/08/07 Doja1.5                sizeTitle.setText("HTML - Invalid state");

                /* Change the state of ListBox to invalid state */
//2002/08/07 Doja1.5                ListBoxObj1.setEnabled(false);
//2002/08/07 Doja1.5                ListBoxObj2.setEnabled(false);
//2002/08/07 Doja1.5                ListBoxObj3.setEnabled(false);
//2002/08/07 Doja1.5                ListBoxObj4.setEnabled(false);
//2002/08/07 Doja1.5                ListBoxObj5.setEnabled(false);
//2002/08/07 Doja1.5                ListBoxObj6.setEnabled(false);

//2002/08/07 Doja1.5                break;

//J211_1904_0108
//2002/08/07 Doja1.5            case 7:
                /* Set Panel layout to HTMLayoutL */
//2002/08/07 Doja1.5                setLayoutManager(htmlLayout);

//2002/08/07 Doja1.5                sizeTitle.setText("HTML - Invisible");

                /* Change ListBox to invisible */
//2002/08/07 Doja1.5                ListBoxObj1.setVisible(false);
//2002/08/07 Doja1.5                ListBoxObj2.setVisible(false);
//2002/08/07 Doja1.5                ListBoxObj3.setVisible(false);
//2002/08/07 Doja1.5                ListBoxObj4.setVisible(false);
//2002/08/07 Doja1.5                ListBoxObj5.setVisible(false);
//2002/08/07 Doja1.5                ListBoxObj6.setVisible(false);
//2002/08/07 Doja1.5                resultLabel.setText("Empty line exists below");
//2002/08/07 Doja1.5                resultLabel.setSize(getWidth(), resultLabel.getHeight());
//2002/08/07 Doja1.5                add(resultLabel);

//2002/08/07 Doja1.5                break;

            default:
                break;
            }

            break;

        case 1:
            /* Set Panel layout to null */
            setLayoutManager(null);

            subTitle.setText("NULL layout");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            subTitle.setLocation(0,0);
            sizeTitle.setLocation(0,13);

            /* Specify location of the ListBox */
            ListBoxObj1.setLocation(0,40);
            ListBoxObj2.setLocation(0,76);
//2002/09/12 Doja1.5            ListBoxObj2.setLocation(0,57);
            ListBoxObj3.setLocation(0,112);
//2002/09/12 Doja1.5            ListBoxObj3.setLocation(0,83);
            ListBoxObj4.setLocation(0,148);
//2002/09/12 Doja1.5            ListBoxObj4.setLocation(0,109);
            ListBoxObj5.setLocation(0,184);
//2002/09/12 Doja1.5            ListBoxObj5.setLocation(0,135);
            ListBoxObj6.setLocation(0,220);
//2002/09/12 Doja1.5            ListBoxObj6.setLocation(0,161);


            switch(menu2Index) {
//J211_1403_0201
            case 0:
                sizeTitle.setText("NULL - Normal");

                break;

//J211_1403_0202
            case 1:
                sizeTitle.setText("NULL - Screen's height");

                ListBoxObj6.setSize(getWidth(), getHeight());

                break;

//J211_1403_0203
            case 2:
                sizeTitle.setText("NULL - Invalid state");

                /* Change the state of ListBox to invalid state */
                ListBoxObj1.setEnabled(false);
                ListBoxObj2.setEnabled(false);
                ListBoxObj3.setEnabled(false);
                ListBoxObj4.setEnabled(false);
                ListBoxObj5.setEnabled(false);
                ListBoxObj6.setEnabled(false);

                break;

//J211_1403_0204
            case 3:
                sizeTitle.setText("NULL - Invisible");

                /* Change ListBox to invisible */
                resultLabel.setText("Empty line exists below");
                resultLabel.setSize(getWidth(), resultLabel.getHeight());
                resultLabel.setLocation(0,25);
                add(resultLabel);
                ListBoxObj1.setVisible(false);
                ListBoxObj2.setVisible(false);
                ListBoxObj3.setVisible(false);
                ListBoxObj4.setVisible(false);
                ListBoxObj5.setVisible(false);
                ListBoxObj6.setVisible(false);
                break;

            default:
                break;
            }
        default:
            break;
        }

        /* Set the size of sub title */
        sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1904_0101.mainPanel);
        }
    }
}
