/**
 * J211_1907_0101
 * Check behavior of the class
 * ListBox - Check the state and behavior of currently-selected items
 *
 * $Id: J211_1907_0101.java,v 1.1 2002/02/01 06:56:12 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ListBox - Check the state and behavior of currently-selected items
 * @extends IApplication
 */
public class J211_1907_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ListBox - Check the state and behavior of currently-selected items
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Sub division menu */
    String[] menuListItem1 = {
        "1. Adding operations",
        "2. Deleting operations",
        "3. Setting operations"
    };

    String[][] menuListItem2 = {
        /* Menu by ListBox type */
        {
            "1.CHOICE",
            "2.SINGLE_SELECT",
            "3.MULTIPLE_SELECT",
            "4.NUMBERED_LIST",
            "5.RADIO_BUTTON",
            "6.CHECK_BOX"
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Operations of the state of items being selected");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(
                    menuListItem2[0]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * ListBox - Check the state and behavior of currently-selected items
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;
    int menu1Index;
    int menu2Index;
    Button  execButton = new Button("execute");
    ListBox ListBoxObj;
    TextBox textBox = new TextBox("", 16, 2, TextBox.DISPLAY_ANY);

    /* For test execution judgement */
    boolean testExec = true;

    /* ListBox type */
    int[] listType = {
        ListBox.CHOICE,
        ListBox.SINGLE_SELECT,
        ListBox.MULTIPLE_SELECT,
        ListBox.NUMBERED_LIST,
        ListBox.RADIO_BUTTON,
        ListBox.CHECK_BOX,
    };

    /* ListBox type name */
    String[] listTypeName = {
        "CHOICE",
        "SINGLE_SELECT",
        "MULTIPLE_SELECT",
        "NUMBERED_LIST",
        "RADIO_BUTTON",
        "CHECK_BOX"
    };

    /* Menu list */
    String[] menuListItem = {
        "1.String",
        "2.String"
    };

    /**
     * Display a sub screen
     * @param anInt1  Sub division of test
     * @param anInt2  Detail items of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt1, int anInt2, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = anInt1;
        menu2Index = anInt2;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    void testPanel() {

        switch(menu1Index) {

        /* Adding operations */
        case 0:
            subTitle.setText("Adding operations");
            break;

        /* Deleting operations */
        case 1:
            subTitle.setText("Deleting operations");
            break;

        /* Setting operations */
        case 2:
            subTitle.setText("Setting operations");
            break;

        default:
            break;
        }

        /* Create ListBox */
        ListBoxObj = new ListBox(listType[menu2Index]);
        ListBoxObj.setItems(menuListItem);
        ListBoxObj.requestFocus();

        /* Title setting */
        subTitle.setSize(getWidth(), subTitle.getHeight());
        sizeTitle.setText(listTypeName[menu2Index]);
        sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

        /* Add components */
        add(ListBoxObj);
        add(execButton);
        add(textBox);
    }



    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1907_0101.mainPanel);
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {


        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {
            if(testExec) {
                try {
                    setItemClass setItemClassObj = new setItemClass();
                    Thread testThread = new Thread(setItemClassObj);
                    testThread.start();
                } catch(UIException e) {
                    textBox.setText("NG");
                }
            } else {
                textBox.setText("Test has already been executed.");
            }
        }
    }

    /**
     * Class for execution of Threads
     * @implements Runnable
     */
    class setItemClass implements Runnable {

        /**
         * Constructor of setItemClass
         */
        public setItemClass(){
        }

        /**
         * Thread execution method
         */
        public void run() {
            try {
                Thread.sleep(10000);
                switch(menu1Index) {

//J211_1907_0101
//J211_1907_0102
//J211_1907_0103
//J211_1907_0104
//J211_1907_0105
//J211_1907_0106
                case 0:
                    if(testExec) {
                        ListBoxObj.append("3.Additional strings");
                        textBox.setText("An item has been added.");
                        testExec = false;
                    }
                    break;

//J211_1907_0201
//J211_1907_0202
//J211_1907_0203
//J211_1907_0204
//J211_1907_0205
//J211_1907_0206
                case 1:
                    if(testExec) {
                        ListBoxObj.removeAll();
                        textBox.setText("An item has been deleted.");
                        testExec = false;
                    }
                    break;

//J211_1907_0301
//J211_1907_0302
//J211_1907_0303
//J211_1907_0304
//J211_1907_0305
//J211_1907_0306
                case 2:
                    if(testExec) {
                        String[] menuListItem = {
                            "1. New string",
                            "2. New string"
                        };
                        
                        ListBoxObj.setItems(menuListItem);
                        textBox.setText("An item has been set.");
                        testExec = false;
                    }
                    break;

                default:
                    break;
                }
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
                errDialog.setText("NG:" + e.toString());
                errDialog.show();
            }
        }
    }
}
