/**
 * J211_1908_0601
 * Check behavior of the class
 * ListBox - Check behavior of the event (Events of out of range)
 *
 * $Id: J211_1908_0601.java,v 1.1 2002/02/01 06:56:12 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ListBox - Check behavior of the event (Events of out of range)
 * @extends IApplication
 */
public class J211_1908_0601 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ListBox - Check behavior of the event (Events of out of range)
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Sub division menu */
    String[] menuListItem1 = {
        "1.When selected/confirmed",
        "2.invisible-select",
        "3.Invalid state-select",
        "4.invisible-deselect",
        "5.Invalid state-deselect",
    };

    String[][] menuListItem2 = {
        /* Menu by ListBox type */
        {
            "1.CHOICE",
            "2.SINGLE_SELECT",
            "3.MULTIPLE_SELECT",
            "4.NUMBERED_LIST",
            "5.RADIO_BUTTON",
            "6.CHECK_BOX"
        },
        /* deselect has no CHOICE */
        {
            "1.SINGLE_SELECT",
            "2.MULTIPLE_SELECT",
            "3.NUMBERED_LIST",
            "4.RADIO_BUTTON",
            "5.CHECK_BOX"
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Events out of range");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                switch(menuList1.getSelectedIndex()) {
                    case 0:
                    case 1:
                    case 2:
                        menuList2.setItems(menuListItem2[0]);
                        break;
                    case 3:
                    case 4:
                        menuList2.setItems(menuListItem2[1]);
                    default:
                        break;
                }
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * ListBox - Check behavior of the event (Events of out of range)
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;
    int menu1Index;
    int menu2Index;
    ListBox ListBoxObj;
    Button  selectButton = new Button("Select");
    Button  deselectButton = new Button("Release");

    /* ListBox type */
    int[] listType = {
        ListBox.CHOICE,
        ListBox.SINGLE_SELECT,
        ListBox.MULTIPLE_SELECT,
        ListBox.NUMBERED_LIST,
        ListBox.RADIO_BUTTON,
        ListBox.CHECK_BOX,
    };

    /* ListBox type name */
    String[] listTypeName = {
        "CHOICE",
        "SINGLE_SELECT",
        "MULTIPLE_SELECT",
        "NUMBERED_LIST",
        "RADIO_BUTTON",
        "CHECK_BOX"
    };

    /* Menu list */
    String[] menuListItem = {
        "0.String",
        "1.String",
        "2.String"
    };

    /**
     * Display a sub screen
     * @param anInt1  Sub division of test
     * @param anInt2  Detail items of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt1, int anInt2, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = anInt1;
        menu2Index = anInt2;
        
        /* When deselect is selected +1 to menu2Index (as compensation for omitted CHOICE) */
        if (menu1Index==3 || menu1Index==4) {
            menu2Index++;
        }

        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    void testPanel() {

        /* Create ListBox */
        ListBoxObj = new ListBox(listType[menu2Index]);
        ListBoxObj.setItems(menuListItem);
        ListBoxObj.requestFocus();

        /* Title setting */
        subTitle.setText("Events out of range");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        sizeTitle.setText(listTypeName[menu2Index]);
        sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

        /* Add components */
        add(ListBoxObj);

        switch(menu1Index) {
//J211_1908_0601
//J211_1908_0602
//J211_1908_0603
//J211_1908_0604
//J211_1908_0605
//J211_1908_0606
        case 0:
            break;
//J211_1908_0607
//J211_1908_0608
//J211_1908_0609
//J211_1908_0610
//J211_1908_0611
//J211_1908_0612
        case 1:
            ListBoxObj.setVisible(false);
            add(selectButton);
            selectButton.requestFocus();
            break;
//J211_1908_0613
//J211_1908_0614
//J211_1908_0615
//J211_1908_0616
//J211_1908_0617
//J211_1908_0618
        case 2:
            ListBoxObj.setEnabled(false);
            add(selectButton);
            selectButton.requestFocus();
            break;
//J211_1908_0620
//J211_1908_0621
//J211_1908_0622
//J211_1908_0623
//J211_1908_0624
        case 3:
            ListBoxObj.setVisible(false);
            add(deselectButton);
            deselectButton.requestFocus();
            ListBoxObj.select(2);
            break;
//J211_1908_0626
//J211_1908_0627
//J211_1908_0628
//J211_1908_0629
//J211_1908_0630
        case 4:
            ListBoxObj.setEnabled(false);
            add(deselectButton);
            deselectButton.requestFocus();
            ListBoxObj.select(2);
            break;
        default:
            break;
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1908_0601.mainPanel);
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        /* For item index(Initial value is 99) */
        int selectIndex=99;
        Dialog msgDialog;

        /* BUTTON_PRESSED */
        if ( aType == ComponentListener.BUTTON_PRESSED ) {
            /* When select button is pressed */
            if( aComponent == selectButton ) {
                ListBoxObj.select(2);
            }

            /* When release button is pressed */
            if ( aComponent == deselectButton ) {
                if (ListBoxObj.getSelectedIndex()==-1) {
                    msgDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    msgDialog.setText("NG: Not selected");
                    msgDialog.show();
                } else {
                    ListBoxObj.deselect(2);
                }
            }

            /* Displayed only when checking SELECTION_CHANGED occurrence */
            if(menu1Index==0) {
                msgDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                msgDialog.setText("NG:BUTTON_PRESSED");
                msgDialog.show();
            }
        }
        /* SELECTION_CHANGED */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
                msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
                msgDialog.setText("OK:SELECTION_CHANGED");
                msgDialog.show();
        }

        /* TEXT_CHANGED */
        if ( aType == ComponentListener.TEXT_CHANGED ) {
            msgDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            msgDialog.setText("NG:TEXT_CHANGED");
            msgDialog.show();
        }

    }
}