/**
 * J211_1909_0101
 * Check behavior of the class
 * ListBox - Check behavior of the event (Check behavior of menu UI)
 *
 * $Id: J211_1909_0101.java,v 1.1 2002/02/01 06:56:13 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * ListBox - Check behavior of the event (Check behavior of menu UI)
 * @extends IApplication
 */
public class J211_1909_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * ListBox - Check behavior of the event (Check behavior of menu UI)
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Sub division menu */
    String[] menuListItem1 = {
        "1.Expanding operations",
        "2.Confirming operations",
        "3.Releasing operations",
    };

    String[][] menuListItem2 = {
        /* Menu by ListBox type */
        {
            "1.CHOICE",
            "2.SINGLE_SELECT",
            "3.MULTIPLE_SELECT",
            "4.NUMBERED_LIST",
            "5.RADIO_BUTTON",
            "6.CHECK_BOX"
        },
        {
            "1.MULTIPLE_SELECT",
            "2.NUMBERED_LIST",
        },
        {
            "1.CHOICE",
            "2.SINGLE_SELECT",
            "3.MULTIPLE_SELECT",
            "4.NUMBERED_LIST",
            "5.RADIO_BUTTON",
            "6.CHECK_BOX"
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText(" Menu UI operations");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * ListBox - Check behavior of the event (Check behavior of menu UI)
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;
    int menu1Index;
    int menu2Index;
    ListBox ListBoxObj;

    /* ListBox type */
    int[] listType = {
        ListBox.CHOICE,
        ListBox.SINGLE_SELECT,
        ListBox.MULTIPLE_SELECT,
        ListBox.NUMBERED_LIST,
        ListBox.RADIO_BUTTON,
        ListBox.CHECK_BOX,
    };

    /* ListBox type name */
    String[] listTypeName = {
        "CHOICE",
        "SINGLE_SELECT",
        "MULTIPLE_SELECT",
        "NUMBERED_LIST",
        "RADIO_BUTTON",
        "CHECK_BOX"
    };

    /* Menu list */
    String[] menuListItem = {
        "0.String",
        "1.String",
        "2.String"
    };

    /* Menu list (For expanded CHOICE) */
    String[] menuListItem1 = {
        "1.123456789012345678901234567980",
        "2.12345678901234567890",
    };

    /* Menu list(For confirmed NUMBER_LIST) */
    String[] menuListItem2 = {
        "1.String",
        "2.String",
        "3.String",
        "4.String",
        "5.String",
        "6.String",
        "7.String",
        "8.String",
        "9.String"
    };

    /**
     * Display a sub screen
     * @param anInt1  Sub division of test
     * @param anInt2  Detail items of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt1, int anInt2, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = anInt1;
        menu2Index = anInt2;
        
        /* 2.When operation for confirmation is selected  +2 to menu2Index (Supplement the omission) */
        if (menu1Index==1 ) {
            menu2Index+=2;
        }

        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    void testPanel() {

        /* Create ListBox */
        ListBoxObj = new ListBox(listType[menu2Index]);
        ListBoxObj.setItems(menuListItem);
        ListBoxObj.requestFocus();

        /* Title setting */
        subTitle.setText(" Menu UI operations");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        sizeTitle.setText(listTypeName[menu2Index]);
        sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

//J211_1909_0101
//J211_1909_0102
        /* Re-set the menu when expanding operation is CHOICE */
        if(menu1Index==0 && menu2Index==0) {
            ListBoxObj.setItems(menuListItem1);
        }

//J211_1909_0206
        /* Re-set the menu when confirming operation is NUMBER_LIST */
        if(menu1Index==1 && menu2Index==3) {
            ListBoxObj.setItems(menuListItem2);
        }

//J211_1909_0103
//J211_1909_0104
//J211_1909_0105
//J211_1909_0106
//J211_1909_0107
//J211_1909_0204
//J211_1909_0301
//J211_1909_0302
//J211_1909_0303
//J211_1909_0304
//J211_1909_0305
//J211_1909_0306
        /* Add components */
        add(ListBoxObj);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_1909_0101.mainPanel);
        }
    }
}
