/**
 * J211_2301_0101
 * Check behavior of the class
 * MediaPresenter
 *
 * $Id: J211_2301_0101.java,v 1.2 2002/05/01 01:48:58 torikatu Exp $
 */
import java.lang.*;
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * MediaPresenter
 * @extends IApplication
 */
public class J211_2301_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * MediaPresenter
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Sub division menu */
    String[] menuListItem1 = {
        "1.Replay",
        "2.Stop replay",
        "3.Setting of the listener",
        "4.Deletion of the listener",
    };

    String[][] menuListItem2 = {
        /* Menu by ListBox type */
        {
            "1.AudioPresenter",
            "2.VisualPresenter",
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("MediaPresenter");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(
                    menuListItem2[0]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * MediaPresenter
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements MediaListener
 */
class SubPanel extends Panel implements SoftKeyListener, MediaListener {

    Frame prevFrame;
    Label subTitle = null;
    int menu1Index;
    int menu2Index;
    TextBox textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);

    AudioPresenter  ap;
    VisualPresenter vp;
    MediaPresenter  mp;

    /* Setting of the Resource */
    String apResource = "resource:///MFi1-1.mld";
    String vpResource = "resource:///java1.gif";

    /**
     * Display a sub screen
     * @param anInt1  Sub division of test
     * @param anInt2  Detail items of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt1, int anInt2, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = anInt1;
        menu2Index = anInt2;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {
        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);

    }

    void testPanel() {

        switch(menu1Index) {
        case 0:
            switch(menu2Index) {
//J211_2301_0101
            case 0:
                try {
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound(apResource);
                    ms.use();
                    ap.setSound(ms);
                    mp = (MediaPresenter)ap;
                    mp.play();
                    textBox.setText("Replay OK");
                } catch(Exception e) {
                    textBox.setText("Replay NG:" +e.toString());
                }
                break;
//J211_2301_0102
            case 1:
                try {
                    vp = new VisualPresenter();
                    MediaImage mi = MediaManager.getImage(vpResource);
                    mi.use();
                    vp.setImage(mi);
                    mp = (MediaPresenter)vp;
                    mp.play();
                    textBox.setText("Replay OK");
                } catch(Exception e) {
                    textBox.setText("Replay NG:" +e.toString());
                }
                break;
            default:
                break;
            }
            break;
        case 1:
            switch(menu2Index) {
//J211_2301_0201
            case 0:
                try {
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound(apResource);
                    ms.use();
                    ap.setSound(ms);
                    mp = (MediaPresenter)ap;
                    mp.play();
                    mp.stop();
                    textBox.setText("Stop OK");
                } catch(Exception e) {
                    textBox.setText(" Stop+C2104NG:" +e.toString());
                }
                break;
//J211_2301_0202
            case 1:
                try {
                    vp = new VisualPresenter();
                    MediaImage mi = MediaManager.getImage(vpResource);
                    mi.use();
                    vp.setImage(mi);
                    mp = (MediaPresenter)vp;
                    mp.play();
                    mp.stop();
                    textBox.setText("Stop OK");
                } catch(Exception e) {
                    textBox.setText(" Stop+C2104NG:" +e.toString());
                }
                break;
            default:
                break;
            }
            break;
        case 2:
            switch(menu2Index) {
//J211_2301_0301
            case 0:
                try {
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound(apResource);
                    ms.use();
                    ap.setSound(ms);
                    mp = (MediaPresenter)ap;
                    mp.setMediaListener(this);
                    textBox.setText("Listener entry OK");
                } catch(Exception e) {
                    textBox.setText("Listener entry NG" +e.toString());
                }
                break;
//J211_2301_0302
            case 1:
                try {
                    vp = new VisualPresenter();
                    MediaImage mi = MediaManager.getImage(vpResource);
                    mi.use();
                    vp.setImage(mi);
                    mp = (MediaPresenter)vp;
                    mp.setMediaListener(this);
                    textBox.setText("Listener entry OK");
                } catch(Exception e) {
                    textBox.setText("Listener entry NG" +e.toString());
                }
                break;
            default:
                break;
            }
            break;
        case 3:
            switch(menu2Index) {
//J211_2301_0401
            case 0:
                try {
                    ap = AudioPresenter.getAudioPresenter();
                    MediaSound ms = MediaManager.getSound(apResource);
                    ms.use();
                    ap.setSound(ms);
                    mp = (MediaPresenter)ap;
                    mp.setMediaListener(this);
                    mp.setMediaListener(null);
                    textBox.setText("Listener deletion OK");
                } catch(Exception e) {
                    textBox.setText("Listener deletion NG" +e.toString());
                }
                break;
//J211_2301_0402
            case 1:
                try {
                    vp = new VisualPresenter();
                    MediaImage mi = MediaManager.getImage(vpResource);
                    mi.use();
                    vp.setImage(mi);
                    mp = (MediaPresenter)vp;
                    mp.setMediaListener(this);
                    mp.setMediaListener(null);
                    textBox.setText("Listener deletion OK");
                } catch(Exception e) {
                    textBox.setText("Listener deletion NG" +e.toString());
                }
                break;
            default:
                break;
            }
            break;
        default:
            break;
        }

        /* Title setting */
        subTitle.setText("Check the MediaPresenter");
        subTitle.setSize(getWidth(), subTitle.getHeight());

        /* Add components */
        add(textBox);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_2301_0101.mainPanel);
        }
    }

    /** 
     * Process that registers events (No behavior in particular)
     */
    public void mediaAction(MediaPresenter source,int aType,int aParam) {}

}
