/**
 * J211_2501_0101
 * Check behavior of the class
 * MediaSound
 *
 * $Id: J211_2501_0101.java,v 1.2 2002/05/01 01:52:37 torikatu Exp $
 */
import java.lang.*;
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * MediaSound
 * @extends IApplication
 */
public class J211_2501_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * MediaSound
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Sub division menu */
    String[] menuListItem1 = {
        "1.Unavailable state",
        "2.Resource-disposed state",
        "3.Check collection of GC",
        "4.Check forced collection",
    };

    String[][] menuListItem2 = {
        /* Menu by ListBox type */
        {
            "1.unuse()",
            "2.use()",
            "3.dispose()",
        },
        {
            "1.dispose()",
            "2.After UIException is thrown",
        },
        {
            "1.Check collection of GC",
        },
        {
            "1.Check forced collection",
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("MediaSound");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(
                    menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * MediaSound
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener, ComponentListener {

    Frame prevFrame;
    Label subTitle = null;
    int menu1Index;
    int menu2Index;
    Button  execButton = new Button("execute");
    TextBox textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);
    MediaSound MediaSoundObj;

    Runtime rt =  Runtime.getRuntime();
    long beforeFreeMem = 0;
    long afterFreeMem = 0;

    Dialog errDialog;

    /**
     * Display a sub screen
     * @param anInt1  Sub division of test
     * @param anInt2  Detail items of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt1, int anInt2, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = anInt1;
        menu2Index = anInt2;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {
        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

    }

    void testPanel() {
        
        try {
            /* Create MediaData */
            MediaSoundObj = MediaManager.getSound("resource:///MFi1-1.mld");
        } catch(Exception e) {
            errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }

        /* Title setting */
        subTitle.setText("Check MediaSound");
        subTitle.setSize(getWidth(), subTitle.getHeight());

        /* Add components */
        add(execButton);
        add(textBox);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_2501_0101.mainPanel);
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            try {
                switch(menu1Index) {
                case 0:
                    switch(menu2Index) {
//J211_2501_0101
                    case 0:
                        MediaSoundObj.unuse();
                        textBox.setText("OK:unuse()");
                        break;
//J211_2501_0102
                    case 1:
                        MediaSoundObj.use();
                        textBox.setText("OK:use()");
                        break;
//J211_2501_0103
                    case 2:
                        MediaSoundObj.dispose();
                        textBox.setText("OK:dispose()");
                        break;
                    default:
                        break;
                    }

                    break;
                case 1:
                    switch(menu2Index){
//J211_2501_0301
                    case 0:
                        MediaSoundObj.use();
                        MediaSoundObj.dispose();
                        MediaSoundObj.dispose();
                        textBox.setText("OK:dispose()");
                        break;

//J211_2501_0302
                    case 1:
                        MediaSoundObj.use();
                        MediaSoundObj.dispose();
                        MediaSoundObj.use();
                    default:
                        break;
                    }

                    break;

//J211_2502_0101
                case 2:
                    beforeFreeMem = rt.freeMemory();
                    MediaSoundObj = null;
                    rt.gc();
                    afterFreeMem = rt.freeMemory();
                    textBox.setText("Before GC->" + beforeFreeMem +
                        "\nAfter GC->" + afterFreeMem);
                    break;
//J211_2502_0201
                case 3:
                    MediaSoundObj.use();
                    rt.gc();
                    beforeFreeMem = rt.freeMemory();
                    MediaSoundObj.dispose();
                    rt.gc();
                    afterFreeMem = rt.freeMemory();
                    textBox.setText("Before dispose()\n ->" + beforeFreeMem +
                        "\nAfter dispose()\n ->" + afterFreeMem);
                    break;

                default:
                    break;
                }
            } catch(Exception e) {
                errDialog = new Dialog(Dialog.DIALOG_ERROR, "Exception");
                errDialog.setText("Exception:" + e.toString());
                errDialog.show();
                if(menu1Index == 1 && menu2Index == 1) {
                    try {
                        MediaSoundObj.dispose();
                        textBox.setText("OK:dispose()");
                    } catch(Exception e2) {
                        errDialog = new Dialog(Dialog.DIALOG_ERROR, "Exception");
                        errDialog.setText("Exception:" + e2.toString());
                        errDialog.show();
                    }
                }
            } catch (Error e) {
                errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }
    }
}