/**
 * J211_2601_0101
 * Check behavior of the class
 * Panel - Check behavior of basic/display/container
 *
 * $Id: J211_2601_0101.java,v 1.1 2002/02/01 07:02:11 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * Panel - Check behavior of basic/display/container
 * @extends IApplication
 */
public class J211_2601_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * Panel - Check behavior of basic/display/container
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Basic operation check",
        "2.Check behavior of display",
        "3.Check behavior of the container",
    };

    String[][] menuListItem2 = {
        /* Menu for check basic operations */
        {
            "1.Default layout",
//2002/08/07 Doja1.5            "2.HTML layout",
            "3.NULL layout",
        },
        /* Menu for checking display operations */
        {
            "1.Behavior of the title",
            "2.Alignment",
            "3.Linefeed",
            "4.All types mixed",
            "5.Soft key display",
            "6.Soft key character type 1",
//2002/08/07 Doja1.5            "7.Soft key character type 2",
//2002/08/07 Doja1.5            "8.Soft key character type 3",
            "9.Soft key character type 4",
            "10.Soft key character type 5",
            "11.Soft key character type 6",
        },
        /* Menu for checking behavior of the container */
        {
            "1.Exclude components",
            "2.getHeight- No title",
            "3.getHeight- with title",
            "4.getHeight-Logical value 1",
            "5.getHeight-Logical value 2",
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Check behavior of the Panel");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * Panel - Check behavior of basic/display/container
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener, ComponentListener  {

    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;

    int menu1Index;
    int menu2Index;
    Button button = new Button("Button");
    Button softKey1Button;
    Button softKey2Button;
    int softKey1Flag = 0;
    int softKey2Flag = 0;
    TextBox textBox = new TextBox("", 16, 16, TextBox.DISPLAY_ANY);
//2002/08/07 Doja1.5    HTMLLayout htmlLayout = new HTMLLayout();

    /* Character code for pictograph */
    char[] emoji = {0xE63E, 0xE63F};

    /**
     * Display a sub screen
     * @param anInt1  Sub division of test
     * @param anInt2  Detail items of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt1, int anInt2, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = anInt1;
        menu2Index = anInt2;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        sizeTitle = new Label("");
        add(sizeTitle);
        setTitle("Behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    void testPanel() {

        switch(menu1Index) {

        /* Check display operations */
        case 0:
            subTitle.setText("Check scrolling operations");
            subTitle.setSize(getWidth(), subTitle.getHeight());

            /* Change the size for checking scrolling */
            button.setSize(getWidth(), getHeight()/2);

            /* Setting of the text box */
            textBox.setText("For checking scrolling");

            switch(menu2Index) {

//J211_2601_0102
//J211_2601_0107
            case 0:
                sizeTitle.setText("Default");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                break;

//J211_2601_0109
//J211_2601_0114
//2002/08/07 Doja1.5            case 1:
                /* Set Panel layout to HTMLayoutL */
//2002/08/07 Doja1.5                setLayoutManager(htmlLayout);

//2002/08/07 Doja1.5                sizeTitle.setText("HTML");
//2002/08/07 Doja1.5                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
//2002/08/07 Doja1.5                break;

//J211_2601_0116
//J211_2601_0117
            case 1:
//2002/08/07 Doja1.5            case 2:
                /* Set Panel layout to null */
                setLayoutManager(null);

                sizeTitle.setText("NULL");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                /* Setting of the Location */
                subTitle.setLocation(0,0);
                sizeTitle.setLocation(0,13);
                button.setLocation(0,26);
                textBox.setLocation(0,100);
                break;

            default:
                break;
            }

            add(button);
            add(textBox);

            break;

        /* Check display operations */
        case 1:

            switch(menu2Index) {

//J211_2602_0101
            case 0:
                subTitle.setText("Check behavior of the title");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                break;

//J211_2602_0104
            case 1:
                subTitle.setText("Check the alignment");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                break;

//J211_2602_0205
            case 2:
                setTitle("->\n<-");
                subTitle.setText("Linefeed");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                break;

//J211_2602_0206
            case 3:
                setTitle("\nAb" + String.valueOf(emoji));
//2002/08/07 Doja1.5                setTitle("Tow bytes kana characters,One byte kana character\nAb" + String.valueOf(emoji));
                subTitle.setText("All types mixed");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                break;

//J211_2602_0301
//J211_2602_0302
//J211_2602_0303
//J211_2602_0304
            case 4:
                subTitle.setText("Check the soft key display");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                softKey1Button = new Button("Change over SoftKey1");
                softKey2Button = new Button("Change over SoftKey2");
                add(softKey1Button);
                add(softKey2Button);
                break;

//J211_2602_0401
            case 5:
                subTitle.setText("Check the character type of the soft key");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                sizeTitle.setText("ASCII character");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                setSoftLabel(Frame.SOFT_KEY_1, "ABCD");
                setSoftLabel(Frame.SOFT_KEY_2, "1234");
                break;

//J211_2602_0402
//2002/08/07 Doja1.5            case 6:
//2002/08/07 Doja1.5                subTitle.setText("Check the character type of the soft key");
//2002/08/07 Doja1.5                subTitle.setSize(getWidth(), subTitle.getHeight());
//2002/08/07 Doja1.5                sizeTitle.setText("Japanese one byte kana characters");
//2002/08/07 Doja1.5                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
//2002/08/07 Doja1.5                setSoftLabel(Frame.SOFT_KEY_1, "One byte kana character ");
//2002/08/07 Doja1.5                setSoftLabel(Frame.SOFT_KEY_2, "One byte kana character ");
//2002/08/07 Doja1.5                break;

//J211_2602_0403
//2002/08/07 Doja1.5            case 7:
//2002/08/07 Doja1.5                subTitle.setText("Check the character type of the soft key");
//2002/08/07 Doja1.5                subTitle.setSize(getWidth(), subTitle.getHeight());
//2002/08/07 Doja1.5                sizeTitle.setText("Double byte characters");
//2002/08/07 Doja1.5                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
//2002/08/07 Doja1.5                setSoftLabel(Frame.SOFT_KEY_1, "Two byte characters");
//2002/08/07 Doja1.5                setSoftLabel(Frame.SOFT_KEY_2, "Character");
//2002/08/07 Doja1.5                break;

//J211_2602_0404
            case 6:
//2002/08/07 Doja1.5            case 8:
                subTitle.setText("Check the character type of the soft key");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                sizeTitle.setText("Pictograph");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                setSoftLabel(Frame.SOFT_KEY_1, String.valueOf(emoji));
                setSoftLabel(Frame.SOFT_KEY_2, String.valueOf(emoji));
                break;

//J211_2602_0405
            case 7:
//2002/08/07 Doja1.5            case 9:
                subTitle.setText("Check the character type of the soft key");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                sizeTitle.setText("Linefeed");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                setSoftLabel(Frame.SOFT_KEY_1, "A\nB");
                setSoftLabel(Frame.SOFT_KEY_2, "1\n2");
                break;

//J211_2602_0406
           case 8:
//2002/08/07 Doja1.5           case 10:
                subTitle.setText("Check the character type of the soft key");
                subTitle.setSize(getWidth(), subTitle.getHeight());
                sizeTitle.setText("All types mixed");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                setSoftLabel(Frame.SOFT_KEY_1, "A\n");
//2002/08/07 Doja1.5                setSoftLabel(Frame.SOFT_KEY_1, "A\nTow bytes kana characters");
                setSoftLabel(Frame.SOFT_KEY_2, "\n" + emoji[0]);
//2002/08/07 Doja1.5                setSoftLabel(Frame.SOFT_KEY_2, "\n" + emoji[0]);
                break;

            default:
                break;
            }

            break;

        /* Checking behavior of the container */
        case 2:
            subTitle.setText("Check behavior of the container");
            subTitle.setSize(getWidth(), subTitle.getHeight());
            textBox = new TextBox("", 16, 4, TextBox.DISPLAY_ANY);
            Panel p = new Panel();
            Button addButton;
            int dHeight = Display.getHeight();

            switch(menu2Index) {

//J211_2603_0101
            case 0:
                try {
                    sizeTitle.setText("Exclude components");
                    sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                    /* Paste the identical component twice */
                    add(button);
                    add(button);
                } catch(Exception e) {
                    Dialog errDialog =
                        new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Error:" + e.toString());
                    errDialog.show();
                }
                break;

//J211_2603_0201
            case 1:
                sizeTitle.setText("No title");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                textBox.setText("Screen size->" + dHeight +
                    "\nPanel Size->" + p.getHeight());
                break;

//J211_2603_0202
            case 2:
                sizeTitle.setText("With title");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                p.setTitle("Title");
                textBox.setText("Screen size->" + dHeight +
                    "\nPanel Size->" + p.getHeight());

                break;

//J211_2603_0203
            case 3:
                sizeTitle.setText("Component within the screen");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());

                p.setTitle("Title");
                p.add(button);
                textBox.setText("Screen size->" + dHeight +
                    "\nPanel Size->" + p.getHeight());

                break;

//J211_2603_0204
            case 4:
                sizeTitle.setText("Component outside the screen");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
                p.setTitle("Title");
                for(int i=0; i<20; i++){
                    addButton = new Button("Button");
                    addButton.setSize(getWidth(), addButton.getHeight());
                    p.add(addButton);
                }
                textBox.setText("Screen size->" + dHeight +
                    "\nPanel Size->" + p.getHeight());

                break;

            default:
                break;
            }

            add(textBox);
            break;

        default:
            break;
        }
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J211_2601_0101.mainPanel);
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == softKey1Button ) {
//J211_2602_0302
            if ( softKey1Flag == 0) {
                setSoftLabel(Frame.SOFT_KEY_1, null);
                softKey1Flag = 1;
//J211_2602_0301
            } else if ( softKey1Flag == 1) {
                setSoftLabel(Frame.SOFT_KEY_1, "exit");
                softKey1Flag = 0;
            }
        }

        if ( aComponent == softKey2Button ) {
//J211_2602_0304
            if ( softKey2Flag == 0) {
                setSoftLabel(Frame.SOFT_KEY_2, null);
                softKey2Flag = 1;
//J211_2602_0303
            } else if ( softKey2Flag == 1) {
                setSoftLabel(Frame.SOFT_KEY_2, "back");
                softKey2Flag = 0;
            }
        }
    }
}
