/**
 * J211_2604_0101
 * Check behavior of the class
 * Panel - Behavior for changing over the layout
 *
 * $Id: J211_2604_0101.java,v 1.2 2002/05/16 02:31:49 torikatu Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * Panel - Behavior for changing over the layout
 * @extends IApplication
 */
public class J211_2604_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * Panel - Behavior for changing over the layout
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Layout change over",
        "2.Component has already been set",
    };

    String[][] menuListItem2 = {
        /* Layout change-over */
        {
            "7.Default->Non display NULL",
            "8.Default->displayed NULL",
        },
        /* Component has been set up already */
        {
            "7.Default->Non display NULL",
            "8.Default->displayed NULL",
        },
        /* Layout association */
        {
            "1.Identical panel",
            "2.Another panel 1",
            "3.Another panel 2",
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Check behavior of the Panel");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();

            SubPanel sp = new SubPanel(menu1Index, menu2Index, this);

            /* Component for SubPanel */
            Label subTitle = new Label("");
            sp.setTitle("Behavior of the class");

            if(menu1Index==0 || menu1Index==1) {
                /* Change the layout before displaying in case of non-displayed */
                if (menu2Index == 0) {
                    /* NULL */
                    sp.setLayoutManager(null);
                }

                /* Display sub panel */
                Display.setCurrent(sp);

            }
        }
    }
}

/**
 * Check behavior of the class
 * Panel - Behavior for changing over the layout
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener  {

    Frame prevFrame;

    int menu1Index;
    int menu2Index;
    boolean addFlag = true;
    Label addLabel = new Label("Additional label");
    TextBox addTextBox = new TextBox("Additional TextBox", Display.getWidth()/18, 2, TextBox.DISPLAY_ANY);
    Label chgLabel = new Label("Default layout");
    Button chgbutton = new Button("Check the button");

    /**
     * Display a sub screen
     * @param anInt1    Sub division of test
     * @param anInt2   Detail items of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt1, int anInt2, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = anInt1;
        menu2Index = anInt2;

        try {
            /* Display sub panels */
            ShowSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        if((menu1Index)==0 && (menu2Index%2)==0) {
            setSoftLabel(Frame.SOFT_KEY_2, "Add");
        } else if(((menu1Index)==1 && (menu2Index%2)==0)
                  || menu1Index==2) {
            setSoftLabel(Frame.SOFT_KEY_2, "back");
        } else {
            setSoftLabel(Frame.SOFT_KEY_2, "Change over");
        }

        /* Listener setting */
        setSoftKeyListener(this);

        if((menu1Index)==1){
			// 2003/03/13 ->
            //chgLabel.setLocation(0,36);
            //chgbutton.setLocation(0,50);
			chgLabel.setLocation(0,0);
			chgbutton.setLocation(0,0);
			// 2003/03/13 <-
            add(chgLabel);
            add(chgbutton);
        }

    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* Add component when soft key2 is released */
        if (anIndex == Frame.SOFT_KEY_2) {

            /**
             * Change over to non-display of already-displayed component
             * Return to the previous screen in case of layout association
             */
            if(((menu1Index)==1 && (menu2Index)==0)) {
                Display.setCurrent(J211_2604_0101.mainPanel);
            } else {
                if(addFlag) {

//J211_2604_0108
//J211_2604_0208
                    if(menu2Index==1) {
                        setLayoutManager(null);
                    }

                    if(((menu1Index)==1 && (menu2Index)==1)) {
                        chgLabel.setLocation(10,36);
                        chgbutton.setLocation(10,50);
                    }

                    /* Set the location in case of NULL */
                    if(menu2Index==0 || menu2Index==1) {
                        addLabel.setLocation(0,36);
                        addTextBox.setLocation(0,50);
                    }

                    /* Add components (J211_2604_01) */
                    if(menu1Index == 0) {
                        add(addLabel);
                        add(addTextBox);
                    }

                    /* Change the SOFTKEY2 after an execution */ 
                    addFlag = false;
                    setSoftLabel(Frame.SOFT_KEY_2, "back");

                } else {
                    Display.setCurrent(J211_2604_0101.mainPanel);
                }
            }
        }
    }
}
