/**
 * J211_2604_0401
 * Check behavior of the class
 * Panel - Behavior of the layout when changing the size
 *
 * $Id: J211_2604_0401.java,v 1.1 2002/02/01 07:02:12 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check behavior of the class
 * Panel - Behavior of the layout when changing the size
 * @extends IApplication
 */
public class J211_2604_0401 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check behavior of the class
 * Panel - Behavior of the layout when changing the size
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1.Change the size",
        "2.Add components",
        "3.Change the location of component",
        "4.Change the state of component",
        "5.Change outside the screen",
    };

    String[][] menuListItem2 = {
        /* Change the size */
        {
            "1.Change the size",
            "2.Change the text 1",
            "3.Change the text 2",
            "4.Change the text 3",
            "5.Change the image 1",
            "6.Change the image 2",
            "7.Change the image 3",
            "8.Change the list 1",
            "9.Change the list 2",
            "10.Change the list 3",
            "11.Change the list 4",
            "12.Change the list 5",
            "13.Add title",
            "14.Delete title",
            "15.Change the label 1",
            "16.Change the label 2",
            "17.Change the label 3",
        },
        /* Add components */
        {
            "1.Add components"
        },
        /* Change the location of component */
        {
            "1.NULL layout",
            "2.Default layout",
//2002/08/07 Doja1.5            "2.HTML layout",
        },
        /* Change in the component status */
        {
            "1.Change the title",
            "2.Nullification",
            "3.Validation",
            "4.Make it non-displayed",
            "5.Make it displayed",
            "6.With or without the focus",
        },
        /* Change outside the screen */
        {
            "1.Upper part of the screen",
            "2.Bottom part of the screen",
        },
    };

    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    ListBox menuList2  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Check behavior of the Panel");
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        menuList2.setItems(menuListItem2[0]);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(menuList2);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* When menu list (menuList1) is selected set item(menuList2) */
        if ( aType == ComponentListener.SELECTION_CHANGED ) {
            if ( aComponent == menuList1 ) {
                menuList2.setItems(menuListItem2[menuList1.getSelectedIndex()]);
            }
        }

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            int menu2Index = menuList2.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, menu2Index, this));
        }
    }
}

/**
 * Check behavior of the class
 * Panel - Check behavior of basic/display/container
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener  {

    Frame prevFrame;
    Label subTitle = null;

    int menu1Index;
    int menu2Index;

    int labelSizeX = 0;
    int labelSizeY = 0;
    int tickerSizeX = 0;
    int tickerSizeY = 0;

    boolean testFlag = true;
    MediaImage imageObj = null;
//2002/08/07 Doja1.5    HTMLLayout htmlLayout = new HTMLLayout();

    /* Create each component */
    Label labelObj = new Label("Label");
//2002/08/07 Doja1.5    AnchorButton anchorObj = new AnchorButton("Anchor");
    Button  buttonObj = new Button("Button"); 
    ImageLabel imageLabelObj = new ImageLabel();
    VisualPresenter vPresenterObj = new VisualPresenter();
//2002/08/07 Doja1.5    ImageButton imageButtonObj = new ImageButton();
    ListBox listBoxObj = new ListBox(ListBox.SINGLE_SELECT);
    String[] menuListItem = {"1. List","2. List","3. List",};
    Ticker tickerObj = new Ticker("Ticker");
    TextBox textBoxObj = new TextBox("Text", 16, 1, TextBox.DISPLAY_ANY);

    String bigImage = "resource:///java1.gif";
    String normalImage = "resource:///java2.gif";
    String smallImage = "resource:///java3.gif";

    /**
     * Display a sub screen
     * @param anInt1  Sub division of test
     * @param anInt2  Detail items of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt1, int anInt2, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = anInt1;
        menu2Index = anInt2;

        /* Get image from resource */
        imageObj = MediaManager.getImage(normalImage);

        /* Reading media */
        try {
            imageObj.use();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Image read error" + e.toString());
            errDialog.show();
        }

//2002/08/07 Doja1.5        anchorObj.setImage(imageObj.getImage());
//2002/08/07 Doja1.5        imageButtonObj.setImage(imageObj.getImage());
        imageLabelObj.setImage(imageObj.getImage());
        vPresenterObj.setImage(imageObj);
        listBoxObj.setItems(menuListItem);

        try {
            /* Display sub panels */
            ShowSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
        subTitle = new Label("");
        add(subTitle);
        setTitle("Behavior of the class");

        switch(menu1Index) {
        case 0:
            switch(menu2Index) {

            /**
             * Table 2-a
             * Label,AncorButton,Button,ImageLabel,VisualPresenter
             * ImageButton,ListBox,Ticker
             */
            case 0:
                add(labelObj);
//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
                add(imageLabelObj);
                add(vPresenterObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(listBoxObj);
                add(tickerObj);
                break;

            /**
             * Table 2-b
             * Label,AncorButton
             */
            case 1:
            case 2:
            case 3:
                add(labelObj);
//2002/08/07 Doja1.5                add(anchorObj);
                break;

            /**
             * Table 2-c
             * ImageLabel,VisualPresenter,ImageButton
             */
            case 4:
            case 5:
            case 6:
                add(imageLabelObj);
                add(vPresenterObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                break;

            /**
             * Table 2-d
             * ListBox
             */
            case 7:
            case 8:
            case 9:
            case 10:
            case 11:
                add(listBoxObj);
                break;

            /* Alignment of all the components Table 2-a + TextBox */
            case 12:
                setTitle(null);
                add(labelObj);
//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
                add(imageLabelObj);
                add(vPresenterObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(listBoxObj);
                add(tickerObj);
                add(textBoxObj);
                break;
            case 13:
                add(labelObj);
//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
                add(imageLabelObj);
                add(vPresenterObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(listBoxObj);
                add(tickerObj);
                add(textBoxObj);
                break;

            /**
             * Table 2-f
             * Button
             */
            case 14:
            case 15:
            case 16:
                add(buttonObj);
                break;
            default:
                break;
            }
            break;

        case 1:
            add(labelObj);
//2002/08/07 Doja1.5            add(anchorObj);
            add(buttonObj);
            add(imageLabelObj);
            add(vPresenterObj);
//2002/08/07 Doja1.5            add(imageButtonObj);
            add(listBoxObj);
            add(tickerObj);
            break;

        case 2:
            add(labelObj);
//2002/08/07 Doja1.5            add(anchorObj);
            add(buttonObj);
            add(imageLabelObj);
            add(vPresenterObj);
//2002/08/07 Doja1.5            add(imageButtonObj);
            add(listBoxObj);
            add(tickerObj);

            switch(menu2Index) {
                case 0:
                    setLayoutManager(null);
                    break;

                case 1:
                    break;

//2002/08/07 Doja1.5                case 2:
//2002/08/07 Doja1.5                    setLayoutManager(htmlLayout);
//2002/08/07 Doja1.5                    break;

                default:
                 break;
            }
            break;

        case 3:
            switch(menu2Index) {

            /* Alignment of all the components Table 2-a + TextBox */
            case 0:
                add(labelObj);
//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
                add(imageLabelObj);
                add(vPresenterObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(listBoxObj);
                add(tickerObj);
                add(textBoxObj);
                break;


            /**
             * Table 2-e
             * AncorButton,Button,ImageButton,ListBox
             */
            case 1:
//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(listBoxObj);
                break;

            case 2:
//2002/08/07 Doja1.5                anchorObj.setEnabled(false);
                buttonObj.setEnabled(false);
//2002/08/07 Doja1.5                imageButtonObj.setEnabled(false);
                listBoxObj.setEnabled(false);
//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(listBoxObj);
                break;

            /**
             * Table 2-a
             * Label,AncorButton,Button,ImageLabel,VisualPresenter
             * ImageButton,ListBox,Ticker
             */
            case 3:
                add(labelObj);
//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
                add(imageLabelObj);
                add(vPresenterObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(listBoxObj);
                add(tickerObj);
                break;

            case 4:
                labelObj.setVisible(false);
//2002/08/07 Doja1.5                anchorObj.setVisible(false);
                buttonObj.setVisible(false);
                imageLabelObj.setVisible(false);
                vPresenterObj.setVisible(false);
//2002/08/07 Doja1.5                imageButtonObj.setVisible(false);
                listBoxObj.setVisible(false);
                tickerObj.setVisible(false);
                add(labelObj);
//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
                add(imageLabelObj);
                add(vPresenterObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(listBoxObj);
                add(tickerObj);
                break;

            /**
             * Table 2-e
             * AncorButton,Button,ImageButton,ListBox
             */
            case 5:
            case 6:
//2002/08/07 Doja1.5                add(anchorObj);
                add(buttonObj);
//2002/08/07 Doja1.5                add(imageButtonObj);
                add(listBoxObj);
                break;

            default:
                break;
            }
            break;

        case 4:
            add(labelObj);
//2002/08/07 Doja1.5            add(anchorObj);
            add(buttonObj);
            add(imageLabelObj);
            add(vPresenterObj);
//2002/08/07 Doja1.5            add(imageButtonObj);
            add(listBoxObj);
            add(tickerObj);

            /* Save the original size of Label and Ticker  */
            labelSizeX = labelObj.getWidth();
            labelSizeY = labelObj.getHeight();
            tickerSizeX = tickerObj.getWidth();
            tickerSizeY = tickerObj.getHeight();

            /* Make the size of Label and Ticker be the screen size  */
            labelObj.setSize(getWidth(),getHeight());
            tickerObj.setSize(getWidth(),getHeight());

            break;
        default:
            break;
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "execute");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* execute test when soft key2 is released */
        if (anIndex == Frame.SOFT_KEY_2) {

            if(testFlag) {

                switch(menu1Index) {
                case 0:
                    switch(menu2Index) {
//J211_2604_0401
                    case 0:
                        labelObj.setSize(getWidth()/2,
                                        labelObj.getHeight() + 5);
//2002/08/07 Doja1.5                        anchorObj.setSize(getWidth()/2,
//2002/08/07 Doja1.5                                        anchorObj.getHeight() + 5);
                        buttonObj.setSize(getWidth()/2,
                                        buttonObj.getHeight() + 5);
                        imageLabelObj.setSize(getWidth()/2,
                                        imageLabelObj.getHeight() + 5);
                        vPresenterObj.setSize(getWidth()/2,
                                        vPresenterObj.getHeight() + 5);
//2002/08/07 Doja1.5                        imageButtonObj.setSize(getWidth()/2,
//2002/08/07 Doja1.5                                        imageButtonObj.getHeight() + 5);
                        listBoxObj.setSize(getWidth()/2,
                                        listBoxObj.getHeight() + 5);
                        tickerObj.setSize(getWidth()/2,
                                        tickerObj.getHeight() + 5);
                        break;

//J211_2604_0402
                    case 1:
                        labelObj.setText("123");
//2002/08/07 Doja1.5                        anchorObj.setText("Anchor");
                    break;

//J211_2604_0403
                    case 2:
                        labelObj.setText("Label");
//2002/08/07 Doja1.5                        anchorObj.setText("Anchor");
                    break;

//J211_2604_0404
                    case 3:
                        labelObj.setText("123456789123456789");
//2002/08/07 Doja1.5                        anchorObj.setText("Anchor");
                    break;

//J211_2604_0405
                    case 4:
                        /* Get image from resource */
                        imageObj = MediaManager.getImage(bigImage);

                        /* Reading media */
                        try {
                            imageObj.use();
                        } catch (Exception e) {
                            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                            errDialog.setText("Image read error" + e.toString());
                            errDialog.show();
                        }
//2002/08/07 Doja1.5                        imageButtonObj.setImage(imageObj.getImage());
                        imageLabelObj.setImage(imageObj.getImage());
                        vPresenterObj.setImage(imageObj);
                        break;

//J211_2604_0406
                    case 5:
                        /* Get image from resource */
                        imageObj = MediaManager.getImage(normalImage);

                        /* Reading media */
                        try {
                            imageObj.use();
                        } catch (Exception e) {
                            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                            errDialog.setText("Image read error" + e.toString());
                            errDialog.show();
                        }
//2002/08/07 Doja1.5                        imageButtonObj.setImage(imageObj.getImage());
                        imageLabelObj.setImage(imageObj.getImage());
                        vPresenterObj.setImage(imageObj);
                        break;
//J211_2604_0407
                    case 6:
                        /* Get image from resource */
                        imageObj = MediaManager.getImage(smallImage);

                        /* Reading media */
                        try {
                            imageObj.use();
                        } catch (Exception e) {
                            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                            errDialog.setText("Image read error" + e.toString());
                            errDialog.show();
                        }
//2002/08/07 Doja1.5                        imageButtonObj.setImage(imageObj.getImage());
                        imageLabelObj.setImage(imageObj.getImage());
                        vPresenterObj.setImage(imageObj);
                        break;

//J211_2604_0408
                    case 7:
                        String[] menuListItem1 = {
                            "1. Additional list",
                            "2. Additional list",
                            "3. Additional list",
                            "4. Additional list",
                        };
                        listBoxObj.setItems(menuListItem1);
                        break;

//J211_2604_0409
                    case 8:
                        String[] menuListItem2 = {
                            "1. List",
                            "2. List",
                            "3. List",
                        };
                        listBoxObj.setItems(menuListItem2);
                        break;

//J211_2604_0410
                    case 9:
                        String[] menuListItem3 = {
                            "1.List",
                        };
                        listBoxObj.setItems(menuListItem3);
                        break;

//J211_2604_0411
                    case 10:
                        listBoxObj.append("4. Additional list");
                        break;
//J211_2604_0412
                    case 11:
                        listBoxObj.removeAll();
                        break;

//J211_2604_0413
                    case 12:
                        setTitle("Behavior of the class");
                        break;

//J211_2604_0414
                    case 13:
                        setTitle(null);
                        break;

//J211_2604_0415
                    case 14:
                        buttonObj.setLabel("123456789123456789");
                        break;

//J211_2604_0416
                    case 15:
                        buttonObj.setLabel("Button");
                        break;

//J211_2604_0417
                    case 16:
                        buttonObj.setLabel("123");
                        break;

                    default:
                        break;
                    }
                    break;

//J211_2604_0501
                case 1:
                    add(textBoxObj);
                    break;

//J211_2604_0601
//J211_2604_0602
//J211_2604_0603
                case 2:
//2002/08/07 Doja1.5                    anchorObj.setLocation(13,0);
                    labelObj.setLocation(13,15);
                    buttonObj.setLocation(13,30);
                    imageLabelObj.setLocation(13,48);
                    vPresenterObj.setLocation(30,48);
//2002/08/07 Doja1.5                    imageButtonObj.setLocation(50,47);
                    tickerObj.setLocation(13,63);
                    listBoxObj.setLocation(13,80);
                    break;

                case 3:
                    switch(menu2Index) {
//J211_2604_0701
                    case 0:
                        setTitle("Change the title");
                        break;

//J211_2604_0702
                    case 1:
//2002/08/07 Doja1.5                        anchorObj.setEnabled(false);
                        buttonObj.setEnabled(false);
//2002/08/07 Doja1.5                        imageButtonObj.setEnabled(false);
                        listBoxObj.setEnabled(false);
                        break;

//J211_2604_0703
                    case 2:
//2002/08/07 Doja1.5                        anchorObj.setEnabled(true);
                        buttonObj.setEnabled(true);
//2002/08/07 Doja1.5                        imageButtonObj.setEnabled(true);
                        listBoxObj.setEnabled(true);
                        break;

//J211_2604_0704
                    case 3:
                        labelObj.setVisible(false);
//2002/08/07 Doja1.5                        anchorObj.setVisible(false);
                        buttonObj.setVisible(false);
                        imageLabelObj.setVisible(false);
                        vPresenterObj.setVisible(false);
//2002/08/07 Doja1.5                        imageButtonObj.setVisible(false);
                        listBoxObj.setVisible(false);
                        tickerObj.setVisible(false);
                        break;

//J211_2604_0705
                    case 4:
                        labelObj.setVisible(true);
//2002/08/07 Doja1.5                        anchorObj.setVisible(true);
                        buttonObj.setVisible(true);
                        imageLabelObj.setVisible(true);
                        vPresenterObj.setVisible(true);
//2002/08/07 Doja1.5                        imageButtonObj.setVisible(true);
                        listBoxObj.setVisible(true);
                        tickerObj.setVisible(true);
                        break;

//J211_2604_0706
//J211_2604_0707
                    case 5:
                    case 6:
                        break;
                    default:
                        break;
                    }
                    break;

                case 4:
                    switch(menu2Index) {
//J211_2604_0801
                    case 0:
                        labelObj.setSize(labelSizeX, labelSizeY);
                        break;
//J211_2604_0802
                    case 1:
                        tickerObj.setSize(tickerSizeX, tickerSizeY);
                        break;

                    default:
                    }
                    break;
                
                default:
                    break;
                }

                /* Change SOFTKWY2 once it is executed */
                testFlag = false;
                setSoftLabel(Frame.SOFT_KEY_2, "back");

            } else {
                Display.setCurrent(J211_2604_0401.mainPanel);
            }
        }
    }
}
