/**
 * J211_2801_0103
 * MainPanel
 *
 * Class operations(ShortTimer)
 *
 *
 * $Id:
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;
import java.lang.*;

/**
 * Class for checking behavior of the class (ShortTimer)
 * @extends IApplication
 */

public class J211_2801_0103 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main class for checking behavior of the class (ShortTimer)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 Interval",
            "2 Non-displayed ST",
            "3 Dialog now displayed",
            "4 Resolution value to be under 100",
            "5 Specified=JVM",
            "6 Resolution > Set value",
            "7 Resolution = Set value",
            "8 Resolution < Set value",
            "9 After exceptions are thrown",
            "10 Asynchronous 2 pieces",
            "11 Behavior of 5 pieces",
            "12 2 synchronous pieces",
    };
    private Button button = new Button("execute");
    private int selection;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    public void showMainPanel() {

        /* Settings of display items */
        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            selection = menuList.getSelectedIndex();
            if ( selection == 4 ) {
                Display.setCurrent(new TimerCanvas2(this));
            } else if ( selection == 5 ) {
                Display.setCurrent(new TimerCanvas5(this, selection));
            } else if ( selection == 6 ) {
                Display.setCurrent(new TimerCanvas5(this, selection));
            } else if ( selection == 7 ) {
                Display.setCurrent(new TimerCanvas5(this, selection));
            } else if ( selection == 8 ) {
                Display.setCurrent(new TimerCanvas3(this));
            } else if ( selection == 11 ) {
                Display.setCurrent(new TimerCanvas4(this));
            }else {
                Display.setCurrent(new TimerCanvas(this, selection));
            }
        }
    }
    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}


/**
 * Sub class for checking behavior of the class (ShortTimer)1
 * @extends Canvas
 * @implements Runnable
 */
class TimerCanvas extends Canvas implements Runnable{
    private Frame previousFrame = null;
    private int selection;
    private int count = 0;
    private int count2 = 0;
    private ShortTimer st1,st2,st3,st4,st5;
    TestTimers tt = new TestTimers();


    /**
     * Constructor of TimerCanvas
     * @param aPrev Object of MainPanel
     */
    TimerCanvas( Frame aPrev, int aSelection) {
        previousFrame = aPrev;
        selection = aSelection;

        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Count: "+(count), 5, 20);
        g.drawString("Count: "+(count2), 5, 40);
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {

        /* Timer event */
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            if ( aParam == 0 ) {
                count++;
            } else {
                count2++;
            }
            repaint();
        }
        
        /* Key event */
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    if ( selection == 0 ) {
//J211_2801_0103
                        st1 = tt.test(this,0,1000,true);
                        st1.start();
                        st2 = tt.test(this,1,2500,true);
                        st2.start();
                    } else if ( selection == 1 ) {
//J211_2801_0106
                        TestCanvas tc = new TestCanvas(this);
                        tc.test();
                    } else if ( selection == 2) {
                        st1 = tt.test(this,0,1000,true);
                        Thread t1 = new Thread(this);
                        t1.start();
//J211_2801_0107
                        st1.start();
                        try {
                            Thread.sleep(5000);
                        } catch (Exception e){}
                    } else if ( selection == 3 ) {
                        st1 = tt.test(this,0,1000,true);
//J211_2801_0201
                        int rl = st1.getResolution();
                        if ( rl <= 100 ){
                            showDialog("Resolution under 100: OK:"+rl);
                        } else {
                            showDialog("Resolution under 100: NG:"+rl);
                        }
                    } else if ( selection == 9 ) {
//J211_2802_0101
                        try {
                            st1 = tt.test(this,0,1000,true);
                            st2 = tt.test(this,1,2500,true);
                            st1.start();
                            st2.start();
                            showDialog("Synchronous operations: OK");
                        } catch (Exception e) {
                            showDialog("Synchronous operations: NG");
                        }
                    } else if ( selection == 10 ) {
//J211_2802_0102
                        try {
                            st1 = tt.test(this,0,1000,true);
                            st2 = tt.test(this,1,2500,true);
                            st3 = tt.test(this,2,1000,true);
                            st4 = tt.test(this,3,2500,true);
                            st5 = tt.test(this,4,2500,true);
                            st1.start();
                            st2.start();
                            st3.start();
                            st4.start();
                            st5.start();
                        } catch ( Exception e ) {
                            showDialog("Synchronous behavior of 5 pieces : NG");
                        }
                        try {
                            Thread.sleep(3000);
                        } catch ( Exception e ) {}
                        showDialog("Synchronous behavior of 5 pieces : OK");
                    }
                    break;

                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;

                /* When Select key is pressed */
                case Display.KEY_SELECT:
                    break;
            }
        }
    }

    /**
     * Thread execution method
     */
    public void run() {
        showDialog("Wait 10 seconds then delete the dialog");
    }

    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
        d.setText(str);
        d.show();
    }
}

/**
 * Sub class for checking behavior of the class (ShortTimer)2
 * @extends Canvas
 */
class TimerCanvas2 extends Canvas {
    private Frame previousFrame = null;
    private int count = 0;
    private ShortTimer st1;
    TestTimers tt = new TestTimers();
    private long l1,l2;
    private long[] t1 = new long[6];


    /**
     * Constructor of TimerCanvas2
     * @param aPrev Object of MainPanel
     */
    TimerCanvas2( Frame aPrev ) {
        previousFrame = aPrev;

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Count: "+(count), 5, 20);
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {
        /* Timer event */
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            l2 = System.currentTimeMillis();
            if ( count >= 5 ) {
                for ( int i=0; i<=5; i++ ){
                    t1[5] = t1[5] + t1[i];
                }
//J211_2801_0202
                t1[5] = t1[5]/60000;
                if ( t1[5] < 10000 ) {
                    showDialog(" Time specified by timer: OK");
                } else {
                    showDialog(" Time specified by timer: NG");
                }
                st1.stop();
            } else {
                t1[count] = (l2 - l1) - (count*60000);
                count++;
                repaint();
            }
        }
        
        /* Key event */
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    st1 = tt.test(this,0,60000,true);
                    st1.start();
                    l1 = System.currentTimeMillis();
                    break;
                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }


    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
        d.setText(str);
        d.show();
    }
}


/**
 * Sub class for checking behavior of the class (ShortTimer)3
 * @extends Canvas
 */
class TimerCanvas3 extends Canvas {
    private Frame previousFrame = null;
    private String count = "start";
    private ShortTimer st1;
    TestTimers tt = new TestTimers();

    /**
     * Constructor of TimerCanvas3
     * @param aPrev Object of MainPanel
     */
    TimerCanvas3( Frame aPrev ) {
        previousFrame = aPrev;

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Count: "+(count), 5, 20);
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {

        /* Timer event */
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            count = "NG";
            repaint();
        }

        /* Key event */
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    st1 = tt.test(this,0,1000,true);
                    st1.dispose();
                    try {
                        st1.start();
                    } catch (UIException uie) {
//J211_2801_0503
                        st1.dispose();
                        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
                        d.setText("dispose:OK");
                        d.show();
                    }
                    break;
                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }
}

/**
 * Sub class for checking behavior of the class (ShortTimer)4
 * @extends Canvas
 */
class TimerCanvas4 extends Canvas implements Runnable{
    private Frame previousFrame = null;
    private String count1 = "";
    private String count2 = "";
    private boolean flag = false;
    private boolean flag1 = false;
    private ShortTimer st1,st2;
    TestTimers tt = new TestTimers();


    /**
     * Constructor of TimerCanvas4
     * @param aPrev Object of MainPanel
     */
    TimerCanvas4( Frame aPrev ) {
        previousFrame = aPrev;

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Count: "+(count1), 5, 20);
        g.drawString("Count: "+(count2), 5, 40);
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {

        /* Timer event */
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            if ( flag == true ) {
                count1 = "start";
                if ( flag1 == true ) {
                    count2 = "start";
                }
            }
            repaint();
        }

        /* Key event */
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    st1 = tt.test(this,0,1000,true);
                    st2 = tt.test(this,1,1000,true);
                    Thread t1 = new Thread(this);
                    try {
                        Thread.sleep(500);
                    } catch ( Exception e ) {}
//J211_2802_0103
                    t1.start();
                    flag = true;
                    break;
                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }

    /**
     * Method for executing the method
     */
    public void run() {
        st2.start();
        flag1 = true;
    }
}

/**
 * Sub class for checking behavior of the class (ShortTimer)5
 * @extends Canvas
 */
class TimerCanvas5 extends Canvas{
    private Frame previousFrame = null;
    private ShortTimer st1;
    private ShortTimer st2;
    private int selection,rl;
    private int count = 0;
    private boolean flag = false;
    private boolean flag2 = false;
    private long l1,l2;
    TestTimers tt = new TestTimers();


    /**
     * Constructor of TimerCanvas5
     * @param aPrev Object of MainPanel
     */
    TimerCanvas5( Frame aPrev, int aSelection ) {
        previousFrame = aPrev;
        selection = aSelection;

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1, "test");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Setting of the Timer */
        st1 = tt.test(this,0,1000,false);
        rl = st1.getResolution();
        st1.dispose();
        if ( selection == 5 ) {
            st2 = tt.test(this,1,rl-5,true);
        } else if ( selection == 6 ) {
            st2 = tt.test(this,1,rl,true);
        } else if ( selection == 7 ) {
            st2 = tt.test(this,1,rl+5,true);
        }
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent( int aType , int aParam ) {
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            count++;
            if ( count == 10000 ) {
                l2 = System.currentTimeMillis();
                st2.stop();
                flag2 = false;
                flag = true;
                repaint();
            }
        }

        if( aType == Display.KEY_RELEASED_EVENT) {
            switch( aParam){
                case Display.KEY_SOFT1:
                    flag2 = true;
                    if(flag2 == true) {
                        repaint();
                    }
                    st2.start();
                    l1 = System.currentTimeMillis();
                    break;
                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g) {
        g.lock();
        g.clearRect(0,0,200,200);
//        g.drawString("Check the timer's set value",15,40);
        String s1 = Integer.toString(rl);
        g.drawString("Resolution:" + s1,15,60);

        if(flag == true) {
            String s2 = Long.toString((l2 - l1)/10000);
//J211_2801_0301
//J211_2801_0302
//J211_2801_0303
            g.drawString("Set value:" + s2, 15,80);
        }
        if(flag2 == true) {
//          g.drawString("Start the timer 10000 times", 20,80);
            g.drawString("Start the timer", 20,80);
        }
        g.unlock(false);
    }
}

/**
 * Sub class for checking behavior of the class (ShortTimer)6
 * @extends Canvas
 */
class TestCanvas extends Canvas {

    private Frame previousFrame = null;
    private int count = 0;
    private ShortTimer st1;
    TestTimers tt = new TestTimers();

    /**
     * Constructor of TestCanvas
     * @param aPrev Object of MainPanel
     */
    TestCanvas( Frame aPrev) {
        previousFrame = aPrev;

        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Count: "+(count), 5, 20);
    }

    /**
     * Method for test implementation
     */
    public void test(){
        st1 = tt.test(this,0,1000,true);
        st1.start();
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {

        /* Timer event */
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            count++;
            repaint();
        }
        
        /* Key event */
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    st1 = tt.test(this,0,1000,true);
                    st1.start();
                    break;

                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;

                /* When Select key is pressed */
                case Display.KEY_SELECT:
                    break;
            }
        }
    }
}

/**
 * Short timer creating class
 */
class TestTimers {

    private ShortTimer st;

    /**
     * Method for creating the short timer
     */
    public ShortTimer test(Canvas aCanvas, int anId, int anInterval, boolean aRepeat) {
        try {
            st = ShortTimer.getShortTimer(aCanvas, anId, anInterval, aRepeat);
        } catch (UIException e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
        return(st);
    }
}
