/**
 * J211_2803_0101
 * MainPanel
 *
 * Class operations(ShortTimer)
 *
 *
 * $Id:
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;
import java.lang.*;

/**
 * Class for checking behavior of the class (ShortTimer)
 * @extends IApplication
 */

public class J211_2803_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main class for checking behavior of the class (ShortTimer)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 While Dialog is displayed",
            "2 Canvas->Cnavas",
            "3 Canvas->Panel",
            "4 Interruption"
    };
    private Button button = new Button("execute");
    private int selection;

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    public void showMainPanel() {

        /* Settings of display items */
        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            selection = menuList.getSelectedIndex();
            if ( selection == 0 ) {
                /* menuListItem = 0 */
                Display.setCurrent(new TimerCanvas(this));
            } else if ( selection == 1 || selection == 2 ) {
                /* menuListItem = 1 , menuListItem = 2 */
                Display.setCurrent(new TimerCanvas2(this, selection));
            } else {
                /* Except for menuListItem = 1,menuListItem = 1, menuListItem = 2 */
                Display.setCurrent(new TimerCanvas3(this));
            }
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}

/**
 * Sub class 1 for checking behavior of the class (ShortTimer)
 * @extends Canvas
 */
class TimerCanvas extends Canvas {
    private Frame previousFrame = null;
    private int count = 0;

    private ShortTimer st1;
    TestTimers tt = new TestTimers();

    /**
     * Constructor of TimerCanvas
     * @param aPrev Object of MainPanel
     */
    TimerCanvas( Frame aPrev ) {
        previousFrame = aPrev;

        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Count: "+(count), 5, 20);
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            if ( count == 5 ) {
//J211_2803_0101
                showDialog("Delete the dialog");
            }
            count++;
            repaint();
        }

        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    st1 = tt.test(this,0,1000,true);
                    st1.start();
                    break;
                
                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }

    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
        d.setText(str);
        d.show();
    }
}

/**
 * Sub class2 for checking behavior of the class (ShortTimer)
 * @extends Canvas
 */
class TimerCanvas2 extends Canvas {
    private Frame previousFrame = null;
    private int selection;
    private int count = 0;

    private ShortTimer st1;
    TestTimers tt = new TestTimers();

    /**
     * Constructor of TimerCanvas2
     * @param aPrev Object of MainPanel
     */
    TimerCanvas2( Frame aPrev, int aSelection) {
        previousFrame = aPrev;
        selection = aSelection;

        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Count: "+(count), 5, 20);
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            if ( count == 5 ) {
                if ( selection == 1 ) {
//J211_2803_0201
                    Display.setCurrent(new TestCanvas(this));
                } else if ( selection == 2 ) {
//J211_2803_0202
                    Display.setCurrent(new TestPanel(this));
                }
            } else {
                count++;
                repaint();
            }
        }
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    count = 0;
                    /* Start the short timer */
                    st1 = tt.test(this,0,1000,true);
                    st1.start();
                    break;
            
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }
}

/**
 * Class for checking the change over of the Canvas (ShortTimer)
 * @extends Canvas
 */
class TestCanvas extends Canvas {
    private Frame previousFrame = null;
    private int selection;
    private int count = 0;
    
    /**
     * Constructor of TestCanvas
     * @param aPrev Object of TimerCanvas2 class
     */
    TestCanvas( Frame aPrev ) {
        previousFrame = aPrev;
        setSoftLabel(Frame.SOFT_KEY_1, "back");
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Return to the previous screen", 5, 20);
    }
}

/**
 * Class for checking change over of the Panel (ShortTimer)
 * @extends Panel
 */
class TestPanel extends Panel implements SoftKeyListener {
    private Frame previousFrame = null;
    private Label label = new Label("Return to the previous screen");

    /**
     * Constructor of TestPanel
     * @param aPrev Object of TimerCanvas2 class
     */
    public TestPanel(Frame aPrev) {
        previousFrame = aPrev;

        /* Settings of display items */
        add(label);

        setSoftLabel(Frame.SOFT_KEY_1, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Sub class 3 for checking behavior of the class (ShortTimer)
 * @extends Canvas
 */
class TimerCanvas3 extends Canvas {

    private Frame previousFrame = null;
    private int count = 0;

    private ShortTimer st1;
    TestTimers tt = new TestTimers();

    /**
     * Constructor of TimerCanvas3
     * @param aPrev Object of MainPanel
     */
    TimerCanvas3( Frame aPrev ) {
        previousFrame = aPrev;
        st1 = tt.test(this,0,1000,true);

        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Count: "+(count), 5, 20);
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            count++;
            repaint();
        }

        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    st1.start();
                    break;
                
                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }

    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
        d.setText(str);
        d.show();
    }
}

/**
 * Class for getting the short timer object
 */
class TestTimers {

    private ShortTimer st;
    /**
     * Method for getting the short timer object
     * @param aCanvas Canvas object that notifies the timer event
     * @param anId TimerID
     * @param anInterval Time intervals of timer events
     * @param aRepeat Determination of either repeat or non-repeat
     * @return ShortTimer
     */
    public ShortTimer test(Canvas aCanvas, int anId, int anInterval, boolean aRepeat) {
        try {
            st = ShortTimer.getShortTimer(aCanvas, anId, anInterval, aRepeat);
        } catch (UIException e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
        return(st);
    }
}
