/**
 * J211_3201_0201
 * MainPanel
 *
 * Check behavior of the class(Class operations)
 *
 * $Id: J211_3201_0201.java,v 1.1 2002/02/04 07:28:38 t_yaeda Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import java.lang.*;

/**
 * Main class for checking behavior of the VisualPresenter class and the class
 * @extends IApplication
 */

public class J211_3201_0201 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the VisualPresenter class and the class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 Image<->Data",
            "2 Default layout",
//2002/08/07 DoJa1.5            "3 HTML layout",
            "4 NULL layout",
          
            "6 Com > Height of the graphic image",
            "7 Com = Height of the graphic image",
            "8 Com < Height of the graphic image",
            "9 Com > Width of the graphic image",
            "10 Com = Width of the graphic image",
            "11 Com < Width of the graphic image",
            "12 Clipping",
            "13 Scrolling",
            "14 Now displaying graphic image"
    };
    private VisualPresenter vp = new VisualPresenter();
    private VisualPresenter vp1 = new VisualPresenter();
    private MediaImage mi = null;
    private Button button = new Button("execute");
    private int height, width;

    /** 
     * Constructor of MainPanel
     */
    public MainPanel(){
        try{
            /* Display MainPanel */
            showMainPanel();
        }catch(Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }
    }
    
    /** 
     * Display a main panel
     */
    void showMainPanel(){
        /* Settings of display items */

        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        vp.setBackground(Graphics.getColorOfName(Graphics.LIME));
        add(vp);
        add(vp1);

        try {
            mi = MediaManager.getImage("resource:///anima8.gif");
            mi.use();
            vp1.setImage(mi);
            vp1.play();
        } catch (Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == menuList ) {
            vp1.setSize(mi.getWidth(),mi.getHeight());
//2002/09/18 Doja1.5            vp1.setSize(height,width);
        }

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    /* Create NextPanel1 */
                    Display.setCurrent(new NextPanel1((Frame) this));
                    break;
                case 1:
                    /* Create NextPanel2 */
                    Display.setCurrent(new NextPanel2((Frame) this));
                    break;
//2002/08/07 DoJa1.5                case 2:
                    /* Create NextPanel3 */
//2002/08/07 DoJa1.5                    Display.setCurrent(new NextPanel3((Frame) this));
//2002/08/07 DoJa1.5                    break;
//2002/08/07 DoJa1.5                case 3:
                case 2:
                    /* Create NextPanel4 */
                    Display.setCurrent(new NextPanel4((Frame) this));
                    break;
//2002/08/07 DoJa1.5                case 4:
                case 3:
                   
                    /* Create NextPanel5 */
                    Display.setCurrent(new NextPanel5((Frame) this, menuList.getSelectedIndex()));
                    break;
//2002/08/07 DoJa1.5                case 6:
                case 4:
                    /* Create NextPanel5 */
                    Display.setCurrent(new NextPanel5((Frame) this, menuList.getSelectedIndex()));
                    break;
//2002/08/07 DoJa1.5                case 7:
                case 5:
                    /* Create NextPanel5 */
                    Display.setCurrent(new NextPanel5((Frame) this, menuList.getSelectedIndex()));
                    break;
//2002/08/07 DoJa1.5                case 8:
                case 6:
                    /* Create NextPanel5 */
                    Display.setCurrent(new NextPanel5((Frame) this, menuList.getSelectedIndex()));
                    break;
//2002/08/07 DoJa1.5                case 9:
                case 7:
                    /* Create NextPanel5 */
                    Display.setCurrent(new NextPanel5((Frame) this, menuList.getSelectedIndex()));
                    break;
//2002/08/07 DoJa1.5                case 10:
                case 8:
                    /* Create NextPanel5 */
                    Display.setCurrent(new NextPanel5((Frame) this, menuList.getSelectedIndex()));
                    break;
//2002/08/07 DoJa1.5                case 11:
                case 9:
//J211_3203_0301
                    vp1.setAttribute(VisualPresenter.IMAGE_XPOS, 10);
                    vp1.setAttribute(VisualPresenter.IMAGE_YPOS, 5);
                    break;
//2002/08/07 DoJa1.5                case 12:
                case 10:
//J211_3203_0302
                    for( int i=0; i<50; i++ ){
                        try {
                            Thread.sleep(100);
                        } catch (Exception e ){}
                        vp1.setAttribute(VisualPresenter.IMAGE_XPOS, (i+10));
                        vp1.setAttribute(VisualPresenter.IMAGE_YPOS, (i+5));
                    }
                    break;
//2002/08/07 DoJa1.5                case 13:
                case 11:
                    /* Create NextPanel6 */
                    Display.setCurrent(new NextPanel6((Frame) this));
                    break;
            }
        }
    }


    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}

/**
 * Sub screen 1 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel1 extends Panel implements SoftKeyListener,ComponentListener {

    private Frame previousFrame = null;
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 Image->Data",
            "2 Data->Image"
    };
    private Button button = new Button(" execute ");
    private VisualPresenter vp = new VisualPresenter();
    private MediaImage mi = null;
    private MediaData mi2 = null;


    /**
     * Constructor of NextPanel1
     * @param aPrev Object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;
    
        /* Settings of display items */
        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        add(vp);

        mi = MediaManager.getImage("resource:///anima8.gif");
        mi2 = MediaManager.getData("resource:///89a10-1.gif");

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

	// modified by kuroda 2003/2/13
	showDialog("The following test case is deleted from DoJa1.5oe ConformanceTest.");


        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    try {
                        mi.use();
                        mi2.use();
                        vp.setImage(mi);
                        vp.setData(mi2);
                        vp.play();
                        showDialog("setData:NG");
                    } catch( UIException uie ) {
//J211_3201_0201
                        showDialog("setData:OK");
                    } catch( UnsupportedOperationException uoe ) {
                        showDialog("UnsupportedOperationException: test not available");
                    } catch( Exception e ) {
                        showDialog("setData:NG:"+e.toString());
                    }
                    break;
                case 1:
                    try {
                        mi.use();
                        mi2.use();
                        vp.setData(mi2);
                        vp.setImage(mi);
                        vp.play();
                        showDialog("setImage:NG");
                    } catch( UIException uie ) {
//J211_3201_0202
                        showDialog("setImage:OK");
                    } catch( UnsupportedOperationException uoe ) {
                        showDialog("UnsupportedOperationException: test not available");
                    } catch( Exception e ) {
                        showDialog("setImage:NG"+e.toString());
                    }
                    break;
            }
        }
    }

    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
        d.setText(str);
        d.show();
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Sub screen 2 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel2 extends Panel implements SoftKeyListener, ComponentListener{

    private Frame previousFrame = null;
    private Label label = new Label("Check scrolling of default layout");
    private Button button = new Button("execute");
    private VisualPresenter vp1 = new VisualPresenter();
    private VisualPresenter vp2 = new VisualPresenter();
    private VisualPresenter vp3 = new VisualPresenter();
    private MediaImage mi1 = null;
    private MediaImage mi2 = null;
    private MediaImage mi3 = null;

    /**
     * Constructor of NextPanel2
     * @param aPrev Object of MainPanel
     */
    public NextPanel2(Frame aPrev) {
        previousFrame = aPrev;

        /* Settings of display items */
        add(label);
        add(button);
        add(vp1);
        add(vp2);
//J211_3202_0102
        vp3.setSize(Display.getWidth(),Display.getHeight());
        add(vp3);

        try {
            mi1 = MediaManager.getImage("resource:///89a5-1.gif");
            mi2 = MediaManager.getImage("resource:///anima8.gif");
            mi3 = MediaManager.getImage("resource:///heno.gif");
            mi1.use();
            mi2.use();
            mi3.use();
            vp1.setImage(mi1);
            vp2.setImage(mi2);
            vp3.setImage(mi3);
            vp1.play();
            vp2.play();
            vp3.play();
        } catch( Exception e ) {
            Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
            d.setText("Error:NG");
            d.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
//J211_3202_0104
            vp2.setVisible(false);
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Sub screen 3 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
//2002/08/07 DoJa1.5class NextPanel3 extends Panel implements SoftKeyListener, ComponentListener{

//2002/08/07 DoJa1.5    private Frame previousFrame = null;
//2002/08/07 DoJa1.5    private HTMLLayout hm = new HTMLLayout();
//2002/08/07 DoJa1.5    private Label label = new Label("Check scrolling of HTML layout");
//2002/08/07 DoJa1.5    private Button button = new Button("execute");
//2002/08/07 DoJa1.5    private VisualPresenter vp1 = new VisualPresenter();
//2002/08/07 DoJa1.5    private VisualPresenter vp2 = new VisualPresenter();
//2002/08/07 DoJa1.5    private VisualPresenter vp3 = new VisualPresenter();
//2002/08/07 DoJa1.5    private MediaImage mi1 = null;
//2002/08/07 DoJa1.5    private MediaImage mi2 = null;
//2002/08/07 DoJa1.5    private MediaImage mi3 = null;

    /**
     * Constructor of NextPanel3
     * @param aPrev Object of MainPanel
     */
//2002/08/07 DoJa1.5    public NextPanel3(Frame aPrev) {
//2002/08/07 DoJa1.5        previousFrame = aPrev;
//2002/08/07 DoJa1.5        setLayoutManager(hm);

        /* Settings of display items */
//2002/08/07 DoJa1.5        hm.begin(HTMLLayout.CENTER);
//2002/08/07 DoJa1.5        add(label);
//2002/08/07 DoJa1.5        hm.br();
//2002/08/07 DoJa1.5        add(button);
//2002/08/07 DoJa1.5        hm.br();
//2002/08/07 DoJa1.5        add(vp1);
//2002/08/07 DoJa1.5        hm.br();
//2002/08/07 DoJa1.5        add(vp2);
//2002/08/07 DoJa1.5        hm.br();
//J211_3202_0106
//2002/08/07 DoJa1.5        vp3.setSize(Display.getWidth(),Display.getHeight());
//2002/08/07 DoJa1.5        add(vp3);

//2002/08/07 DoJa1.5        try {
//2002/08/07 DoJa1.5            mi1 = MediaManager.getImage("resource:///89a5-1.gif");
//2002/08/07 DoJa1.5            mi2 = MediaManager.getImage("resource:///anima8.gif");
//2002/08/07 DoJa1.5            mi3 = MediaManager.getImage("resource:///heno.gif");
//2002/08/07 DoJa1.5            mi1.use();
//2002/08/07 DoJa1.5            mi2.use();
//2002/08/07 DoJa1.5            mi3.use();
//2002/08/07 DoJa1.5            vp1.setImage(mi1);
//2002/08/07 DoJa1.5            vp2.setImage(mi2);
//2002/08/07 DoJa1.5            vp3.setImage(mi3);
//2002/08/07 DoJa1.5            vp1.play();
//2002/08/07 DoJa1.5            vp2.play();
//2002/08/07 DoJa1.5            vp3.play();
//2002/08/07 DoJa1.5        } catch( Exception e ) {
//2002/08/07 DoJa1.5            Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
//2002/08/07 DoJa1.5            d.setText("Error:NG");
//2002/08/07 DoJa1.5            d.show();
//2002/08/07 DoJa1.5        }

//2002/08/07 DoJa1.5        setSoftLabel(Frame.SOFT_KEY_1, "exit");
//2002/08/07 DoJa1.5        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
//2002/08/07 DoJa1.5        setSoftKeyListener(this);
//2002/08/07 DoJa1.5        setComponentListener(this);
//2002/08/07 DoJa1.5    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
//2002/08/07 DoJa1.5    public void componentAction(Component aComponent, int aType, int aParam) {

//2002/08/07 DoJa1.5        if ( aComponent == button && aType == BUTTON_PRESSED ) {
//J211_3202_0108
//2002/08/07 DoJa1.5            vp2.setVisible(false);
//2002/08/07 DoJa1.5        }
//2002/08/07 DoJa1.5    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
//2002/08/07 DoJa1.5    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
//2002/08/07 DoJa1.5    public void softKeyReleased(int anIndex) {
//2002/08/07 DoJa1.5        if (anIndex == Frame.SOFT_KEY_1) {
//2002/08/07 DoJa1.5            IApplication.getCurrentApp().terminate();
//2002/08/07 DoJa1.5        }
//2002/08/07 DoJa1.5        if (anIndex == Frame.SOFT_KEY_2) {
//2002/08/07 DoJa1.5            Display.setCurrent(previousFrame);
//2002/08/07 DoJa1.5        }
//2002/08/07 DoJa1.5    }
//2002/08/07 DoJa1.5}

/**
 * Sub screen 4 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel4 extends Panel implements SoftKeyListener, ComponentListener{

    private Frame previousFrame = null;
    private Label label = new Label("Check scrolling of NULL layout");
    private Button button = new Button("execute");
    private VisualPresenter vp1 = new VisualPresenter();
    private VisualPresenter vp2 = new VisualPresenter();
    private VisualPresenter vp3 = new VisualPresenter();
    private MediaImage mi1 = null;
    private MediaImage mi2 = null;
    private MediaImage mi3 = null;

    /**
     * Constructor of NextPanel4
     * @param aPrev Object of MainPanel
     */
    public NextPanel4(Frame aPrev) {
        previousFrame = aPrev;
        setLayoutManager(null);

        /* Settings of display items */
        label.setLocation(1,0);
        add(label);
        button.setLocation(1,20);
        add(button);
        vp1.setLocation(1,40);
        add(vp1);
        vp2.setLocation(1,130);
        add(vp2);
//J211_3202_0202
        vp3.setSize(Display.getWidth(),Display.getHeight());
        vp3.setLocation(1,220);
        add(vp3);

        try {
            mi1 = MediaManager.getImage("resource:///89a5-1.gif");
            mi2 = MediaManager.getImage("resource:///anima8.gif");
            mi3 = MediaManager.getImage("resource:///heno.gif");
            mi1.use();
            mi2.use();
            mi3.use();
            vp1.setImage(mi1);
            vp2.setImage(mi2);
            vp3.setImage(mi3);
            vp1.play();
            vp2.play();
            vp3.setSize(Display.getWidth(),Display.getHeight());
            vp3.play();
        } catch( Exception e ) {
            Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
            d.setText("Error:NG");
            d.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
//J211_3202_0204
            vp2.setVisible(false);
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Sub screen 5 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel5 extends Panel implements SoftKeyListener  {

    private Frame previousFrame = null;
    private Label label = new Label("Check the behavior of the size specification");
    private int selection;
    private VisualPresenter vp = new VisualPresenter();
    private MediaImage mi = null;
    private Image img;

    /**
     * Constructor of NextPanel 5
     * @param aPrev Object of MainPanel
     */
    public NextPanel5(Frame aPrev, int aSelection) {
        previousFrame = aPrev;
        selection = aSelection;

        /* Settings of display items */
        setTitle("Check behavior of the class");
        add(label);

        mi = MediaManager.getImage("resource:///cat.gif");
        //img = mi.getImage();
        add(vp);
        vp.setBackground(Graphics.getColorOfName(Graphics.LIME));

        try {
            mi.use();
            vp.setImage(mi);
            vp.play();
        } catch( Exception e ) {
            Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
            d.setText("Error:NG");
            d.show();
        }
        test();

    
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }


    public void test(){
        switch( selection ){
            case 3:
//2002/09/18 Doja1.5            case 5:
                vp.setSize(30,(mi.getHeight()+30));
                break;
//J211_3203_0201
            case 4:
//2002/09/18 Doja1.5            case 6:
//J211_3203_0202
                vp.setSize(30,mi.getHeight());
                if( mi.getHeight() == vp.getHeight()){
                    showDialog("Height: OK");
                } else {
                    showDialog("Height: NG");
                }
                break;
            case 5:
//2002/09/18 Doja1.5            case 7:
//J211_3203_0203
                vp.setSize(30,15);
                break;
            case 6:
//2002/09/18 Doja1.5            case 8:
                vp.setSize((mi.getWidth()+30),30);
                break;
//J211_3203_0204
            case 7:
//2002/09/18 Doja1.5            case 9:
//J211_3203_0205
                vp.setSize(mi.getWidth(),30);
                if( mi.getWidth() == vp.getWidth()){
                    showDialog("Width: OK");
                } else {
                    showDialog("Width: NG");
                }
                break;
            case 8:
//2002/09/18 Doja1.5            case 10:
//J211_3203_0206
                vp.setSize(15,30);
                break;
        }
    }

    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
        d.setText(str);
        d.show();
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

/**
 * Sub screen 6 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel6 extends Panel implements SoftKeyListener,ComponentListener {

    private Frame previousFrame = null;
    private Button button = new Button("execute");
    private VisualPresenter vp = new VisualPresenter();
    private MediaImage mi = null;
    private Label label = new Label("Clipping of graphic image");

    /**
     * Constructor of NextPanel 6
     * @param aPrev Object of MainPanel
     */
    public NextPanel6(Frame aPrev) {
        previousFrame = aPrev;

        /* Settings of display items */
        setTitle("Check behavior of the class");
        add(label);
        add(button);
        add(vp);

        try {
            mi = MediaManager.getImage("resource:///concerge.gif");
            mi.use();
            vp.setImage(mi);
        } catch( Exception e ) {
            Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
            d.setText("Error:NG");
            d.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            for( int i=0; i<30; i++ ){
                try {
                    Thread.sleep(100);
                } catch (Exception e ){}
//J211_3204_0201
                vp.setAttribute(VisualPresenter.IMAGE_XPOS, (i+10));
                vp.setAttribute(VisualPresenter.IMAGE_YPOS, (i+5));
            }
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

