/**
 * J211_3203_0101
 * MainPanel
 *
 * Check behavior of the class(Class operations)
 *
 * $Id: J211_3203_0101.java,v 1.1 2002/02/04 07:28:38 t_yaeda Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import java.lang.*;

/**
 * Main class for checking behavior of the VisualPresenter class and the class
 * @extends IApplication
 */

public class J211_3203_0101 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the VisualPresenter class and the class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

	 

    Label classLabel   = new Label();
    TextBox textBox1 = new TextBox("",20,1,TextBox.DISPLAY_ANY);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Check behavior of the class");
        
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(textBox1);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

     

        /* In the case execute button is pressed */
        if ( aType == ComponentListener.BUTTON_PRESSED) {

            
            Display.setCurrent(new SubPanel(textBox1.getText(),this));
           
        }
    }
}

/**
 * Check behavior of the class
 * ImageLabel - Check behavior of the size
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {
//	private Frame previousFrame = null;
    private VisualPresenter vp = new VisualPresenter();
    Frame prevFrame;
    Label subTitle = null;
    Label sizeTitle = null;
  
    ImageLabel imageLabelObj = new ImageLabel();
     String text;

    /**
     * Display a sub screen
     * @param anInt1  Sub division of test
     * @param anInt2  Detail items of test
     * @param aFrame  Main screen object
     */
    public SubPanel( String str,Frame aFrame) {
		 prevFrame = aFrame;
        try {
            /* Display sub panels */
            ShowSubPanel();
            testPanel(str);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Settings of display items */
       
        sizeTitle = new Label("");
        add(sizeTitle);
    
        setTitle("Check behavior of the class");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    
    }

	public  void testPanel(String text) {
           
                sizeTitle.setText("Specify null");
                sizeTitle.setSize(getWidth(), sizeTitle.getHeight());
             
               	vp.setBackground(Graphics.getColorOfName(Graphics.LIME));
    	        add(vp);
                sizeTitle.setText(text);
    }
              

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent( prevFrame);
        }
    }
}

