/**
 * J211_3205_0101
 * MainPanel
 *
 * Check behavior of the class(Class operations)
 *
 * $Id: J211_3205_0101.java,v 1.2 2002/05/02 04:13:56 torikatu Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import java.lang.*;

/**
 * Main class for checking behavior of the VisualPresenter class and the class
 * @extends IApplication
 */

public class J211_3205_0101 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the VisualPresenter class and the class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements MediaListener
 * @implements Runnable
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener, MediaListener, Runnable {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 Replay completed",
            "2 Start replaying",
            "3 Stop replaying",
            "4 Replay during the replay",
            "5 Event queue",
            "6 Select the event",
            "7 Interruption"
    };
    private VisualPresenter vp = new VisualPresenter();
    private VisualPresenter vp1 = new VisualPresenter();
    private MediaImage mi = null;
    private Button button = new Button("execute");
    private TextBox textBox = new TextBox ("", 20, 6, TextBox.DISPLAY_ANY);

    /** 
     * Constructor of MainPanel
     */
    public MainPanel(){
        try{
            /* Display MainPanel */
            showMainPanel();
        }catch(Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }
    }
    
    /** 
     * Display a main panel
     */
    void showMainPanel(){

        /* Settings of display items */
        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        add(textBox);
        add(vp);
        add(vp1);

        try {
            mi = MediaManager.getImage("resource:///anima8.gif");
            mi.use();
            vp.setImage(mi);
            vp1.setImage(mi);
        } catch (Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
        vp.setMediaListener(this);
        vp1.setMediaListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            textBox.setText("");
            switch(menuList.getSelectedIndex()){
                case 0:
                    vp.play();
                    break;
                case 1:
//J211_3205_0102
                    vp.play();
                    break;
                case 2:
//J211_3205_0103
                    vp.play();
                    vp.stop();
                    break;
                case 3:
//J211_3205_0104
                    try {
                        vp.play();
                        Thread.sleep(3000);
                        vp.play();
                    } catch (Exception e){}
                    break;
                case 4:
//J211_3205_0201
                    Thread t1 = new Thread(this);
                    Thread t2 = new Thread(this);
                    t1.start();
                    try {
                        Thread.sleep(500);
                    } catch (Exception e ){}
                    t2.start();
                    vp.play();
                    break;
                case 5:
//J211_3205_0301
                    vp.play();
                    vp1.play();
                    break;
                case 6:
                    vp.play();
                    break;
            }
        }
    
        if ( aComponent == menuList ) {
            textBox.setText("");
        }

    }

    public void run() {
//        textBox.setText("Event\n");
                addResult("Event\n");
        try {
            Thread.sleep(1500);
        } catch (Exception e){}
        vp.play();
    }   

    /**
     * Receive events that occurred in the media
     * @param aSource  Media presenter of the occurrence-origin
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void mediaAction(MediaPresenter aSource, int aType, int aParam) {

        if ( aType == VisualPresenter.VISUAL_PLAYING ) {
            if ( menuList.getSelectedIndex() == 1 ) {
                textBox.setText("VISUAL_PLAYING:OK");
            } else if ( menuList.getSelectedIndex() == 3 ) {
                addResult("VISUAL_PLAYING:OK\n");
            } else if ( menuList.getSelectedIndex() == 4 ) {
                addResult("VISUAL_PLAYING:OK\n");
            } else if ( menuList.getSelectedIndex() == 5 ) {
                addResult("VISUAL_PLAYING:OK\n");
            }
        }

        if ( aType == VisualPresenter.VISUAL_STOPPED ) {
            if ( menuList.getSelectedIndex() == 2 ) {
                textBox.setText("VISUAL_STOPPED:OK");
            } else if ( menuList.getSelectedIndex() == 3 ){
                addResult("VISUAL_STOPPED:OK\n");
            } else if ( menuList.getSelectedIndex() == 6 ) {
                textBox.setText("Interruption:NG");
            }
        }

        if (aType == VisualPresenter.VISUAL_COMPLETE) {
            if (menuList.getSelectedIndex() == 0) {
                textBox.setText("VISUAL_COMPLETE:OK");
            }
        }
    }

    /**
     * Add output to resultBox
     * @param aMessage Output character strings
     */
    public void addResult(String aMessage) {
        textBox.setText(textBox.getText()+aMessage);
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}

/**
 * Sub screen 1 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements MediaListener
 */
class NextPanel1 extends Panel implements SoftKeyListener, MediaListener{

    private Frame previousFrame = null;
    private VisualPresenter vp = new VisualPresenter();
    private MediaImage mi = null;

    /**
     * Constructor of NextPanel1
     * @param aPrev Object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;
    
        /* Settings of display items */
        setTitle("Check behavior of the class");
        add(vp);

        mi = MediaManager.getImage("resource:///anima8.gif");
        try {
            mi.use();
            vp.setImage(mi);
            vp.play();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        vp.setMediaListener(this);
    }

    /**
     * Receive events that occurred in the media
     * @param aSource  Media presenter of the occurrence-origin
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void mediaAction(MediaPresenter aSource, int aType, int aParam) {
//J211_3205_0101
        if( aType == VisualPresenter.VISUAL_COMPLETE ) {
            Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
            d.setText("VISUAL_COMPLETE:OK");
            d.show();
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}
