/**
 * J211_3206_0101
 * MainPanel
 *
 * Check behavior of the class(Class operations)
 *
 * $Id: J211_3206_0101.java,v 1.1 2002/02/04 07:28:38 t_yaeda Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import java.lang.*;

/**
 * Main class for checking behavior of the VisualPresenter class and the class
 * @extends IApplication
 */

public class J211_3206_0101 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the VisualPresenter class and the class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 With or without the listener",
            "2 Single before the replay",
            "3 Multiple before the replay",
            "4 Delete before the replay",
            "5 Single during the replay",
            "6 Multiple during the replay",
            "7 Delete during the replay"
    };
    private VisualPresenter vp = new VisualPresenter();
    private MediaImage mi = null;
    private Button button = new Button("execute");
    private Button button1 = new Button("Replay");


    /** 
     * Constructor of MainPanel
     */
    public MainPanel(){
        try{
            /* Display MainPanel */
            showMainPanel();
        }catch(Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }
    }
    
    /** 
     * Display a main panel
     */
    void showMainPanel(){

        /* Settings of display items */
        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        add(button1);
        add(vp);

        try {
            mi = MediaManager.getImage("resource:///anima8.gif");
            mi.use();
            vp.setImage(mi);
        } catch (Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == menuList ) {
            vp.setMediaListener(null);
        }

        if ( aComponent == button1 ){
            vp.play();
        }

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    /* Create NextPanel1 */
                    Display.setCurrent(new NextPanel1((Frame) this));
                    break;
                case 1:
//J211_3206_0201
                    vp.setMediaListener(new MediaListener() {
                                public void mediaAction(MediaPresenter source,
                                        int aType,int aParam) {
                                    if(aType == VisualPresenter.VISUAL_PLAYING) {
                                        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
                                        d.setText("Single listener entry before the replay: OK");
                                        d.show();
                                    }
                                }
                    });
                    vp.play();
                    break;
                case 2:
//J211_3206_0202
                    vp.setMediaListener(new MediaListener() {
                                public void mediaAction(MediaPresenter source,
                                        int aType,int aParam) {
                                    if(aType == VisualPresenter.VISUAL_PLAYING) {
                                        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
                                        d.setText("Multiple listener entry before the replay:NG");
                                        d.show();
                                    }
                                }
                    });
                    vp.setMediaListener(new MediaListener() {
                                public void mediaAction(MediaPresenter source,
                                        int aType,int aParam) {
                                    if(aType == VisualPresenter.VISUAL_PLAYING) {
                                        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
                                        d.setText("Multiple listener entry before the replay: OK");
                                        d.show();
                                    }
                                }
                    });
                    vp.play();
                    break;
                case 3:
//J211_3206_0203
                    vp.setMediaListener(new MediaListener() {
                                public void mediaAction(MediaPresenter source,
                                        int aType,int aParam) {
                                    if(aType == VisualPresenter.VISUAL_PLAYING) {
                                        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
                                        d.setText("Deletion of listener before the replay:NG");
                                        d.show();
                                    }
                                }
                    });
                    vp.setMediaListener(null);
                    vp.play();
                    break;
                case 4:
//J211_3206_0301
                    vp.setMediaListener(new MediaListener() {
                                public void mediaAction(MediaPresenter source,
                                        int aType,int aParam) {
                                    if(aType == VisualPresenter.VISUAL_PLAYING) {
                                    Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
                                    d.setText("Single listener entry during the replay:OK");
                                    d.show();
                                }
                            }
                    });
                    vp.play();
                    break;
                case 5:
//J211_3206_0302
                    vp.setMediaListener(new MediaListener() {
                                public void mediaAction(MediaPresenter source,
                                        int aType,int aParam) {
                                    if(aType == VisualPresenter.VISUAL_PLAYING) {
                                    Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
                                    d.setText("Multiple listener entry during the replay:NG");
                                    d.show();
                                }
                            }
                    });
                    vp.setMediaListener(new MediaListener() {
                                public void mediaAction(MediaPresenter source,
                                        int aType,int aParam) {
                                    if(aType == VisualPresenter.VISUAL_PLAYING) {
                                    Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
                                    d.setText("Multiple listener entry during the replay:OK");
                                    d.show();
                                }
                            }
                    });
                    vp.play();
                    break;
                case 6:
//J211_3206_0303
                    vp.setMediaListener(new MediaListener() {
                                public void mediaAction(MediaPresenter source,
                                        int aType,int aParam) {
                                    if(aType == VisualPresenter.VISUAL_PLAYING) {
                                    Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
                                    d.setText("Deletion of listener during the replay:NG");
                                    d.show();
                                }
                            }
                    });
                    vp.setMediaListener(null);
                    vp.play();
                    break;
            }
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}




/**
 * Sub screen 1 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel1 extends Panel implements SoftKeyListener, ComponentListener{

    private Frame previousFrame = null;
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 No listener",
            "2 Listener exists"
    };
    private VisualPresenter vp = new VisualPresenter();
    private VisualPresenter vp1 = new VisualPresenter();
    private MediaImage mi = null;
    private Button button = new Button("execute");

    /**
     * Constructor of NextPanel1
     * @param aPrev Object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;
    
        /* Settings of display items */
        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        add(vp);
        add(vp1);

        mi = MediaManager.getImage("resource:///anima8.gif");
        try {
            mi.use();
            vp.setImage(mi);
            vp1.setImage(mi);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
//J211_3206_0101
                    vp.play();
                    break;
                case 1:
//J211_3206_0102
                    vp1.setMediaListener(new MediaListener() {
                                public void mediaAction(MediaPresenter source,
                                        int aType,int aParam) {
                                    if(aType == VisualPresenter.VISUAL_PLAYING) {
                                    Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
                                    d.setText("Listener exists: OK");
                                    d.show();
                                }
                            }
                    });
                    vp1.play();
                    break;
            }
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

