/**
 * J211_3207_0101
 * MainPanel
 *
 * Check behavior of the class(Class operations)
 *
 * $Id: J211_3207_0101.java,v 1.1 2002/02/04 07:28:39 t_yaeda Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import java.lang.*;

/**
 * Main class for checking behavior of the VisualPresenter class and the class
 * @extends IApplication
 */

public class J211_3207_0101 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the VisualPresenter class and the class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 Unmoving during the replay",
            "2 Replayed animation",
            "3 Replay Suspend Unmoving",
            "4 Stopped animation",
            "5 Complete static image",
            "6 Transition of the state"
    };

    private VisualPresenter vp = new VisualPresenter();
    private VisualPresenter vp1 = new VisualPresenter();
    private VisualPresenter vp2 = new VisualPresenter();
    private MediaImage mi = null;
    private MediaImage mi1 = null;
    private Button button = new Button("execute");

    /** 
     * Constructor of MainPanel
     */
    public MainPanel(){
        try{
            /* Display MainPanel */
            showMainPanel();
        }catch(Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }
    }
    
    /** 
     * Display a main panel
     */
    void showMainPanel(){

        /* Settings of display items */
        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        vp.setBackground(Graphics.getColorOfName(Graphics.LIME));
//J211_3207_0101
        add(vp);
//J211_3207_0102
        add(vp1);
//J211_3207_0103
        add(vp2);

        try {
            mi = MediaManager.getImage("resource:///anima8.gif");
            mi1 = MediaManager.getImage("resource:///cat.gif");
            mi.use();
            mi1.use();
            vp2.setImage(mi);
            vp1.setImage(mi1);
        } catch (Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
        vp1.setMediaListener(new MediaListener() {
            public void mediaAction(MediaPresenter source,
                int aType,int aParam) {
                    if(aType == VisualPresenter.VISUAL_COMPLETE){
                        if ( menuList.getSelectedIndex() == 4 ) {
                            showDialog("Complete static image"); 
                        }
                    }
                }
        });


    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
//J211_3207_0201
                    vp1.play();
                    showDialog("Replay static image");
                    break;
                case 1:
//J211_3207_0202
                    vp2.play();
                    break;
                case 2:
//J211_3207_0203
                    vp1.stop();
                    showDialog("Stop static image"); 
                    break;
                case 3:
//J211_3207_0204
                    vp2.stop();
                    break;
                case 4:
//J211_3207_0301
                    vp1.play();
                    break;
                case 5:
                    /* Create NextPanel1 */
                    Display.setCurrent(new NextPanel1((Frame) this));
                    break;
            }
        }
    }

    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
        d.setText(str);
        d.show();
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}

/**
 * Sub screen 1 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel1 extends Panel implements SoftKeyListener,ComponentListener {

    private Frame previousFrame = null;
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 Initial state",
            "2 Replaying state"
    };
    private VisualPresenter vp = new VisualPresenter();
    private MediaImage mi = null;
    private Button button = new Button("execute");

    /**
     * Constructor of NextPanel1
     * @param aPrev Object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;
    
        /* Settings of display items */
        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        add(vp);


        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
//J211_3208_0105
                /* Initial status */
                    MediaResource mr = vp.getMediaResource();
                    try {
                        mi = MediaManager.getImage("resource:///anima8.gif");
                        MediaResource mr2 = null;
                        mi.use();
                        vp.setImage(mi);
                        mr2 = vp.getMediaResource();
                        if ( mr == mr2 ) {
                            showDialog2("getMediaResource:NG");
                        } else {
                            showDialog2("getMediaResource:OK");
                        }
                    } catch (Exception e) {
                        showDialog("Error:" +e.toString());
                    }
                    break;
                case 1:
//J211_3208_0305
                /* Playback status */
                    mi = MediaManager.getImage("resource:///anima8.gif");
                    MediaResource mr1 = null;
                    try {
                        mi.use();
                        vp.setImage(mi);
                    } catch (Exception e) {
                        showDialog("Error:" +e.toString());
                    }
                    vp.play();
                    try {
                        mr1 = vp.getMediaResource();
                        mr1.unuse();
                        showDialog2("getMediaResource:OK");
                    } catch (Exception e){
                        showDialog("Error:" +e.toString());
                    }
                    break;
            }
        }
    }

    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.DIALOG_ERROR,"Error");
        d.setText(str);
        d.show();
    }

    /**
     * Dialog display method2
     * @param str  String to display
     */
    public void showDialog2(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
        d.setText(str);
        d.show();
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

