/**
 * J211_3301_0103
 * MainPanel
 *
 * Check behavior of the class(Class operations)
 *
 * $Id: J211_3301_0103.java,v 1.1 2002/02/04 07:28:39 t_yaeda Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.util.*;
import java.lang.*;

/**
 * Main class for checking behavior of the Timer class and the class
 * @extends IApplication
 */

public class J211_3301_0103 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the Timer class and class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 Check the resolution",
            "2 Specified time=JVM",
            "3 Timer interval",
            "4 Resolution > Set value",
            "5 Resolution = Set value",
            "6 Resolution < Set value"
    };
    private Timer timer;
    static final int TIMER_INTERVAL = 60000;
    private Label label = new Label(" Timer:0");
    private int timerCounter = 0;
    private Button button = new Button("execute");
    private long l1,l2;
    private long t1[] = new long[6];

        /*
         * Constructor of MainPanel class
         */
        public MainPanel() {
            try {
                /* Main panel display */
                showMainPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

    /**
     * Display a main panel
     */
    public void showMainPanel() {

        /* Setting of the displayed items */
        setTitle("Behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        add(label);

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    timerCreate();
//J211_3301_0103
                    int rl = timer.getResolution();
                    showDialog("Resolution:"+rl);
                    break;
                case 1:
                    timerCreate();
                    timer.start();
                    l1 = System.currentTimeMillis();
                    break;
                case 2:
                    Display.setCurrent(new NextPanel1((Frame) this));
                    break;
                case 3:
                    Display.setCurrent(new NextPanel2((Frame) this, menuList.getSelectedIndex()));
                    break;
                case 4:
                    Display.setCurrent(new NextPanel2((Frame) this, menuList.getSelectedIndex()));
                    break;
                case 5:
                    Display.setCurrent(new NextPanel2((Frame) this, menuList.getSelectedIndex()));
                    break;
            }
        }
    }

    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "message");
        d.setText(str);
        d.show();
    }

    /**
     * Timer method
     */
    public void timerCreate() {
        timer = new Timer();
        timer.setTime(TIMER_INTERVAL);
        timer.setRepeat(true);
        timer.setListener(
            new TimerListener() {
                public void timerExpired(Timer t) {
                    if (t == timer) {
                        l2 = System.currentTimeMillis();
                        if ( timerCounter >= 5 ) {
                            for ( int i=0; i<=5; i++ ){
                                t1[5] = t1[5] + t1[i];
                            }
                            t1[5] = t1[5]/60000;
                            if ( t1[5] < 5000 ) {
//J211_3301_0104
                                showDialog(" Time specified by timer: OK");
                            } else {
                                showDialog(" Time specified by timer: NG");
                            }
                            timer.stop();
                        } else {
                            t1[timerCounter] = (l2 - l1) - (timerCounter*60000);
                            timerCounter++;
                            label.setText(" Timer:"+timerCounter);
                        }
                    }
                }
            }
        );
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}

/**
 * Sub screen 1 for checking behavior of the Timer class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel1 extends Panel implements SoftKeyListener, ComponentListener {

    private Frame previousFrame = null;
    private Timer timer1 = new Timer();
    private Timer timer2 = new Timer();
    static final int TIMER_INTERVAL1 = 1000;
    static final int TIMER_INTERVAL2 = 2500;
    private Label label = new Label(" Timer:0");
    private Label label1 = new Label(" Timer:0");
    private int timerCounter1 = 0;
    private int timerCounter2 = 0;
    private Button button = new Button(" execute ");
    

    /**
     * Constructor of NextPanel1
     * @param aPrev Object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;
    
        /* Settings of display items */
        setTitle("Check behavior of the class");
        add(button);
        add(label);
        add(label1);

        setSoftLabel(Frame.SOFT_KEY_2, "back");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        timer1.setTime(TIMER_INTERVAL1);
        timer1.setRepeat(true);
        timer2.setTime(TIMER_INTERVAL2);
        timer2.setRepeat(true);


        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
        timer1.setListener(new TimerListener() {
                public void timerExpired(Timer t) {
                    if ( t == timer1 ) {
                        timerCounter1++;
                        label.setText(" Timer:"+timerCounter1);
                    }
                }
        });
        timer2.setListener(new TimerListener() {
                public void timerExpired(Timer t) {
                    if ( t == timer2 ) {
                        timerCounter2++;
                        label1.setText(" Timer:"+timerCounter2);
                    }
                }
        });

    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
//J211_3301_0105
            timer1.start();
            timer2.start();
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}


/**
 * Sub screen 2 for checking behavior of the Timer class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class NextPanel2 extends Panel implements SoftKeyListener, ComponentListener {

    private Frame previousFrame = null;
    private Timer timer1 = new Timer();
    private Timer timer2 = new Timer();
    private Label label = new Label("");
    private Label label2 = new Label("");
    private int timerCounter1 = 0;
    private Button button = new Button(" execute ");
    private int selection,rl;
    private long l1,l2;

    /**
     * Constructor of NextPanel2
     * @param aPrev Object of MainPanel
     */
    NextPanel2( Frame aPrev, int aSelection ) {
        previousFrame = aPrev;
        selection = aSelection;

        /* Setting of the display item */
        setTitle("Behavior of the class");
        add(button);
        add(label);
        add(label2);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Setting of the Timer */
        timer1.setRepeat(false);
        timer2.setRepeat(true);
        rl = timer1.getResolution();
        label.setText(" Timer's resolution : "+rl);
        timer1.dispose();
        if ( selection == 3 ) {
            timer2.setTime(rl-5);
        } else if ( selection == 4 ) {
            timer2.setTime(rl);
        } else if ( selection == 5 ) {
            timer2.setTime(rl+5);
        }

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
        timer2.setListener(new TimerListener() {
                public void timerExpired(Timer t) {
                    if ( t == timer2 ) {
                        timerCounter1++;
                        if ( timerCounter1 == 10000 ) {
                            l2 = System.currentTimeMillis();
                            timer2.stop();
//J211_3301_0201
//J211_3301_0202
//J211_3301_0203
                            String s2 = Long.toString((l2 - l1)/10000);
                            label2.setText("Timer's set value : " + s2);
                        }
                    }
                }
        });
    }


    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            timer2.start();
            l1 = System.currentTimeMillis();
            label2.setText("Start the timer 10000 times");
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}
