/**
 * J211_3302_0101
 * MainPanel
 *
 * Check behavior of the class(Class operations)
 *
 * $Id: J211_3302_0101.java,v 1.1 2002/02/04 07:28:40 t_yaeda Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.util.*;
import java.lang.*;

/**
 * Main class for checking behavior of the Timer class and the class
 * @extends IApplication
 */

public class J211_3302_0101 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the Timer class and class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 No listener",
            "2 Single listener before playback",
            "3 Multiple listeners before playback",
            "4 Delete before playback",
            "5 Single listener after playback",
            "6 Multiple listeners after playback",
            "7 Delete after playback"
    };
    private Timer timer;
    static final int TIMER_INTERVAL = 1000;
    private Label label = new Label(" Timer:0");
    private int timerCounter = 0;
    private Button button = new Button("execute");


    /*
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    public void showMainPanel() {

        /* Setting of the displayed items */
        setTitle("Behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        add(label);

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* Setting of the timer */
        timer = new Timer();
        timer.setTime(TIMER_INTERVAL);
        timer.setRepeat(true);

    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == menuList ) {
            timer.stop();
            timer.setListener(null);
            timerCounter = 0;
            label.setText(" Timer:0");
        }

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
//J211_3302_0101
                    try {
                        timer.start();
                        showDialog("Listener: OK");
                    } catch ( Exception e ) {
                        showDialog("Listener: NG");
                    }
                    break;
                case 1:
//J211_3302_0201
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if ( t == timer ) {
                                timerCounter++;
                                label.setText(" Timer:"+timerCounter);
                            }
                        }
                    });
                    timer.start();
                    break;
                case 2:
//J211_3302_0202
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if ( t == timer ) {
                                label.setText(" Timer:NG");
                                timer.stop();
                            }
                        }
                    });
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if ( t == timer ) {
                                timerCounter++;
                                label.setText(" Timer:"+timerCounter);
                            }
                        }
                    });
                    timer.start();
                    break;
                case 3:
//J211_3302_0203
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if ( t == timer ) {
                                label.setText(" Timer:NG");
                                timer.stop();
                            }
                        }
                    });
                    timer.setListener(null);
                    try {
                        timer.start();
                        showDialog("Delete the listener: OK");
                    } catch( Exception e ) {
                        showDialog("Delete the listener: NG");
                    }
                    break;
                case 4:
//J211_3302_0301
                    timer.start();
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if ( t == timer ) {
                                timerCounter++;
                                label.setText(" Timer:"+timerCounter);
                            }
                        }
                    });
                    break;
                case 5:
//J211_3303_0302
                    timer.start();
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if ( t == timer ) {
                                label.setText(" Timer:NG");
                                timer.stop();
                            }
                        }
                    });
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if ( t == timer ) {
                                timerCounter++;
                                label.setText(" Timer:"+timerCounter);
                            }
                        }
                    });
                    break;
                case 6:
//J211_3303_0303
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if ( t == timer ) {
                                label.setText(" Timer:NG");
                                timer.stop();
                            }
                        }
                    });
                    timer.start();
                    timer.setListener(null);
                    try {
                        showDialog("Delete the listener: OK");
                    } catch( Exception e ) {
                        showDialog("Delete the listener: NG");
                    }
                    break;

            }
        }
    }



    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(str);
        d.show();
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}
