/**
 * J211_3303_0201
 * MainPanel
 *
 * Check behavior of the class(Class operations)
 *
 * $Id: J211_3303_0201.java,v 1.1 2002/02/04 07:28:40 t_yaeda Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.util.*;
import java.lang.*;

/**
 * Main class for checking behavior of the Timer class and the class
 * @extends IApplication
 */

public class J211_3303_0201 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the Timer class and class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements Runnable
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener, Runnable {

    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 Now displaying the dialog",
            "2 Non-displayed Panel",
            "3 Interruption"
    };
    private Timer timer;
    static final int TIMER_INTERVAL = 1000;
    private Label label = new Label(" Timer:0");
    private int timerCounter = 0;
    private Button button = new Button("execute");
    private Button button1 = new Button("Start the Timer");

    /*
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    public void showMainPanel() {

        /* Setting of the displayed items */
        setTitle("Behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        add(button1);
        add(label);

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* Setting of the timer */
        timer = new Timer();
        timer.setTime(TIMER_INTERVAL);
        timer.setRepeat(true);

    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == menuList ) {
            timer.stop();
            timer.setListener(null);
            timerCounter = 0;
            label.setText(" Timer:0");
        }

        if ( aComponent == button1 && aType == BUTTON_PRESSED ) {
            timer.setListener(new TimerListener() {
                public void timerExpired(Timer t) {
                    if ( t == timer ) {
                        timerCounter++;
                        label.setText(" Timer:"+timerCounter);
                    }
                }
            });
            timer.start();
        }

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    Thread t1 = new Thread(this);
                    t1.start();
//J211_3303_0201
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if ( t == timer ) {
                                timerCounter++;
                                label.setText(" Timer:"+timerCounter);
                            }
                        }
                    });
                    timer.start();
                    break;
                case 1:
//J211_3303_0202
                    /* Create NextPanel1 */
                    Display.setCurrent(new NextPanel1((Frame) this));
                    break;
                case 2:
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if ( t == timer ) {
                                timerCounter++;
                                label.setText(" Timer:"+timerCounter);
                            }
                        }
                    });
                    timer.start();
                    break;
            }
        }
    }

    /**
     * Thread execution method
     */
    public void run(){
        try {
            Thread.sleep(2000);
        } catch(Exception e) {}
        showDialog("Display the dialog for over 5 seconds");
    }


    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(str);
        d.show();
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}

/**
 * Sub screen1 for checking behavior of the Timer class
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel1 extends Panel implements SoftKeyListener {

    private Frame previousFrame = null;
    private Label label = new Label("Wait 5 second and then return");

    /**
     * Constructor of NextPanel1
     * @param aPrev Object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;
    
        /* Settings of display items */
        setTitle("Check behavior of the class");
        add(label);

        setSoftLabel(Frame.SOFT_KEY_1, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Return to the previous screen when soft key1 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            Display.setCurrent(previousFrame);
        }
    }
}
    