/**
 * J211_3304_0101
 * MainPanel
 *
 * Check behavior of the class(Class operations)
 *
 * $Id: J211_3304_0101.java,v 1.1 2002/02/04 07:28:40 t_yaeda Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.util.*;
import java.lang.*;

/**
 * Main class for checking behavior of the Timer class and the class
 * @extends IApplication
 */

public class J211_3304_0101 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the Timer class and class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    private ListBox menuList1 = new ListBox(ListBox.CHOICE);
    private ListBox menuList2 = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem1 = {
            "1 Suspended state",
            "2 execute state",
            "3 Disposing state"
    };
    private  String[] menuListItem2 = {
            "1 getResolution",
            "2 setTime",
            "3 setRepeat",
            "4 stop",
            "5 dispose",
            "6 One shot",
            "7 Suspend"
    };
    
    private Timer timer = new Timer();
    static final int TIMER_INTERVAL = 1000;
    private Label label = new Label(" Timer : 0");
    private int timerCounter = 0;
    private Button button = new Button("execute");

    /*
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    public void showMainPanel() {

        /* Setting of the displayed items */
        setTitle("Behavior of the class");
        menuList1.setItems(menuListItem1);
        add(menuList1);
        menuList2.setItems(menuListItem2);
        add(menuList2);
        add(button);
        add(label);

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
        timer.setListener(new TimerListener() {
            public void timerExpired(Timer t) {
                if ( t == timer ) {
                    timerCounter++;
                    label.setText(" Timer:"+timerCounter);
                }
            }
        });
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList1.getSelectedIndex()){
                case 0:
                    switch(menuList2.getSelectedIndex()){
                        case 0:
//J211_3304_0101
                            int rl = timer.getResolution();
                            showDialog("getResolution:"+rl);
                            break;
                        case 1:
                            try {
//J211_3304_0102
                                timer.setTime(TIMER_INTERVAL);
                                showDialog("setTime:OK");
                            } catch ( Exception e ) {
                                showDialog("setTime:NG");
                            }
                            break;
                        case 2:
                            try {
//J211_3304_0103
                                timer.setRepeat(true);
                                showDialog("setRepeat:OK");
                            } catch ( Exception e ) {
                                showDialog("setRepeat:NG");
                            }
                            break;
                        case 3:
                            try {
//J211_3304_0104
                                timer.stop();
                                showDialog("stop:OK");
                            } catch ( Exception e ) {
                                showDialog("stop:NG");
                            }
                            break;
                    }
                    break;
                case 1:
                    switch(menuList2.getSelectedIndex()){
                        case 0:
                            timer.setTime(TIMER_INTERVAL);
                            timer.setRepeat(true);
                            timer.start();
                            try {
//J211_3304_0203
                                int rl = timer.getResolution();
                                showDialog("getResolution:"+rl);
                            } catch ( Exception e ) {
                                showDialog("getResolution:NG");
                            }
                            break;
                        case 4:
                            timer.setTime(TIMER_INTERVAL);
                            timer.setRepeat(true);
                            timer.start();
                            try {
//J211_3304_0204
                                timer.dispose();
                                showDialog("dispose:OK");
                            } catch ( Exception e ) {
                                showDialog("dispose:NG");
                            }
                            break;
                        case 5:
                            timer.setTime(TIMER_INTERVAL);
                            timer.setRepeat(false);
//J211_3304_0201
                            timer.start();
                            break;
                        case 6:
                            timer.setTime(TIMER_INTERVAL);
                            timer.setRepeat(true);
                            timer.start();
                            break;
                    }
                    break;
                case 2:
                    timer.dispose();
                    switch(menuList2.getSelectedIndex()){
                        case 4:
                            try {
//J211_3304_0301
                                timer.dispose();
                                showDialog("dispose:OK");
                            } catch ( Exception e ) {
                                showDialog("dispose:NG");
                            }
                            break;
                    }
                    break;
            }
        }
    }

    /**
     * Dialog display method
     * @param str  String to display
     */
    public void showDialog(String str) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(str);
        d.show();
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}
