/**
 * J212_0201_0101.java
 * 
 * J212_0201_0101
 * MenuPanel
 * 
 * Class's operational test
 * 
 * $Id: J212_0201_0101.java,v 1.1 2002/02/05 12:02:39 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Main class for Button of the UI boundary
 * @extends IApplication
 */
public class J212_0201_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * Menu screen for checking Button of the UI boundary
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    Label            subTitle      = null;  /* Sub title */
    ListBox          menuList1     = null;  /* Menu list */
    ListBox          menuList2     = null;  /* Menu list */
    Button           execButton    = null;  /* execute button */
    TextBox          resultText    = null;  /* Text box for displaying the result */
    boolean          okFlag        = false; /* Flag for determination of test result */
    int              menu1Index    = 0;
    String[] menu1Item = {
        "0.Created quantity is 1",
        "1.Created quantity is 2",
        
        "3.Behavior of when the maximum size is specified 1",
        "4.Behavior of when the maximum size is specified 2"
    };

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("UI boundary operations");

        /* Create and add components */
        subTitle       = new Label("Button");
        menuList1      = new ListBox(ListBox.CHOICE,4);
        execButton     = new Button("execute");
        add(subTitle);
        add(menuList1);
        add(execButton);

        /* Setting of the Menu items */
        menuList1.setItems(menu1Item);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            /* Transit to Panel for checking behavior */
            Display.setCurrent(new TestPanel(
                menuList1.getSelectedIndex(), this));
        }
    }
}

/**
 * Confirmation screen for behavior of Button of the UI boundary
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class TestPanel extends Panel implements SoftKeyListener, ComponentListener {
    Frame        previousFrame    = null;  /* Store the previous screen */
    int          menu1Index       = 0;     /* Index of the menu of previous screen */
    Label        subTitle         = null;  /* Sub title */
    Button       testButton1      = null;
    Button       testButton2      = null;
    Button       testButton3      = null;

    /**
     * Constructor of TestPanel class
     * @param  menu1Index  Index of menu1
     * @param  aFrame      Previous screen
     */
    TestPanel(int menu1Index, Frame aFrame) {
        previousFrame = aFrame;
        menu1Index    = menu1Index;

        try {
            showTestPanel();
            test(menu1Index);
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Panel for checking operations
     */
    void showTestPanel() {

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        setSoftLabel(Frame.SOFT_KEY_2,"back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * The method of confirming operations
     * @param  menu1Index  Index of menu1 of menu screen
     * @param  menu2Index  Index of menu2 of menu screen
     * @param  menu3Index  Index of Menu 3 of menu screen
     */
    void test(int menu1Index) {
        switch (menu1Index) {
        /* Created quantity is 1 */
// J212_0201_0101
        case 0:
            /* Display title/sub title */
            setTitle("UI boundary operations");
            subTitle = new Label("Check the created quantity to be 20");
            add(subTitle);
            subTitle.setSize(getWidth(), subTitle.getHeight());

           try {
                for(int i = 1; i < 21; i++) {
                    testButton1 = new Button(((i<10)?"0":"") + i);
                    add(testButton1);
                }
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J212_0201_0102
        /* Created quantity is 2 */
        case 1:
            /* Display title/sub title */
            setTitle("UI boundary operations");
            subTitle = new Label("Check the created quantity to be 21");
            add(subTitle);
            subTitle.setSize(getWidth(), subTitle.getHeight());

           try {
                for(int i = 1; i < 22; i++) {
                    testButton1 = new Button(((i<10)?"0":"") + i);
                    add(testButton1);
                }
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;

// J212_0201_0301
        /* Operations with maximum size specified1 */
        case 2:

            testButton1 = new Button("testButton");
            add(testButton1);
//2002/09/17 Doja1.5            testButton1.setSize(getWidth()+10,getHeight()+10);
            testButton1.setSize(getWidth()+10,Display.getHeight());
            break;
// J212_0201_0302
        /* Operations with maximum size specified2 */
        case 3:
            setTitle("UI boundary operations");
            testButton1 = new Button("testButton");
            add(testButton1);
//2002/09/17 Doja1.5            testButton1.setSize(getWidth()+10,getHeight()+10);
            testButton1.setSize(getWidth()+10,Display.getHeight());
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application if soft key1 is released
     * Transit to the whole screen in the event of soft key2
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(
        Component aComponent, int aAction, int aParam) {}
}