/**
 * J212_0702_0101
 * UI boundary operations
 * Check behavior of the ImageLabel display - Check behavior for maximum setting
 *
 * $Id: J212_0702_0101.java,v 1.2 2002/02/28 02:01:29 takanao Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * UI boundary operations
 * Check behavior of the ImageLabel display - Check behavior for maximum setting
 * @extends IApplication
 */
public class J212_0702_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * UI boundary operations
 * Check behavior of the ImageLabel display - Check behavior for maximum setting
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    Label classLabel = new Label();
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Create an image exceeding the screen's size");
        setTitle("UI boundary operations");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

//J212_0702_0101
            Display.setCurrent(new SubPanel(this));
        }
    }
}

/**
 * UI boundary operations
 * Check behavior of the ImageLabel display - Check behavior for maximum setting
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Image imageObj;
    Frame prevFrame;
    TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);

	MediaImage aMediaImage;

    /**
     * Display a sub screen
     * @param aFrame  Main screen object
     */
    public SubPanel(Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;

        try {
            /* Display sub panels */
            ShowSubPanel();
            resultText.setText("OK\nDisplaySuccessful\n");
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Creation and acquisition of image objects */
//2002/08/07 Do_Ja1.5        MakeImage getImageObj = new MakeImage();

        try {
            /* Create ImageLabel */
            ImageLabel imageLabelObj = new ImageLabel();
//2002/08/07 Do_Ja1.5            imageObj = getImageObj.create();
            aMediaImage = MediaManager.getImage
                                     ("resource:///GIF20k.gif");
            aMediaImage.use();
            imageObj = aMediaImage.getImage();

            imageLabelObj.setImage(imageObj);
            add(imageLabelObj);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }

        /* Settings of display items */
        setTitle("UI boundary operations");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Add each component to screen */
        add(resultText);

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J212_0702_0101.mainPanel);
        }
    }
}

/**
 * Acquisition of graphical contents in Image format
 * @extends Panel
 */
//2002/08/07 Do_Ja1.5class MakeImage extends Panel {

//2002/08/07 Do_Ja1.5    Image makeImage;

    /**
     * Creation of image objects
     */
//2002/08/07 Do_Ja1.5    MakeImage() {
//2002/08/07 Do_Ja1.5    }

    /**
     * Creation of images
     */
//2002/08/07 Do_Ja1.5    public Image create() {
//2002/08/07 Do_Ja1.5        int sizeX = getWidth() * 2;                     /* Twice of the screen's horizontal size */
//2002/08/07 Do_Ja1.5        int sizeY = getHeight() * 2;                    /* Twice of the screen's vertical size */

//2002/08/07 Do_Ja1.5        makeImage = Image.createImage(sizeX, sizeY);

//2002/08/07 Do_Ja1.5        Graphics g = makeImage.getGraphics();
//2002/08/07 Do_Ja1.5        g.setColor(g.getColorOfName(g.AQUA));           /* Set to sky blue */
//2002/08/07 Do_Ja1.5        g.fillRect(0, 0, (sizeX - 1), (sizeY - 1));     /* Paint in the rectangle */
//2002/08/07 Do_Ja1.5        g.setColor(g.getColorOfName(g.RED));            /* Set to red */
//2002/08/07 Do_Ja1.5        g.drawString("ImageLabel", 0, 12);              /* Write ImageLabel */
//2002/08/07 Do_Ja1.5        return makeImage;
//2002/08/07 Do_Ja1.5    }
//2002/08/07 Do_Ja1.5}
