/**
 * J212_0802_0301
 * UI boundary operations
 * Check behavior for display - Check behavior for maximum size specification
 *
 * $Id: J212_0802_0301.java,v 1.1 2002/02/01 07:15:42 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * UI boundary operations
 * Check behavior for display - Check behavior for maximum size specification
 * @extends IApplication
 */
public class J212_0802_0301 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * UI boundary operations
 * Check behavior for display - Check behavior for maximum size specification
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem = {
        "1.No title",
        "2.With title",
    };

    Label classLabel = new Label();
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Label exceeding the screen's size");
        setTitle("UI boundary operations");
        menuList.setItems(menuListItem);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int titleExistence = menuList.getSelectedIndex();
            Display.setCurrent(new SubPanel(titleExistence, this));
        }
    }
}

/**
 * UI boundary operations
 * Check behavior for display - Check behavior for maximum size specification
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    int title;
    Label classLabel = new Label("Label exceeding the screen's size");
    TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        title = anInt;
        
        try {
            /* Display sub panels */
            ShowSubPanel();
            resultText.setText("OK\nDisplaySuccessful\n");
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

//J212_0802_0301
//J212_0802_0302
        /* Settings of display items */
        if(title == 1) {
            setTitle("UI boundary operations");
        }
        
        /* Set the size of the label to be twice of the screen's width */
        classLabel.setSize((getWidth() * 2), (getHeight() * 2));

        /* Turn the background into AQUA to confirm the size */
        classLabel.setBackground(Graphics.getColorOfName(Graphics.AQUA));

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Add each component to screen */
        add(classLabel);
        add(resultText);

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J212_0802_0301.mainPanel);
        }
    }
}
