/**
 * J212_0901_0101
 * UI boundary operations
 * Check the created quantity of ListBox
 *
 * $Id: J212_0901_0101.java,v 1.1 2002/02/01 07:15:42 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * UI boundary operations
 * Check the created quantity of ListBox
 * @extends IApplication
 */
public class J212_0901_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * UI boundary operations
 * Check the created quantity of ListBox
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem = {
        "1. 10 of list boxes",
        "2. 11 of list boxes"
    };

    Label classLabel = new Label();
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        setTitle("UI boundary operations");
        classLabel.setText("Check the creation of list box");
        classLabel.setSize(getWidth(), classLabel.getHeight());
        menuList.setItems(menuListItem);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int testType = menuList.getSelectedIndex();
            Display.setCurrent(new SubPanel(testType, this));
        }
    }
}

/**
 * UI boundary operations
 * Check the created quantity of ListBox
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    int testType;
    Label classLabel = new Label();
    TextBox resultText = new TextBox("", 20, 2, TextBox.DISPLAY_ANY);
    
    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt, Frame aFrame) {

        /* Object name setting */
        testType = anInt;
        prevFrame = aFrame;

        try {
            /* Display sub panels */
            ShowSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        classLabel.setText("List box" + (10 + testType) + "Display the number");
        classLabel.setSize(getWidth(), classLabel.getHeight());
        add(classLabel);

//J212_0901_0101
//J212_0901_0102
        try {
            /* Create  1* of ListBoxes */
            for(int i=0; i<(10 + testType); i++) {
                /* ListBox menu for test */
                String[] menuListItem = {
                    (i + 1) + ".test",
                };
                ListBox menuList   = new ListBox(ListBox.CHECK_BOX);
                menuList.setItems(menuListItem);
                add(menuList);
            }
            resultText.setText("OK\nGenerationSuccessful\n");
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }

        /* Settings of display items */
        setTitle("UI boundary operations");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        
        /* Add each component to screen */
        add(resultText);

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J212_0901_0101.mainPanel);
        }
    }
}
