/**
 * J212_1002_0201
 * UI boundary operations
 * Check behavior of Panel display - Check behavior for the excessive setting being specified
 *
 * $Id: J212_1002_0201.java,v 1.1 2002/02/01 07:15:44 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * UI boundary operations
 * Check behavior of Panel display - Check behavior for the excessive setting being specified
 * @extends IApplication
 */
public class J212_1002_0201 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * UI boundary operations
 * Check behavior of Panel display - Check behavior for the excessive setting being specified
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    TextBox textBox1 = new TextBox("",20,1,TextBox.DISPLAY_ANY);

    Label classLabel = new Label();
   
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Behavior of setting over the maximum size");
        setTitle("UI boundary operations");
       
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
         add(textBox1);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

          //  int testType = menuList.getSelectedIndex();
            Display.setCurrent(new SubPanel(textBox1.getText()));
        }
    }
}

/**
 * UI boundary operations
 * Check behavior of Panel display - Check behavior for the excessive setting being specified
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    ListBox menuList   = new ListBox(ListBox.CHECK_BOX);
     String text;
	

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(String text) {

      
        
        try {
            /* Display sub panels */
            ShowSubPanel(text);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel(String text) {

       
            /* Set 30 one byte characters to the title */
        setTitle(text);

        Label classLabel = new Label("Behavior of setting over the maximum size");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        add(classLabel);

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Return to the main screen when soft key2 is released
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J212_1002_0201.mainPanel);
        }
    }
}
