/**
 * J212_1003_0301
 * UI boundary operations
 * Check the alignment of Panel component - NULL layout
 *
 * $Id: J212_1003_0301.java,v 1.2 2002/02/26 06:23:20 torikatu Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * UI boundary operations
 * Check the alignment of Panel component - NULL layout
 * @extends IApplication
 */
public class J212_1003_0301 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * UI boundary operations
 * Check the alignment of Panel component - NULL layout
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem = {
//2002/08/07 Do_Ja1.5        "1.AnchorButton",
        "2.Button",
//2002/08/07 Do_Ja1.5        "3.ImageButton",
        "4.ImageLabel",
        "5.ListBox",
        "6.TextBox",
        "7.Ticker",
        "8.VisualPresenter",
    };

    Label classLabel = new Label();
    ListBox menuList   = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        setTitle("UI boundary operations");
        classLabel.setText("NULL layout alignment");
        menuList.setItems(menuListItem);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int testType = menuList.getSelectedIndex();
            Display.setCurrent(new SubPanel(testType, this));
        }
    }
}

/**
 * UI boundary operations
 * Check the alignment of Panel component - HTML layout
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 */
class SubPanel extends Panel implements SoftKeyListener {

    Frame prevFrame;
    Label classLabel = new Label();
    int testType;

    /* X and Y coordinate for the Location */
    int x=0;
    int y=0;

    /**
     * Display a sub screen
     * @param anInt    Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        testType = anInt;
        
        /* Set Panel layout to null */
        setLayoutManager(null);
        
        try {
            /* Display sub panels */
            ShowSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        /* Creation and acquisition of image objects */
        Image imageObj;
//2002/08/07 Do_Ja1.5        MakeImage getImageObj = new MakeImage();

        /* Settings of display items */
        switch(testType) {

//J212_1003_0301
//2002/08/07 Do_Ja1.5        case 0:
//2002/08/07 Do_Ja1.5            classLabel.setText("20 of AnchorButtons");
//2002/08/07 Do_Ja1.5            classLabel.setSize(getWidth(), classLabel.getHeight());
//2002/08/07 Do_Ja1.5            classLabel.setLocation(0,0);
//2002/08/07 Do_Ja1.5            add(classLabel);
            
//2002/08/07 Do_Ja1.5            try {
//2002/08/07 Do_Ja1.5                for(int i=1; i<21; i++) {
//2002/08/07 Do_Ja1.5                    x = ((i-1)%4)*32;
                    /* Create 20 of AnchorButton */
//2002/08/07 Do_Ja1.5                    AnchorButton AnchorButtonObj = new AnchorButton(
//2002/08/07 Do_Ja1.5                        ((i<10)?"0":"") + i);
//2002/08/07 Do_Ja1.5                    imageObj = getImageObj.create();
//2002/08/07 Do_Ja1.5                    AnchorButtonObj.setImage(imageObj);
//2002/08/07 Do_Ja1.5                    AnchorButtonObj.setLocation(x,(y*18+15));
//2002/08/07 Do_Ja1.5                    add(AnchorButtonObj);
//2002/08/07 Do_Ja1.5                    if(((i-1)%4)==3) {
//2002/08/07 Do_Ja1.5                        y++;
//2002/08/07 Do_Ja1.5                    }
//2002/08/07 Do_Ja1.5                }
//2002/08/07 Do_Ja1.5            } catch (Exception e) {
//2002/08/07 Do_Ja1.5                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
//2002/08/07 Do_Ja1.5                errDialog.setText("Error:" + e.toString());
//2002/08/07 Do_Ja1.5                errDialog.show();
//2002/08/07 Do_Ja1.5            }

//2002/08/07 Do_Ja1.5            break;
            
//J212_1003_0302
//2002/08/07 Do_Ja1.5        case 1:
        case 0:
            classLabel.setText("20 of Button ");
            classLabel.setSize(getWidth(), classLabel.getHeight());
            add(classLabel);

           try {
                for(int i=1; i<21; i++) {
                    x = ((i-1)%4)*32;
                    /* Create 20 Buttons */
                    Button ButtonObj = new Button(((i<10)?"0":"") + i);
                    ButtonObj.setLocation(x,(y*18+15));
                    add(ButtonObj);
                    if(((i-1)%4)==3) {
                        y++;
                    }
                }
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }

            break;

//J212_1003_0303
//2002/08/07 Do_Ja1.5        case 2:
//2002/08/07 Do_Ja1.5            classLabel.setText("20 of ImageButton");
//2002/08/07 Do_Ja1.5            classLabel.setSize(getWidth(), classLabel.getHeight());
//2002/08/07 Do_Ja1.5            add(classLabel);

//2002/08/07 Do_Ja1.5            try {
//2002/08/07 Do_Ja1.5                for(int i=1; i<21; i++) {
//2002/08/07 Do_Ja1.5                    x = ((i-1)%4)*32;
                    /* Create 20 ImageButton  */
//2002/08/07 Do_Ja1.5                    ImageButton imageButtonObj = new ImageButton();
//2002/08/07 Do_Ja1.5                    imageObj = getImageObj.create();
//2002/08/07 Do_Ja1.5                    imageButtonObj.setImage(imageObj);
//2002/08/07 Do_Ja1.5                    imageButtonObj.setLocation(x,(y*18+15));
//2002/08/07 Do_Ja1.5                    add(imageButtonObj);
//2002/08/07 Do_Ja1.5                    if(((i-1)%4)==3) {
//2002/08/07 Do_Ja1.5                        y++;
//2002/08/07 Do_Ja1.5                    }
//2002/08/07 Do_Ja1.5                }
//2002/08/07 Do_Ja1.5            } catch (Exception e) {
//2002/08/07 Do_Ja1.5                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
//2002/08/07 Do_Ja1.5                errDialog.setText("Error:" + e.toString());
//2002/08/07 Do_Ja1.5                errDialog.show();
//2002/08/07 Do_Ja1.5            }

//2002/08/07 Do_Ja1.5            break;
            
//J212_1003_0304
//2002/08/07 Do_Ja1.5        case 3:
		case 1:
            classLabel.setText("30 of ImageLabel");
            classLabel.setSize(getWidth(), classLabel.getHeight());
            add(classLabel);

            try {
                for(int i=1; i<31; i++) {
                    x = ((i-1)%6)*20;
                    /* Create 30 of ImageLabel */
                    ImageLabel imageLabelObj = new ImageLabel();
//2002/08/07 Do_Ja1.5                    imageObj = getImageObj.create();
		            MediaImage viewImage;
		            viewImage = MediaManager.getImage("resource:///89a10-1.gif");
                    viewImage.use();
                    imageObj = viewImage.getImage();

                    imageLabelObj.setImage(imageObj);
                    imageLabelObj.setLocation(x,(y*18+15));
                    add(imageLabelObj);
                    if(((i-1)%6)==5) {
                        y++;
                    }
                }
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }

            break;

//J212_1003_0305
//2002/08/07 Do_Ja1.5        case 4:
		case 2:
            classLabel.setText("10 of ListBox");
            classLabel.setSize(getWidth(), classLabel.getHeight());
            add(classLabel);

            try {
                for(int i=1; i<11; i++) {
                    x = ((i-1)%2)*64;
                    /* Create 10 ListBox */
                    String[] menuListItem = {
                        ((i<10)?"0":"") + i,
                    };
                    ListBox menuList   = new ListBox(ListBox.CHOICE);
                    menuList.setSize(52,18);
                    menuList.setItems(menuListItem);
                    menuList.setLocation(x,(y*18+15));
                    add(menuList);
                    if(((i-1)%2)==1) {
                        y++;
                    }
                }
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }

            break;
            
//J212_1003_0306
//2002/08/07 Do_Ja1.5        case 5:
		case 3:
            classLabel.setText("30 of TextBox");
            classLabel.setSize(getWidth(), classLabel.getHeight());
            add(classLabel);

            try {
                for(int i=1; i<31; i++) {
                    x = ((i-1)%6)*20;
                    /* Create 30 TextBox */
                    TextBox TextBoxObj = new TextBox(
                        ((i<10)?"0":"") + i,
                        2,
                        1,
                        TextBox.DISPLAY_ANY
                    );
                    TextBoxObj.setLocation(x,(y*18+15));
                    add(TextBoxObj);
                    if(((i-1)%6)==5) {
                        y++;
                    }
                }
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }

            break;

//J212_1003_0307
//2002/08/07 Do_Ja1.5        case 6:
		case 4:
            classLabel.setText("10 of Ticker");
            classLabel.setSize(getWidth(), classLabel.getHeight());
            add(classLabel);

            try {
                for(int i=1; i<11; i++) {
                    x = ((i-1)%2)*64;
                    /* Create 10 Ticker  */
                    Ticker TickerObj = new Ticker(
                        ((i<10)?"0":"") + i + "Ticker tape");
                    TickerObj.setSize(52,18);
                    TickerObj.setLocation(x,(y*18+15));
                    add(TickerObj);
                    if(((i-1)%2)==1) {
                        y++;
                    }
                }
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }

            break;
            
//J212_1003_0308
//2002/08/07 Do_Ja1.5        case 7:
		case 5:
            classLabel.setText("30 of VisualPresenter");
            classLabel.setSize(getWidth(), classLabel.getHeight());
            add(classLabel);

            /* Get image for VisualPresenter from the resource */
            MediaImage viewImage;
            viewImage = MediaManager.getImage("resource:///89a10-1.gif");

            /* Reading media */
            try {
                viewImage.use();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("VP Image read error" + e.toString());
                errDialog.show();
            }
            
            try {
                for(int i=1; i<31; i++) {
                    x = ((i-1)%6)*21;
                    /* Create 30 VisualPresenters */
                    Label viewLabel = new Label();
                    viewLabel.setText(((i<10)?"0":"") + i);
                    viewLabel.setLocation(x,(y*19+15));
                    add(viewLabel);
                    VisualPresenter visualImage = new VisualPresenter();
                    visualImage.setImage(viewImage);
                    visualImage.setLocation((x+11),(y*19+15));
                    add(visualImage);
                    if(((i-1)%6)==5) {
                        y++;
                    }
                }
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }


            break;

        default:
            break;
        }
        
        /* Settings of display items */
        setTitle("UI boundary operations");
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* When soft key2 is released, return to the main screen */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J212_1003_0301.mainPanel);
        }
    }
}

/**
 * Acquisition of graphical contents in Image format
 */
//2002/08/07 Do_Ja1.5class MakeImage {

//2002/08/07 Do_Ja1.5    Image makeImage;
//2002/08/07 Do_Ja1.5    int labelCount = 1;

    /**
     * Creation of image objects
     */
//2002/08/07 Do_Ja1.5    MakeImage() {
//2002/08/07 Do_Ja1.5    }

    /**
     * Creation of images
     */
//2002/08/07 Do_Ja1.5    public Image create() {
        /* Create the image by 13*13 */
//2002/08/07 Do_Ja1.5        makeImage = Image.createImage(13, 13);

//2002/08/07 Do_Ja1.5        Graphics g = makeImage.getGraphics();
//2002/08/07 Do_Ja1.5        g.setColor(g.getColorOfName(Graphics.AQUA));
//2002/08/07 Do_Ja1.5        g.fillRect(0, 0, 12, 12);
//2002/08/07 Do_Ja1.5        g.setColor(g.getColorOfName(Graphics.RED));
//2002/08/07 Do_Ja1.5        g.drawString(((labelCount<10)?"0":"") + labelCount, 1, 11);
//2002/08/07 Do_Ja1.5        labelCount++;

//2002/08/07 Do_Ja1.5        return makeImage;
//2002/08/07 Do_Ja1.5    }
//2002/08/07 Do_Ja1.5}
