/**
 * J212_1201_0101
 * MainPanel
 *
 * Check behavior of TextBox class (behavior of UI boundary)
 *
 * $Id: J212_1201_0101.java,v 1.3 2002/04/11 04:21:37 takanao Exp $
 */

import com.nttdocomo.ui.*;
import java.lang.*;

/**
 * Main class for checking behavior of the TextBox class and the class
 * @extends IApplication
 */

public class J212_1201_0101 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the TextBox class and the class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1  31 pieces",
            "3 Over the display",

    };
    private TextBox[] textBox = new TextBox[30];
    private Button button = new Button(" execute ");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    public void showMainPanel() {

        
        /* Settings of display items */
        setTitle("Class operation UI boundary");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);

        for ( int i = 0; i < 30; i++ ) {
//J212_1201_0101
            textBox[i] = new TextBox("TextBox"+(i+1), 20, 1, TextBox.DISPLAY_ANY);
            add(textBox[i]);
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    /* Create NextPanel1 */
                    Display.setCurrent(new NextPanel1((Frame) this));
                    break;
                case 1:

                    textBox[0].setSize(255,255);
//J212_1202_0103
                    textBox[0].setText("\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63F\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63F\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E\uE63E");
                    break;

            }
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Call the addResult method when soft key2 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Add output to the textBox[0]
     * @param aMessage Output character strings
     */
    public void addResult(String aMessage) {
//J212_1202_0105
        textBox[0].setText(textBox[0].getText()+aMessage);
    }
}


/**
 * Sub screen1 for checking behavior of  ImageButton class
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel1 extends Panel implements SoftKeyListener{

    private Frame previousFrame = null;
    private TextBox[] textBox = new TextBox[31];

    /**
     * Constructor of NextPanel1
     * @param aPrev Object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;

        /* Settings of display items */
        setTitle("Class operation UI boundary");

        for ( int i = 0; i < 31; i++ ) {
//J212_1201_0102
            textBox[i] = new TextBox("TextBox"+(i+1), 20, 1, TextBox.DISPLAY_ANY);
            add(textBox[i]);
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}

