/**
 * J212_1401_0101
 * MainPanel
 *
 * Check behavior of the class (Behavior of UI boundary)
 *
 * $Id: J212_1401_0101.java,v 1.1 2002/02/04 07:28:46 t_yaeda Exp $
 */

import com.nttdocomo.ui.*;
import java.lang.*;

/**
 * Main class for checking behavior of the VisualPresenter class and the class
 * @extends IApplication
 */

public class J212_1401_0101 extends IApplication {
    
    /**
     * Appli startup method
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main screen for checking behavior of the VisualPresenter class and the class
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1  31 pieces",
            "2 No title",
            "3 With title",
            "4 Image of the size of the screen"
    };
    private VisualPresenter[] vp = new VisualPresenter[30];
    private Label[] label = new Label[30];
    private Button button = new Button(" execute ");


    /** 
     * Constructor of MainPanel
     */
    public MainPanel(){
        try{
            /* Display MainPanel */
            showMainPanel();
        }catch(Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }
    }
    
    /** 
     * Display a main panel
     */
    void showMainPanel(){
        /* Settings of display items */

        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);


        for ( int i = 0; i < 30; i++ ) {
            label[i] = new Label("VisualPresenter"+(i+1));
            add(label[i]);
            vp[i] = new VisualPresenter();
            vp[i].setBackground(Graphics.getColorOfName(Graphics.LIME));
            add(vp[i]);
        }


        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    /* Create NextPanel1 */
                    Display.setCurrent(new NextPanel1((Frame) this));
                    break;
                case 1:
                    /* Create NextPanel2 */
                    Display.setCurrent(new NextPanel2((Frame) this));
                    break;
                case 2:
                    /* Create NextPanel3 */
                    Display.setCurrent(new NextPanel3((Frame) this));
                    break;
                case 3:
                    /* Create NextPanel4 */
                    Display.setCurrent(new NextPanel4((Frame) this));
                    break;
            }
        }
    }


    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}

   
/**
 * Sub screen 1 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel1 extends Panel implements SoftKeyListener{

    private Frame previousFrame = null;
    private VisualPresenter[] vp = new VisualPresenter[31];
    private Label[] label = new Label[31];

    /**
     * Constructor of NextPanel1
     * @param aPrev Object of MainPanel
     */
    public NextPanel1(Frame aPrev) {
        previousFrame = aPrev;

        /* Settings of display items */
        setTitle("Class operation UI boundary");


        for ( int i = 0; i < 31; i++ ) {
            label[i] = new Label("VisualPresenter"+(i+1));
            add(label[i]);
            vp[i] = new VisualPresenter();
            vp[i].setBackground(Graphics.getColorOfName(Graphics.LIME));
            add(vp[i]);
        }


        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}


/**
 * Sub screen 2 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel2 extends Panel implements SoftKeyListener{

    private Frame previousFrame = null;
    private VisualPresenter vp = new VisualPresenter();
    private MediaImage mi = null;

    /**
     * Constructor of NextPanel2
     * @param aPrev Object of MainPanel
     */
    public NextPanel2(Frame aPrev) {
        previousFrame = aPrev;

        /* Settings of display items */
        add(vp);

        try {
            mi = MediaManager.getImage("resource:///heno.gif");
            mi.use();
            vp.setImage(mi);
            vp.play();
        } catch (Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}


/**
 * Sub screen 3 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel3 extends Panel implements SoftKeyListener{

    private Frame previousFrame = null;
    private VisualPresenter vp = new VisualPresenter();
    private MediaImage mi = null;

    /**
     * Constructor of NextPanel3
     * @param aPrev Object of MainPanel
     */
    public NextPanel3(Frame aPrev) {
        previousFrame = aPrev;

        /* Settings of display items */
        setTitle("Class operation UI boundary");
        add(vp);

        try {
            mi = MediaManager.getImage("resource:///heno.gif");
            mi.use();
            vp.setImage(mi);
            vp.play();
        } catch (Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}


/**
 * Sub screen 4 for checking behavior of the VisualPresenter class
 * @extends Panel
 * @implements SoftKeyListener
 */
class NextPanel4 extends Panel implements SoftKeyListener{

    private Frame previousFrame = null;
    private VisualPresenter vp = new VisualPresenter();
    private MediaImage mi = null;
    private Image img;
    private int sizeX = 0;
    private int sizeY = 0;


    /**
     * Constructor of NextPanel4
     * @param aPrev Object of MainPanel
     */
    public NextPanel4(Frame aPrev) {
        previousFrame = aPrev;

        /* Settings of display items */
        setTitle("Class operation UI boundary");
        add(vp);


        try {
            mi = MediaManager.getImage("resource:///honocolor.gif");
            mi.use();
            vp.setImage(mi);
            vp.play();
        } catch (Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}
