/**
 * J213_0101_0101
 * Check UI combination operations
 * Check scrolling operations
 *
 * $Id: J213_0101_0101.java,v 1.1 2002/02/01 07:24:47 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check UI combination operations
 * Check scrolling operations
 * @extends IApplication
 */
public class J213_0101_0101 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Check UI combination operations
 * Check scrolling operations
 * Main screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Menu, Selection of display type */
    String[] menuListItem1 = {
        "1. Default layout",
//2002/08/06 Do_Ja1.5        "2. HTML layout",
        "3. NULL layout",
//2002/08/06 Do_Ja1.5        "4. Layout change-over",
    };


    Label classLabel   = new Label();
    ListBox menuList1  = new ListBox(ListBox.CHOICE);
    Button  execButton = new Button("execute");

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    void showMainPanel() {

        /* Settings of display items */
        classLabel.setText("Check scrolling operations");
        setTitle("Behavior of combining UI");
        menuList1.setItems(menuListItem1);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Add each component to screen */
        add(classLabel);
        add(menuList1);
        add(execButton);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        /* In the case execute button is pressed */
        if (aComponent == execButton
            && aType == ComponentListener.BUTTON_PRESSED) {

            int menu1Index = menuList1.getSelectedIndex();
            Display.setCurrent(new SubPanel(menu1Index, this));
        }
    }
}

/**
 * Check UI combination operations
 * Check scrolling operations
 * Sub screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class SubPanel extends Panel implements SoftKeyListener, ComponentListener  {

    Frame prevFrame;
    Label subTitle = null;

    int menu1Index;
    boolean testFlag = true;

//2002/08/06 Do_Ja1.5    HTMLLayout htmlLayout = new HTMLLayout();

    /* Create each component */
    MediaImage imageObj;
    VisualPresenter vPresenterObj = new VisualPresenter();
    Ticker tickerObj = new Ticker("Ticker");
    TextBox textBoxObj = new TextBox("For checking scrolling", 16, 30, TextBox.DISPLAY_ANY);
    Button button = new Button("For checking scrolling");
    Button execButton = new Button("execute");

    /* Label for blank space */
    Label nullLabel1 = new Label();
    Label nullLabel2 = new Label();

    String vPImage = "resource:///89a4-1-1.gif";

    /**
     * Display a sub screen
     * @param anInt1  Sub division of test
     * @param aFrame  Main screen object
     */
    public SubPanel(int anInt1, Frame aFrame) {

        /* Object name setting */
        prevFrame = aFrame;
        menu1Index = anInt1;

        /* Get image from resource */
        imageObj = MediaManager.getImage(vPImage);

        /* Reading media */
        try {
            imageObj.use();
            vPresenterObj.setImage(imageObj);
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Image read error" + e.toString());
            errDialog.show();
        }

        try {
            /* Display sub panels */
            ShowSubPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    void ShowSubPanel() {

        switch(menu1Index) {
//J213_0101_0101
        case 0:
            /* Default layout */
            break;

//J213_0101_0102
//2002/08/06 Do_Ja1.5        case 1:
            /* HTML layout */
//2002/08/06 Do_Ja1.5            setLayoutManager(htmlLayout);
//2002/08/06 Do_Ja1.5            break;

//J213_0101_0103
//2002/08/06 Do_Ja1.5        case 2:
        case 1:
            /* NULL layout */
            setLayoutManager(null);
            button.setLocation(0,0);
            tickerObj.setLocation(0,18);
            nullLabel1.setLocation(0,35);
            vPresenterObj.setLocation(0,50);
            nullLabel2.setLocation(0,85);
            textBoxObj.setLocation(0,100);
            add(button);
            break;

//J213_0101_0201
//2002/08/06 Do_Ja1.5        case 3:
            /* Layout change-over */
//2002/08/06 Do_Ja1.5            setLayoutManager(htmlLayout);
//2002/08/06 Do_Ja1.5            add(execButton);
//2002/08/06 Do_Ja1.5            break;

        default:
            break;
        }

        /* Settings of display items */
        setTitle("Behavior of combining UI");
        nullLabel1.setSize(getWidth(), nullLabel1.getHeight());
        nullLabel2.setSize(getWidth(), nullLabel2.getHeight());

        add(tickerObj);
        add(nullLabel1);
        add(vPresenterObj);
        add(nullLabel2);
        add(textBoxObj);

        try {
            vPresenterObj.play();
        } catch(Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Image read error" + e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * When soft key is pressed, it does not operate
     * @param anIndex  The value of the soft key pressed
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * When soft key1 is released, the application ends
     * @param anIndex  The value of released soft key
     */
    public void softKeyReleased(int anIndex) {

        /* When soft key is released, the application ends */
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }

        /* execute test when soft key2 is released */
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(J213_0101_0101.mainPanel);
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == execButton ) {
            if(testFlag) {
                ChangeLayout cl = new ChangeLayout();
                Thread t1 = new Thread(cl);
                t1.start();
                testFlag = false;
            }
        }
    }

//J213_0101_0201
    /**
     * Class for execution of Threads
     * @implements Runnable
     */
    class ChangeLayout implements Runnable {
        int count = 0;

        /**
         * Constructor of ChangeLayout
         */
        public ChangeLayout() {}

        /**
         * Thread execution method
         */
        public void run() {
            try {
                while(count<100) {
                    Thread.sleep(1000);
                    switch(count%2) {
                        case 0:
                            setLayoutManager(null);
                            textBoxObj.setText("NULL layout");
                            break;
                        case 1:
//2002/08/06 Do_Ja1.5                            setLayoutManager(htmlLayout);
                            textBoxObj.setText("HTML layout");
                            break;
                    }
                    count++;
                }
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
                errDialog.setText("NG:" + e.toString());
                errDialog.show();
            }
        }
    }


}
