/**
 * J213_0201_0101
 * MainPanel
 *
 * Class operations(ShortTimer)
 *
 *
 * $Id:
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;
import java.lang.*;

/**
 * Class for checking behavior of the class (Timer-combining operations)
 * @extends IApplication
 */

public class J213_0201_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main class for checking behavior of the class (Timer-combining operations)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 Combine T and ST",
            "2 Combine T,ST and T"
    };
    private Button button = new Button(" execute ");


    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    public void showMainPanel() {

        /* Settings of display items */
        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch ( menuList.getSelectedIndex() ) {
                case 0:
                    /* Creation of TimerCanvas */
                    Display.setCurrent(new TimerCanvas(this));
                    break;
                case 1:
                    /* Creation of TimerCanvas2 */
                    Display.setCurrent(new TimerCanvas2(this));
                    break;
            }
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}


/**
 * Sub class for checking behavior of the class (Timer-combining operations)1
 * @extends Canvas
 * @implements Runnable
 */
class TimerCanvas extends Canvas implements Runnable{
    private Frame previousFrame = null;
    private int count = 0;
    private int count2 = 0;
    private ShortTimer st1;
    private Timer timer = new Timer();
    static final int TIMER_INTERVAL = 1000;

    /**
     * Constructor of TimerCanvas
     * @param aPrev Object of MainPanel
     */
    TimerCanvas( Frame aPrev ) {
        previousFrame = aPrev;

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    
    }


    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Timer ", 5, 20);
        g.drawString("Count: "+(count), 10, 40);
        g.drawString("ShortTimer ", 5, 60);
        g.drawString("Count: "+(count2), 10, 80);
    }


    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {

        /* Timer event */
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            count2++;
            repaint();
        }

        
        /* Key event */
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    timer.setTime(TIMER_INTERVAL);
                    timer.setRepeat(true);
                    timer.setListener(new TimerListener() {
                            public void timerExpired(Timer t) {
                                if (t == timer) {
                                    count++;
                                    repaint();
                                }
                            }
                    });
                    st1 = ShortTimer.getShortTimer(this,0,1000,true);
                    Thread t1 = new Thread(this);
//J213_0201_0101
                    t1.start();
                    try {
                        Thread.sleep(500);
                    } catch ( Exception e ){}
                    timer.start();
                    break;
                

                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }

    /**
     * Thread execution method
     */
    public void run() {
        st1.start();
    }
}


/**
 * Sub class for checking behavior of the class (Timer-combining operations)2
 * @extends Canvas
 * @implements Runnable
 */
class TimerCanvas2 extends Canvas implements Runnable{
    private Frame previousFrame = null;
    private int count = 0;
    private int count2 = 0;
    private ShortTimer st1;
    private Timer timer = new Timer();
    static final int TIMER_INTERVAL = 5000;
    TestTimer tt = new TestTimer();

    /**
     * Constructor of TimerCanvas2
     * @param aPrev Object of MainPanel
     */
    TimerCanvas2( Frame aPrev ) {
        previousFrame = aPrev;

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    
    }


    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Timer ", 5, 20);
        g.drawString("Count: "+(count), 10, 40);
        g.drawString("ShortTimer ", 5, 60);
        g.drawString("Count: "+(count2), 10, 80);
        g.drawString("Thread ", 5, 100);
        g.drawString("Count: "+(tt.count3), 10, 120);
    }


    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {

        /* Timer event */
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            count2++;
            repaint();
        }

        
        /* Key event */
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
//J213_0201_0201
                    timer.setTime(TIMER_INTERVAL);
                    timer.setRepeat(true);
                    timer.setListener(new TimerListener() {
                            public void timerExpired(Timer t) {
                                if (t == timer) {
                                    count++;
                                    repaint();
                                }
                            }
                    });
                    Thread t1 = new Thread(this);
                    Thread t2 = new Thread(tt);
                    st1 = ShortTimer.getShortTimer(this,0,5000,true);
                    t1.start();
                    t2.start();
                    timer.start();
                    break;
                

                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }

    /**
     * Thread execution method
     */
    public void run() {
        st1.start();
    }
}


/**
 * Short timer creating class
 */
class TestTimer implements Runnable{
    
    int count3;

    /**
     * Thread execution method
     */
    public void run() {
        while( count3 < 100 ) {
            try {
                Thread.sleep(5000);
            } catch ( Exception e ) {}
            count3++;
        }
    }
}