/**
 * J213_0202_0101
 * MainPanel
 *
 * Class operations(ShortTimer)
 *
 *
 * $Id:
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;
import java.lang.*;

/**
 * Class for checking behavior of the class (Timer-combining operations)
 * @extends IApplication
 */

public class J213_0202_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * Main class for checking behavior of the class (Timer-combining operations)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private  String[] menuListItem = {
            "1 STCanvas",
            "2 TCanvas",
            "3 TPanel"
    };
    private Button button = new Button(" execute ");


    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {
        try {
            /* Main panel display */
            showMainPanel();
        } catch (Exception e) {
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
            errDialog.setText("Error:" + e.toString());
            errDialog.show();
        }
    }

    /**
     * Display a main panel
     */
    public void showMainPanel() {

        /* Settings of display items */
        setTitle("Check behavior of the class");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch ( menuList.getSelectedIndex() ) {
                case 0:
                    /* Creation of TimerCanvas */
                    Display.setCurrent(new TimerCanvas(this));
                    break;
                case 1:
                    /* Creation of TimerCanvas2 */
                    Display.setCurrent(new TimerCanvas2(this));
                    break;
                case 2:
                    /* Creation of TimerCanvas3 */
                    Display.setCurrent(new TimerPanel(this));
                    break;
            }
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}


/**
 * Sub class for checking behavior of the class (Timer-combining operations)1
 * @extends Canvas
 */
class TimerCanvas extends Canvas{
    private Frame previousFrame = null;
    private int count = 0;
    private int count2 = 0;
    private ShortTimer st1;

    /**
     * Constructor of TimerCanvas
     * @param aPrev Object of MainPanel
     */
    TimerCanvas( Frame aPrev ) {
        previousFrame = aPrev;

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    
    }


    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("ShortTimer1 ", 5, 20);
        g.drawString("Count: "+(count), 10, 40);
        g.drawString("ShortTimer2 ", 5, 60);
        g.drawString("Count: "+(count2), 10, 80);
    }


    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {

        /* Timer event */
        if ( aType == Display.TIMER_EXPIRED_EVENT ) {
            if ( aParam == 0 ) {
                count++;
            } else if ( aParam == 1 ) {
                count2++;
            }
            repaint();
        }

        
        /* Key event */
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    TestCanvas tc = new TestCanvas(this);
                    st1 = ShortTimer.getShortTimer(this,0,1000,true);
                    st1.start();
                    tc.test();
                    break;
                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }
}


/**
 * Test class for checking behavior of the class (Timer-combining operations)1
 * @extends Canvas
 */
class TestCanvas extends Canvas {
    private Frame previousFrame = null;
    private int count = 0;
    private int count2 = 0;
    private ShortTimer st1;

    /**
     * Constructor of TestCanvas
     * @param aPrev Object of MainPanel
     */
    TestCanvas( Frame aPrev) {
        previousFrame = aPrev;
    }

    public void test(){
//J213_0202_0101
        st1 = ShortTimer.getShortTimer(this,1,1000,true);
        st1.start();
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){}
}
    

/**
 * Sub class for checking behavior of the class (Timer-combining operations)2
 * @extends Canvas
 */
class TimerCanvas2 extends Canvas{
    private Frame previousFrame = null;
    private Timer timer;
    static final int TIMER_INTERVAL = 1000;
    private String s1 = "";

    /**
     * Constructor of TimerCanvas2
     * @param aPrev Object of MainPanel
     */
    TimerCanvas2( Frame aPrev ) {
        previousFrame = aPrev;

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1, "Start");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
    
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){
        g.clearRect(0,0,getWidth(), getHeight());
        g.drawString("Timer1 ", 5, 20);
        g.drawString("Count: "+(s1), 10, 40);
    }

    /**
     * Event acceptance method
     * @param type  Event type
     * @param param  parameter of an event
     */
    public void processEvent(int aType, int aParam) {
        if ( aType == Display.KEY_RELEASED_EVENT ) {
            switch ( aParam ) {
                case Display.KEY_SOFT1:
                    TestCanvas2 tp = new TestCanvas2(this);
                    tp.test();
                    timer = new Timer();
                    timer.setTime(TIMER_INTERVAL);
                    timer.setRepeat(true);
                    timer.setListener(new TimerListener() {
                        public void timerExpired(Timer t) {
                            if (t == timer) {
                                s1 = "start";
                                repaint();
                            }
                        }
                    });
                    timer.start();
                    break;

                /* When Return is pressed */
                case Display.KEY_SOFT2:
                    /* Return to Main menu screen */
                    Display.setCurrent(previousFrame);
                    break;
            }
        }
    }
}


/**
 * Test class for checking behavior of the class (Timer-combining operations)2
 * @extends Canvas
 */
class TestCanvas2 extends Canvas {

    private Frame previousFrame = null;
    private Timer timer = new Timer();
    static final int TIMER_INTERVAL = 1;
    private boolean flag = false;
    private AudioPresenter ap = null;

    /**
     * Constructor of TestCanvas2
     * @param aPrev Object of MainPanel
     */
    TestCanvas2( Frame aPrev) {
        previousFrame = aPrev;
    }

    /**
     * Method to execute the test
     */
    public void test(){
        try {
            ap = AudioPresenter.getAudioPresenter();
            MediaSound ms = MediaManager.getSound("resource:///mfi.mld");
            ms.use();
            ap.setSound(ms);
        }catch(Exception e){
            Dialog errDialog2 = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog2.setText("Error:" +e.toString());
            errDialog2.show();
        }

        timer.setTime(TIMER_INTERVAL);
        timer.setRepeat(false);
        timer.setListener(new TimerListener() {
            public void timerExpired(Timer t) {
                if (t == timer) {
                        ap.play();
                }
            }
        });
        timer.start();
    }

    /**
     * implement the paint() method
     * @param g  Graphics object of Canvas
     */
    public void paint(Graphics g){}
}
    

/**
 * Sub class for checking behavior of the class (Timer-combining operations)3
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class TimerPanel extends Panel implements SoftKeyListener, ComponentListener {
    private Frame previousFrame = null;
    private Timer timer;
    static final int TIMER_INTERVAL = 1000;
    private Label label = new Label(" TimerStart:");
    private Button button = new Button(" execute ");

    /**
     * Constructor of TimerPanel
     * @param aPrev Object of MainPanel
     */
    TimerPanel( Frame aPrev ) {
        previousFrame = aPrev;

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setSoftLabel(Frame.SOFT_KEY_2, "back");
        
        add(button);
        add(label);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            TestPanel tp = new TestPanel(this);
            tp.test();
            timer = new Timer();
            timer.setTime(TIMER_INTERVAL);
            timer.setRepeat(true);
            timer.setListener(new TimerListener() {
                public void timerExpired(Timer t) {
                    if (t == timer) {
//J213_0202_0201
                        label.setText( " TimerStart : start" );
                    }
                }
            });
            timer.start();
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param anIndex Key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * Terminate appli when soft key1 is released
     * Return to the previous screen when soft key2 is released.
     * @param anIndex Key index
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (anIndex == Frame.SOFT_KEY_2) {
            Display.setCurrent(previousFrame);
        }
    }
}    

/**
 * Test class for checking behavior of the class (Timer-combining operations)2
 * @extends Panel
 */
class TestPanel extends Panel {

    private Frame previousFrame = null;
    private Timer timer = new Timer();
    static final int TIMER_INTERVAL = 1;
    private boolean flag = false;
    private AudioPresenter ap = null;

    /**
     * Constructor of TestPanel
     * @param aPrev Object of MainPanel
     */
    TestPanel( Frame aPrev) {
        previousFrame = aPrev;
    }

    /**
     * Method to execute the test
     */
    public void test(){
        try {
            ap = AudioPresenter.getAudioPresenter();
            MediaSound ms = MediaManager.getSound("resource:///mfi.mld");
            ms.use();
            ap.setSound(ms);
        }catch(Exception e){
            Dialog errDialog2 = new Dialog(Dialog.DIALOG_ERROR,"Error");
            errDialog2.setText("Error:" +e.toString());
            errDialog2.show();
        }

        timer.setTime(TIMER_INTERVAL);
        timer.setRepeat(false);
        timer.setListener(new TimerListener() {
            public void timerExpired(Timer t) {
                if (t == timer) {
//J213_0202_0202
                        ap.play();
                }
            }
        });
        timer.start();
    }

}
