/**
 * J213_0301_0104
 * Check UI combination operations
 * Check behavior of the background process
 * High level component - SSL
 *
 * $Id: J213_0301_0104.java,v 1.2 2002/03/29 02:55:37 takanao Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check UI combination operations
 * Check behavior of the background process
 * High level component - SSL
 * @extends IApplication
 */
public class J213_0301_0104 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }


    /**
     * Check UI combination operations
     * Check behavior of the background process
     * High level component - SSL
     * Main screen
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

        /* Menu, Selection of display type */
        String[] menuListItem1 = {
            "1.Animation being processed",
            "2.Sound replay being processed",
        };


        Label classLabel   = new Label();
        ListBox menuList1  = new ListBox(ListBox.CHOICE);
        Button  execButton = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            try {
                /* Main panel display */
                showMainPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        /**
         * Display a main panel
         */
        void showMainPanel() {

            /* Settings of display items */
            classLabel.setText("Check behavior of BG process");
            setTitle("Behavior of combining UI");
            menuList1.setItems(menuListItem1);
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(classLabel);
            add(menuList1);
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                int menu1Index = menuList1.getSelectedIndex();
                Display.setCurrent(new SubPanel(menu1Index, this));
            }
        }
    }

    /**
     * Check UI combination operations
     * Check behavior of the background process
     * High level component - SSL
     * Sub screen
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class SubPanel extends Panel implements SoftKeyListener, ComponentListener  {

        Frame prevFrame;
        Label subTitle = new Label();

        int menu1Index;
        boolean testFlag = true;

        /* Create each component */
        MediaImage imageObj;
        MediaSound soundObj;
        MediaImage addImageObj;
        VisualPresenter vPresenterObj = new VisualPresenter();
        AudioPresenter aPresenterObj = AudioPresenter.getAudioPresenter(); 
        Ticker tickerObj = new Ticker("Ticker");
        TextBox textBoxObj = new TextBox("", 16, 2, TextBox.DISPLAY_ANY);
        Button execButton = new Button("execute");

        ImageLabel imageLabelObj = new ImageLabel();

        String addImagePath = getSourceURL() + "blue.gif";
        String vPImagePath = "resource:///89a4-1-1.gif";
        String aPSoundPath = "resource:///mfi.mld";

        /**
         * Display a sub screen
         * @param anInt1  Sub division of test
         * @param aFrame  Main screen object
         */
        public SubPanel(int anInt1, Frame aFrame) {

            /* Object name setting */
            prevFrame = aFrame;
            menu1Index = anInt1;

            switch(menu1Index) {
                case 0:
                    /* Get image from resource */
                    imageObj = MediaManager.getImage(vPImagePath);

                    /* Reading media */
                    try {
                        imageObj.use();
                        vPresenterObj.setImage(imageObj);
                    } catch (Exception e) {
                        Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                        errDialog.setText("Image read error" + e.toString());
                        errDialog.show();
                    }
                    break;
                case 1:
                    /* Get sound data from the resource */
                    soundObj = MediaManager.getSound(aPSoundPath);

                    /* Reading media */
                    try {
                        soundObj.use();
                        aPresenterObj.setSound(soundObj);
                    } catch (Exception e) {
                        Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                        errDialog.setText("Sound read error" + e.toString());
                        errDialog.show();
                    }
                    break;
                default:
            }

            try {
                /* Display sub panels */
                ShowSubPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        void ShowSubPanel() {

            /* Settings of display items */
            setTitle("Behavior of combining UI");
            add(subTitle);

            switch(menu1Index) {
//J213_0301_0104
            case 0:
                subTitle.setText("Replay animation");
                add(vPresenterObj);
                add(tickerObj);

                try {
                    vPresenterObj.play();
                } catch(Exception e) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Image play error" + e.toString());
                    errDialog.show();
                }

                break;

//J213_0301_0204
            case 1:
                subTitle.setText("Replay sound");
                try {
                    aPresenterObj.play();
                } catch(Exception e) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                    errDialog.setText("Sound play error" + e.toString());
                    errDialog.show();
                }
                break;

            default:
                break;
            }

            subTitle.setSize(getWidth(), subTitle.getHeight());
            add(textBoxObj);
            add(execButton);


            setSoftLabel(Frame.SOFT_KEY_1, "exit");
            setSoftLabel(Frame.SOFT_KEY_2, "back");

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }

            /* execute test when soft key2 is released */
            if (anIndex == Frame.SOFT_KEY_2) {
                Display.setCurrent(J213_0301_0104.mainPanel);
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            if ( aComponent == execButton ) {
                if(testFlag) {
                    try {
                        /* Read data */
                        addImageObj = MediaManager.getImage(addImagePath);
                        addImageObj.use();
                        imageLabelObj.setImage(addImageObj.getImage());
                    } catch (Exception e) {
                        Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                        errDialog.setText("Image read error" + e.toString());
                        errDialog.show();
                    }
                    add(imageLabelObj);
                    textBoxObj.setText("OK");
                }
            }
        }
    }
}
