/**
 * J213_0302_0103
 * Check UI combination operations
 * Check behavior of the background process
 * Low level component - HTTP
 *
 * $Id: J213_0302_0103.java,v 1.1 2002/02/01 07:25:06 uruno Exp $
 */
import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Check UI combination operations
 * Check behavior of the background process
 * Low level component - HTTP
 * @extends IApplication
 */
public class J213_0302_0103 extends IApplication {

    static MainPanel mainPanel;

    /**
     * Overview of functions  :Startup method of i-appli
     */
    public void start() {
        mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }

    /**
     * Check UI combination operations
     * Check behavior of the background process
     * Low level component - HTTP
     * Main screen
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

        /* Menu, Selection of display type */
        String[] menuListItem1 = {
            "1.Graphics being processed",
        };


        Label classLabel   = new Label();
        ListBox menuList1  = new ListBox(ListBox.CHOICE);
        Button  execButton = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            try {
                /* Main panel display */
                showMainPanel();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Error:" + e.toString());
                errDialog.show();
            }
        }

        /**
         * Display a main panel
         */
        void showMainPanel() {

            /* Settings of display items */
            classLabel.setText("Check behavior of BG process");
            setTitle("Behavior of combining UI");
            menuList1.setItems(menuListItem1);
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(classLabel);
            add(menuList1);
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }

        /**
         * When soft key is pressed, it does not operate
         * @param anIndex  The value of the soft key pressed
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key1 is released, the application ends
         * @param anIndex  The value of released soft key
         */
        public void softKeyReleased(int anIndex) {

            /* When soft key is released, the application ends */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent, int aType, int aParam) {

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {

                int menu1Index = menuList1.getSelectedIndex();
                Display.setCurrent(new SubPanel(menu1Index, this));
            }
        }
    }

    /**
     * Check UI combination operations
     * Check behavior of the background process
     * High level component - HTTP
     * Sub screen
     * @extends Canvas
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class SubPanel extends Canvas {

        int menu1Index;
        int testFlag = 0;
        int paintCount = 0;

        /* Create each component */
        MediaImage addImageObj;
        TextBox textBoxObj = new TextBox("", 16, 2, TextBox.DISPLAY_ANY);

        String addImagePath = getSourceURL() + "blue.gif";

        /**
         * Display a sub screen
         * @param anInt1  Sub division of test
         * @param aFrame  Main screen object
         */
        public SubPanel(int anInt1, Frame aFrame) {

            /* Object name setting */
            menu1Index = anInt1;

            /* Settings of display items */
            setSoftLabel(Canvas.SOFT_KEY_1, "exit");
            setSoftLabel(Canvas.SOFT_KEY_2, "Start");
        }

        /**
         * Drawing into Canvas
         * @param aGraphics Depiction object
         */
        public void paint(Graphics aGraphics) {
            aGraphics.drawString("Canvas screen", 10, 20);
            aGraphics.drawString("repaint -> " + paintCount++ + "Time", 10, 40);
        }

        /**
         * Types of events
         * @param type type of an event
         * @param param  parameter of an event
         */
        public void processEvent(int type, int param) {
        
            /* When soft key is released, the application ends */
            if(type == Display.KEY_RELEASED_EVENT) {
                switch(param){

                    /* When soft key is released, the application ends */
                    case Display.KEY_SOFT1:
                        IApplication.getCurrentApp().terminate();
                        break;

                    case Display.KEY_SOFT2:
                        switch(testFlag) {
                        case 0:
                            RequestRepaint rr = new RequestRepaint();
                            Thread t1 = new Thread(rr);
                            t1.start();
                            setSoftLabel(Canvas.SOFT_KEY_2, "execute");
                            break;
//J213_0302_0103
                        case 1:
                            test();
                            setSoftLabel(Canvas.SOFT_KEY_2, "back");
                            break;
                        case 2:
                            Display.setCurrent(J213_0302_0103.mainPanel);
                            break;
                        default:
                            break;
                        }
                        testFlag++;
                        break;
                }
            }
        }

        /**
         * Class for execution of Threads
         * @implements Runnable
         */
        class RequestRepaint implements Runnable {
            int count = 0;

            /**
             * Constructor of RequestRepaint
             */
            public RequestRepaint() {}

            /**
             * Thread execution method
             */
            public void run() {
                try {
                    while(count<1000) {
                        Thread.sleep(100);
                        Graphics g = getGraphics();
                        g.clearRect(5,28,115,15);
                        repaint();
                        count++;
                    }
                } catch (Exception e) {
                    Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"Error");
                    errDialog.setText("NG:" + e.toString());
                    errDialog.show();
                }
            }
        }

        /**
         * Execution of a test
         */
        public void test() {
            /* Reading media */
            try {
                /* Read data */
                addImageObj = MediaManager.getImage(addImagePath);
                addImageObj.use();

                Graphics g = getGraphics();
                g.drawImage(addImageObj.getImage(), 10, 50);
                g.drawString("OK", 20 + addImageObj.getWidth(), 70);
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error");
                errDialog.setText("Image read error" + e.toString());
                errDialog.show();
            }
        }
    }
}
