/**
 * J221_0101_0401
 *
 * Check the setting of auto-startup
 *
 * $Id: J221_0101_0401.java,v 1.1 2001/12/29 01:45:18 takanao Exp $
 */

import java.io.*;
import java.util.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;

/**
 * Main class of checking the setting of auto-startup
 * @extends IApplication
 */
public class J221_0101_0401 extends IApplication {

    MainPanel testPanel = new MainPanel();

    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * Confirmation screen for auto-startup setting
 * @extends Panel
 * @implements SoftKeyListener
 */
class MainPanel extends Panel implements SoftKeyListener {

    /* Definition of GUI components */
    TextBox currentBox = new TextBox(null, 16, 1, TextBox.DISPLAY_ANY);
    TextBox resultBox = new TextBox(null, 16, 4, TextBox.DISPLAY_ANY);

    /* Logs of the startup time (10 of them) */
    final static int LOG_MAX = 10;
    long[] lastLaunch = null;

    /**
     * Create panel (Constructor of Panel)
     */
    public MainPanel() {

        /* GUI settings */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("Auto-startup"+IApplication.getCurrentApp().getArgs()[0]);

        /* GUI location */
        add(new Label("This time's startup time"));
        add(currentBox);
        add(new Label("Previous time's startup time"));
        add(resultBox);

        /* Listener setting */
        this.setSoftKeyListener(this);

        try {
            /* Measure the startup time */
            long currentTime = System.currentTimeMillis();
            
            /* Get the startup time logs so far from the Scratchpad */
            lastLaunch = loadTime();
            
            /* Rotate logs */
            for (int i=lastLaunch.length-1; i>0; i--) {
                lastLaunch[i] = lastLaunch[i-1];
            }
            lastLaunch[0] = currentTime;
            
            /* Save logs in the Scratchpad */
            storeTime(lastLaunch);
            
            /* Get the startup time and old logs */
            currentBox.setText(convertTime(currentTime));
            for (int i=1; i<lastLaunch.length; i++) {
                resultBox.setText(resultBox.getText()+convertTime(lastLaunch[i])+"\n");
            }
        } catch (Exception e) {
            Dialog infoDialog = new Dialog(Dialog.DIALOG_INFO, "info");
            infoDialog.setText("Failed"+e.getClass().getName());
            infoDialog.show();
        }
    }

    /**
     * Soft key handler
     * @param aKey Pressed key
     */
    public void softKeyPressed(int aKey) {}

    /**
     * Soft key handler
     * @param aKey Released key
     */
    public void softKeyReleased(int aKey) {
        /* When soft key1 is released, end the application */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Convert the system time to a string
     * @param aTime Returned value of System.getTimeMillis
     * @return Time in string format
     */
    public String convertTime(long aTime) {
        Calendar cal = Calendar.getInstance();
        cal.setTimeZone(TimeZone.getTimeZone("JST"));
        cal.setTime(new Date(aTime));
        int hour = cal.get(Calendar.HOUR_OF_DAY);
        int min = cal.get(Calendar.MINUTE);
        int sec = cal.get(Calendar.SECOND);
        return ((hour<10) ? "0" : "") + hour + ":" +
            ((min<10) ? "0" : "") + min + ":" +
            ((sec<10) ? "0" : "") + sec;
    }

    /**
     * Get Long data from the Scratchpad
     * @return Alignment of the old logs in long format
     */
    public long[] loadTime() {
        long[] timeList = new long[LOG_MAX];
        DataInputStream dis = null;
        try {
            dis = Connector.openDataInputStream("scratchpad:///0");
            for (int i=0; i<timeList.length; i++) {
                timeList[i] = dis.readLong();
            }
            dis.close();
        } catch (IOException ioe) {
            Dialog infoDialog = new Dialog(Dialog.DIALOG_INFO, "Info");
            infoDialog.setText("SP's read error:"+ioe.getClass().getName());
            infoDialog.show();
        }
        return timeList;
    }

    /**
     * Store Long data into Scratchpad
     * @param timeList Alignment of the old logs in long format
     */
    public void storeTime(long[] timeList) {
        DataOutputStream dos = null;
        try {
            dos = Connector.openDataOutputStream("scratchpad:///0");
            for (int i=0; i<timeList.length; i++) {
                dos.writeLong(timeList[i]);
            }
            dos.close();
        } catch (IOException ioe) {
            Dialog infoDialog = new Dialog(Dialog.DIALOG_INFO, "Info");
            infoDialog.setText("SP's read error:"+ioe.getClass().getName());
            infoDialog.show();
        }
    }
}
