/**
 * J221_0403_0201.java
 * Recovery operation for mobile terminal setting
 * J221_0403_0201
 * 
 * $Id: J221_0403_0201.java,v 1.1 2002/01/07 01:57:20 hoshi Exp $
*/

import com.nttdocomo.lang.*;
import java.util.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Main class for recovery operation for mobile terminal setting
 * @extends IApplication
 */
public class J221_0403_0201 extends IApplication {
    public void start() {
        MainPanel mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Main class for recovery operation for mobile terminal setting
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener {

    /* Creation of message dialog (error/Information) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"error");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "info");

    /* execute button */
    Button execButton = null;

    /* Create menu for selecting process */
    ListBox mainMenu = new ListBox(ListBox.CHOICE,4);

    /* Menu item for selecting process */
    String[] mainItem = {
        "0. Back light",
        "1. Vibrator",
    };

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {

        try {
            showMainPanel();
        } catch(Exception e) {
            err.setText("Exception:" + e.toString());
        } catch(Error e) {
            err.setText("Error" + e.toString());
        }

    }

    /**
     * Display main screen for recovery operation for mobile terminal setting
     */
    public void showMainPanel() {

        /* Display title */
        setTitle("JAM-JVM");

        /* Display sub title */
        Label subTitle = new Label("Recovery operation for mobile terminal setting");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);

        /* Text box for displaying test result */
        TextBox resultTextBox = new TextBox("", getWidth(), 3, 
                                                TextBox.DISPLAY_ANY);
        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* Setting of the main menu */
        mainMenu.setItems(mainItem);

        /* Setting of the execute button */
        execButton = new Button("execute");

        /* Add component to the screen */
        add(mainMenu);
        add(execButton);
        add(resultTextBox);

    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * softKeyReleased
     * When soft key 1 is released, end the application
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        /* Completed when soft key 1 is released */
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aPram) {

        /* Transit to the screen that is compliant with menu by pressing execute button */
        if ( aComponent == execButton
             && aType == BUTTON_PRESSED ) {
            Display.setCurrent(new testPanel(mainMenu.getSelectedIndex(),
                this));
        }
    }
}               


/**
 * Class of screen for checking behavior of mobile terminal priority setting
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class testPanel extends Panel implements SoftKeyListener, ComponentListener {

    boolean buttonFlg = true;
    Button aButton;
    Button bButton;
    Button cButton;

    /* Creation of message dialog (error/Information) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"error");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "info");

    /* Variable in order to return to the previous screen */
    Frame previousFrame = null;

    /* Text box for displaying test result */
    TextBox resultTextBox = new TextBox("", getWidth(), 3, TextBox.DISPLAY_ANY);
    /**
     * Constructor of testPanel class
     * @param aType  Location of items of Menu
     * @param aFrame  Screen
     */
    public testPanel(int aType, Frame aFrame) {

        /* Assign the previous screen */
        previousFrame = aFrame;

        /* Display title */
        setTitle("JAM-JVM");
        Label subTitle = new Label("");
        aButton = new Button("   on   ");
        bButton = new Button("   off   ");
        cButton = new Button("   on   ");

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");
        setSoftLabel(Frame.SOFT_KEY_2,"back");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* Add component to the screen */
        add(subTitle);
        add(resultTextBox);

        switch (aType) {
        /* Back light */
        // J221_0403_0201
        case 0:
            subTitle.setText("   Back light   ");
            resultTextBox.setText("Change the back light setting.");
            add(aButton);
            add(bButton);
            break;
        /* Vibrator */
        // J221_0403_0202
        case 1:
            buttonFlg = false;
            subTitle.setText("   Vibrator   ");
            resultTextBox.setText("Change the vibrator setting.");
            add(cButton);
            break;

        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aPram) {

        if ( aComponent == aButton && aType == BUTTON_PRESSED) {
                PhoneSystem.setAttribute(0,1);
                
        } else if ( aComponent == bButton && aType == BUTTON_PRESSED) {
                PhoneSystem.setAttribute(0,0);
        } else if ( aComponent == cButton && aType == BUTTON_PRESSED) {
                PhoneSystem.setAttribute(1,1);
            resultTextBox.setText("Vibrator setting turned on.");
        }
    }

    /**
     * When soft key is pressed, do not carry out any operations.
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Define the behavior for the case soft key being released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
        if (aSoftKey == Frame.SOFT_KEY_2) {
            if ( previousFrame != null ) {
                Display.setCurrent(previousFrame);
            }
        }
    }
}
