/**
 * J221_0404_0101
 *
 * Check restriction of package access
 *
 * $Id: J221_0404_0101.java,v 1.1 2001/12/29 01:45:36 takanao Exp $
 */

import com.nttdocomo.ui.*;

/**
 * Main class for checking restriction of package access
 * @extends IApplication
 */

public class J221_0404_0101 extends IApplication {

    MainPanel testPanel = new MainPanel();

    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * Menu screen for checking restriction of access
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    String[] menuItem = {
        "Restrict java",
        "Restrict javax.microedition",
        "Restrict nttdocomo",
    };

    /* Definition of GUI components */
    TextBox resultBox = new TextBox(null, 16, 16, TextBox.DISPLAY_ANY);
    ListBox menuList = new ListBox(ListBox.CHOICE);
    Button processButton = new Button("execute");

    /**
     * Create panel (Constructor of Panel)
     */
    public MainPanel() {

        /* GUI settings */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("Check the access restriction");
        menuList.setItems(menuItem);

        /* GUI location */
        add(menuList);
        add(processButton);
        add(resultBox);

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /** 
     * Soft key handler
     * @param aKey Pressed key
     */
    public void softKeyPressed(int aKey) {}

    /** 
     * Soft key handler
     * @param aKey Released key
     */
    public void softKeyReleased(int aKey) {
        /* When soft key1 is released, end the application */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Component event
     * @param aComponent Event occurrence component
     * @param aType Event type
     * @param aParam Event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if (aType == ComponentListener.BUTTON_PRESSED && aComponent == processButton) {
            int index = menuList.getSelectedIndex();
            if (index >= 0) {
                try {
                    doTest(index);
                } catch (Exception e) {
                    Dialog infoDialog = new Dialog(Dialog.DIALOG_INFO, "info");
                    infoDialog.setText("Exceptions outside the test:"+e.getClass().getName());
                    infoDialog.show();
                }
            }
        }
    }

    /**
     * Add texts to the text box for result
     * @param aText Additional texts
     */
    public void addResult(String aText) {
        resultBox.setText(resultBox.getText() + aText);
    }

    /**
     * Test
     * @param aNumber Test number
     */
    public void doTest(int aNumber) {

        resultBox.setText(menuItem[aNumber]+"\n");

        switch (aNumber) {

        // J221_0404_0101
        case 0:
            try {
                java.original.orig1.isClassMethod();
                addResult("Class method: access");
            } catch (Throwable t) {
                addResult("Class method: OK["+t.getClass().getName()+"]");
            }
            addResult("\n");
            try {
                java.original.orig1 notAccess = new java.original.orig1();
                notAccess.isClassMethod();
                addResult("Instant method: access");
            } catch (Throwable t) {
                addResult("Instant method: OK"+t.getClass().getName()+"]");
            }
            break;

        // J221_0404_0102
        case 1:
            try {
                javax.microedition.original.orig2.isClassMethod();
                addResult("Class method: access");
            } catch (Throwable t) {
                addResult("Class method: OK["+t.getClass().getName()+"]");
            }
            addResult("\n");
            try {
                javax.microedition.original.orig2 notAccess = new javax.microedition.original.orig2();
                notAccess.isClassMethod();
                addResult("Instant method: access");
            } catch (Throwable t) {
                addResult("Instant method: OK"+t.getClass().getName()+"]");
            }
            break;

        // J221_0404_0103
        case 2:
            try {
                com.nttdocomo.original.orig3.isClassMethod();
                addResult("Class method: access");
            } catch (Throwable t) {
                addResult("Class method: OK["+t.getClass().getName()+"]");
            }
            addResult("\n");
            try {
                com.nttdocomo.original.orig3 notAccess = new com.nttdocomo.original.orig3();
                notAccess.isClassMethod();
                addResult("Instant method: access");
            } catch (Throwable t) {
                addResult("Instant method: OK"+t.getClass().getName()+"]");
            }
            break;

        default:
            break;
        }
    }
}
