/**
 * J221_0405_0201.java
 * Check behavior of CLDC timer
 * J221_0405_0201
 * 
 * $Id: J221_0405_0201.java,v 1.2 2002/02/13 02:22:21 lan Exp $
*/

import java.util.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Main class for checking behavior of CLDC timer
 * @extends IApplication
 */
public class J221_0405_0201 extends IApplication {
    public void start() {
        MainPanel mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Main class for checking behavior of CLDC timer
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener {

    /* Creation of message dialog (error/Information) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"error");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "info");

    /* execute button */
    Button execButton = null;

    /* Text box for displaying test result */
    TextBox resultTextBox = new TextBox("", getWidth(), 3, 
                                                TextBox.DISPLAY_ANY);
    /* Create menu for selecting process */
    ListBox mainMenu = new ListBox(ListBox.CHOICE,4);

    /* Menu item for selecting process */
    String[] mainItem = {
        "0. Get the time",
        "1. Time zone",
    };

    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {

        try {
            showMainPanel();
        } catch(Exception e) {
            err.setText("Exception:" + e.toString());
        } catch(Error e) {
            err.setText("Error" + e.toString());
        }
    }

    /**
     * Display main screen for checking behavior of CLDC timer
     */
    public void showMainPanel() {

        /* Display title */
        setTitle("JAM-JVM");

        /* Display sub title */
        Label subTitle = new Label("CLDC timer operations");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* Setting of the main menu */
        mainMenu.setItems(mainItem);

        /* Setting of the execute button */
        execButton = new Button("execute");

        /* Add component to the screen */
        add(mainMenu);
        add(execButton);
        add(resultTextBox);

    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * softKeyReleased
     * When soft key 1 is released, end the application
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        /* Completed when soft key 1 is released */
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aPram) {

        /* Transit to the screen that is compliant with menu by pressing execute button */
        if ( aComponent == execButton
             && aType == BUTTON_PRESSED ) {

            switch (mainMenu.getSelectedIndex()) {
            /* Get time */
            // J221_0405_0201
            // J221_0405_0202
            // J221_0405_0203
            case 0:
                try {
                    Calendar c = Calendar.getInstance();
                    c.setTimeZone(TimeZone.getTimeZone("GMT"));
                    /* add 2002.02.13 */
                    String month = new String("");
                    switch( c.get(Calendar.MONTH) ) {
                    case Calendar.JANUARY:
//2002/08/13 Doja1.5                    case c.JANUARY:
                        month = "1";
                        break;
                    case Calendar.FEBRUARY:
//2002/08/13 Doja1.5                    case c.FEBRUARY:
                        month = "2";
                        break;
                    case Calendar.MARCH:
//2002/08/13 Doja1.5                    case c.MARCH:
                        month = "3";
                        break;
                    case Calendar.APRIL:
//2002/08/13 Doja1.5                    case c.APRIL:
                        month = "4";
                        break;
                    case Calendar.MAY:
//2002/08/13 Doja1.5                    case c.MAY:
                        month = "5";
                        break;
                    case Calendar.JUNE:
//2002/08/13 Doja1.5                    case c.JUNE:
                        month = "6";
                        break;
                    case Calendar.JULY:
//2002/08/13 Doja1.5                    case c.JULY:
                        month = "7";
                        break;
                    case Calendar.AUGUST:
//2002/08/13 Doja1.5                    case c.AUGUST:
                        month = "8";
                        break;
                    case Calendar.SEPTEMBER:
//2002/08/13 Doja1.5                    case c.SEPTEMBER:
                        month = "9";
                        break;
                    case Calendar.OCTOBER:
//2002/08/13 Doja1.5                    case c.OCTOBER:
                        month = "10";
                        break;
                    case Calendar.NOVEMBER:
//2002/08/13 Doja1.5                    case c.NOVEMBER:
                        month = "11";
                        break;
                    case Calendar.DECEMBER:
//2002/08/13 Doja1.5                    case c.DECEMBER:
                        month = "12";
                        break;
                    }
                    /* modified month-get-method 2002.02.13 */
                    resultTextBox.setText("Current time : " + c.get(Calendar.YEAR)
                        + "Year" + month + "Month" + c.get(
                            Calendar.DATE) + "Day" + c.get(Calendar.HOUR_OF_DAY)
                                + "Time" + c.get(Calendar.MINUTE) + "Minute" + c.get(
                                    Calendar.SECOND) + "Second");
                } catch (Exception e) {
                    resultTextBox.setText("NG : " + e.toString());
                }
                break;
            /* Time zone */
            // J221_0405_0204
            // J221_0405_0205
            case 1:
                try {
                    String str;
                    String id[] = TimeZone.getAvailableIDs();
                    int x = id.length;
                    str = id[0];

                    for (int i = 0; i < x-1; i++) {
                        str = str.concat(" ");
                        str = str.concat(id[i+1]);
                    }
                    resultTextBox.setText(str);
                } catch (Exception e) {
                    resultTextBox.setText("NG : " + e.toString());
                }
                break;
            }
        }
    }
}
