/**
 * J221_0405_0301.java
 * Check CLDC-prescribed property
 * J221_0405_0301
 * 
 * $Id: J221_0405_0301.java,v 1.1 2002/01/07 01:55:36 hoshi Exp $
*/

import com.nttdocomo.lang.*;
import java.util.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Main class for checking CLDC-prescribed property
 * @extends IApplication
 */
public class J221_0405_0301 extends IApplication {
    public void start() {
        MainPanel mainPanel = new MainPanel();
        Display.setCurrent(mainPanel);
    }
}

/**
 * Main class for checking CLDC-prescribed property
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener {

    /* Creation of message dialog (error/Information) */
    Dialog err = new Dialog(Dialog.DIALOG_ERROR,"error");
    Dialog info = new Dialog(Dialog.DIALOG_INFO, "info");

    /* execute button */
    Button execButton = null;

    /* Text box for displaying test result */
    TextBox resultTextBox = new TextBox("", getWidth(), 3, 
                                                TextBox.DISPLAY_ANY);
    /* Create menu for selecting process */
    ListBox mainMenu = new ListBox(ListBox.CHOICE,4);

    /* Menu item for selecting process */
    String[] mainItem = {
        "0.platform",
        "1.encoding",
        "2.configuration",
        "3.profiles",
    };

    /* Define the alignment of keys */
    String[] key = {
        "microedition.platform",
        "microedition.encoding",
        "microedition.configuration",
        "microedition.profiles",
    };



    /**
     * Constructor of MainPanel class
     */
    public MainPanel() {

        try {
            showMainPanel();
        } catch(Exception e) {
            err.setText("Exception:" + e.toString());
        } catch(Error e) {
            err.setText("Error" + e.toString());
        }

    }

    /**
     * Display main screen for checking CLDC-prescribed property
     */
    public void showMainPanel() {

        /* Display title */
        setTitle("JAM-JVM");

        /* Display sub title */
        Label subTitle = new Label("Check property standardised by CLDC");
        subTitle.setSize(getWidth(), subTitle.getHeight());
        add(subTitle);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* Setting of the main menu */
        mainMenu.setItems(mainItem);

        /* Setting of the execute button */
        execButton = new Button("execute");

        /* Add component to the screen */
        add(mainMenu);
        add(execButton);
        add(resultTextBox);

    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * softKeyReleased
     * When soft key 1 is released, end the application
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        /* Completed when soft key 1 is released */
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType  Type of events
     * @param aParam  Parameter of events
     */
    public void componentAction(Component aComponent, int aType, int aPram) {

        /* Transit to the screen that is compliant with menu by pressing execute button */
        if ( aComponent == execButton
             && aType == BUTTON_PRESSED ) {

            switch (mainMenu.getSelectedIndex()) {
            /* platform */
            // J221_0405_0301
            case 0:
                try {
                    resultTextBox.setText(
                        System.getProperty(key[0]));
                } catch (Exception e) {
                    resultTextBox.setText("NG : " + e.toString());
                }
                break;
            /* encoding */
            // J221_0405_0302
            case 1:
                try {
                    resultTextBox.setText(
                        System.getProperty(key[1]));
                } catch (Exception e) {
                    resultTextBox.setText("NG : " + e.toString());
                }
                break;
            /* configuration */
            // J221_0405_0303
            case 2:
                try {
                    resultTextBox.setText(
                        System.getProperty(key[2]));
                } catch (Exception e) {
                    resultTextBox.setText("NG : " + e.toString());
                }
                break;
            /* profiles */
            // J221_0405_0304
            case 3:
                try {
                    resultTextBox.setText(
                        System.getProperty(key[3]));
                } catch (Exception e) {
                    resultTextBox.setText("NG : " + e.toString());
                }
                break;
            }
        }
    }
}
