/**
 * J222_0101_0101
 *
 * Competitive behavior of native dialogs from Java dialogs
 *
 * $Id: J222_0101_0101.java,v 1.1 2001/12/29 01:20:45 takanao Exp $
 */

import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;
import com.nttdocomo.util.*;

/**
 * Main class for competitive behavior of native dialogs from Java dialogs
 * @extends IApplication
 */

public class J222_0101_0101 extends IApplication {

    MainPanel testPanel = new MainPanel();

    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * Main screen for competitive behavior of native dialogs from Java dialogs
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Definition of GUI components */
    TextBox resultBox = new TextBox(null, 16, 16, TextBox.DISPLAY_ANY);
    ListBox menuList = new ListBox(ListBox.CHOICE);
    Button processButton = new Button("execute");
    
    String[] menuItem = {
        "00 Termination during Dialog",
        "01 Basic authentication during Dialog",
        "02 SSl connection during Dialog",
//2002/08/08 DoJa1.5        "03 Use infrared rays during Dialog",
//2002/08/08 DoJa1.5        "04 Launch during Dialog",
//2002/08/08 DoJa1.5        "05 Launch during Dialog (NW not available)",
//2002/08/08 DoJa1.5        "06 Phone during Dialog",
    };

    /**
     * Create panel (Constructor of Panel)
     */
    public MainPanel() {

        /* GUI settings */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("Java dialog and native dialog");
        menuList.setItems(menuItem);

        /* GUI location */
        add(menuList);
        add(processButton);
        add(resultBox);

        /* Listener setting */
        this.setSoftKeyListener(this);
        this.setComponentListener(this);
    }

    /** 
     * Soft key handler
     * @param aKey Pressed key
     */
    public void softKeyPressed(int aKey) {}

    /** 
     * Soft key handler
     * @param aKey Released key
     */
    public void softKeyReleased(int aKey) {
        /* When soft key1 is released, end the application */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Component event
     * @param aComponent Event occurrence component
     * @param aType Event type
     * @param aParam Event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if (aType == ComponentListener.BUTTON_PRESSED && aComponent == processButton) {
            int index = menuList.getSelectedIndex();
            if (index >= 0) {
                try {
                    doTest(index);
                } catch (Exception e) {
                    resultBox.setText("Out of the range: "+e.getClass().getName());
                }
            }
        }
    }

    public void doTest(int selected) {

        String ret;

        switch (selected) {
        // J222_0101_0101
        case 0:
            Dialog testDialog = new Dialog(Dialog.DIALOG_INFO, "Dialog");
            testDialog.setText("Dialog for checking forcedly termination should be displayed by the forcedly termination button while dialog is displayed");
            testDialog.show();
            break;

        // J222_0101_0201
        case 1:
            resultBox.setText("Start the test");
            ret = doHttp(IApplication.getCurrentApp().getSourceURL()+"sec/data",
                         "Display Basic authentication after displaying the dialog");
            resultBox.setText(ret);
            break;
            
        // J222_0101_0202
        case 2:
            resultBox.setText("Start the test");
            ret = doHttp(IApplication.getCurrentApp().getSourceURL()+"data",
                         "Display SSL communication may not be secured after displaying the dialog");
            resultBox.setText(ret);
            break;

        // J222_0101_0204
//2002/08/08 DoJa1.5        case 3:
//2002/08/08 DoJa1.5            resultBox.setText("Start the test");
//2002/08/08 DoJa1.5            ret = doIrOBEX("Display Ir communication dialog after displaying the dialog");
//2002/08/08 DoJa1.5            resultBox.setText(ret);
//2002/08/08 DoJa1.5            break;
            
        // J222_0101_0301
//2002/08/08 DoJa1.5        case 4:
//2002/08/08 DoJa1.5            resultBox.setText("Start the test");
//2002/08/08 DoJa1.5            ret = doBrowser(IApplication.getCurrentApp().getSourceURL(),
//2002/08/08 DoJa1.5                           "Display browser startup dialog after displaying the dialog");
//2002/08/08 DoJa1.5            resultBox.setText(ret);
//2002/08/08 DoJa1.5            break;

        // J222_0101_0302
//2002/08/08 DoJa1.5        case 5:
//2002/08/08 DoJa1.5            resultBox.setText("Start the test");
//2002/08/08 DoJa1.5            ret = doBrowser(IApplication.getCurrentApp().getSourceURL(),
//2002/08/08 DoJa1.5                           "Display dialog of browser startup incapability after displaying the dialog");
//2002/08/08 DoJa1.5            resultBox.setText(ret);
//2002/08/08 DoJa1.5            break;

        // J222_0101_0303
//2002/08/08 DoJa1.5        case 6:
//2002/08/08 DoJa1.5            resultBox.setText("Start the test");
//2002/08/08 DoJa1.5            ret = doCall("117", "Display call startup dialog after displaying the dialog");
//2002/08/08 DoJa1.5            resultBox.setText(ret);
//2002/08/08 DoJa1.5            break;

        default:
            break;
        }
    }

    /**
     * Use HttpConnection while displaying dialog
     * @param url Connect-to URL
     * @param message Dialog text
     * @return Return the result of HttpConnetion.Successful:OK Failed:Name of the exception
     */
    public String doHttp(String url, String message) {

        HttpThread ht = null;
        Dialog testDialog = new Dialog(Dialog.DIALOG_INFO, "Dialog");

        ht = new HttpThread(url, 5000);
        ht.start();

        testDialog.setText(message);
        testDialog.show();

        try {
            ht.join();
        } catch (InterruptedException ie) {
            return "join fail";
        }
        return ht.getMessage();
    }

    /**
     * Utilize ClientObexConnection while dialog box is displayed
     * @param message Dialog text
     * @return Return the result of HttpConnetion.Successful:OK Failed:Name of the exception
     */
//2002/08/08 DoJa1.5    public String doIrOBEX(String message) {

//2002/08/08 DoJa1.5        IrThread irt = null;
//2002/08/08 DoJa1.5        Dialog testDialog = new Dialog(Dialog.DIALOG_INFO, "Dialog");

//2002/08/08 DoJa1.5        irt = new IrThread(5000);
//2002/08/08 DoJa1.5        irt.start();

//2002/08/08 DoJa1.5        testDialog.setText(message);
//2002/08/08 DoJa1.5        testDialog.show();

//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            irt.join();
//2002/08/08 DoJa1.5        } catch (InterruptedException ie) {
//2002/08/08 DoJa1.5            return "join fail";
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5        return irt.getMessage();
//2002/08/08 DoJa1.5    }

    /**
     * Utilize browser startup while dialog is being displayed
     * @param url Connect-to URL
     * @param message Dialog text
     */
//2002/08/08 DoJa1.5    public String doBrowser(String url, String message) {

//2002/08/08 DoJa1.5        BrowserThread bt = null;
//2002/08/08 DoJa1.5        Dialog testDialog = new Dialog(Dialog.DIALOG_INFO, "Dialog");

//2002/08/08 DoJa1.5        bt = new BrowserThread(url, 5000);
//2002/08/08 DoJa1.5        bt.start();

//2002/08/08 DoJa1.5        testDialog.setText(message);
//2002/08/08 DoJa1.5        testDialog.show();

//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            bt.join();
//2002/08/08 DoJa1.5        } catch (InterruptedException ie) {
//2002/08/08 DoJa1.5            return "join fail";
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5        return bt.getMessage();
//2002/08/08 DoJa1.5    }

    /**
     * Use call startup while displaying dialog
     * @param number Connected phone number
     * @param message Dialog text
     */
//2002/08/08 DoJa1.5    public String doCall(String number, String message) {

//2002/08/08 DoJa1.5        CallThread ct = null;
//2002/08/08 DoJa1.5        Dialog testDialog = new Dialog(Dialog.DIALOG_INFO, "Dialog");

//2002/08/08 DoJa1.5        ct = new CallThread(number, 5000);
//2002/08/08 DoJa1.5        ct.start();

//2002/08/08 DoJa1.5        testDialog.setText(message);
//2002/08/08 DoJa1.5        testDialog.show();

//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            ct.join();
//2002/08/08 DoJa1.5        } catch (InterruptedException ie) {
//2002/08/08 DoJa1.5            return "join fail";
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5        return ct.getMessage();
//2002/08/08 DoJa1.5    }
}

/**
 * Thread for HTTP communication
 * @extends Thread
 */
class HttpThread extends Thread {

    long waitTimer = 0;
    String connectUrl = null;
    String lastMessage  = null;

    /**
     * HTTP communication class constructor
     * @param url Connect-to URL
     * @param wait Stand-by time before starting the connection(ms)
     */
    public HttpThread(String url, long wait) {
        waitTimer = wait;
        connectUrl = url;
        lastMessage = "OK";
    }

    /**
     * Get the communication result
     * @return Result at the time of communication.Return OK when successful and the last thrown exception when failed
     */
    public String getMessage() {
        return lastMessage;
    }

    /**
     * Main look of the Http communication thread
     */
    public void run() {
        HttpConnection con = null;

        /* Stand-by */
        try{
            Thread.sleep(waitTimer);
        } catch (InterruptedException ie) {
            lastMessage = "Thread.sleep abort.";
        }

        /* Connect to the URL specified by constructor */
        try {
            con = (HttpConnection)Connector.open(connectUrl, Connector.READ);
            con.setRequestMethod(HttpConnection.GET);
            con.connect();
        } catch (Exception e) {
            lastMessage = "HttpConnection abort. ->" + e.getClass().getName();
        } finally {
            try {
                con.close();
            } catch (Exception e) {
                lastMessage = "close error. ->" + e.getClass().getName();
            }
        }
    }
}

/**
 * Thread for IrObex
 * @extends Thread
 */
//2002/08/08 DoJa1.5class IrThread extends Thread {

//2002/08/08 DoJa1.5    long waitTimer = 0;
//2002/08/08 DoJa1.5    String lastMessage  = null;

    /**
     * Constructor of Ir communication class
     * @param wait Stand-by time before starting the connection(ms)
     */
//2002/08/08 DoJa1.5    public IrThread(long wait) {
//2002/08/08 DoJa1.5        waitTimer = wait;
//2002/08/08 DoJa1.5        lastMessage = "OK";
//2002/08/08 DoJa1.5    }

    /**
     * Get the communication result
     * @return Result at the time of communication.Return OK when successful and the last thrown exception when failed
     */
//2002/08/08 DoJa1.5    public String getMessage() {
//2002/08/08 DoJa1.5        return lastMessage;
//2002/08/08 DoJa1.5    }

    /**
     * Main loop of Ir communication thread
     */
//2002/08/08 DoJa1.5    public void run() {
//2002/08/08 DoJa1.5        ClientObexConnection coc = null;

        /* Stand-by */
//2002/08/08 DoJa1.5        try{
//2002/08/08 DoJa1.5            Thread.sleep(waitTimer);
//2002/08/08 DoJa1.5        } catch (InterruptedException ie) {
//2002/08/08 DoJa1.5            lastMessage = "Thread.sleep abort.";
//2002/08/08 DoJa1.5        }

        /* Try utilizing Ir */
//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            coc = (ClientObexConnection)Connector.open("obex:/irclient");
            // Dialog for Now connecting is displayed but close after time out as there is no answer on the connecting end
//2002/08/08 DoJa1.5            coc.connect();
//2002/08/08 DoJa1.5        } catch (ConnectionException ce) {
//2002/08/08 DoJa1.5            if (ce.getStatus() == ConnectionException.TIMEOUT) {
//2002/08/08 DoJa1.5                lastMessage = "OK";
//2002/08/08 DoJa1.5            } else {
//2002/08/08 DoJa1.5                lastMessage = "ObexConnection abort. -> ConnectionException[" + ce.getStatus() +"]";
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5        } catch (Exception e) {
//2002/08/08 DoJa1.5            lastMessage = "ObexConnection abort. ->" + e.getClass().getName();
//2002/08/08 DoJa1.5        } finally {
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                coc.close();
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                lastMessage = "close error ->" + e.getClass().getName();
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5    }
//2002/08/08 DoJa1.5}

/**
 * Thread for starting browser
 * @extends Thread
 */
//2002/08/08 DoJa1.5class BrowserThread extends Thread {

//2002/08/08 DoJa1.5    long waitTimer = 0;
//2002/08/08 DoJa1.5    String connectUrl = null;
//2002/08/08 DoJa1.5    String lastMessage  = null;

    /**
     * Constructor of browser startup class
     * @param url Connect-to URL
     * @param wait Stand-by time before starting the connection(ms)
     */
//2002/08/08 DoJa1.5    public BrowserThread(String url, long wait) {
//2002/08/08 DoJa1.5        waitTimer = wait;
//2002/08/08 DoJa1.5        connectUrl = url;
//2002/08/08 DoJa1.5        lastMessage = "OK";
//2002/08/08 DoJa1.5    }

    /**
     * Get the result of browser startup
     * @return Startup resultReturn OK when successful and the last thrown exception when failed
     */
//2002/08/08 DoJa1.5    public String getMessage() {
//2002/08/08 DoJa1.5        return lastMessage;
//2002/08/08 DoJa1.5    }

    /**
     * Main loop of browser startup thread
     */
//2002/08/08 DoJa1.5    public void run() {

        /* Stand-by */
//2002/08/08 DoJa1.5        try{
//2002/08/08 DoJa1.5            Thread.sleep(waitTimer);
//2002/08/08 DoJa1.5        } catch (InterruptedException ie) {
//2002/08/08 DoJa1.5            lastMessage = "Thread.sleep abort.";
//2002/08/08 DoJa1.5        }

//2002/08/08 DoJa1.5        IApplication appli = IApplication.getCurrentApp();
//2002/08/08 DoJa1.5        String[] args = new String[1];
//2002/08/08 DoJa1.5        args[0] = connectUrl;
//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            appli.launch(IApplication.LAUNCH_BROWSER, args);
//2002/08/08 DoJa1.5        } catch (Exception e) {
//2002/08/08 DoJa1.5            lastMessage = "launch abort. ->" + e.getClass().getName();
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5    }
//2002/08/08 DoJa1.5}


/**
 * Thread for starting up a call
 * @extends Thread
 */
//2002/08/08 DoJa1.5class CallThread extends Thread {

//2002/08/08 DoJa1.5    long waitTimer = 0;
//2002/08/08 DoJa1.5    String connectNumber = null;
//2002/08/08 DoJa1.5    String lastMessage  = null;

    /**
     * Constructor of call startup class
     * @param number Connected phone number
     * @param wait Stand-by time before starting the connection(ms)
     */
//2002/08/08 DoJa1.5    public CallThread(String number, long wait) {
//2002/08/08 DoJa1.5        waitTimer = wait;
//2002/08/08 DoJa1.5        connectNumber = number;
//2002/08/08 DoJa1.5        lastMessage = "OK";
//2002/08/08 DoJa1.5    }

    /**
     * Get the result of call startup
     * @return Startup resultReturn OK when successful and the last thrown exception when failed
     */
//2002/08/08 DoJa1.5    public String getMessage() {
//2002/08/08 DoJa1.5        return lastMessage;
//2002/08/08 DoJa1.5    }

    /**
     * Main loop for call startup thread
     */
//2002/08/08 DoJa1.5    public void run() {

        /* Stand-by */
//2002/08/08 DoJa1.5        try{
//2002/08/08 DoJa1.5            Thread.sleep(waitTimer);
//2002/08/08 DoJa1.5        } catch (InterruptedException ie) {
//2002/08/08 DoJa1.5            lastMessage = "Thread.sleep abort.";
//2002/08/08 DoJa1.5        }

//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            Phone.call(connectNumber);
//2002/08/08 DoJa1.5        } catch (Exception e) {
//2002/08/08 DoJa1.5            lastMessage = "call abort. ->" + e.getClass().getName();
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5    }
//2002/08/08 DoJa1.5}

