/**
 * J222_0202_0101
 *
 * Native dialogs from SSL authentication
 *
 * $Id: J222_0202_0101.java,v 1.1 2001/12/29 01:20:46 takanao Exp $
 */

import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;
import com.nttdocomo.util.*;

/**
 * Main class for competitive behavior of native dialogs from SSL dialog
 * @extends IApplication
 */

public class J222_0202_0101 extends IApplication {

    MainPanel testPanel = new MainPanel();

    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * Native dialogs from SSL authentication
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Definition of GUI components */
    TextBox resultBox = new TextBox(null, 16, 16, TextBox.DISPLAY_ANY);
    ListBox menuList = new ListBox(ListBox.CHOICE);
    Button processButton = new Button("execute");
    
    String[] menuItem = {
        "00 Finish during SSL authentication",
//2002/08/08 DoJa1.5        "01 Launch during SSL authentication",
//2002/08/08 DoJa1.5        "02 Launch during SSL authentication (not available)",
//2002/08/08 DoJa1.5        "03 Call during SSL authentication",
    };

    /**
     * Create panel (Constructor of Panel)
     */
    public MainPanel() {

        /* GUI settings */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("Native dialog from SSL authentication");
        menuList.setItems(menuItem);

        /* GUI location */
        add(menuList);
        add(processButton);
        add(resultBox);

        /* Listener setting */
        this.setSoftKeyListener(this);
        this.setComponentListener(this);
    }

    /** 
     * Soft key handler
     * @param aKey Pressed key
     */
    public void softKeyPressed(int aKey) {}

    /** 
     * Soft key handler
     * @param aKey Released key
     */
    public void softKeyReleased(int aKey) {
        /* When soft key1 is released, end the application */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Component event
     * @param aComponent Event occurrence component
     * @param aType Event type
     * @param aParam Event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if (aType == ComponentListener.BUTTON_PRESSED && aComponent == processButton) {
            int index = menuList.getSelectedIndex();
            if (index >= 0) {
                try {
                    doTest(index);
                } catch (Exception e) {
                    resultBox.setText("Out of the range: "+e.getClass().getName());
                }
            }
        }
    }

    public void doTest(int selected) {

        String ret;
        resultBox.setText("Start the test");

        switch (selected) {
        // J222_0202_0101
        case 0:
            ret = doHttp(IApplication.getCurrentApp().getSourceURL()+"data");
            resultBox.setText(ret);
            break;

        // J222_0202_0201
//2002/08/08 DoJa1.5        case 1:
//2002/08/08 DoJa1.5            ret = doBrowser(IApplication.getCurrentApp().getSourceURL()+"data",
//2002/08/08 DoJa1.5                            IApplication.getCurrentApp().getSourceURL()+"data");
//2002/08/08 DoJa1.5            resultBox.setText(ret);
//2002/08/08 DoJa1.5            break;
            
        // J222_0202_0202
//2002/08/08 DoJa1.5        case 2:
//2002/08/08 DoJa1.5            ret = doBrowser(IApplication.getCurrentApp().getSourceURL()+"data",
//2002/08/08 DoJa1.5                            IApplication.getCurrentApp().getSourceURL()+"data");
//2002/08/08 DoJa1.5            resultBox.setText(ret);
//2002/08/08 DoJa1.5            break;

        // J222_0202_0203
//2002/08/08 DoJa1.5        case 3:
//2002/08/08 DoJa1.5            ret = doCall(IApplication.getCurrentApp().getSourceURL()+"data", "117");
//2002/08/08 DoJa1.5            resultBox.setText(ret);
//2002/08/08 DoJa1.5            break;

        default:
            break;
        }
    }

    /**
     * Use HttpConnection while displaying dialog
     * @param url Connect-to URL
     * @return Return the result of HttpConnetion.Successful:OK Failed:Name of the exception
     */
    public String doHttp(String url) {

        HttpConnection con = null;

        /* Connect to the specified URL */
        try {
            con = (HttpConnection)Connector.open(url, Connector.READ);
            con.setRequestMethod(HttpConnection.GET);
            con.connect();
        } catch (Exception e) {
            return "[Http:abort->" + e.getClass().getName() + "]";
        } finally {
            try {
                con.close();
            } catch (Exception e) {
                return "[Http:close error->" + e.getClass().getName() + "]";
            }
            return "[Http:ok]";
        }
    }

    /**
     * Utilize browser startup while dialog is being displayed
     * @param url Connect-to URL
     * @param message Dialog text
     * @return Return the result of browser's startupSuccessful:OK Failed:Name of the exception
     */
//2002/08/08 DoJa1.5    public String doBrowser(String url, String browser) {

//2002/08/08 DoJa1.5        BrowserThread bt = null;

//2002/08/08 DoJa1.5        bt = new BrowserThread(browser, 5000);
//2002/08/08 DoJa1.5        bt.start();

//2002/08/08 DoJa1.5        String ret = doHttp(url);

//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            bt.join();
//2002/08/08 DoJa1.5        } catch (InterruptedException ie) {
//2002/08/08 DoJa1.5            return "join fail";
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5        return ret + "\n" + bt.getMessage();
//2002/08/08 DoJa1.5    }

    /**
     * Use call startup while displaying dialog
     * @param number Connected phone number
     * @param message Dialog text
     * @return Return the result of call's startupSuccessful:OK Failed:Name of the exception
     */
//2002/08/08 DoJa1.5    public String doCall(String url, String number) {

//2002/08/08 DoJa1.5        CallThread ct = null;

//2002/08/08 DoJa1.5        ct = new CallThread(number, 5000);
//2002/08/08 DoJa1.5        ct.start();

//2002/08/08 DoJa1.5        String ret = doHttp(url);

//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            ct.join();
//2002/08/08 DoJa1.5        } catch (InterruptedException ie) {
//2002/08/08 DoJa1.5            return "join fail";
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5        return ret + "\n" + ct.getMessage();
//2002/08/08 DoJa1.5    }
}

/**
 * Thread for starting browser
 * @extends Thread
 */
//2002/08/08 DoJa1.5class BrowserThread extends Thread {

//2002/08/08 DoJa1.5    long waitTimer = 0;
//2002/08/08 DoJa1.5    String connectUrl = null;
//2002/08/08 DoJa1.5    String lastMessage  = null;

    /**
     * Constructor of browser startup class
     * @param url Connect-to URL
     * @param wait Stand-by time before starting the connection(ms)
     */
//2002/08/08 DoJa1.5    public BrowserThread(String url, long wait) {
//2002/08/08 DoJa1.5        waitTimer = wait;
//2002/08/08 DoJa1.5        connectUrl = url;
//2002/08/08 DoJa1.5        lastMessage = "[launch:OK]";
//2002/08/08 DoJa1.5    }

    /**
     * Get the result of browser startup
     * @return Startup resultReturn OK when successful and the last thrown exception when failed
     */
//2002/08/08 DoJa1.5    public String getMessage() {
//2002/08/08 DoJa1.5        return lastMessage;
//2002/08/08 DoJa1.5    }

    /**
     * Main loop of browser startup thread
     */
//2002/08/08 DoJa1.5    public void run() {

        /* Stand-by */
//2002/08/08 DoJa1.5        try{
//2002/08/08 DoJa1.5            Thread.sleep(waitTimer);
//2002/08/08 DoJa1.5        } catch (InterruptedException ie) {
//2002/08/08 DoJa1.5            lastMessage = "[launch:Thread.sleep abort]";
//2002/08/08 DoJa1.5        }

//2002/08/08 DoJa1.5        IApplication appli = IApplication.getCurrentApp();
//2002/08/08 DoJa1.5        String[] args = new String[1];
//2002/08/08 DoJa1.5        args[0] = connectUrl;
//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            appli.launch(IApplication.LAUNCH_BROWSER, args);
//2002/08/08 DoJa1.5        } catch (Exception e) {
//2002/08/08 DoJa1.5            lastMessage = "[launch:abort->" + e.getClass().getName() + "]";
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5    }
//2002/08/08 DoJa1.5}

/**
 * Thread for starting up a call
 */
//2002/08/08 DoJa1.5class CallThread extends Thread {

//2002/08/08 DoJa1.5    long waitTimer = 0;
//2002/08/08 DoJa1.5    String connectNumber = null;
//2002/08/08 DoJa1.5    String lastMessage  = null;

    /**
     * Constructor of call startup class
     * @param number Connected phone number
     * @param wait Stand-by time before starting the connection(ms)
     */
//2002/08/08 DoJa1.5    public CallThread(String number, long wait) {
//2002/08/08 DoJa1.5        waitTimer = wait;
//2002/08/08 DoJa1.5        connectNumber = number;
//2002/08/08 DoJa1.5        lastMessage = "[call:OK]";
//2002/08/08 DoJa1.5    }

    /**
     * Get the result of call startup
     * @return Startup resultReturn OK when successful and the last thrown exception when failed
     */
//2002/08/08 DoJa1.5    public String getMessage() {
//2002/08/08 DoJa1.5        return lastMessage;
//2002/08/08 DoJa1.5    }

    /**
     * Main loop for call startup thread
     */
//2002/08/08 DoJa1.5    public void run() {

        /* Stand-by */
//2002/08/08 DoJa1.5        try{
//2002/08/08 DoJa1.5            Thread.sleep(waitTimer);
//2002/08/08 DoJa1.5        } catch (InterruptedException ie) {
//2002/08/08 DoJa1.5            lastMessage = "[call:Thread.sleep abort.]";
//2002/08/08 DoJa1.5        }

//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            Phone.call(connectNumber);
//2002/08/08 DoJa1.5        } catch (Exception e) {
//2002/08/08 DoJa1.5            lastMessage = "[call:abort->" + e.getClass().getName() + "]";
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5    }
//2002/08/08 DoJa1.5}

