/**
 * J222_0301_0101
 *
 * Basic authentication and timer's behavior
 *
 * $Id: J222_0301_0101.java,v 1.1 2001/12/29 01:20:47 takanao Exp $
 */

import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;
import com.nttdocomo.util.*;

/**
 * Basic authentication and timer's behavior
 * @extends IApplication
 */

public class J222_0301_0101 extends IApplication {

    MainPanel testPanel = new MainPanel();

    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * Basic authentication and timer's behavior
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Definition of GUI components */
    TextBox resultBox = new TextBox(null, 16, 16, TextBox.DISPLAY_ANY);
    ListBox menuList = new ListBox(ListBox.CHOICE);
    Button processButton = new Button("execute");
    
    String[] menuItem = {
        "00 Timer during Basic authentication",
        "01 ShortTimer during Basic authentication",
    };

    /**
     * Create panel (Constructor of Panel)
     */
    public MainPanel() {

        /* GUI settings */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("Timer during Basic authentication");
        menuList.setItems(menuItem);

        /* GUI location */
        add(menuList);
        add(processButton);
        add(resultBox);

        /* Listener setting */
        this.setSoftKeyListener(this);
        this.setComponentListener(this);
    }

    /** 
     * Soft key handler
     * @param aKey Pressed key
     */
    public void softKeyPressed(int aKey) {}

    /** 
     * Soft key handler
     * @param aKey Released key
     */
    public void softKeyReleased(int aKey) {
        /* When soft key1 is released, end the application */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Component event
     * @param aComponent Event occurrence component
     * @param aType Event type
     * @param aParam Event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if (aType == ComponentListener.BUTTON_PRESSED && aComponent == processButton) {
            int index = menuList.getSelectedIndex();
            if (index >= 0) {
                try {
                    doTest(index);
                } catch (Exception e) {
                    resultBox.setText("Out of the range: "+e.getClass().getName());
                }
            }
        }
    }

    public void doTest(int selected) {

        TimerPanel timerPanel = null;
        ShortTimerCanvas shortTimerCanvas = null;

        switch (selected) {
        // J222_0301_0101
        case 0:
            if (timerPanel == null) {
                timerPanel = new TimerPanel(this);
            }
            Display.setCurrent(timerPanel);

            break;
            
        // J222_0301_0102
        case 1:
            if (shortTimerCanvas == null) {
                shortTimerCanvas = new ShortTimerCanvas(this);
            }
            Display.setCurrent(shortTimerCanvas);

            break;
            
        default:
            break;
        }
    }
}

/**
 * Thread for starting up Http
 * @extends Thread
 */
class HttpThread extends Thread {

    long waitTimer = 0;
    String connectUrl = null;
    String lastMessage  = null;

    /**
     * Constructor of Http connection class
     * @param url Connect-to URL
     * @param wait Stand-by time before starting the connection(ms)
     */
    public HttpThread(String url, long wait) {
        waitTimer = wait;
        connectUrl = url;
        lastMessage = "[http:OK]";
    }

    /**
     * Get the result of Http connection
     * @return Result of connectionReturn OK when successful and the last thrown exception when failed
     */
    public String getMessage() {
        return lastMessage;
    }

    /**
     * Main loop of Http connection's thread
     */
    public void run() {


        /* Stand-by */
        try{
            Thread.sleep(waitTimer);
        } catch (InterruptedException ie) {
            lastMessage = "[launch:Thread.sleep abort]";
        }

        HttpConnection con = null;
        try {
            con = (HttpConnection)Connector.open(connectUrl, Connector.READ);
            con.setRequestMethod(HttpConnection.GET);
            con.connect();
        } catch (Exception e) {
            lastMessage = "[http:abort->" + e.getClass().getName() + "]";
        } finally {
            try {
                con.close();
            } catch (Exception e) {
                lastMessage = "[http:close->" + e.getClass().getName() + "]";
            }
            lastMessage = "[http:ok]";
        }

    }
}

/**
 * Panel for timer test
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements TimerListener
 */
class TimerPanel extends Panel implements ComponentListener, SoftKeyListener, TimerListener {

    Frame previousFrame = null;

    Button processButton = new Button("Test");
    Label timerLabel = new Label();
    Timer timer = null;
    int timerCounter = 0;

    /**
     * Panel for timer test
     * @param aFrame Frame of the calling side
     */
    public TimerPanel(Frame aFrame) {
        /* Save the previous screen */
        previousFrame = aFrame;

        /* GUI settings */
        timerLabel.setSize(Display.getWidth(), timerLabel.getHeight());
        setSoftLabel(Frame.SOFT_KEY_1, "back");

        /* GUI location */
        add(processButton);
        add(timerLabel);

        /* Setting of event handler */
        setComponentListener(this);
        setSoftKeyListener(this);
        
    }

    /** 
     * Soft key handler
     * @param aKey Pressed key
     */
    public void softKeyPressed(int aKey) {}

    /** 
     * Soft key handler
     * @param aKey Released key
     */
    public void softKeyReleased(int aKey) {
        if (aKey == Frame.SOFT_KEY_1) {
            Display.setCurrent(previousFrame);
        }
    }

    /**
     * Component event
     * @param aComponent Event occurrence component
     * @param aType Event type
     * @param aParam Event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if (aType == ComponentListener.BUTTON_PRESSED && aComponent == processButton) {
            if (timer == null) {
                timer = new Timer();
            }
            timer.stop();
            timer.setTime(500);
            timer.setRepeat(true);
            timer.setListener(this);
            timer.start();

            // J222_0301_0101
            doHttp(IApplication.getCurrentApp().getSourceURL()+"sec/data");
        }
    }
    
    /**
     * Timer event handler
     * @param aTimer Origin of timer event occurrence
     */
    public void timerExpired(Timer aTimer) {
        if (aTimer == timer) {
            timerCounter++;
            timerLabel.setText("Timer:" + timerCounter);
        }
    }

    /**
     * Establish HTTP connection after 5 seconds
     * @param url Connect-to URL
     */
    public void doHttp(String url) {

        HttpThread ht = null;

        ht = new HttpThread(url, 5000);
        ht.start();
    }
}

/**
 * Canvas for testing short timer
 * @extends Canvas
 */
class ShortTimerCanvas extends Canvas {

    Frame previousFrame = null;
    ShortTimer stimer = null;
    int timerCounter = 0;

    /**
     * Canvas for testing timer
     * @param aFrame Frame of the calling side
     */
    public ShortTimerCanvas(Frame aFrame) {
        previousFrame = aFrame;
        setSoftLabel(Frame.SOFT_KEY_1, "back");
        setSoftLabel(Frame.SOFT_KEY_2, "Start");
    }

    /**
     * Canvas drawing method
     * @param aGraphics Graphics object set by the system
     */
    public void paint(Graphics aGraphics) {
        aGraphics.lock();
        aGraphics.clearRect(0, 0, getWidth(), getHeight());
        aGraphics.drawString("Timer:"+timerCounter, 0, 50);
        aGraphics.unlock(false);
    }

    /**
     * Event handler
     * @param aType Event type
     * @param aParam Event parameter
     */
    public void processEvent(int aType, int aParam) {

        /* Behavior when soft key is pressed */
        if (aType == Display.KEY_RELEASED_EVENT) {
            if (aParam == Display.KEY_SOFT1) {
                Display.setCurrent(previousFrame);
            } else if (aParam == Display.KEY_SOFT2) {
                if (stimer != null) {
                    stimer.stop();
                    stimer.dispose();
                }
                stimer = ShortTimer.getShortTimer(this, 1, 500, true);
                stimer.start();

                // J222_0301_0102
                doHttp(IApplication.getCurrentApp().getSourceURL()+"sec/data");
            }
        }

        /* Behavior in case of timer event occurrence */
        if (aType == Display.TIMER_EXPIRED_EVENT) {
            if (aParam == 1) {
                timerCounter ++;
                repaint();
            }
        }
    }

    /**
     * Establish HTTP connection after 5 seconds
     * @param url Connect-to URL
     */
    public void doHttp(String url) {

        HttpThread ht = null;

        ht = new HttpThread(url, 5000);
        ht.start();
    }
}
