/**
 * J223_0102_0104
 *
 * Check setting of NW usage
 *
 */

import java.io.*;
import java.util.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * Main class of checking of setting of NW usage
 * @extends IApplication
 */
public class J223_0102_0104 extends IApplication {

    MainPanel testPanel = new MainPanel();

    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * Confirmation screen for checking setting of NW usage
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* Definition of GUI components */
    Button  processButton = new Button("execute");
    TextBox resultBox = new TextBox(null, 16, 4, TextBox.DISPLAY_ANY);

    /**
     * Create panel (Constructor of Panel)
     */
    public MainPanel() {

        /* GUI settings */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("Check the NW configuration");

        /* GUI location */
        add(processButton);
        add(resultBox);

        /* Listener setting */
        this.setSoftKeyListener(this);
        this.setComponentListener(this);
    }

    /**
     * Soft key handler
     * @param aKey Pressed key
     */
    public void softKeyPressed(int aKey) {}

    /**
     * Soft key handler
     * @param aKey Released key
     */
    public void softKeyReleased(int aKey) {
        /* When soft key1 is released, end the application */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Component event handler
     * @param aComponent Event occurrence component
     * @param aType Event type
     * @param aParam Event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        
        /* Start test when Enter key is pressed */
        if (ComponentListener.BUTTON_PRESSED == aType && aComponent == processButton) {
            try {
                doTest();
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error information");
                errDialog.setText("Exceptions thrown outside the test:"+e.getClass().getName());
                errDialog.show();
            }
        }
    }

    /**
     * Add texts to the result field
     * @param aText Text to be added
     */
    public void addResultText(String aText) {
        resultBox.setText(resultBox.getText()+aText);
    }

    /**
     * Test terminal
     * Conduct HTTP communication and then display the result of communication.
     * OK when the communication result is normal and Data error when it ends up with data error
     * Display Exception:XXXX in the result field when exception is thrown.
     */
    public void doTest() {
        HttpConnection httpConn = null;
        InputStream in = null;
        try {
            /* Open HTTP */
            resultBox.setText("Open-> ");
            httpConn = (HttpConnection)Connector.open(IApplication.getCurrentApp().getSourceURL()+"../data");
            httpConn.setRequestMethod(HttpConnection.GET);

            /* Commencing communication */
            addResultText("Start connection->");
            httpConn.connect();

            /* Get the result */
            addResultText("Connection completed->");

            in = httpConn.openInputStream();

            /* Check whether content is identical to the data length */
            int c;
            int contentLength = 0;
            while ((c = in.read()) != -1) {
                if (c == 'A') {
                    contentLength++;
                }
            }
            if (contentLength == httpConn.getLength()) {
                addResultText("Communication OK");
            } else {
                addResultText("Illegal communication data");
            }
        } catch (ConnectionException ce) {
            addResultText("Exceptions in case of communication (CE)");
        } catch (IOException ce) {
            addResultText("Exceptions in case of communication (IOE)");
        } catch (SecurityException se) {
            addResultText("Exceptions in case of communication (SE)");
        } finally {
            /* Clear up */
            try {
                if (in != null) {
                    in.close();
                }
                if (httpConn != null) {
                    httpConn.close();
                }
            } catch (Exception e) {
                Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR, "Error information");
                errDialog.setText("Failed to close HTTP:"+e.getClass().getName());
                errDialog.show();
            }
        }
    }
}
