/**
 * J311_0101_0301
 * MainPanel
 *
 * HTTP basic behavior/check the variation of scheme names
 *
 * $Id: J311_0101_0301.java,v 1.1 2002/02/04 04:31:41 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the variation of scheme names
 * @extends IApplication
 */
public class J311_0101_0301 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the variation of scheme names 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener{
        String[] menuItems = {
            "1. http:URL",
            "2. http:/URL",
            "3. http:///URL",
            "4. HTTP://URL"
        };

        Label   lab              = new Label("scheme name");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;

            // J311_0101_0301
            // J311_0101_0302
            // J311_0101_0303
            // J311_0101_0304
            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url0 = getSourceURL();
            String url = new String("");
            String URL = new String("");
            if( url0.startsWith("https://") ) {
                if( idx == 3 ) {
                    url += "HTTPS:";
                } else {
                    url += "https:";
                }
                URL += url0.substring(8);
            } else {
                if( idx == 3 ) {
                    url += "HTTP:";
                } else {
                    url += "http:";
                }
                URL += url0.substring(7);
            }
            switch( idx ) {
            case 0:
                url += URL;
                break;
            case 1:
                url += "/" + URL;
                break;
            case 2:
                url += "///" + URL;
                break;
            case 3:
                url += "//" + URL;
                break;
            }
            url += "J311_0101_0301.jam";

            /* execute HTTP connection */
            try {
                con = (HttpConnection) Connector.open(url,Connector.READ,true);
                con.setRequestMethod(con.GET);
                con.connect();
                con.close();
                showDialog("OK");
            } catch( IllegalArgumentException iae ) {
                showDialog("IllegalArgumentException");
            } catch( IOException ioe ) {
                showDialog("IOException: " + ioe.getMessage());
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
            }
        }
    }
}
