/**
 * J311_0102_0101
 * MainPanel
 *
 * HTTP basic behavior/check the scheme-wise connection behavior 
 *
 * $Id: J311_0102_0101.java,v 1.1 2002/02/04 04:31:41 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the scheme-wise connection behavior  
 * @extends IApplication
 */
public class J311_0102_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the scheme-wise connection behavior 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. GET",
            "2. POST"
        };

        Label   lab              = new Label("scheme-wise connection");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;
            OutputStream ous = null;

            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL();
            if( idx != 1 ) {
                url += "J311_0102_0101.jam";
            } else {
                url += "../cgi-bin/post.cgi";
            }

            /* execute HTTP connection */
            switch( idx ) {
            case 0:
                // J311_0102_0101
                // J311_0102_0104
                try {
                    con = (HttpConnection) Connector.open(url,Connector.READ,
                                                        true);
                    con.setRequestMethod(con.GET);
                    con.connect();
                    ins = con.openInputStream();
                    for( int i=0; i<con.getLength(); i++ ) {
                        int b = ins.read();
                    }
                    ins.close();
                    con.close();
                    showDialog("OK");
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                } finally {
                    if( con != null ) {
                        try {
                            con.close();
                        } catch( Exception e1 ) {}
                    }
                }
                break;
            case 1:
                // J311_0102_0102
                // J311_0102_0105
                try {
                    con = (HttpConnection) Connector.open(url,Connector.WRITE,
                                                        true);
                    con.setRequestMethod(con.POST);
                    ous = con.openOutputStream();
                    ous.write(64);
                    ous.close();
                    con.connect();
                    con.close();
                    showDialog("OK");
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                } finally {
                    if( con != null ) {
                        try {
                            con.close();
                        } catch( Exception e1 ) {}
                    }
                }
                break;
            }
        }
    }
}
