/**
 * J311_0102_0201
 * MainPanel
 *
 * HTTP basic behavior/check the Basic certification behavior
 *
 * $Id: J311_0102_0201.java,v 1.3 2002/03/06 09:24:29 takanao Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTP basic behavior/main class of checking the Basic certification behavior
 * @extends IApplication
 */
public class J311_0102_0201 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     * @param   aFrame    call frame
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.DIALOG_INFO, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTP basic behavior/main screen of checking the Basic certification behavior 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. continuous access",
        };

        Label   lab              = new Label("Basic certification");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");
	TextBox result           = new TextBox(null, 20, 20, TextBox.DISPLAY_ANY);

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);
            add(result);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;

            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL();
            String url1 = url + "../sec/";
            String url2 = url + "../sec/aaa.html";

            /* execute HTTP connection */
            if( idx == 0 ) {
                // J311_0102_0201
                try {
                    /* 1st access/certification screen should appear */
                    showDialog("URL1");
                    con = (HttpConnection) Connector.open(url1,Connector.READ,
                                                        true);
                    con.setRequestMethod(con.GET);
                    con.connect();
                    ins = con.openInputStream();
                    for( int i=0; i<con.getLength(); i++ ) {
                        int b = ins.read();
                    }
                    ins.close();
                    con.close();

                    // J311_0102_0202
                    /* 2nd access/certification screen should not appear */
                    showDialog("URL2");
                    con = (HttpConnection) Connector.open(url2,Connector.READ,
                                                        true);
                    con.setRequestMethod(con.GET);
                    con.connect();
                    ins = con.openInputStream();
                    for( int i=0; i<con.getLength(); i++ ) {
                        int b = ins.read();
                    }
                    ins.close();
                    con.close();
                    showDialog("OK");
                    showDialog("URL1:"+url1);
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                } finally {
                    if( con != null ) {
                        try {
                            con.close();
                        } catch( Exception e1 ) {}
                    }
                }
            }
        }
    }
}
