/**
 * J311_0102_0602
 * MainPanel
 *
 * HTTP basic behavior/check the behavior of OutputStream
 *
 * $Id: J311_0102_0602.java,v 1.1 2002/02/04 04:31:44 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the behavior of OutputStream
 * @extends IApplication
 */
public class J311_0102_0602 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the behavior of OutputStream 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. RW-GET",
            "3. POST-NoWrite",
            "4. POST-NoOpen"
        };

        Label   lab              = new Label("empty OutputStream");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;
            OutputStream ous = null;

            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL();

            /* execute HTTP connection */
            try {
                url += "../cgi-bin/post.cgi";
                con = (HttpConnection) Connector.open(url,Connector.READ_WRITE,
                                                    true);
                if( idx == 0 ) {
                    // J311_0102_0602
                    con.setRequestMethod(con.GET);
                } else {
                    // J311_0102_0604
                    // J311_0102_0605
                    con.setRequestMethod(con.POST);
                }

                if( idx != 2 ) {
                    ous = con.openOutputStream();
                    if( idx != 1 ) {
                        ous.write("def".getBytes());
                    }
                    ous.close();
                }
                con.connect();
                ins = con.openInputStream();
                int ret = ins.read();
                byte[] b = new byte[3];
                if( ret != -1 ) {
                    b[0] = (byte) ret;
                    b[1] = (byte) ins.read();
                    b[2] = (byte) ins.read();
                }
                ins.close();
                con.close();
                if( ret == -1 ) {
                    showDialog("OK");
                } else {
                    showDialog("NG: not empty InputStream:"+ (new String(b)));
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
            }
        }
    }
}
