/**
 * J311_0103_0101
 * MainPanel
 *
 * HTTP basic behavior/check the simultaneous connection
 *
 * $Id: J311_0103_0101.java,v 1.1 2002/02/04 04:31:44 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the simultaneous connection 
 * @extends IApplication
 */
public class J311_0103_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the simultaneous connection
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. serial execution",
            "2. simultaneous execution"
        };

        Label   lab              = new Label("simultaneous connection");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            int num = 5;
            HttpConnection[] con = new HttpConnection[num];

            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL() + "J311_0103_0101.jam";

            /* get X number of HttpConnection */
            int i = 0;
            try {
                for( i=0; i<num; i++ ) {
                    con[i] = (HttpConnection) Connector.open(url,Connector.READ,
                                                            true);
                    con[i].setRequestMethod(con[i].GET);
                }
            } catch( Exception e ) {
                showDialog("NG" + i + ": " + e.toString());
                return;
            }

            if( idx == 0 ) {
                // J311_0103_0101
                /* serial execution of X number of connections */
                try {
                    for( i=0; i<num; i++ ) {
                        con[i].connect();
                        con[i].close();
                    }
                    showDialog("OK");
                } catch( Exception e ) {
                    showDialog("("+(i+1)+")NG" + i + ": " + e.toString());
                } finally {
                    for( i=0; i<num; i++ ) {
                        try {
                            con[i].close();
                        } catch( Exception e1 ) {}
                    }
                }
                return;
            }

            if( idx == 1 ) {
                // J311_0103_0201
                /* simultaneous execution of X number of connections */
                try {
                    for( i=0; i<num; i++ ) {
                        con[i].connect();
                    }
                    for( i=0; i<num; i++ ) {
                        con[i].close();
                    }
                    showDialog("OK");
                } catch( ConnectionException ce ) {
                    showDialog("("+(i+1)+")ConnectionException: " +
                                ce.getMessage());
                } catch( Exception e ) {
                    showDialog("("+(i+1)+")NG" + i + ": " + e.toString());
                } finally {
                    for( i=0; i<num; i++ ) {
                        try {
                            con[i].close();
                        } catch( Exception e1 ) {}
                    }
                }
            }
        }
    }
}
