/**
 * J311_0104_0101
 * MainPanel
 *
 * HTTP basic behavior/check the header submission behavior 
 *
 * $Id: J311_0104_0101.java,v 1.1 2002/02/04 04:31:45 lan Exp $
 */

import java.io.*;
import java.util.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of check the header submission behavior 
 * @extends IApplication
 */
public class J311_0104_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen orcheck the header submission behavior 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "2. If-Modified-Since-G",
            "3. If-Modified-Since-P",
            "5. Content-Type-G",
            "6. Content-Type-P",
            "7. Date",
            "8. Pragma",
            "9. Connection",
            "10. Authorization",
            "11. User-Agent-setting",
            "12. User-Agent-auto",
            "13. Host",
            "14. Content-Length",
            "15. LastModified"
        };

        Label   lab              = new Label("header submission");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;
            OutputStream ous = null;

            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL();
            String files[] = {
                "J311_0104_0101.jam",
                "J311_0104_0101.jam",
                "../cgi-bin/post.cgi"
            };

            /* execute HTTP connection */
            /* If-Modified-Since */
            if( idx>=0 && idx<=1 ) {
                // J311_0104_0102
                // J311_0104_0103
                try {
//                    url += files[idx];
                    if( idx == 0 ) {
			   url += files[0];
                        con = (HttpConnection) Connector.open(url,
                                                    Connector.READ,true);
                        con.setRequestMethod(con.GET);
                    } else {
			   url += files[2];
                        con = (HttpConnection) Connector.open(url,
                                                    Connector.WRITE,true);
                        con.setRequestMethod(con.POST);
                    }
                    /* set the time 16 min prior to the current time */
                    Calendar rightNow = Calendar.getInstance();
                    Date d = rightNow.getTime();
                    con.setIfModifiedSince(d.getTime()-1000000L);
                    con.connect();
                    int res = con.getResponseCode();
                    con.close();
                    /* If-Modified-Since should be ignored and 304 should not be returned.  */
                    if( res == 304 ) {
                        showDialog("NG: Responsed 304");
                    } else {
                        showDialog("OK" + res);
                    }
                } catch( ConnectionException ce ) {
		      if( con == null ) {
			   showDialog("Connection was not established.");
		      }
                    else {
                        int res=999;
                        try {
                            res = con.getResponseCode();
                        } catch( Exception e1 ) {}
                        showDialog("ConnectionException: response-code=" + res);
		      }
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                } finally {
                    if( con != null ) {
                        try {
                            con.close();
                        } catch( Exception e1 ) {}
                    }
                }
                return;
            }

            /* Content-Type */
            if( idx>=2 && idx<=3 ) {
                // J311_0104_0202
                // J311_0104_0203
                try {
                    url += "../cgi-bin/get1.cgi";
                    if( idx == 2 ) {
                        con = (HttpConnection) Connector.open(url,
                                                    Connector.READ,true);
                        con.setRequestMethod(con.GET);
                    } else {
                        con = (HttpConnection) Connector.open(url,
                                                    Connector.READ_WRITE,true);
                        con.setRequestMethod(con.POST);
                    }
                    con.setRequestProperty("Content-Type","mytype");
                    con.connect();
                    ins = con.openInputStream();
                    byte[] b = new byte[1024];
                    int len = ins.read(b);
                    ins.close();
                    con.close();
                    String s = new String(b);
                    if( s.startsWith("mytype") ) {
                        showDialog("Connect-Type submission");
                    } else {
                        showDialog("Content-Type not submitted ");
                    }
                } catch( ConnectionException ce ) {
		      if( con == null ) {
			   showDialog("Connection was not established.");
		      }
                    else {
                        int res=999;
                        try {
                            res = con.getResponseCode();
                        } catch( Exception e1 ) {}
                        showDialog("ConnectionException: response-code=" + res);
		      }
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                } finally {
                    if( con != null ) {
                        try {
                            con.close();
                        } catch( Exception e1 ) {}
                    }
                }
                return;
            }

            /* Date,Pragma,Connection,Authorization,LastModified */
            if( (idx>=4 && idx<=7) || idx==12 ) {
                try {
                    url += files[0];
                    con = (HttpConnection) Connector.open(url,Connector.READ_WRITE,
                                                        true);
                    con.setRequestMethod(con.POST);
                    if( idx == 4 ) {
                        // J311_0104_0301
                        con.setRequestProperty("Date",
                                            "Thu, 10 Jan 2002 12:12:31 GMT");
                    } else if( idx == 5 ) {
                        // J311_0104_0401
                        con.setRequestProperty("Pragma","no-cache");
                    } else if( idx == 6 ) {
                        // J311_0104_0501
                        con.setRequestProperty("Connection","close");
                    } else if( idx == 7 ) {
                        // J311_0104_0601
                        con.setRequestProperty("Authorization","credentials");
                    } else {
                        // J311_0104_1001
                        con.setRequestProperty("LastModified",
                                            "Thu, 10 Jan 2002 12:12:31 GMT");
                    }
                    con.connect();
                    con.close();
                    /* no way to check whether submission has been executed or not. */
                    showDialog("communication terminated");
                } catch( ConnectionException ce ) {
                    int res=999;
                    try {
                        res = con.getResponseCode();
                    } catch( Exception e1 ) {}
                    showDialog("ConnectionException: response-code=" + res);
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                } finally {
                    if( con != null ) {
                        try {
                            con.close();
                        } catch( Exception e1 ) {}
                    }
                }
                return;
            }

            /* User-Agent,Host,Content-Length */
            if( idx>=8 && idx<=11 ) {
                String cgi[] = {
                    "../cgi-bin/get2.cgi",
                    "../cgi-bin/get2.cgi",
                    "../cgi-bin/get3.cgi",
                    "../cgi-bin/get4.cgi"
                };
                url += cgi[idx-8];

                try {
                    con = (HttpConnection) Connector.open(url,Connector.READ,
                                                        true);
                    con.setRequestMethod(con.GET);
                    switch( idx ) {
                    case  8:
                        // J311_0104_0701
                        con.setRequestProperty("User-Agent","myagent");
                        break;
                    case  9:
                        // J311_0104_0702
                        /* do not set */
                        break;
                    case 10:
                        // J311_0104_0801
                        con.setRequestProperty("Host","myhost");
                        break;
                    case 11:
                        // J311_0104_0901
                        con.setRequestProperty("Content-Length","1234");
                        break;
                    }
                    con.connect();
                    ins = con.openInputStream();
                    byte[] b = new byte[1024];
                    int len = ins.read(b);
                    ins.close();
                    con.close();
                    String s = new String(b);
                    switch( idx ) {
                    case  8:
                        /* no break sentence */
                    case  9:
                        showDialog("User-Agent: " + s);
                        break;
                    case 10:
                        showDialog("Host: " + s );
                        break;
                    case 11:
                        showDialog("Content-Length: " + s);
                        break;
                    }
                } catch( ConnectionException ce ) {
                    int res=999;
                    try {
                        res = con.getResponseCode();
                    } catch( Exception e1 ) {}
                    showDialog("ConnectionException: response-code=" + res);
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString());
                } finally {
                    if( con != null ) {
                        try {
                            con.close();
                        } catch( Exception e1 ) {}
                    }
                }
                return;
            }
        }
    }
}
