/**
 * J311_0105_0101
 * MainPanel
 *
 * HTTP basic behavior/check the header reception behavior
 *
 * $Id: J311_0105_0101.java,v 1.1 2002/02/04 04:31:45 lan Exp $
 */

import java.io.*;
import java.util.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the header reception behavior 
 * @extends IApplication
 */
public class J311_0105_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the header reception behavior 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. Date",
            "2. Connection-1",
//2002/08/08 DoJa1.5            "3. Connection-2",
//            "4. Authorization",
//            "5. Host",
            "6. Content-Length",
            "7. Last-Modified",
            "8. Content-Type",
            "9. Location",
            "10. WWW-Authenticate"
        };
        String[] head = {
            "Date",
            "Connection",
//2002/08/08 DoJa1.5            "Connection",
//            "Authorization",
//            "Host",
            "Content-Length",
            "Last-Modified",
            "Content-Type",
            "Location",
            "WWW-Authenticate"
        };

        Label   lab              = new Label("header reception");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;

            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL();
//2002/08/08 DoJa1.5            if( idx == 2 ) {
//2002/08/08 DoJa1.5                url += "J311_0105_0101.jam";
//2002/08/08 DoJa1.5            } else {
                url += "../head/head.asis";
//2002/08/08 DoJa1.5            }

            /* execute HTTP connection */
            // J311_0105_0101
            // J311_0105_0201
            // J311_0105_0202
            // J311_0105_0301
            // J311_0105_0401
            // J311_0105_0501
            // J311_0105_0601
            // J311_0105_0701
            // J311_0105_0801
            // J311_0105_0901
            try {
                con = (HttpConnection) Connector.open(url,Connector.READ,true);
                con.setRequestMethod(con.GET);
                con.connect();
                String headValue = con.getHeaderField(head[idx]);
  
		  if (idx == 1 && headValue == null)
			headValue = con.getHeaderField("Proxy-Connection");

              con.close();
                showDialog(head[idx] + ": " + headValue);
            } catch( ConnectionException ce ) {
                int res=999;
                try {
                    res = con.getResponseCode();
                } catch( Exception e1 ) {}
                showDialog("ConnectionException: response-code=" + res);
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
            }
        }
    }
}
