/**
 * J311_0107_0101
 * MainPanel
 *
 * HTTP basic behavior/check the exceptions thrown at connection
 *
 * $Id: J311_0107_0101.java,v 1.2 2002/03/06 08:19:49 takanao Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the exceptions thrown at connection 
 * @extends IApplication
 */
public class J311_0107_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the exceptions thrown at connection 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        Label   lab              = new Label("exception thrown at connection");
        Button  execButton       = new Button("execute");
        Button  execButton1      = new Button("execution timeout");
        Button  execButton2      = new Button("execution HTTP_ERR");
        TextBox status           = new TextBox("status", 20,1,
                                        TextBox.DISPLAY_ANY);
        int flag = 0;

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);
            execButton1.setSize(getWidth(),execButton1.getHeight());
            add(execButton1);
            execButton2.setSize(getWidth(),execButton2.getHeight());
            add(execButton2);
            add(status);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if ( aType == ComponentListener.BUTTON_PRESSED) {
                if( aComponent == execButton ) {
                    flag = 0;
                } else if( aComponent == execButton1 ) {
                    flag = 1;
                } else if( aComponent == execButton2 ) {
                    flag = 2;
                } else {
                    return;
                }
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;

            /* URL creation */
            String url = getSourceURL();
            if( flag == 2 ) {
                url += "notfound";
            } else if( flag == 1 ) {
                url += "../cgi-bin/timeout.cgi";
            } else {
                url += "data";
            }

            status.setText("now connecting");
            /* execute HTTP connection */
            try {
                con = (HttpConnection) Connector.open(url,Connector.READ,true);
                con.setRequestMethod(con.GET);
                con.connect();
                ins = con.openInputStream();
                /* the fastest connection speed is 10240/3600 second, and the period of time for reading the input stream is indefinite. */
                for( int i=0; i<con.getLength(); i++ ) {
                    int b = ins.read();
                }
                ins.close();
                con.close();
                status.setText("finish exception thrown at connection ");
            } catch ( ConnectionException ce ) {
                status.setText("finish connection exception");
                switch( ce.getStatus() ) {
                case ConnectionException.IMODE_LOCKED:
                    // J311_0107_0101
                    showDialog("ConnectionException(IMODE_LOCKED)");
                    break;
                case ConnectionException.TIMEOUT:
                    // J311_0107_0102
                    showDialog("ConnectionException(TIMEOUT)");
                    break;
                case ConnectionException.USER_ABORT:
                    // J311_0107_0103
                    showDialog("ConnectionException(USER_ABORT)");
                    break;
                case ConnectionException.SYSTEM_ABORT:
                    // J311_0107_0104
                    showDialog("ConnectionException(SYSTEM_ABORT)");
                    break;
                case ConnectionException.HTTP_ERROR:
                    // J311_0107_0105
                    showDialog("ConnectionException(HTTP_ERROR)");
                    break;
                case ConnectionException.SELF_MODE:
                    // J311_0107_0106
                    showDialog("ConnectionException(SELF_MODE)");
                    break;
                case ConnectionException.SSL_ERROR:
                    // J311_0107_0107
                    showDialog("ConnectionException(SSL_ERROR)");
                    break;
                case ConnectionException.NO_USE:
                    // J311_0107_0108
                    showDialog("ConnectionException(NO_USE)");
                    break;
                case ConnectionException.OUT_OF_SERVICE:
                    // J311_0107_0109
                    // J311_0107_0110
                    showDialog("ConnectionException(OUT_OF_SERVICE)");
                    break;
                default:
                    showDialog("ConnectionException(other-status)");
                    break;
                }
            } catch( InterruptedIOException ie ) {
                // J311_0107_0201
                // J311_0107_0202
                // J311_0107_0203
                // J311_0107_0204
                // J311_0107_0205
                // J311_0107_0206
                // J311_0107_0207
                // J311_0107_0208
                status.setText("finish connection exception");
                showDialog("InterruptedIOException");
            } catch( Exception e ) {
                status.setText("finish connection exception");
                showDialog("NG:" + e.toString());
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
            }
        }
    }
}
