/**
 * J311_0108_0101
 * MainPanel
 *
 * HTTP basic behavior/check the input and output operations
 *
 * $Id: J311_0108_0101.java,v 1.1 2002/02/04 04:31:48 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the input and output operations
 * @extends IApplication
 */
public class J311_0108_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the input and output operations
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. InputStream",
            "2. DataInputStream"
        };
        String[][] subItems = {
            {
                "1. read()",
                "2. read(byte[])",
                "3. read(byte[],int,int)"
            },
            {
                "1. read()",
                "2. read(byte[])",
                "3. read(byte[],int,int)",
                "4. readBoolean()",
                "5. readByte()",
                "6. readChar()",
                "7. readFully(byte[])",
                "8. readFully(byte[],int,int)",
                "9. readInt()",
                "10. readLong()",
                "11. readShort()",
                "12. readUnsignedByte()",
                "13. readUnsignedShort()",
                "14. readUTF()"
            },
        };

        Label   lab              = new Label("input and output");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        ListBox menu2            = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            menu2.setItems(subItems[0]);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* when menu 1 is selected. */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* Configuration of sub menu */
                menu2.setItems(subItems[menu.getSelectedIndex()]);
                return;
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                switch( menu.getSelectedIndex() ) {
                case 0:
                    test1();
                    break;
                case 1:
                    test2();
                    break;
                }
            }
        }

        /**
         * method to execute the InputStream-OutputStream test
         */
        public void test1() {
            HttpConnection con = null;
            InputStream  ins = null;
            OutputStream ous = null;

            /* Acquisition of selected menu index */
            int idx = menu2.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL();
            url += "../cgi-bin/post.cgi";

            /* execute HTTP connection */
            int a = 0;
            byte[] b = new byte[2];
            byte[] c = new byte[3];
            int len = 0;
            try {
                con = (HttpConnection) Connector.open(url,Connector.READ_WRITE,
                                                    true);
                con.setRequestMethod(con.POST);
                /* output */
                ous = con.openOutputStream();
                String str = new String("abcd");
                byte[] bt = str.getBytes();
                switch( idx ) {
                case 0:
                    // J311_0108_0301
                    ous.write((int) bt[0]);
                    break;
                case 1:
                    // J311_0108_0302
                    ous.write(bt);
                    break;
                case 2:
                    // J311_0108_0303
                    ous.write(bt,0,4);
                    break;
                }
                ous.close();
                con.connect();
                /* input */
                ins = con.openInputStream();
                switch( idx ) {
                case 0:
                    // J311_0108_0101
                    a = ins.read();
                    break;
                case 1:
                    // J311_0108_0102
                    len = ins.read(b);
                    break;
                case 2:
                    // J311_0108_0103
                    len = ins.read(c,0,3);
                    break;
                }
                ins.close();
                con.close();
                switch( idx ) {
                case 0:
                    if( a == 'a' ) {
                        showDialog("OK");
                    } else {
                        showDialog("NG: " + a);
                    }
                    break;
                case 1:
                    if( len==2 && b[0]=='a' && b[1]=='b' ) {
                        showDialog("OK");
                    } else {
                        showDialog("NG: len=" + len + "bytes=" +
                                    (new String(b)));
                    }
                    break;
                case 2:
                    if( len==3 && c[0]=='a' && c[1]=='b' && c[2]=='c' ) {
                        showDialog("OK");
                    } else {
                        showDialog("NG: len=" + len + "bytes=" +
                                    (new String(c)));
                    }
                    break;
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
            }
        }

        /**
         * method to execute the DataInputStream-DataOutputStream test 
         */
        public void test2() {
            HttpConnection con = null;
            InputStream  ins = null;
            DataInputStream  dis = null;
            OutputStream ous = null;
            DataOutputStream dos = null;
            int v1 = 1234;
            long v2 = 12345678L;
            String str = "abcdefgh";
            byte[] bt = str.getBytes();

            /* Acquisition of selected menu index */
            int idx = menu2.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL();
            url += "../cgi-bin/post.cgi";

            /* execute HTTP connection */
            int len = 0;
            String msg = new String("");
            try {
                con = (HttpConnection) Connector.open(url,Connector.READ_WRITE,
                                                    true);
                con.setRequestMethod(con.POST);
                /* output */
                ous = con.openOutputStream();
                dos = new DataOutputStream(ous);
                switch( idx ) {
                case 0:
                    // J311_0108_0401
                    dos.write((int) bt[0]);
                    break;
                case 1:
                    /* no break sentence */
                case 2:
                    // J311_0108_0403
                    dos.write(bt,0,4);
                    break;
                case 3:
                    // J311_0108_0404
                    dos.writeBoolean(true);
                    break;
                case 4:
                    // J311_0108_0405
                    dos.writeByte((int) bt[0]);
                    break;
                case 5:
                    // J311_0108_0406
                    dos.writeChar('a');
                    break;
                case 6:
                    /* no break sentence */
                case 7:
                    // J311_0108_0407
                    dos.writeChars(str);
                    break;
                case 8:
                    // J311_0108_0408
                    dos.writeInt(v1);
                    break;
                case 9:
                    // J311_0108_0409
                    dos.writeLong(v2);
                    break;
                case 10:
                    /* no break sentence */
                case 12:
                    // J311_0108_0410
                    dos.writeShort(v1);
                    break;
                case 11:
                    dos.writeByte((int) bt[0]);
                    break;
                case 13:
                    // J311_0108_0411
                    dos.writeUTF(str);
                    break;
                }

                dos.close();
                con.connect();

                /* input */
                ins = con.openInputStream();
                dis = new DataInputStream(ins);
                switch( idx ) {
                case 0:
                    // J311_0108_0201
                    int a = dis.read();
                    if( a == 'a' ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + a;
                    }
                    break;
                case 1:
                    // J311_0108_0202
                    byte[] b = new byte[2];
                    len = dis.read(b);
                    if( len==2 && b[0]=='a' && b[1]=='b' ) {
                        msg +="OK";
                    } else {
                        msg += "NG: len=" + len + "bytes=" + (new String(b));
                    }
                    break;
                case 2:
                    // J311_0108_0203
                    byte[] c = new byte[3];
                    len = dis.read(c,0,3);
                    if( len==3 && c[0]=='a' && c[1]=='b' && c[2]=='c' ) {
                        msg += "OK";
                    } else {
                        msg += "NG: len=" + len + "bytes=" + (new String(c));
                    }
                    break;
                case 3:
                    // J311_0108_0204
                    boolean boo = dis.readBoolean();
                    if( boo ) {
                        msg += "OK";
                    } else {
                        msg += "NG: false";
                    }
                    break;
                case 4:
                    // J311_0108_0205
                    byte e = dis.readByte();
                    if( e == 'a' ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + e;
                    }
                    break;
                case 5:
                    // J311_0108_0206
                    char f = dis.readChar();
                    if( f == 'a' ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + f;
                    }
                    break;
                case 6:
                    // J311_0108_0207
                    byte[] g = new byte[4];
                    for( int i=0; i<4; i++ ) {
                        g[i] = 0;
                    }
                    dis.readFully(g);
                    if( g[0]==0 && g[1]=='a' && g[2]==0 && g[3]=='b' ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + new String(g);
                    }
                    break;
                case 7:
                    // J311_0108_0208
                    byte[] h = new byte[10];
                    for( int i=0; i<10; i++ ) {
                        h[i] = 0;
                    }
                    dis.readFully(h,0,4);
                    if( h[0]==0 && h[1]=='a' && h[2]==0 && h[3]=='b'
                        && h[5]==0 ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + new String(h);
                    }
                    break;
                case 8:
                    // J311_0108_0209
                    int j = dis.readInt();
                    if( j == v1 ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + j;
                    }
                    break;
                case 9:
                    // J311_0108_0210
                    long k = dis.readLong();
                    if( k == v2 ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + k;
                    }
                    break;
                case 10:
                    // J311_0108_0211
                    short l = dis.readShort();
                    if( l == v1 ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + l;
                    }
                    break;
                case 11:
                    // J311_0108_0212
                    int m = dis.readUnsignedByte();
                    if( m == 'a' ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + m;
                    }
                    break;
                case 12:
                    // J311_0108_0213
                    int n = dis.readUnsignedShort();
                    if( n == v1 ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + n;
                    }
                    break;
                case 13:
                    // J311_0108_0214
                    String s = dis.readUTF();
                    if( s.compareTo(str) == 0 ) {
                        msg += "OK";
                    } else {
                        msg += "NG: " + s;
                    }
                    break;
                }
                ins.close();
                con.close();
                showDialog(msg);
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
            }
        }
    }
}
