/**
 * J311_0201_0102
 *
 * HTTP connection/check the communication between server and clients for Servlet
 *
 * $Id: J311_0201_0102.java,v 1.1 2002/02/04 04:31:48 lan Exp $
 */

import java.io.*;
import java.net.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
 * check the communication behavior between server and clients for MainClass of Servlet
 * @extends HttpServlet
 */
public class J311_0201_0102 extends HttpServlet {

    /**
     * doGet method
     * @param request  HttpServletRequest
     * @param response HttpServletResponse
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response)
        throws IOException, ServletException {
        // J311_0201_0102
        /* getParameter */
        Enumeration enum = request.getParameterNames();
        String data = "";
        while( enum.hasMoreElements() ) {
            String key = (String)enum.nextElement();
            String[] v = request.getParameterValues(key);
            data += v[0];
        }
        response.setContentType("text/plain");
        response.setContentLength(data.length());
        PrintWriter out = response.getWriter();
        out.println(data);
    }

    /**
     * doGet method
     * @param request  HttpServletRequest
     * @param response HttpServletResponse
     */
    public void doPost(HttpServletRequest request, HttpServletResponse response)
        throws IOException, ServletException {
        /* getInpuStream */
        ServletInputStream sis = request.getInputStream();
        byte[] data = new byte[1024];
        int len = sis.read(data,0,1024);
        sis.close();
        if( len <= 0 ){
            return;
        }
        String s1 = "";
        if( data[0] == 1 ) {
            /* UTF */
            // J311_0201_0201
            s1 = new String(data,3,len-3,"UTF8");

        } else if( data[0] == 2 ) {
            /* Shift-JIS */
            // J311_0201_0202
            s1 = new String(data,1,len-1,"SJIS");

        } else if( data[0] == 3 ) {
            /* URLEncode */
            // J311_0201_0203
            String ss = new String(data,1,len-1,"SJIS");
            //byte[] bb = URLdecode(ss);
            //s1 = new String(bb,"SJIS");
            s1 = decode(ss);
        }
        response.setContentType("text/plain; charset=SJIS");
        PrintWriter out = response.getWriter();
        if( data[0] == 1 ) {
            out.print("UTF:");
        } else if( data[0] == 2 ) {
            out.print("SJIS:");
        } else if( data[0] == 3 ) {
            out.print("URLEncode:");
        }
        String s0 = new String("Japanese");
        if( s1.compareTo(s0) == 0 ) {
            out.print("OK:");
        } else {
            out.print("NG:");
        }
        out.print(s1);
        out.close();
    }

    /**
     * URLdecode
     * @param s  URLEncode String
     * @return byte[]  URLDecode String
     */
    private String decode(String s) throws NullPointerException,
                                                 IllegalArgumentException {
        if(s == null){
            throw new NullPointerException();
        }
        StringBuffer sb = new StringBuffer();
        for(int i=0; i<s.length(); i++) {
            char c = s.charAt(i);
            switch (c) {
                case '+':
                    sb.append(' ');
                    break;
                case '%':
                    try {
                        sb.append((char)Integer.parseInt(
                                        s.substring(i+1,i+3),16));
                    } catch (NumberFormatException e) {
                        throw new IllegalArgumentException(
                            "String is not x-www-form-urlencoded");
                    }
                    i += 2;
                    break;
                default:
                    sb.append(c);
                    break;
            }
        }
        // Undo conversion to external encoding
        String result = sb.toString();
        try {
            byte[] inputBytes = result.getBytes("ISO8859_1");
            result = new String(inputBytes,"SJIS");
        } catch (UnsupportedEncodingException e) {
            // The system should always have 8859_1
           System.out.println("****** Unsupported Encoding *****");
        }
        return result;
    }

    /**
     * Convert sjis -> unicode method
     * @param  s     sjis String
     * @return String  unicode string
     */
    private String sjis2unicode(String s)
        throws UnsupportedEncodingException {

        return new String(s.getBytes("8859_1"), "SJIS");
    }

    /**
     * Convert unicode -> sjis method
     * @param  s     unicode String
     * @return String  sjis string
     */
    private String unicode2sjis(String s)
        throws UnsupportedEncodingException {

        return new String(s.getBytes("SJIS"), "8859_1");
    }
}
