/**
 * J311_0301_0101
 * MainPanel
 *
 * HTTP basic behavior/prohibited behavior for the get Stream method 
 *
 * $Id: J311_0301_0101.java,v 1.1 2002/02/04 04:31:49 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of the prohibited behavior for the get Stream method 
 * @extends IApplication
 */
public class J311_0301_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of the prohibited behavior for the get Stream method 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. openInputS",
            "2. openOutputS",
            "3. openDataInputS",
            "4. openDataOutputS"
        };

        Label   lab              = new Label("get Stream prohibited ");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL() + "J311_0301_0101.jam";

            /* execute the process to get stream directly form Connector */
            try {
                switch( idx ) {
                case 0:
                    // J311_0301_0101
                    // J311_0301_0105
                    InputStream is = Connector.openInputStream(url);
                    break;
                case 1:
                    // J311_0301_0102
                    // J311_0301_0106
                    OutputStream os = Connector.openOutputStream(url);
                    break;
                case 2:
                    // J311_0301_0103
                    // J311_0301_0107
                    DataInputStream dis = Connector.openDataInputStream(url);
                    break;
                case 3:
                    // J311_0301_0104
                    // J311_0301_0108
                    DataOutputStream dos = Connector.openDataOutputStream(url);
                    break;
                }
                showDialog("NG: no Exception");
            } catch( IOException ioe ) {
                showDialog("IOException: " + ioe.getMessage());
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
        }
    }
}
