/**
 * J311_0302_0201
 * MainPanel
 *
 * HTTP basic behavior/prohibited behavior for wrong port
 *
 * $Id: J311_0302_0201.java,v 1.1 2002/02/04 04:31:50 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of the prohibited behavior for wrong port 
 * @extends IApplication
 */
public class J311_0302_0201 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of the prohibited behavior for wrong port 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. default->port",
            "2. port->default",
            "3. port -> another port"
        };

        Label   lab              = new Label("wrong port");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url0 = getSourceURL();
            int slashIdx = url0.indexOf("/",9);
            if( slashIdx == -1 ) {
                showDialog("SourceURL NG: " + url0);
                return;
            }
            int colonIdx = url0.indexOf(":",9);
            String url = new String("");
            try {
                switch( idx ) {
                case 0:
                    // J311_0302_0201
                    // J311_0302_0301
                    /* default->another port */
                    url = url0.substring(0,slashIdx);
                    url += ":10002";
                    url += url0.substring(slashIdx);
                    break;
                case 1:
                    // J311_0302_0202
                    // J311_0302_0302
                    /* port->default */
                    url = url0.substring(0,colonIdx);
                    url += url0.substring(slashIdx);
                    break;
                case 2:
                    // J311_0302_0203
                    // J311_0302_0303
                    /* port->another port */
                    url = url0.substring(0,colonIdx);
                    url += ":20100";
                    url += url0.substring(slashIdx);
                    break;
                }
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
                return;
            }

            /* open behavior, check that an exception occurs. */
            try {
                HttpConnection con = (HttpConnection) Connector.open(url,
                                        Connector.READ,true);
                showDialog("NG: no Exception");
            } catch( SecurityException se ) {
                showDialog("SecurityException: " + se.getMessage());
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
        }
    }
}
