/**
 * J311_0303_0101
 * MainPanel
 *
 * HTTP basic behavior/check the race condition
 *
 * $Id: J311_0303_0101.java,v 1.1 2002/02/04 04:31:50 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the race condition 
 * @extends IApplication
 */
public class J311_0303_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the race condition 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. wrong server",
            "2. wrong port",
            "3. wrong scheme",
            "4. IP"
        };

        Label   lab              = new Label("race condition");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        ListBox menu2            = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            menu2.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* when menu 1 is selected */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED ) {
                /* reset the sub menu */
                menu2.setItems(menuItems);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx1 = menu.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();
            if( idx1 == idx2 ) {
                showDialog("there is no such combination ");
                return;
            }

            /* URL creation */
            String url0 = getSourceURL();
            int slashIdx = url0.indexOf("/",9);
            if( slashIdx == -1 ) {
                showDialog("SourceURL NG: " + url0);
                return;
            }

            String url = new String("");
            String host = null;
            String port = null;
            String skeam = null;
            String ip = null;
            String prohibit = null;
            /* wrong server */
            if( idx1 == 0 || idx2 == 0 ) {
                host = "www.yahoo.com";
            } else {
                if( url0.startsWith("https") ) {
					// 2003/03/14 ->
                    //host = url0.substring(8,slashIdx-1);
					host = url0.substring(8,slashIdx);
					// 2003/03/14 <-
                } else {
					// 2003/03/14 ->
                    //host = url0.substring(7,slashIdx-1);
					host = url0.substring(7,slashIdx);
					// 2003/03/14 <-
                }
            }
            /* wrong port */
            if( idx1 == 1 || idx2 == 1 ) {
				// 2003/03/14 ->
                //port = ":10001";
				int colonIdx = url0.indexOf(":", 9);
				if( colonIdx == -1 ) {
					port = ":10001";
				} else {
					port = "1";
				}
				// 2003/03/14 <-
            }
            /* Wrong scheme */
            if( idx1 == 2 || idx2 == 2 ) {
                if( url0.startsWith("https") ) {
                    skeam = "http://";
                } else {
                    skeam = "https://";
                }
            } else {
                if( url0.startsWith("https") ) {
                    skeam = "https://";
                } else {
                    skeam = "http://";
                }
            }
            /* IP address */
            if( idx1 == 3 || idx2 == 3 ) {
                if( idx1 == 0 || idx2 == 0 ) {
                    ip = "172.158.64.151";
                } else {
                    ip = getServerIP();
                    if( ip == null ) {
                        /* abnormal termination */
                        showDialog("NG: can't get server ip");
                        return;
                    }
                    ip = ip.trim();
                }
            }
            /* prohibited address */
            if( idx1 == 4 || idx2 == 4 ) {
                if( idx1 == 3 || idx2 == 3 ) {
                    prohibit = "172.158.64.151";
                } else {
                    prohibit = "docomo.ne.jp";
                }
            }
            /* URL structure */
            url = skeam;
            if( prohibit != null ) {
                url += prohibit;
            } else if( ip != null ) {
                url += ip;
            } else {
                url += host;
            }
            if( port != null ) {
                url += port;
            }
            if( prohibit != null ) {
                url += "/ml";
            }
            url += url0.substring(slashIdx);

            /* open behavior, check that an exception occurs. */
            // J311_0303_0101
            // J311_0303_0102
            // J311_0303_0103
            // J311_0303_0104
            // J311_0303_0201
            // J311_0303_0202
            // J311_0303_0203
            // J311_0303_0204
            // J311_0303_0301
            // J311_0303_0302
            // J311_0303_0303
            // J311_0303_0304
            // J311_0303_0401
            // J311_0303_0402
            // J311_0303_0403
            // J311_0303_0404
            // J311_0303_0501
            // J311_0303_0502
            // J311_0303_0503
            // J311_0303_0504
            try {
                HttpConnection con = (HttpConnection) Connector.open(url,
                                        Connector.READ,true);
                showDialog("NG: no Exception");
            } catch( SecurityException se ) {
                showDialog("SecurityException: " + se.getMessage());
            } catch( IllegalArgumentException iae ) {
                showDialog("IllegalArgumentException: " + iae.getMessage());
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
        }

        /**
         * method to get the server IP address
         * @return  IP address of String server (null will be returned when it fails)
         */
        public String getServerIP() {
            HttpConnection con = null;
            InputStream is = null;
            String url = getSourceURL() + "../cgi-bin/getip.cgi";
            byte[] data = new byte[15];
            int len = 0;
            try {
                con= (HttpConnection) Connector.open(url,Connector.READ,true);
                con.setRequestMethod(con.GET);
                con.connect();
                is = con.openInputStream();
                len = is.read(data);
                is.close();
                con.close();
            } catch( Exception e ) {
                showDialog("getServerIP NG: " + e.toString());
                return null;
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e ) {}
                }
            }
            if( len > 6 ) {
                return (new String(data));
            } else {
                return null;
            }
        }
    }
}
