/**
 * J311_0303_0104
 * MainPanel
 *
 * HTTP basic behavior/check the race condition
 *
 * $Id: J311_0303_0104.java,v 1.1 2002/02/04 04:31:50 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the race condition 
 * @extends IApplication
 */
public class J311_0303_0104 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    	TextBox menu;
    }


    /**
     * HTTP basic behavior/main screen of checking the race condition 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. wrong server",
            "2. wrong port",
            "3. wrong scheme",
           
        };

        Label   lab              = new Label("race condition");
        ListBox menu             = new ListBox(ListBox.CHOICE);
       
        TextBox textBox1 = new TextBox("",20,1,TextBox.DISPLAY_ANY);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
       
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            add(textBox1);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* when menu 1 is selected */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED ) {
                /* reset the sub menu */
              
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }
    	
    	/**
         * method to execute the test
         */
        public void test() {
        	  int idx1 = menu.getSelectedIndex();
        
        
        	 /* URL creation */
            String url0 = getSourceURL();
            int slashIdx = url0.indexOf("/",9);
            if( slashIdx == -1 ) {
                showDialog("SourceURL NG: " + url0);
                return;
            }
            String url = new String("");
            String host = null;
            String port = null;
            String skeam = null;
            String ip = null;
            String prohibit = null;

            /* wrong server */
            if( idx1 == 0 ) {
                host = "www.yahoo.com";
            } else {
                if( url0.startsWith("https") ) {
                    host = url0.substring(8,slashIdx-1);
                } else {
                    host = url0.substring(7,slashIdx-1);
                }
            }
            /* wrong port */
            if( idx1 == 1) {
                port = ":10001";
            }
            /* Wrong scheme */
            if( idx1 == 2 ) {
                if( url0.startsWith("https") ) {
                    skeam = "http://";
                } else {
                    skeam = "https://";
                }
            } else {
                if( url0.startsWith("https") ) {
                    skeam = "https://";
                } else {
                    skeam = "http://";
                }
            }
        prohibit = textBox1.getText();

    	 /* URL structure */
            url = skeam;
            if( prohibit != null ) {
                url += prohibit;
            } else if( ip != null ) {
                url += ip;
            } else {
                url += host;
            }
            if( port != null ) {
                url += port;
            }
            url += url0.substring(slashIdx);

        /**
         * method to execute the test
         */

            try {
                HttpConnection con = (HttpConnection) Connector.open(url,Connector.READ,true);
                showDialog("NG: no Exception");
            } catch( SecurityException se ) {
                showDialog("SecurityException: " + se.getMessage());
            } catch( IllegalArgumentException iae ) {
                showDialog("IllegalArgumentException: " + iae.getMessage());
            } catch( Exception e ) {
                showDialog("NG:" + e.toString());
            }
        }

        
        	        /**
         * method to get the server IP address
         * @return  IP address of String server (null will be returned when it fails)
         */
        public String getServerIP() {
            HttpConnection con = null;
            InputStream is = null;
            String url = getSourceURL() + "../cgi-bin/getip.cgi";
            byte[] data = new byte[15];
            int len = 0;
            try {
                con= (HttpConnection) Connector.open(url,Connector.READ,true);
                con.setRequestMethod(con.GET);
                con.connect();
                is = con.openInputStream();
                len = is.read(data);
                is.close();
                con.close();
            } catch( Exception e ) {
                showDialog("getServerIP NG: " + e.toString());
                return null;
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e ) {}
                }
            }
            if( len > 6 ) {
                return (new String(data));
            } else {
                return null;
            }
        }
    }
}
