/**
 * J311_0402_0101
 * MainPanel
 *
 * HTTP basic behavior/check the ready to write status
 *
 * $Id: J311_0402_0101.java,v 1.2 2002/03/04 02:25:28 takanao Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the ready to write status 
 * @extends IApplication
 */
public class J311_0402_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     * @param   aFrame    call frame
     */
    public void showDialog(String aText, Frame aFrame) {
        MyDialog  d = new MyDialog("Result", aFrame);
        d.setText(aText);
        d.show();
    }

    /**
     * HTTP basic behavior/main screen of checking the ready to write status 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "2. setIfModifiedSince-P"
        };

        Label   lab              = new Label("ready to write status");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;
            OutputStream ous = null;

            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL() + "../cgi-bin/post.cgi";

            /* execute HTTP connection */
            switch( idx ) {
            case 0:
                // J311_0402_1502
                try {
                    con = (HttpConnection) Connector.open(url,
                                                Connector.READ_WRITE,true);
                    if( idx == 0 ) {
                        con.setRequestMethod(con.POST);
                    } else {}
                    con.setIfModifiedSince(10000);
                    con.connect();
                    showDialog("OK", this);
                } catch( Exception e ) {
                    showDialog("NG:" + e.toString(), this);
                } finally {
                    if( con != null ) {
                        try {
                            con.close();
                        } catch( Exception e1 ) {}
                    }
                }
                break;
            }
        }
    }
}

/**
 * dialog emulation class
 * avoid the limit of the number of characters
 * @implements ComponentListener
 */
class MyDialog extends Panel implements ComponentListener {

    Frame previousFrame;

    TextBox textBox;
    Button okButton = new Button("OK");
    
    /**
     * constructor of dialog emulation
     * @param aTitle title
     * @param aFrame refer to the previous screen
     */
    public MyDialog(String aTitle, Frame aFrame) {
	previousFrame = aFrame;

	int textBoxHeight = Display.getHeight()/Font.getDefaultFont().getHeight()-2;
	textBox = new TextBox(null, 40, textBoxHeight, TextBox.DISPLAY_ANY);

	setTitle(aTitle);
	add(textBox);
	add(okButton);

	setComponentListener(this);
    }

    /**
     * event handler for components
     * @param aComponent event source
     * @param aType Event type
     * @param aName event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
	if (aComponent == okButton &&
	    aType == ComponentListener.BUTTON_PRESSED) {
	    Display.setCurrent(previousFrame);
	}
    }

    /**
     * text (pseudo-dialog) display
     */
    public void show() {
	Display.setCurrent(this);
    }

    /**
     * message setting for display
     */
    public void setText(String aMessage) {
	textBox.setText(aMessage);
    }
}
