/**
 * J311_0404_0101
 * MainPanel
 *
 * HTTP basic behavior/check the write operations completed status
 *
 * $Id: J311_0404_0101.java,v 1.2 2002/02/28 13:31:09 takanao Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the write operations  completed status
 * @extends IApplication
 */
public class J311_0404_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the write operations completed status 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. close",
            "2. connect-POST",
            "3. connect-GET",
            "5. getDate",
            "6. getEncoding",
            "7. getExpiration",
            "8. getHeaderField",
            "9. getLastModified",
            "10. getLength",
            "11. getResponseCode",
            "12. getResponseMessage",
            "13. getType",
            "14. getURL",
            "15. openInputStream",
            "16. openOutputStream",
            "17. setIfModifiedSince",
            "18. setRequestMethod",
            "19. setRequestProperty"
        };

        Label   lab              = new Label("writing completed status");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;
            OutputStream ous = null;

            /* Acquisition of selected menu index */
            int idx = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL() + "../cgi-bin/post.cgi";

            /* execute HTTP connection */
            /* put it to the write operations completed status */
            try {
                con = (HttpConnection) Connector.open(url,
                        Connector.READ_WRITE, true);
                if( idx == 2 ) {
                    con.setRequestMethod(con.GET);
                } else {
                    con.setRequestMethod(con.POST);
                }
                ous = con.openOutputStream();
                byte a = (byte) 'a';
                ous.write(a);
                ous.close();
            } catch( Exception e ) {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("NG1: " + e.toString());
                return;
            }

            /* test */
            int status = 0;
            if( idx == 0 ) {
                try {
                    con.close();
                } catch (Exception e) {
                    showDialog("NG(close):" + e.toString());
                }
                // J311_0404_0101
                /* OK if the connection re-opens */
                try {
                    con = (HttpConnection) Connector.open(url,
                            Connector.READ_WRITE, true);
                    con.setRequestMethod(con.POST);
                    con.connect();
                    con.close();
                } catch( Exception e ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                    showDialog("NG3:" + e.toString());
                    return;
                }
                showDialog("OK");
                return;
            }

            if( idx >= 1 && idx <= 2 ) {
                // J311_0404_0201
                // J311_0404_0202
                try {
                    con.connect();
                    status = con.getResponseCode();
                } catch( Exception e ) {
                    if( con != null ) {
                        try {
                            con.close();
                        } catch( Exception e1 ) {}
                    }
                    showDialog("NG1: " + e.toString());
                    return;
                }
                /* close the connection */
                try {
                    con.close();
                } catch( Exception e1 ) {}
                if( status == 200 ) {
                    showDialog("OK");
                } else {
                    showDialog("NG2: status=" + status);
                }
                return;
            }

            if( idx >= 3 && idx <= 14 && idx != 12 ) {
                try {
                    switch( idx ) {
                    case 3:
                        // J311_0404_0301
                        long date = con.getDate();
                        break;
                    case 4:
                        // J311_0404_0401
                        String str = con.getEncoding();
                        break;
                    case 5:
                        // J311_0404_0501
                        long expire = con.getExpiration();
                        break;
                    case 6:
                        // J311_0404_0601
                        String header = con.getHeaderField("Content-Type");
                        break;
                    case 7:
                        // J311_0404_0701
                        long last = con.getLastModified();
                        break;
                    case 8:
                        // J311_0404_0801
                        long len = con.getLength();
                        break;
                    case 9:
                        // J311_0404_0901
                        int code = con.getResponseCode();
                        break;
                    case 10:
                        // J311_0404_1001
                        String msg = con.getResponseMessage();
                        break;
                    case 11:
                        // J311_0404_1101
                        String type = con.getType();
                        break;
                    case 13:
                        // J311_0404_1301
                        ins = con.openInputStream();
                        break;
                    case 14:
                        // J311_0404_1401
                        ous = con.openOutputStream();
                        break;
                    }
                } catch( RuntimeException re ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                    showDialog("RuntimeException: " + re.getMessage());
                    return;
                } catch( Exception e ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                    showDialog("NG2:" + e.toString());
                    return;
                }
                /* close the connection */
                try {
                    con.close();
                } catch( Exception e1 ) {}
                showDialog("NG: no Exception");
                return;
            }

            if( idx == 12 || (idx >= 15 && idx <= 17 ) ) {
                try {
                    switch( idx ) {
                    case 12:
                        // J311_0404_1201
                        String url1 = con.getURL();
                        if( url1.compareTo(url) != 0 ) {
                            try {
                                con.close();
                            } catch( Exception e1 ) {}
                            showDialog("NG: getURL()=" + url1);
                            return;
                        }
                        break;
                    case 15:
                        // J311_0404_1501
                        con.setIfModifiedSince(10000);
                        break;
                    case 16:
                        // J311_0404_1601
                        con.setRequestMethod(con.GET);
                        break;
                    case 17:
                        // J311_0404_1701
                        con.setRequestProperty("Content-Type","text/plain");
                        break;
                    }
                } catch( Exception e ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                    showDialog("NG2:" + e.toString());
                    return;
                }
                /* close the connection */
                try {
                    con.close();
                } catch( Exception e1 ) {}
                showDialog("OK");
            }
        }
    }
}
