/**
 * J311_0405_0101
 * MainPanel
 *
 * HTTP basic behavior/check the communication status
 *
 * $Id: J311_0405_0101.java,v 1.1 2002/02/04 04:31:52 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the communication status 
 * @extends IApplication
 */
public class J311_0405_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the communication status
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. communication completed",
            "2. close-GET",
            "3. close-POST",
            "5. connect",
            "6. getDate",
            "7. getEncoding",
            "8. getExpiration",
            "9. getHeaderField",
            "10. getLastModified",
            "11. getLength",
            "12. getResponseCode",
            "13. getResponseMessage",
            "14. getType",
            "15. getURL",
            "16. openIS-GET",
            "17. openIS-POST",
            "19. openOS-GET",
            "20. openOS-POST",
            "22. setIfMod-GET",
            "23. setIfMod-POST",
            "25. setRequestMethod",
            "26. setRequestProperty"
        };

        Label   lab              = new Label("communication status");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        HttpConnection con = null;
        InputStream  ins = null;
        OutputStream ous = null;
        int idx = 0;
        String url = null;
        boolean threadFlag = false;

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            idx = menu.getSelectedIndex();
            /* URL creation */
            url = getSourceURL() + "../cgi-bin/post.cgi?value=abc";

            /* execute HTTP connection */
            try {
                if( idx == 16 ) {
                    con = (HttpConnection) Connector.open(url,
                            Connector.READ, true);
                } else {
                    con = (HttpConnection) Connector.open(url,
                            Connector.READ_WRITE, true);
                }
                if( idx == 2 || idx == 15 || idx == 17 || idx == 19 ) {
                    con.setRequestMethod(con.POST);
                    // 20030212 add start 
                    //OutputStream ous = con.openOutputStream();
                    //ous.write(new byte[0]);
                    //ous.close();
                    // 20030212 add end
                } else {
                    con.setRequestMethod(con.GET);
                }
            } catch( Exception e ) {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("NG1: " + e.toString());
                return;
            }

            /* put it to the communication status */
            TestThread tt = new TestThread();
            try {
                /* activate Thread that will be operated during the communication status */
                threadFlag = false;
                if( idx != 0 ) {
                    threadFlag = true;
                    tt.start();
                }
                con.connect();
            } catch( IOException ioe ) {
                threadFlag = false;
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("IOException: " + ioe.getMessage());
                return;
            } catch( Exception e ) {
                threadFlag = false;
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("NG1: " + e.toString());
                return;
            }

            /* communication completed */
            if( idx == 0 ) {
                // J311_0405_0101
                /* OK if possible to read */
                try {
                    ins = con.openInputStream();
                    int c = ins.read();
                    ins.close();
                    con.close();
                } catch( Exception e ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                    showDialog("NG3:" + e.toString());
                    return;
                }
                showDialog("OK");
                return;
            }

            /* close the connection */
            if( con != null ) {
                try {
                    con.close();
                } catch( Exception e ) {}
            }
            /* check the result of Thread */
            while ( tt.isAlive() ) {
                try {
                    Thread.sleep(1000);
                } catch( Exception e ) {}
            }
            if( tt.conException != null ) {
                if( tt.conException.getStatus() == 
                    tt.conException.RESOURCE_BUSY ) {
                    showDialog("ConnectionException(RESOURCE_BUSY): " +
                                tt.conException.getMessage());
                } else {
                    showDialog("ConnectionException(" + 
                                tt.conException.getStatus()
                                + "): " + tt.conException.getMessage());
                }
            } else if( tt.runException != null ) {
                showDialog("RuntimeException: "+tt.runException.getMessage());
            } else if ( tt.exception != null ) {
                showDialog("NG4:" + tt.exception.toString());
            } else if( idx == 13 ) {
                if( tt.url1 != null && url.compareTo(tt.url1) == 0 ) {
                    showDialog("OK");
                } else {
                    showDialog("NG: getURL=" + tt.url1);
                }
            } else {
                showDialog("OK");
            }
        }

        /**
         * Thread to execute the test
         */
        public class TestThread extends Thread {
            ConnectionException conException = null;
            RuntimeException runException = null;
            Exception exception = null;
            String url1 = null;

            /**
             * constructor
             */
            public void TestThread() {}

            /**
             * implementation of the run method
             */
            public void run() {
                /* sleep for 1 second before executing connect */
                try {
                    Thread.sleep(1000);
                } catch( Exception e ) {}

                /* the test will be cancelled if exceptions occur in the parent thread during the connection    */
                if( ! threadFlag ) {
                    return;
                }

				// 20030213 add start
                InputStream is = null;
                OutputStream os = null;
				// 20030213 add end

                /* conduct below tests during the communication status */
                try {
                    switch( idx ) {
                    case 1:
                        // J311_0405_0201
                        con.close();			// 20030213 add
                        break;					// 20030213 add
                    case 2:
                        // J311_0405_0202
                        con.close();			// 20030213 add
                        break;					// 20030213 add
                    case 3:
                        // J311_0405_0301
                        con.connect();
                        break;
                    case 4:
                        // J311_0405_0401
                        long date = con.getDate();
                        break;
                    case 5:
                        // J311_0405_0501
                        String str = con.getEncoding();
                        break;
                    case 6:
                        // J311_0405_0601
                        long expire = con.getExpiration();
                        break;
                    case 7:
                        // J311_0405_0701
                        String header = con.getHeaderField("Content-Type");
                        break;
                    case 8:
                        // J311_0405_0801
                        long last = con.getLastModified();
                        break;
                    case 9:
                        // J311_0405_0901
                        long len = con.getLength();
                        break;
                    case 10:
                        // J311_0405_1001
                        int code = con.getResponseCode();
                        break;
                    case 11:
                        // J311_0405_1101
                        String msg = con.getResponseMessage();
                        break;
                    case 12:
                        // J311_0405_1201
                        String type = con.getType();
                        break;
                    case 13:
                        // J311_0405_1301
                        url1 = con.getURL();
                        break;
                    case 14:
                        // J311_0405_1401
                        is = con.openInputStream(); // 20030213 add
                        break;					// 20030213 add
                    case 15:
                        // J311_0405_1402
                        is = con.openInputStream(); // 20030213 add
                        break;					// 20030213 add
                    case 16:
                        // J311_0405_1501
                        os = con.openOutputStream(); // 20030213 add
                        break;					// 20030213 add
                    case 17:
                        // J311_0405_1502
                        os = con.openOutputStream(); // 20030213 add
                        break;					// 20030213 add
                    case 18:
                        // J311_0405_1601
                        con.setIfModifiedSince(10000); // 20030213 add
                        break;					// 20030213 add
                    case 19:
                        // J311_0405_1602
                        con.setIfModifiedSince(10000); // 20030213 add
                        break;					// 20030213 add
                    case 20:
                        // J311_0405_1701
                        con.setRequestMethod(con.GET);
                        break;
                    case 21:
                        // J311_0405_1801
                        con.setRequestProperty("Content-Type","text/plain");
                        break;
                    }
                } catch( ConnectionException ce ) {
                    conException = ce;
                } catch( RuntimeException re ) {
                    runException = re;
                } catch( Exception e ) {
                    exception = e;
                }
            }
        }
    }
}
