/**
 * J311_0408_0101
 * MainPanel
 *
 * HTTP basic behavior/check the reading completed status
 *
 * $Id: J311_0408_0101.java,v 1.3 2002/04/03 06:12:41 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the reading completed status
 * @extends IApplication
 */
public class J311_0408_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the reading completed status
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. close",
            "2. connect",
            "3. getDate",
            "4. getEncoding",
            "5. getExpiration",
            "6. getHeaderField",
            "7. getLastModified",
            "8. getLength",
            "9. getResponseCode",
            "10. getResponseMessage",
            "11. getType",
            "12. getURL",
            "13. openInputStream",
            "14. openOutputStream",
            "15. setIfModifiedSince",
            "16. setRequestMethod",
            "17. setRequestProperty"
        };
        String[] subItems = {
            "1. GET",
            "2. POST"
        };

        Label   lab              = new Label("reading completed status");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        ListBox menu2            = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            menu2.setItems(subItems);
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* when menu 1 is selected */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* reset the sub menu */
                menu2.setItems(subItems);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;
            OutputStream ous = null;

            /* Acquisition of selected menu index */
            int idx1 = menu.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL() + "../cgi-bin/post.cgi?value=abc";

            /* execute HTTP connection */
            /* put it to the reading completed status */
            try {
                con = (HttpConnection) Connector.open(url,
                        Connector.READ_WRITE, true);
                switch( idx2 ) {
                case 0:
                    con.setRequestMethod(con.GET);
                    break;
                case 1:
                    con.setRequestMethod(con.POST);
                    break;
                }
                con.connect();
                ins = con.openInputStream();
                int c = ins.read();
                ins.close();
            } catch( Exception e ) {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("NG1: " + e.toString());
                return;
            }

            /* test */
            if( idx1 == 0 ) {
                // J311_0408_0101
                // J311_0408_0102
                // J311_0408_0103
                try {
                    con.close();
                } catch( Exception e ) {
                    showDialog("NG1: " + e.toString());
                    return;
                }
                /* OK if the connection re-opens */
                try {
                    con = (HttpConnection) Connector.open(url,
                            Connector.READ_WRITE, true);
                    con.setRequestMethod(con.POST);
                    con.connect();
                    con.close();
                    showDialog("OK");
                } catch( Exception e ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                    showDialog("NG3:" + e.toString());
                }
                return;
            }

            if( idx1 == 1 || (idx1 >= 12 && idx1 <= 16) ) {
                try {
                    switch( idx1 ) {
                    case 1:
                        // J311_0408_0201
                        // J311_0408_0202
                        // J311_0408_0203
                        con.connect();
                        break;
                    case 12:
                        // J311_0408_1301
                        // J311_0408_1302
                        // J311_0408_1303
                        InputStream is = con.openInputStream();
                        if( is.equals(ins) ) {
                            showDialog("openInputStream() OK: same instance");
                        } else {
                            showDialog("openInputStream() NG: not same instance");
                        }
                        break;
                    case 13:
                        // J311_0408_1401
                        // J311_0408_1402
                        // J311_0408_1403
                        ous = con.openOutputStream();
                        break;
                    case 14:
                        // J311_0408_1501
                        // J311_0408_1502
                        // J311_0408_1503
                        con.setIfModifiedSince(10000);
                        break;
                    case 15:
                        // J311_0408_1601
                        // J311_0408_1602
                        // J311_0408_1603
                        con.setRequestMethod(con.GET);
                        break;
                    case 16:
                        // J311_0408_1701
                        // J311_0408_1702
                        // J311_0408_1703
                        con.setRequestProperty("Content-Type","text/plain");
                        break;
                    }
                    if( idx1 != 12 ) {
                        showDialog("NG: no Exception");
                    }
                } catch( RuntimeException re ) {
                    showDialog("RuntimeException: " + re.getMessage());
                } catch( Exception e ) {
                    showDialog("NG1: " + e.toString());
                } finally {
                    /* close the connection */
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
                return;
            }

            int status = 0;
            if( idx1 >= 2 && idx1 <= 11 ) {
                try {
                    switch( idx1 ) {
                    case 2:
                        // J311_0408_0301
                        // J311_0408_0302
                        // J311_0408_0303
                        long date = con.getDate();
                        break;
                    case 3:
                        // J311_0408_0401
                        // J311_0408_0402
                        // J311_0408_0403
                        String str = con.getEncoding();
                        break;
                    case 4:
                        // J311_0408_0501
                        // J311_0408_0502
                        // J311_0408_0503
                        long expire = con.getExpiration();
                        break;
                    case 5:
                        // J311_0408_0601
                        // J311_0408_0602
                        // J311_0408_0603
                        String header = con.getHeaderField("Content-Type");
                        break;
                    case 6:
                        // J311_0408_0701
                        // J311_0408_0702
                        // J311_0408_0703
                        long last = con.getLastModified();
                        break;
                    case 7:
                        // J311_0408_0801
                        // J311_0408_0802
                        // J311_0408_0803
                        long len = con.getLength();
                        break;
                    case 8:
                        // J311_0408_0901
                        // J311_0408_0902
                        // J311_0408_0903
                        int code = con.getResponseCode();
                        break;
                    case 9:
                        // J311_0408_1001
                        // J311_0408_1002
                        // J311_0408_1003
                        String msg = con.getResponseMessage();
                        break;
                    case 10:
                        // J311_0408_1101
                        // J311_0408_1102
                        // J311_0408_1103
                        String type = con.getType();
                        break;
                    case 11:
                        // J311_0408_1201
                        // J311_0408_1202
                        // J311_0408_1203
                        String url1 = con.getURL();
                        if( url1.compareTo(url) != 0 ) {
                            showDialog("NG: getURL()=" + url1 );
                            status = 2;
                        }
                        break;
                    }
                } catch( Exception e ) {
                    showDialog("NG2:" + e.toString());
                    status = 3;
                } finally {
                    /* close the connection */
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
                if( status == 0 ) {
                    showDialog("OK");
                }
                return;
            }
        }
    }
}
