/**
 * J311_0501_0101
 * MainPanel
 *
 * HTTP basic behavior/check SSL algorithm
 *
 * $Id: J311_0501_0101.java,v 1.1 2002/02/04 04:31:56 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP basic behavior/main class of checking the SSL algorithm
 * @extends IApplication
 */
public class J311_0501_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP basic behavior/main screen of checking the  SSL algorithm 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        Label   lab              = new Label("SSL algorithm");
        Button  execButton       = new Button("Connection");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            setTitle("HTTP basic behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* when the connect button is pressed down */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            HttpConnection con = null;
            InputStream  ins = null;
            OutputStream ous = null;

            /* URL creation */
            String url = getSourceURL() + "J311_0501_0101.jam";

            /* execute HTTP connection */
            /* check the behavior of SSL algorithm  */
            // J311_0501_0101
            // J311_0501_0102
            // J311_0501_0103
            // J311_0501_0104
            // J311_0501_0105
            // J311_0501_0106
            // J311_0501_0107
            // J311_0501_0201
            // J311_0501_0202
            // J311_0501_0203
            // J311_0501_0204
            // J311_0501_0205
            // J311_0501_0206
            // J311_0501_0207
            try {
                con = (HttpConnection) Connector.open(url,
                        Connector.READ, true);
                con.setRequestMethod(con.GET);
                con.connect();
                con.close();
                showDialog("OK");
            } catch( ConnectionException ce ) {
                if( ce.getStatus() == ce.SSL_ERROR ) {
                    showDialog("ConnectionException(SSL_ERROR)");
                } else {
                    showDialog("ConnectionException(" +
                                ce.getStatus() + ")");
                }
            } catch( Exception e ) {
                showDialog("NG1: " + e.toString());
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
            }
        }
    }
}
