/**
 * J312_0101_0101
 *
 * check the boundary when HTTP connection is opened 
 *
 * $Id: J312_0101_0101.java,v 1.1 2002/02/04 04:40:58 lan Exp $
 */

import java.io.*;
import java.util.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class of checking the boundary when HTTP connection is opened 
 * @extends IApplication
 */
public class J312_0101_0101 extends IApplication
{
    /**
     * the start method of i appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * main screen of checking the boundary when HTTP connection is opened 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menulist = {
            "1. URL255",
            "2. URL256",
            "3. URL255+P512",
            "4. URL255+P513",
            "5. URL256+P513"
        };
        String[] subItems = {
            "1. POST",
            "2. GET",
        };

        Label title;
        ListBox menu;
        ListBox menu2;
        Button exe;

        HttpConnection  con = null;
        InputStream     is = null;
        OutputStream    os = null;

        /**
         * Constructors of the MainPanel class
         */
        MainPanel() {
            /* create components */
            setTitle("HTTP communication boundary");
            title=new Label("boundary when opening");
            title.setSize(getWidth(),title.getHeight());
            add(title);
            menu=new ListBox(ListBox.CHOICE);
            menu2=new ListBox(ListBox.CHOICE);
            menu.setItems(menulist);
            menu2.setItems(subItems);
            add(menu);
            add(menu2);
            exe = new Button("execute");
            add(exe);

            /* Listener setting */
            setSoftKeyListener(this);
            setSoftLabel(Frame.SOFT_KEY_1, "exit");
            setComponentListener(this);
        }

        /**
         * Dialog display method
         * @param   aText       Displayed character string
         */
        public void showDialog(String aText) {
            Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
            d.setText(aText);
            d.show();
        }

        /**
         * When soft key is pressed, end the application
         * @param anIndex   Index of soft key
         */
        public void softKeyPressed(int anIndex) {
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * When soft key is released, operate nothing
         * @param anIndex   Index of soft key
         */
        public void softKeyReleased(int anIndex) {}

        /**
         * receive the events generated in components
         * @param aComponent    the component the event occurred
         * @param aType      event type
         * @param aParam       event parameter
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* When Menu is selected, */
            if( aComponent == menu &&
                aType == ComponentListener.SELECTION_CHANGED ) {
                /* Configuration of sub menu */
                menu2.setItems(subItems);
            }

            /* In the case execute button is pressed */
            if (aComponent == exe &&
                aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test for the selected menu */
                test();
            }
        }

        /**
         * the test to check the boundary when HTTP communication is opened
         */
        public void test() {
            int idx1 = menu.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();
            /* 512byte parameter */
            String para = new String("para=1234567");
            for( int i=0; i<50; i++ ) {
                para += "1234567890";
            }
            if( para.length() != 512 ) {
                showDialog("NG:para.length=" + para.length());
                return;
            }
            /* URL creation */
            String url = getSourceURL();


            if( idx1==0 || idx1==2 || idx1==3 ) {
                int len = url.length();
                len = 255 - len;
                for(int i=0; i<len-4; i++){
                        url += "2";
                }

                url += ".cgi";

                if( url.length() != 255 ) {
                    showDialog("NG: url.length=" + url.length());
                    return;
                }
                   // modified by kuroda 2003/2/13 
                   // sends the value of 'len-4'(4 == strlen(".cgi")) and 
                   // make a file with long filename
                  {
                    HttpConnection  con_cgi = null;
                    String url_cgi = getSourceURL();
                    url_cgi += "longname1.cgi?";
                    url_cgi += Integer.toString(len-4);

                      try{
                        con_cgi=(HttpConnection) Connector.open(url_cgi,Connector.READ_WRITE, true);
                        con_cgi.setRequestMethod(con_cgi.GET);
                        con_cgi.connect();
                        con_cgi.close();
                      }catch(Exception e){
                        showDialog("NG: " + e.toString());
                      }
                  }

            } else {
                int len = url.length();
                len = 256 - len;
                for(int i=0; i<len; i++){
                        url += "3";
                }
                if( url.length() != 256 ) {
                    showDialog("NG: url.length=" + url.length());
                    return;
                }
                   // modified by kuroda 2003/2/13 
                   // sends the value of 'len-4' and make a file with long filename
                  {
                    HttpConnection  con_cgi = null;
                    String url_cgi = getSourceURL();
                    url_cgi += "longname2.cgi?";
                    url_cgi += Integer.toString(len-4);

                      try{
                        con_cgi=(HttpConnection) Connector.open(url_cgi,Connector.READ_WRITE, true);
                        con_cgi.setRequestMethod(con_cgi.GET);
                        con_cgi.connect();
                        con_cgi.close();
                      }catch(Exception e){
                        showDialog("NG: " + e.toString());
                      }
                  }
            }

            /* URL with parameter */
            if( idx1 == 3 || idx1 == 4 ) {
                para += "1";
                if( para.length() != 513 ) {
                    showDialog("NG: para.length=" + para.length());
                    return;
                }
            }
            if( idx1 >= 2 ) {
                url += "?" + para;
            }

            



            /* open the HTTP connection */
            // J312_0101_0101
            // J312_0101_0102
            // J312_0101_0103
            // J312_0101_0104
            // J312_0101_0201
            // J312_0101_0202
            // J312_0101_0203
            // J312_0101_0204
            // J312_0102_0101
            // J312_0102_0102
            // J312_0102_0103
            // J312_0102_0104
            // J312_0102_0201
            // J312_0102_0202
            // J312_0102_0203
            // J312_0102_0204
            // J312_0102_0301
            // J312_0102_0302
            // J312_0102_0303
            // J312_0102_0304
            try {
             con=(HttpConnection) Connector.open(url,Connector.READ_WRITE, true);

             switch( idx2 ) {
                   
                case 0:
                    con.setRequestMethod(con.POST);
                    break;
                case 1:
                    con.setRequestMethod(con.GET);
                    break;
                }
                con.connect();
                con.close();
                showDialog("OK");
            } catch( IllegalArgumentException iae ) {
                showDialog("IllegalArgumentException: " + iae.getMessage());
            } catch( ConnectionException ce ) {
                showDialog("ConnectionException StatusCode: " + ce.getStatus());
            } catch( Exception e ) {
                showDialog("NG: " + e.toString());
            } finally {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e ) {}
                }
            }
        }
    }
}
