/**
 * J312_0201_0201
 * MainPanel
 *
 * HTTP boundary behavior/reception behavior
 *
 * $Id: J312_0201_0201.java,v 1.1 2002/02/04 04:40:58 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP boundary behavior/main class of the reception behavior 
 * @extends IApplication
 */
public class J312_0201_0201 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP boundary behavior/main screen of the reception behavior 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. GET"
        };
        String[] subItems = {
            "1. 10K",
            "2. over 10k"
        };

        Label   lab              = new Label("reception behavior 1");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        ListBox menu2            = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            menu2.setItems(subItems);
            setTitle("HTTP boundary behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* when menu 1 is selected. */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* reset the sub menu */
                menu2.setItems(subItems);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx1 = menu.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL();
            switch( idx2 ) {
            case 0:
                url += "../cgi-bin/get10k.cgi";
                break;
            case 1:
                url += "../cgi-bin/get10kplus.cgi?para=abcdefghij";
                break;
            }

            /* execute HTTP connection */
            HttpConnection con = null;
            InputStream is = null;
            try {
                con = (HttpConnection) Connector.open(url,Connector.READ_WRITE,
                                                    true);
                if( idx1 == 0 ) {
                    con.setRequestMethod(con.GET);
                } else {}
                con.connect();
                is = con.openInputStream();
            } catch( Exception e ) {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("NG: " + e.toString());
                return;
            }

            /* execute the read operations */
            byte[] data = new byte[10250];
            for(int i=10240; i<10250; i++ ) {
                data[i] = 0;
            }
            long contentLen = 0;
            int len = 0;
            // J312_0201_0201
            // J312_0201_0202
            try {
                contentLen = con.getLength();
                len = is.read(data);
                is.close();
                con.close();
            } catch( Exception e ) {
                if( con != null ) {
                    try {
                        con.close();
                    } catch( Exception e1 ) {}
                }
                showDialog("NG: " + e.toString());
                return;
            }
            /* check the data that has been read */
            if( idx2 == 0 && contentLen != 10240 ) {
                showDialog("NG: ContentLength=" + contentLen);
                return;
            }
            if( idx2 == 1 && contentLen != 10250 ) {
                showDialog("NG: ContentLength=" + contentLen);
                return;
            }
            if( len != 10240 ) {
                showDialog("NG: InputDataLength=" + len);
                return;
            }
            int flag = -1;
            for( int i=0; i<1024; i++ ) {
                int a = (int) '1';
                for( int j=0; j<10; j++ ) {
                    int b = a+j;
                    if( j == 9 ) {
                        b = (int) '0';
                    }
                    if( data[i*10+j] != (byte) b ) {
                        flag = i*10+j;
                        break;
                    }
                }
                if( flag != -1 ) {
                    break;
                }
            }
            if( flag != -1 ) {
                for( int i=10240; i<10250; i++ ) {
                    if( data[i] != 0 ) {
                        flag = i;
                        break;
                    }
                }
            }
            if( flag != -1 ) {
                byte[] b = new byte[1];
                b[0] = data[flag];
                String str = new String(b);
                showDialog("NG: data unmatch at " + flag + ":" + str);
                return;
            }
            showDialog("OK");
        }
    }
}
