/**
 * J312_0204_0101
 * MainPanel
 *
 * HTTP boundary behavior/behavior that will become a boundary after the read operations
 *
 * $Id: J312_0204_0101.java,v 1.1 2002/02/04 04:40:59 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP boundary behavior/main class of behavior that will become a boundary after the read operations
 * @extends IApplication
 */
public class J312_0204_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP boundary behavior/main screen of behavior that will become a boundary after the read operations
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. InputStream",
            "2. DataInputStream"
        };
        String[][] subItems = {
            {
                "1. read()",
                "2. read(byte[])",
                "3. read(byte[],int,int)"
            },
            {
                "1. read()",
                "2. read(byte[])",
                "3. read(byte[],int,int)",
                "4. readBoolean()",
                "5. readChar()",
                "6. readFully(byte[])",
                "7. readFully(byte[],int,int)",
                "8. readInt()",
                "9. readLong()",
                "10. readShort()",
                "11. readUnsignedByte()",
                "12. readUnsignedShort()",
                "13. readUTF()"
            }
        };

        Label   lab              = new Label("boundary after reading");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        ListBox menu2            = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            menu2.setItems(subItems[0]);
            setTitle("HTTP boundary behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* when menu 1 is selected. */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* reset the sub menu */
                menu2.setItems(subItems[menu.getSelectedIndex()]);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx1 = menu.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL() + "../cgi-bin/post.cgi";

            /* open the input stream directly */
            HttpConnection con = null;
            InputStream is = null;
            DataInputStream dis = null;
            DataOutputStream dos = null;
            byte[] starts = {(byte)'v', (byte)'a', (byte)'l', (byte)'u',
                             (byte)'e', (byte)'='};
            byte dataA = (byte) 'a';
            byte[] dataB = {(byte) 'a', (byte) 'b'};
            boolean dataC = true;
//2002/09/25 Doja1.5            char dataD = '';
            char dataD = '\uE63E';
            int dataE = 123456;
            long dataF = 123456789L;
            short dataG = 1234;
            String dataH = "unicode";
            try {
                con = (HttpConnection) Connector.open(url,
                                        Connector.READ_WRITE,true);
                con.setRequestMethod(con.POST);
                dos = con.openDataOutputStream();
                dos.write(starts,0,starts.length);
                switch( idx2 ) {
                case 0:
                    /* no break sentence */
                case 10:
                    dos.write((int)dataA);
                    break;
                case 1:
                    /* no break sentence */
                case 2:
                    /* no break sentence */
                case 5:
                    /* no break sentence */
                case 6:
                    dos.write(dataB,0,dataB.length);
                    break;
                case 3:
                    dos.writeBoolean(dataC);
                    break;
                case 4:
                    dos.writeChar((int)dataD);
                    break;
                case 7:
                    dos.writeInt(dataE);
                    break;
                case 8:
                    dos.writeLong(dataF);
                    break;
                case 9:
                    /* no break sentence */
                case 11:
                    dos.writeShort((int)dataG);
                    break;
                case 12:
                    dos.writeUTF(dataH);
                    break;
                }
                dos.close();
                con.connect();
                if( idx1 == 0 ) {
                    is = con.openInputStream();
                } else {
                    dis = con.openDataInputStream();
                }
            } catch( Exception e ) {
                closeConnection(con);
                showDialog("NG1: " + e.toString());
                return;
            }
            if( con.getLength() <= starts.length ) {
                closeConnection(con);
                showDialog("NG2: Content-Length=" + con.getLength());
                return;
            }
            /* read up to the end-1position */
            byte[] sts = new byte[starts.length];
            int len = 0;
            try {
                if( idx1 == 0 ) {
                    len=is.read(sts,0,sts.length);
                } else {
                    len=dis.read(sts,0,sts.length);
                }
            } catch( Exception e ) {
                closeConnection(con);
                showDialog("NG3: " + e.toString());
                return;
            }
            if( len != starts.length ) {
                closeConnection(con);
                showDialog("NG4: len=" + len);
                return;
            }

            /* read the data from the end-1 position */
            boolean flag = false;
            byte b;
            byte[] bb = new byte[2];
            char c = 0;
            try {
                switch( idx1 ) {
                case 0:
                    /* InputStream */
                    switch( idx2 ) {
                    case 0:
                        // J312_0204_0101
                        b = (byte) is.read();
                        if( b == dataA ) {
                            flag = true;
                        }
                        break;
                    case 1:
                        // J312_0204_0102
                        len = is.read(bb);
                        if( bb[0] == dataB[0] && bb[1]==dataB[1] && len == 2 ){
                            flag = true;
                        }
                        break;
                    case 2:
                        // J312_0204_0103
                        len = is.read(bb,0,2);
                        if( bb[0] == dataB[0] && bb[1]==dataB[1] && len == 2 ){
                            flag = true;
                        }
                        break;
                    }
                    break;
                case 1:
                    /* DataInputStream */
                    switch( idx2 ) {
                    case 0:
                        // J312_0204_0201
                        b = (byte) dis.read();
                        if( b == dataA ) {
                            flag = true;
                        }
                        break;
                    case 1:
                        // J312_0204_0202
                        len = dis.read(bb);
                        if( bb[0] == dataB[0] && bb[1]==dataB[1] && len == 2 ){
                            flag = true;
                        }
                        break;
                    case 2:
                        // J312_0204_0203
                        len = dis.read(bb,0,2);
                        if( bb[0] == dataB[0] && bb[1]==dataB[1] && len == 2 ){
                            flag = true;
                        }
                        break;
                    case 3:
                        // J312_0204_0204
                        boolean boo = dis.readBoolean();
                        if( boo == dataC ) {
                            flag = true;
                        }
                        break;
                    case 4:
                        // J312_0204_0205
                        c = dis.readChar();
                        if( c == dataD ) {
                            flag = true;
                        }
                        break;
                    case 5:
                        // J312_0204_0206
                        dis.readFully(bb);
                        if( bb[0] == dataB[0] && bb[1]==dataB[1] ){
                            flag = true;
                        }
                        break;
                    case 6:
                        // J312_0204_0207
                        dis.readFully(bb,0,2);
                        if( bb[0] == dataB[0] && bb[1]==dataB[1] ){
                            flag = true;
                        }
                        break;
                    case 7:
                        // J312_0204_0208
                        int i = dis.readInt();
                        if( i == dataE ) {
                            flag = true;
                        }
                        break;
                    case 8:
                        // J312_0204_0209
                        long j = dis.readLong();
                        if( j == dataF ) {
                            flag = true;
                        }
                        break;
                    case 9:
                        // J312_0204_0210
                        short k = dis.readShort();
                        if( k == dataG ) {
                            flag = true;
                        }
                        break;
                    case 10:
                        // J312_0204_0211
                        i = dis.readUnsignedByte();
                        if( i == (int) dataA ) {
                            flag = true;
                        }
                        break;
                    case 11:
                        // J312_0204_0212
                        i = dis.readUnsignedShort();
                        if( i == (int) dataG ) {
                            flag = true;
                        }
                        break;
                    case 12:
                        // J312_0204_0213
                        String s = dis.readUTF();
                        if( s.compareTo(dataH) == 0 ) {
                            flag = true;
                        }
                        break;
                    }
                    break;
                }
            } catch( EOFException eofe ) {
                closeConnection(con);
                showDialog("EOFException: " + eofe.getMessage());
                return;
            } catch( Exception e ) {
                closeConnection(con);
                showDialog("NG: " + e.toString());
                return;
            }

            /* close the connection */
            closeConnection(con);

            /* result judgment */
            if( flag ) {
                showDialog("OK");
            } else {
                showDialog("NG: data unmatch");
            }
        }

        /**
         * close the connection
         * @param con   HttpConnection
         */
        public void closeConnection(HttpConnection con) {
            if( con != null ) {
                try {
                    con.close();
                } catch( Exception e ) {}
            }
        }
    }
}
