/**
 * J312_0206_0101
 * MainPanel
 *
 * HTTP boundary behavior/the read operations when it straddles the boundary
 *
 * $Id: J312_0206_0101.java,v 1.1 2002/02/04 04:40:59 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP boundary behavior/main class of the read operations when it straddles the boundary 
 * @extends IApplication
 */
public class J312_0206_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP boundary behavior/main screen of the read operations when it straddles the boundary 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. InputStream",
            "2. DataInputStream"
        };
        String[][] subItems = {
            {
                "1. read(byte[])",
                "2. read(byte[],int,int)"
            },
            {
                "1. read(byte[])",
                "2. read(byte[],int,int)",
                "3. readChar()",
                "4. readFully(byte[])",
                "5. readFully(byte[],int,int)",
                "6. readInt()",
                "7. readLong()",
                "8. readShort()",
                "9. readUnsignedShort()",
                "10. readUTF()"
            }
        };

        Label   lab              = new Label("the read operations straddles the boundary");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        ListBox menu2            = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            menu2.setItems(subItems[0]);
            setTitle("HTTP boundary behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* when menu 1 is selected. */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* reset the sub menu */
                menu2.setItems(subItems[menu.getSelectedIndex()]);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx1 = menu.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL() + "../cgi-bin/post.cgi";

            /* open the input stream  */
            HttpConnection con = null;
            InputStream is = null;
            DataInputStream dis = null;
            DataOutputStream dos = null;
            byte[] starts = {(byte)'v', (byte)'a', (byte)'l', (byte)'u',
                             (byte)'e', (byte)'=', (byte)'a'};
            try {
                con = (HttpConnection) Connector.open(url,
                                        Connector.READ_WRITE,true);
                con.setRequestMethod(con.POST);
                dos = con.openDataOutputStream();
                dos.write(starts,0,starts.length);
                dos.close();
                con.connect();
                if( idx1 == 0 ) {
                    is = con.openInputStream();
                } else {
                    dis = con.openDataInputStream();
                }
            } catch( Exception e ) {
                closeConnection(con);
                showDialog("NG1: " + e.toString());
                return;
            }

            /* read up to the end-1byte position */
            byte[] sts = new byte[starts.length-1];
            int len = 0;
            try {
                if( idx1 == 0 ) {
                    len=is.read(sts,0,sts.length);
                } else {
                    len=dis.read(sts,0,sts.length);
                }
            } catch( Exception e ) {
                closeConnection(con);
                showDialog("NG3: " + e.toString());
                return;
            }
            if( len != starts.length-1 ) {
                closeConnection(con);
                showDialog("NG4: len=" + len);
                return;
            }

            /* read the data from the end-1byte position */
            byte[] bb = new byte[2];
            char c = 0;
            try {
                switch( idx1 ) {
                case 0:
                    /* InputStream */
                    switch( idx2 ) {
                    case 0:
                        // J312_0206_0101
                        len = is.read(bb);
                        if( len == 1 ){
                            closeConnection(con);
                            showDialog("OK");
                            return;
                        }
                        break;
                    case 1:
                        // J312_0206_0102
                        len = is.read(bb,0,2);
                        if( len == 1 ){
                            closeConnection(con);
                            showDialog("OK");
                            return;
                        }
                        break;
                    }
                    break;
                case 1:
                    /* DataInputStream */
                    switch( idx2 ) {
                    case 0:
                        // J312_0206_0201
                        len = dis.read(bb);
                        if( len == 1 ){
                            closeConnection(con);
                            showDialog("OK");
                            return;
                        }
                        break;
                    case 1:
                        // J312_0206_0202
                        len = dis.read(bb,0,2);
                        if( len == 1 ){
                            closeConnection(con);
                            showDialog("OK");
                            return;
                        }
                        break;
                    case 2:
                        // J312_0206_0204
                        c = dis.readChar();
                        break;
                    case 3:
                        // J312_0206_0205
                        dis.readFully(bb);
                        break;
                    case 4:
                        // J312_0206_0206
                        dis.readFully(bb,0,2);
                        break;
                    case 5:
                        // J312_0206_0207
                        int i = dis.readInt();
                        break;
                    case 6:
                        // J312_0206_0208
                        long j = dis.readLong();
                        break;
                    case 7:
                        // J312_0206_0209
                        short k = dis.readShort();
                        break;
                    case 8:
                        // J312_0206_0210
                        i = dis.readUnsignedShort();
                        break;
                    case 9:
                        // J312_0206_0211
                        String s = dis.readUTF();
                        break;
                    }
                    break;
                }
                showDialog("NG: no Exception");
            } catch( EOFException eofe ) {
                closeConnection(con);
                showDialog("EOFException");
                return;
            } catch( Exception e ) {
                closeConnection(con);
                showDialog("NG: " + e.toString());
                return;
            }

            /* close the connection */
            closeConnection(con);
        }

        /**
         * close the connection
         * @param con   HttpConnection
         */
        public void closeConnection(HttpConnection con) {
            if( con != null ) {
                try {
                    con.close();
                } catch( Exception e ) {}
            }
        }
    }
}
