/**
 * J312_0306_0101
 * MainPanel
 *
 * HTTP boundary behavior/check the write operations when it straddles the boundary
 *
 * $Id: J312_0306_0101.java,v 1.1 2002/02/04 04:41:01 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP boundary behavior/main class of checking the write operations when it straddles the boundary 
 * @extends IApplication
 */
public class J312_0306_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP boundary behavior/main screen of checking  the write operations when it straddles the boundary 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. OutputStream",
            "2. DataOutputStream"
        };
        String[][] subItems = {
            {
                "1. write(byte[])",
                "2. write(byte[],int,int)"
            },
            {
                "1. write(byte[],int,int)",
                "2. writeChar()",
                "3. writeChars()",
                "4. writeInt()",
                "5. writeLong()",
                "6. writeShort()",
                "7. writeUTF()"
            }
        };

        Label   lab              = new Label("writing straddles the boundary");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        ListBox menu2            = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            menu2.setItems(subItems[0]);
            setTitle("HTTP boundary behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* when menu 1 is selected. */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* reset the sub menu */
                menu2.setItems(subItems[menu.getSelectedIndex()]);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx1 = menu.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL() + "../cgi-bin/post.cgi";

            /* open the input stream  */
            HttpConnection con = null;
            OutputStream os = null;
            DataOutputStream dos = null;
            int len = 5120;
            byte[] data = new byte[len];
            for( int i=0; i<len; i++ ) {
                data[i] = (byte) 'a';
            }
            byte[] bb = {(byte)'b', (byte)'c'};
            int length = 0;
            try {
                con = (HttpConnection) Connector.open(url,
                                        Connector.READ_WRITE,true);
                con.setRequestMethod(con.POST);
                if( idx1 == 0 ) {
                    os = con.openOutputStream();
                    os.write(data,0,len-1);
                    switch( idx2 ) {
                    case 0:
                        // J312_0306_0101
                        os.write(bb);
                        break;
                    case 1:
                        // J312_0306_0102
                        os.write(bb,0,2);
                        break;
                    }
                    os.close();
                } else {
                    dos = con.openDataOutputStream();
                    dos.write(data,0,len-1);
                    switch( idx2 ) {
                    case 0:
                        // J312_0306_0202
                        dos.write(bb,0,2);
                        break;
                    case 1:
                        // J312_0306_0204
//2002/09/26 Doja1.5                        char c = '';
                        char c = '\uE63E';
                        dos.writeChar((int) c);
                        break;
                    case 2:
                        // J312_0306_0205
                        dos.writeChars("Kanji Characters");
                        break;
                    case 3:
                        // J312_0306_0206
                        int i = 1234567;
                        dos.writeInt(i);
                        break;
                    case 4:
                        // J312_0306_0207
                        long j = 1234567890L;
                        dos.writeLong(j);
                        break;
                    case 5:
                        // J312_0306_0208
                        short k = 12345;
                        dos.writeShort((int) k);
                        break;
                    case 6:
                        // J312_0306_0209
                        String str = new String("unicode");
                        dos.writeUTF(str);
                        break;
                    }
                    dos.close();
                }
                con.connect();
                length = (int) con.getLength();
                con.close();
                showDialog("NG: no Exception. getLength=" + length);
            } catch( IOException ioe ) {
                closeConnection(con);
                showDialog("IOException: " + ioe.getMessage());
                return;
            } catch( Exception e ) {
                closeConnection(con);
                showDialog("NG1: " + e.toString());
                return;
            }
        }


        /**
         * close the connection
         * @param con   HttpConnection
         */
        public void closeConnection(HttpConnection con) {
            if( con != null ) {
                try {
                    con.close();
                } catch( Exception e ) {}
            }
        }
    }
}
