/**
 * J312_0307_0101
 * MainPanel
 *
 * HTTP boundary behavior/behavior of header submission  
 *
 * $Id: J312_0307_0101.java,v 1.1 2002/02/04 04:41:02 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP boundary behavior/main class of operating the header submission 
 * @extends IApplication
 */
public class J312_0307_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP boundary behavior/main screen of the header behavior 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. header 256b",
            "2. header over 256b"
        };

        Label   lab              = new Label("header submission behavior");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP boundary behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx1 = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL() + "dummy.cgi";

            /* create header of 7168byte */
            /* 7168-"Content-Type:" = 7155 */
            String header = "123456";
            for(int i=0; i<25; i++ ) {
                header += "1234567890";
            }
            if( header.length() != 256 ) {
                showDialog("NG1: header.length=" + header.length());
                return;
            }
            if( idx1 == 1 ) {
                /* create header larger than 7168byte */
                header += "1";
            }

            /* execute HTTP connection */
            HttpConnection con = null;
            int status = 0;
            try {
                con = (HttpConnection) Connector.open(url,
                                        Connector.READ_WRITE,true);
                con.setRequestMethod(con.POST);
                // J312_0307_0101
                // J312_0307_0102
                con.setRequestProperty("Content-Type",header);
                con.connect();
                /* get response-code */
                status = con.getResponseCode();
                con.close();
            } catch( ConnectionException ce ) {
                try {
                    status = con.getResponseCode();
                } catch( Exception e1 ) {}
                closeConnection(con);
                if( status != 400 ) {
                    showDialog("NG(status=" + status +
                        ": ConnectionException: " + ce.getMessage());
                } else {
                    showDialog("status=400");
                }
                return;
            } catch( Exception e ) {
                closeConnection(con);
                showDialog("NG: " + e.toString());
                return;
            }

            /* result output */
            showDialog("status=" + status);
        }

        /**
         * close the connection
         * @param con   HttpConnection
         */
        public void closeConnection(HttpConnection con) {
            if( con != null ) {
                try {
                    con.close();
                } catch( Exception e ) {}
            }
        }
    }
}
