/**
 * J313_0101_0101
 * MainPanel
 *
 * HTTP repeat behavior/behavior of repeating the single communication 
 *
 * $Id: J313_0101_0101.java,v 1.1 2002/02/04 04:44:06 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP repeat behavior/main class of behavior of repeating the single communication 
 * @extends IApplication
 */
public class J313_0101_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP repeat behavior/main screen of behavior of repeating single communication
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "1. Method-wise",
            "2. URL wise"
        };
        String[] subItems = {
            "1. GET",
            "2. GET-If-Modified",
            "4. POST"
        };

        Label   lab              = new Label("single repeat");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        ListBox menu2            = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            menu2.setItems(subItems);
            setTitle("HTTP repeat behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            add(menu2);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* when menu 1 is selected */
            if (aComponent == menu
                && aType == ComponentListener.SELECTION_CHANGED) {
                /* reset the sub menu */
                menu2.setItems(subItems);
            }

            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx1 = menu.getSelectedIndex();
            int idx2 = menu2.getSelectedIndex();
            /* URL creation */
            String url0 = getSourceURL() + "../cgi-bin/";
            String files[] = {
                "direct1.cgi",
                "direct2.cgi",
                "direct3.cgi",
                "direct4.cgi",
                "direct5.cgi",
                "direct6.cgi",
                "direct7.cgi",
                "direct8.cgi",
                "direct9.cgi",
                "direct10.cgi",
                "direct11.cgi",
                "direct12.cgi",
                "direct13.cgi",
                "direct14.cgi",
                "direct15.cgi",
                "direct16.cgi",
                "direct17.cgi",
                "direct18.cgi",
                "direct19.cgi",
                "direct20.cgi"
            };

            /* operate communication repeatedly */
            HttpConnection con = null;
            int status = 0;
            for( int i=0; i<20; i++ ) {
                String url = url0;
                if( idx1 == 0 ) {
                    url += "direct.cgi";
                } else {
                    url += files[i] + "?param=abc";
                }
                try {
                    con = (HttpConnection) Connector.open(url,
                                        Connector.READ_WRITE,true);
                    switch( idx2 ) {
                    case 0:
                        // J313_0101_0101
                        // J313_0101_0103
                        // J313_0102_0101
                        con.setRequestMethod(con.GET);
                        break;
                    case 1:
                        // J313_0101_0102
                        // J313_0101_0104
                        // J313_0102_0102
                        con.setRequestMethod(con.GET);
                        con.setIfModifiedSince(10000);
                        break;
                    case 2:
                        // J313_0101_0301
                        // J313_0101_0302
                        // J313_0102_0301
                        con.setRequestMethod(con.POST);
                        DataOutputStream dos = con.openDataOutputStream();
                        dos.writeUTF("post data");
                        dos.close();
                        break;
                    }
                    con.connect();
                    status = con.getResponseCode();
                    if( status != 200 ) {
                        closeConnection(con);
                        showDialog("NG(" + i + "): status=" + status);
                        return;
                    }
                    con.close();
                } catch( Exception e ) {
                    closeConnection(con);
                    showDialog("NG(" + i + "): " + e.toString());
                    return;
                }
            }
            showDialog("OK");
        }

        /**
         * close the connection
         * @param con   HttpConnection
         */
        public void closeConnection(HttpConnection con) {
            if( con != null ) {
                try {
                    con.close();
                } catch( Exception e ) {}
            }
        }
    }
}
