/**
 * J313_0201_0101
 * MainPanel
 *
 * HTTP repeat behavior/behavior of repeating continuous communication
 *
 * $Id: J313_0201_0101.java,v 1.2 2002/04/03 11:11:13 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * HTTP repeat behavior/main class of behavior of repeating continuous communication 
 * @extends IApplication
 */
public class J313_0201_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * Dialog display method
     * @param   aText       Displayed character string
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "Result");
        d.setText(aText);
        d.show();
    }


    /**
     * HTTP repeat behavior/main screen of behavior of repeating continuous communication 
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
        String[] menuItems = {
            "2. GET-POST"
        };

        Label   lab              = new Label("continuous repeat");
        ListBox menu             = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * Constructor of MainPanel class
         */
        public MainPanel() {
            /* Settings of display items */
            menu.setItems(menuItems);
            setTitle("HTTP repeat behavior");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* Add each component to screen */
            add(lab);
            add(menu);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* Listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * When soft key is pressed, do not carry out any operations.
         * @param   anIndex     Index of soft keys
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * When soft key is released, end the application
         * @param   anIndex     Index of soft keys
         */
        public void softKeyReleased(int anIndex) {
            /* When soft key1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * Receive events occurred in components
         * @param aComponent  Component where an event occurred
         * @param aType  Type of events
         * @param aParam  Parameter of events
         */
        public void componentAction(Component aComponent,int aType,int aParam){
            /* In the case execute button is pressed */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                /* execute the test method */
                test();
            }
        }

        /**
         * method to execute the test
         */
        public void test() {
            /* Acquisition of selected menu index */
            int idx1 = menu.getSelectedIndex();
            /* URL creation */
            String url = getSourceURL() + "../cgi-bin/direct.cgi";

            /* operate communication repeatedly */
            HttpConnection con = null;
            int status = 0;
            for( int i=0; i<20; i++ ) {
                /* communication using the 1st method */
                try {
                    con = (HttpConnection) Connector.open(url,
                                        Connector.READ_WRITE,true);
                    if( idx1 == 0 ) {
                        // J313_0201_0201
                        con.setRequestMethod(con.GET);
                    } else {}
                    con.connect();
                    status = con.getResponseCode();
                    if( status != 200 ) {
                        closeConnection(con);
                        showDialog("NG1(" + i + "): status=" + status);
                        return;
                    }
                    con.close();
                } catch( Exception e ) {
                    closeConnection(con);
                    showDialog("NG1(" + i + "): " + e.toString());
                    return;
                }

                /* communication using the another method */
                try {
                    con = (HttpConnection) Connector.open(url,
                                        Connector.READ_WRITE,true);
                    if( idx1 == 0 ) {
                        // J313_0201_0101
                        con.setRequestMethod(con.POST);
                    } else {}
                    con.connect();
                    status = con.getResponseCode();
                    if( status != 200 ) {
                        closeConnection(con);
                        showDialog("NG2(" + i + "): status=" + status);
                        return;
                    }
                    con.close();
                } catch( Exception e ) {
                    closeConnection(con);
                    showDialog("NG2(" + i + "): " + e.toString());
                    return;
                }
            }
            showDialog("OK");
        }

        /**
         * close the connection
         * @param con   HttpConnection
         */
        public void closeConnection(HttpConnection con) {
            if( con != null ) {
                try {
                    con.close();
                } catch( Exception e ) {}
            }
        }
    }
}
