/**
 * J331_0101_0101.java
 * 
 * J331_0101_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J331_0101_0101.java,v 1.1 2002/02/01 09:19:21 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class of checking the basic behavior of  Scratchpad 
 * @extends IApplication
 */
public class J331_0101_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the basic behavior of  Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle1       = null;  /* subtitle 1 */
    private  Label     subTitle2       = null;  /* subtitle 2 */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton      = null;  /* execute button */
    private  TextBox   resultTextBox   = null;  /* Text box for displaying the result */
    private  String[]  menuListItem    = {
        "0.scratchpad:///0",
        "1.pos=0",
        "2.pos=100",
        "3.pos=SPSize",
        "4.pos=end",
    };                                         /* Menu list */

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        /* Create and add components */
        setTitle("basic behavior of Scratchpad");

        subTitle1      = new Label("open name behavior");
        subTitle2      = new Label("name variation");
        menuList       = new ListBox(ListBox.CHOICE,5);
        execButton     = new Button("execute");
        resultTextBox  = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);

        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton);
        add(resultTextBox);

        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * execute the test
     * @param  menuIndex  index for selection menu
     */
    public void test(int menuIndex) {
        DataOutputStream dos = null;  /*  */

        try {
            switch(menuIndex) {
// J331_0101_0101
            /* 0.scratchpad:///0 */
            case 0:
                dos = Connector.openDataOutputStream(
                    "scratchpad:///0");
                break;
// J331_0101_0102
            /* 1.pos=0" */
            case 1:
                dos = Connector.openDataOutputStream(
                    "scratchpad:///0;pos=0");
                break;
// J331_0101_0103
            /* 2.pos=100 */
            case 2:
                dos = Connector.openDataOutputStream(
                    "scratchpad:///0;pos=100");
                break;
// J331_0101_0104
            /* 3.pos=SPSize */
            case 3:
                dos = Connector.openDataOutputStream(
                    "scratchpad:///0;pos=512");
                break;
// J331_0101_0105
            /* 4.pos=end */
            case 4:
                dos = Connector.openDataOutputStream(
                    "scratchpad:///0;pos=end");
                break;
            default:
                break;
            }
            resultTextBox.setText("\"OK\": Open succeeded");
        } catch (IOException ioe) {
            showMsg(ioe.toString());
        } catch (Exception e) {
            showMsg(e.toString());
        } finally {
            try {
                if (dos != null) {
                    dos.close();
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            }
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test(menuList.getSelectedIndex());
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultTextBox.setText("");
        }
    }
}