/**
 * J331_0104_0201.java
 * 
 * J331_0104_0201
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J331_0104_0201.java,v 1.1 2002/02/01 09:19:23 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class of checking the basic behavior of  Scratchpad 
 * @extends IApplication
 */
public class J331_0104_0201 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen of basic behavior menu for Scratchpad
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle1       = null;  /* subtitle 1 */
    private  Label     subTitle2       = null;  /* subtitle 2 */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton1     = null;  /* execute button 1 */
    private  Button    execButton2     = null;  /* execute button 2 */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4",
    };                                          /* Menu list */
    private  int       size            = 20;
    private  int       i;
    private  int       k;
    private  int[]     a               = new int[20];
    private  int[]     c               = new int[20];
    private  byte[]    b               = new byte[20];
    private  byte[]    d               = new byte[20];
    private  String    SPread;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("basic behavior of Scratchpad");

        /* Create and add components */
        subTitle1      = new Label("scratchpad independent behavior");
        subTitle2      = new Label("Initial status");
        menuList       = new ListBox(ListBox.CHOICE,4);
        execButton1    = new Button("Write");
        execButton2    = new Button("Read");
        resultText     = new TextBox("",getWidth(),3,TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton1);
        add(execButton2);
        add(resultText);

        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * method to write into the scratchpad
     * @param  index  menu index
     */
    void save(int index) {

        OutputStream     os  = null;
        DataOutputStream dos = null;

        switch (index) {
//J331_0104_0201
        case 0:
            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                byte a = (byte) '0';
                for ( i = 0; i < size; i++) {
                    dos.write(a);
                }
                dos.close();

                dos = Connector.openDataOutputStream("scratchpad:///0;pos=10");
                byte d = (byte) '1';
                for ( i = 0; i < size - 10; i++) {
                    dos.write(d);
                }
                dos.close();

                resultText.setText("Write:OK");
            } catch (IOException e) {
                showMsg("Write:NG");
            } finally {
                try {
                    if (dos != null) dos.close();
                } catch (IOException ie) {
                    showMsg("close:NG");
                }
            }
            break;
//J331_0104_0202
        case 1:
        /* No break */
//J331_0104_0203
        case 2:
        /* No break */
//J331_0104_0204
        case 3:
            try {
                os = Connector.openOutputStream("scratchpad:///0");
                byte a = (byte) '0';
                for ( i = 0; i < size; i++) {
                    os.write(a);
                }
                os.close();

                resultText.setText("Write:OK");
            } catch (IOException e) {
                showMsg("Write:NG");
            } finally {
                try {
                    if (dos != null) dos.close();
                } catch (IOException ie) {
                    showMsg("close:NG");
                }
            }
            break;
        default:
            break;
        }
    }

    /**
     * method to read into the scratchpad
     * @param  index  menu index
     */
    void load(int index) {

        InputStream     is  = null;
        DataInputStream dis = null;
        SPread = new String("");

        switch (index) {
//J331_0104_0201
        case 0:
            try {
                is = Connector.openInputStream("scratchpad:///0");
                for (i = 0; i < size; i++) {
                    a[i] = is.read();
                    b[i] = (byte) a[i];
                    if (a[i] == -1) {
                        break;
                    }
                }

                SPread = new String(b);
                if (i == size) {
                    resultText.setText(SPread);
                } else {
                      showMsg("Read:NG");
                }
            } catch (IOException ioe) {
                showMsg("Read:NG(IOException)");
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (is != null) is.close();
                } catch (IOException ie) {
                    showMsg("close:NG");
                }
            }
            break;
//J331_0104_0202
        case 1:
            try {
                is = Connector.openInputStream("scratchpad:///0");
                is.skip(10);
                for (i = 0; i < size; i++) {
                    a[i] = is.read();
                    b[i] = (byte) a[i];
                    if (a[i] == -1) {
                        break;
                    }
                }
                SPread = new String(b);
                if (i == size) {
                    resultText.setText(SPread);
                } else {
                      showMsg("Read:NG");
                }
            } catch (IOException ioe) {
                showMsg("Read:NG(IOException)");
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (is != null) is.close();
                } catch (IOException ie) {
                    showMsg("close:NG");
                }
            }
            break;
//J331_0104_0203
        case 2:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                dis.skip(10);
                for (i = 0; i < size; i++) {
                    a[i] = dis.read();
                    b[i] = (byte) a[i];
                    if (a[i] == -1) {
                        break;
                    }
                }
                SPread = new String(b);
                if (i == size) {
                    resultText.setText(SPread);
                } else {
                      showMsg("Read:NG");
                }
            } catch (IOException ioe) {
                showMsg("Read:NG(IOException)");
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (is != null) is.close();
                } catch (IOException ie) {
                    showMsg("close:NG");
                }
            }
            break;
//J331_0104_0204
        case 3:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0;pos=5");
                dis.skip(10);
                for (i = 0; i < size; i++) {
                    a[i] = dis.read();
                    b[i] = (byte) a[i];
                    if (a[i] == -1) {
                        break;
                    }
                }
                SPread = new String(b);
                if (i == size) {
                    resultText.setText(SPread);
                } else {
                      showMsg("Read:NG");
                }
            } catch (IOException ioe) {
                showMsg("Read:NG(IOException)");
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (is != null) is.close();
                } catch (IOException ie) {
                    showMsg("close:NG");
                }
            }
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        /* Implement test */
        if (aAction == ComponentListener.BUTTON_PRESSED) {
            if (aComponent == execButton1) {
                if (menuList.getSelectedIndex() == 0) {
//                    showMsg("0");
                    save(0);
                }
                if (menuList.getSelectedIndex() == 1) {
//                    showMsg("1");
                    save(1);
                }
                if (menuList.getSelectedIndex() == 2) {
//                    showMsg("2");
                    save(2);
                }
                if (menuList.getSelectedIndex() == 3) {
//                    showMsg("3");
                    save(3);
                }
            }
            if (aComponent == execButton2) {
                if (menuList.getSelectedIndex() == 0) {
//                    showMsg("0");
                    load(0);
                }
                if (menuList.getSelectedIndex() == 1) {
//                    showMsg("1");
                    load(1);
                }
                if (menuList.getSelectedIndex() == 2) {
//                    showMsg("2");
                    load(2);
                }
                if (menuList.getSelectedIndex() == 3) {
//                    showMsg("3");
                    load(3);
                }
            }
        }
    }
}
