/**
 * J331_0105_0101.java
 * 
 * J331_0105_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J331_0105_0101.java,v 1.1 2002/02/01 09:19:23 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class of checking the basic behavior of  Scratchpad 
 * @extends IApplication
 */
public class J331_0105_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the basic behavior of  Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle1       = null;  /* subtitle 1 */
    private  Label     subTitle2       = null;  /* subtitle 2 */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton      = null;  /* execute button */
    private  TextBox   resultTextBox   = null;  /* Text box for displaying the result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4",
        "4.Test 5",
    };                                          /* Menu list */

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("basic behavior of Scratchpad");

        /* Create and add components */
        subTitle1      = new Label("input/output behavior");
        subTitle2      = new Label("factory method behavior");
        menuList       = new ListBox(ListBox.CHOICE,6);
        execButton     = new Button("execute");
        resultTextBox  = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton);
        add(resultTextBox);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * execute the test
     * @param  menuIndex  index for selection menu
     */
    public void test(int menuIndex) {
        InputConnection   inc       = null;
        InputStream       ins       = null;
        DataInputStream   dins      = null;
        OutputConnection  ouc       = null;
        OutputStream      ous       = null;
        DataOutputStream  dous      = null;
        Connection        con;

        switch(menuIndex) {
//J331_0105_0101
        /* Connector#open */
        case 0:
            try {
             inc = (InputConnection)Connector.open(
                    "scratchpad:///0",Connector.READ,true);
                ins = inc.openInputStream();

                if (ins == null) {
                    resultTextBox.setText("\"NG\":Connector#open");
                } else {
                    resultTextBox.setText("\"OK\":Connector#open");
                }

                ins.close();
                inc.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            }
            break;
//J331_0105_0102
        /* Connector#openInputStream() */
        case 1:
            try {
                ins = Connector.openInputStream("scratchpad:///0");

                if (ins == null) {
                    resultTextBox.setText(
                        "\"NG\":Connector#openInputStream()");
                } else {
                    resultTextBox.setText(
                        "\"OK\":Connector#openInputStream()");
                }

                ins.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            }
            break;
//J331_0105_0103
        /* Connector#openDataInputStream() */
        case 2:
            try {
                dins = Connector.openDataInputStream("scratchpad:///0");

                if (dins == null) {
                    resultTextBox.setText(
                        "\"NG\":Connector#openDataInputStream()");
                } else {
                    resultTextBox.setText(
                        "\"OK\":Connector#openDataInputStream()");
                }

                dins.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            }

            break;
//J331_0105_0104
        /* Connector#openOutputStream() */
        case 3:
            try {
                ous = Connector.openOutputStream("scratchpad:///0");

                if (ous == null) {
                    resultTextBox.setText(
                        "\"NG\"Connector#openOutputStream()");
                } else {
                    resultTextBox.setText(
                        "\"OK\":Connector#openOutputStream()");
                }
                ous.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            }
            break;
//J331_0105_0105
        /* Connector#openDataOutputStream() */
        case 4:
            try {
                dous = Connector.openDataOutputStream("scratchpad:///0");

                if (dous == null) {
                    resultTextBox.setText(
                        "\"NG\":Connector#openDataOutputStream()");
                } else {
                    resultTextBox.setText(
                        "\"OK\":Connector#openDataOutputStream()");
                }
                dous.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        /* Implement test */
        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test(menuList.getSelectedIndex());
        }
        /* initialize the textbox of result display */
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultTextBox.setText("");
        }
    }
}