/**
 * J331_0105_0601.java
 * 
 * J331_0105_0601
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J331_0105_0601.java,v 1.1 2002/02/01 09:19:24 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class of checking the basic behavior of  Scratchpad 
 * @extends IApplication
 */
public class J331_0105_0601 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the basic behavior of  Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle1       = null;  /* subtitle 1 */
    private  Label     subTitle2       = null;  /* subtitle 2 */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton      = null;  /* execute button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4"
    };                                         /* Menu list */

    private  InputConnection   ic      = null;
    private  InputStream       is      = null;
    private  DataInputStream   dis     = null;
    private  OutputConnection  oc      = null;
    private  OutputStream      os      = null;
    private  DataOutputStream  dos     = null;
    private  Connection        con     = null;


    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("basic behavior of Scratchpad");

        /* Create and add components */
        subTitle1      = new Label("input/output behavior");
        subTitle2      = new Label("behavior of copying the writing");
        menuList       = new ListBox(ListBox.CHOICE,8);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 2, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * Method for test implementation
     */
    public void test() {

        try {
            switch (menuList.getSelectedIndex()) {
// J331_0105_0601
                case 0:
                    try {
                        con = Connector.open(
                            "scratchpad:///0", Connector.READ_WRITE,true);

                        oc = (OutputConnection)con;
                        os = oc.openOutputStream();
                        os.write(9);

                        os.close();

                        ic = (InputConnection)con;
                        is = ic.openInputStream();

                        if (is.read() == 9) {
                            resultText.setText("OK");
                        } else {
                            resultText.setText("NG");
                        }

                        is.close();
                        ic.close();
                        oc.close();
                    } catch(IOException ioe) {
                        showMsg(ioe.toString());
                    }
                    break;
// J331_0105_0602
                case 1:
                    try {
                        con = Connector.open(
                            "scratchpad:///0", Connector.READ_WRITE,true);

                        oc = (OutputConnection)con;
                        os = oc.openOutputStream();
                        os.write(9);

                        os.close();

                        ic = (InputConnection)con;
                        dis = ic.openDataInputStream();

                        if (dis.read() == 9) {
                            resultText.setText("OK");
                        } else {
                            resultText.setText("NG");
                        }

                        dis.close();
                        ic.close();
                        oc.close();
                    } catch(IOException ioe) {
                        showMsg(ioe.toString());
                    }
                    break;
// J331_0105_0605
                case 2:
                    try {
                        con = Connector.open(
                            "scratchpad:///0", Connector.READ_WRITE,true);

                        oc = (OutputConnection)con;
                        dos = oc.openDataOutputStream();
                        dos.write(9);

                        dos.close();

                        ic = (InputConnection)con;
                        is = ic.openInputStream();

                        if (is.read() == 9) {
                            resultText.setText("OK");
                        } else {
                            resultText.setText("NG");
                        }

                        is.close();
                        ic.close();
                        oc.close();
                    } catch(IOException ioe) {
                        showMsg(ioe.toString());
                    }
                    break;
// J331_0105_0606
                case 3:
                    try {
                        con = Connector.open(
                            "scratchpad:///0", Connector.READ_WRITE,true);

                        oc = (OutputConnection)con;
                        dos = oc.openDataOutputStream();
                        dos.write(9);

                        dos.close();

                        ic = (InputConnection)con;
                        dis = ic.openDataInputStream();

                        if (dis.read() == 9) {
                            resultText.setText("OK");
                        } else {
                            resultText.setText("NG");
                        }

                        dis.close();
                        ic.close();
                        oc.close();
                    } catch(IOException ioe) {
                        showMsg(ioe.toString());
                    }
                    break;
                default:
                    break;
            }
        }catch (Exception e){
            showMsg(e.toString());
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            if (aComponent == execButton) {
                test();
            }
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}
