/**
 * J332_0101_0101.java
 * 
 * J332_0101_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0101_0101.java,v 1.1 2002/02/01 09:20:01 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when Scratchpad is opened 
 * @extends IApplication
 */
public class J332_0101_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when Scratchpad is opened  
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle1       = null;  /* subtitle 1 */
    private  Label     subTitle2       = null;  /* subtitle 2 */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton1     = null;  /* write button */
    private  Button    execButton2     = null;  /* read button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4"
    };
    private  OutputConnection  oc      = null;
    private  OutputStream      os      = null;
    private  Connection        con     = null;
    private  boolean           okFlag  = false;
    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("Scratchpad boundary behavior");

        /* Create and add components */
        subTitle1      = new Label("boundary behavior at the time of opening");
        subTitle2      = new Label("Scratchpad scheme behavior");
        menuList       = new ListBox(ListBox.CHOICE,6);
        execButton1    = new Button("execute");
        resultText     = new TextBox("",getWidth(), 2, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton1);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * execute the test
     */
    void test() {
        switch (menuList.getSelectedIndex()) {
// J332_0101_0101
        case 0:
            try {
                oc = (OutputConnection)Connector.open(
                    "scratchpad:///0;pos=-1",Connector.WRITE,true);
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0101_0102
        case 1:
            try {
                oc = (OutputConnection)Connector.open(
                    "scratchpad:///0;pos=1025",Connector.WRITE,true);
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0101_0301
        case 2:
            try {
                InputStream is =
                    Connector.openInputStream("scratchpad:///0                                                                                                                                                                                                                                                ");
                okFlag = true;
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }

            if (okFlag) {
                showMsg("OK");
            }
            break;
// J332_0101_0302
        case 3:
            try {
                InputStream is =
                    Connector.openInputStream("scratchpad:///0                                                                                                                                                                                                                                                 ");
            } catch (IllegalArgumentException iae) {
                showMsg("OK:IllegalArgumentException");
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            if (aComponent == execButton1) {
                test();
            }
            if (aComponent == execButton2) {
//                test2();
            }
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}