/**
 * J332_0201_0101.java
 * 
 * J332_0201_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0201_0101.java,v 1.1 2002/02/01 09:20:02 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when Scratchpad is opened 
 * @extends IApplication
 */
public class J332_0201_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when Scratchpad is opened  
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle       = null;  /* Sub title */
    private  Button    execButton      = null;  /* execute button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private int              counter;
    private int              i;
    private byte             byt[]     = null;
	private  ListBox   menuList		= null;  /* Menu list */
	private  String[]  menuListItem	= {
		"0.Test 1",
		"1.Test 2"
	};

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle       = new Label("reading size behavior");
		menuList	= new ListBox(ListBox.CHOICE,2);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 2, TextBox.DISPLAY_ANY);
        add(subTitle);
		add(menuList);
        add(execButton);
        add(resultText);
        subTitle.setSize(getWidth(), subTitle.getHeight());

		/* Setting of the Menu items */
		menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * read from the scratchpad
     */
    void test() {
		int i;
		int readValue;
		switch (menuList.getSelectedIndex()) {
// J332_0201_0101
			case 0:
				counter = 10;
				try {
					InputStream is = Connector.openInputStream("scratchpad:///0");
					for (i = 1; i <= counter; i++) {
						readValue = is.read();
						if(i == counter){
							if(readValue != -1){
								if(is.read() == -1){
									resultText.setText("read OK");
									break;
								}
								else {
									resultText.setText("read NG");
									break;
								}
							}
							else{
								resultText.setText("read NG");
								break;
							}
						}
						else if(readValue == -1){
							resultText.setText("read NG");
							break;
						}
					}
					is.close();
				} catch (Exception e) {
					showMsg("NG:"+e.toString());
				}
				break;
// J332_0201_0102
			case 1:
				counter = 11;
				try {
					InputStream is = Connector.openInputStream("scratchpad:///0");
					for (i = 1; i <= counter; i++) {
						readValue = is.read();
						if (readValue == -1) {
							if (i == counter) {
								resultText.setText("read OK");
								break;
							} else {
								resultText.setText("read NG");
								break;
							}
						}
					}
					is.close();
				} catch (Exception e) {
					showMsg("NG:"+e.toString());
				}
				break;
		}
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}