/**
 * J332_0201_0201.java
 * 
 * J332_0201_0201
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0201_0201.java,v 1.1 2002/02/01 09:20:02 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when reading Scratchpad 
 * @extends IApplication
 */
public class J332_0201_0201 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when reading Scratchpad
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle1       = null;  /* subtitle 1 */
    private  Label     subTitle2       = null;  /* subtitle 1 */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton1     = null;  /* read button */
    private  Button    execButton2     = null;  /* write button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  boolean   okFlag          = false; /* Flag for determination of test result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2"
    };

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle1      = new Label("reading size behavior2");
        menuList       = new ListBox(ListBox.CHOICE,4);
        execButton1    = new Button("execute");
        execButton2    = new Button("preparation");
        resultText     = new TextBox("",getWidth(), 2, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(menuList);
        add(execButton2);
        add(execButton1);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    int counter;
    int i;
    InputStream is = null;

    /**
     * read from the scratchpad
     */
    void test1() {
		int readValue;
        switch (menuList.getSelectedIndex()) {
// J332_0201_0201
        case 0:
            counter = 102400;
			try {
				InputStream is = Connector.openInputStream("scratchpad:///0");
				for (i = 1; i <= counter; i++) {
					readValue = is.read();
					if(i == counter){
						if(readValue != -1){
							if(is.read() == -1){
								resultText.setText("read OK");
								break;
							}
							else {
								resultText.setText("read NG");
								break;
							}
						}
						else{
							resultText.setText("read NG");
							break;
						}
					}
					else if(readValue == -1){
						resultText.setText("read NG");
						break;
					}
				}
				is.close();
			} catch (Exception e) {
				showMsg("NG:"+e.toString());
			}
            break;
// J332_0201_0202
        case 1:
            counter = 102500;
			try {
				InputStream is = Connector.openInputStream("scratchpad:///0");
				for (i = 1; i <= counter; i++) {
					readValue = is.read();
					if (readValue == -1) {
						if (i > 102400) {
							resultText.setText("read OK");
							break;
						} else {
							resultText.setText("read NG");
							break;
						}
					}
				}
				is.close();
			} catch (Exception e) {
				showMsg("NG:"+e.toString());
			}
			break;
        }
    }

    /**
     * write to the scratchpad
     */
    void test2() {
        switch (menuList.getSelectedIndex()) {
        case 0:
            /* No break */
        case 1:
            DataOutputStream dos = null;
            counter = 102400;
            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                byte a = (byte) '1';
                resultText.setText("now writing");
                for ( i = 0; i < counter; i++) {
                    dos.write(a);
                }
                resultText.setText("write OK");
                dos.close();
            } catch (IOException e) {
                showMsg("the write operations NG" + e.toString());
            } finally {
                try {
                    if (dos != null) dos.close();
                } catch (IOException ie) {
                    showMsg("closeNG " + ie.toString());
                }
            }
            break;
        }
    }


    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            if (aComponent == execButton1) {
                test1();
            }
            if (aComponent == execButton2) {
                test2();
            }
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}