/**
 * J332_0202_0101.java
 * 
 * J332_0202_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0202_0101.java,v 1.1 2002/02/01 09:20:02 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when reading Scratchpad 
 * @extends IApplication
 */
public class J332_0202_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when reading Scratchpad
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle1       = null;  /* subtitle 1 */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton1     = null;  /* read button */
    private  Button    execButton2     = null;  /* write button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  boolean   okFlag          = false; /* Flag for determination of test result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4",
        "4.Test 5",
        "5.Test 6",
        "6.Test 7",
        "7.Test 8",
        "8.Test 9",
        "9.Test 10",
        "10.Test 11",
        "11.Test 12",
        "12.Test 13",
        "13.Test 14",
        "14.Test 15",
        "15.Test 16"
    };
    private InputStream      is        = null;
    private DataInputStream  dis       = null;
    private OutputStream     os        = null;
    private DataOutputStream dos       = null;
    private byte             byt[]     = null;

    private int              spSize    = 25;
    private int              pos       = 0;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle1      = new Label("boundary behavior after reading");
        menuList       = new ListBox(ListBox.CHOICE,4);
        execButton1    = new Button("execute");
        execButton2    = new Button("preparation");
        resultText     = new TextBox("",getWidth(), 2, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(menuList);
        add(execButton1);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * read from the scratchpad
     */
    void test() {
        byt = new byte[1];

        switch (menuList.getSelectedIndex()) {
// J332_0202_0101
        case 0:
            pos = spSize - 1;

            try {
                is = Connector.openInputStream("scratchpad:///0;pos=" + pos);
                is.read();
                is.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0102
        case 1:
            pos = spSize - 1;

            try {
                is = Connector.openInputStream("scratchpad:///0;pos=" + pos);
                is.read(byt);
                is.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0103
        case 2:
            pos = spSize - 1;

            try {
                is = Connector.openInputStream("scratchpad:///0;pos=" + pos);
                is.read(byt,0,byt.length);
                is.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0201
        case 3:
            pos = spSize - 1;

            try {
                dis =Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.read();
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0202
        case 4:
            pos = spSize - 1;

            try {
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.read(byt);
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0203
        case 5:
            pos = spSize - 1;

            try {
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.read(byt,0,byt.length);
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0204
        case 6:
            pos = spSize - 1;

            try {
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.readBoolean();
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0205
        case 7:
            pos = spSize - 2;
//            pos = 23;
            try {
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.readChar();
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0206
        case 8:
            pos = spSize - 1;

            try {
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.readFully(byt);
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0207
        case 9:
            pos = spSize - 8;
//            pos = 17;

            try {
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.readFully(byt, 0, byt.length);
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0208
        case 10:
            try {
            pos = spSize - 4;
//            pos = 21;

                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.readInt();
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0209
        case 11:
            pos = spSize - 8;
//            pos = 17;
            try {
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.readLong();
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0210
        case 12:
            pos = spSize - 2;
//            pos = 23;

            try {
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.readShort();
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0211
        case 13:
            pos = spSize - 1;
            try {
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.readUnsignedByte();
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0212
        case 14:
            pos = spSize - 2;
//            pos = 23;

            try {
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.readUnsignedShort();
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
// J332_0202_0213
        case 15:
            try {
            pos = spSize - 2;
//            pos = 23;
                dis = Connector.openDataInputStream(
                    "scratchpad:///0;pos=" + pos);
                dis.readUTF();
                dis.close();
                okFlag = true;
            } catch (IOException ioe) {
                okFlag = false;
                showMsg(ioe.toString());
            } catch (Exception e) {
                okFlag = false;
                showMsg(e.toString());  
            }

            if (okFlag == true) {
                resultText.setText("read OK");
            } else {
                resultText.setText("read NG");
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}