/**
 * J332_0203_0101.java
 * 
 * J332_0203_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0203_0101.java,v 1.1 2002/02/01 09:20:03 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when reading Scratchpad 
 * @extends IApplication
 */
public class J332_0203_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when reading Scratchpad
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle        = null;  /* Sub title */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton1     = null;  /* read button */
    private  Button    execButton2     = null;  /* write button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  boolean   okFlag          = false; /* Flag for determination of test result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4",
        "4.Test 5",
        "5.Test 6",
        "6.Test 7",
        "7.Test 8",
        "8.Test 9",
        "9.Test 10",
        "10.Test 11",
        "11.Test 12",
        "12.Test 13",
        "13.Test 14",
        "14.Test 15",
        "15.Test 16",
        "16.Test 17"
    };
    private int              counter;
    private int              i;
    private InputStream      is        = null;
    private DataInputStream  dis       = null;
    private OutputStream     os        = null;
    private DataOutputStream dos       = null;
    private byte             byt[]     = null;
    private boolean          bl        = false;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle      = new Label("reading from the boundary");
        menuList       = new ListBox(ListBox.CHOICE,4);
        execButton1    = new Button("execute");
        execButton2    = new Button("preparation");
        resultText     = new TextBox("",getWidth(), 2, TextBox.DISPLAY_ANY);
        add(subTitle);
        add(menuList);
//        add(execButton2);
        add(execButton1);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * read from the scratchpad
     */
    void test1() {
        byt     = new byte[10];
        counter = 11;

            try {
                os = Connector.openOutputStream("scratchpad:///0");
                os.write(0);
                os.close();
//                showMsg("write OK");
            } catch (IOException e) {
                showMsg("Write:NG" + e.toString());
            } finally {
                try {
                    if (os != null) os.close();
                } catch (IOException ie) {
                    showMsg("close:NG");
                }
            }


        switch (menuList.getSelectedIndex()) {
// J332_0203_0101
        case 0:
            try {
                is = Connector.openInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (is.read() == -1) {
                        resultText.setText("read OK");
                    } else {
                        resultText.setText("read NG");
                    }
                }
                is.close();
            } catch (IOException ioe) {
                showMsg("Read:NG" + ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (is != null) is.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0102
        case 1:
            try {
                is = Connector.openInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (is.read(byt) == -1) {
                        resultText.setText("read OK");
                    } else {
                        resultText.setText("read NG");
                    }
                }
            } catch (IOException ioe) {
                showMsg("Read:NG" + ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (is != null) is.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0103
        case 2:
            try {
                is = Connector.openInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (is.read(byt, 0, byt.length) == -1) {
                        resultText.setText("read OK");
                    } else {
                        resultText.setText("read NG");
                    }
                }
            } catch (IOException ioe) {
                showMsg("Read:NG" + ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (is != null) is.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0201
// J332_0204_0203
        case 3:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter + 1; i++) {
                    if (dis.read() == -1) {
                        resultText.setText("read OK");
                    } else {
                        resultText.setText("read NG");
                    }
                }
            } catch (IOException ioe) {
                showMsg("Read:NG" + ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0202
        case 4:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (dis.read(byt) == -1) {
                        resultText.setText("read OK");
                    } else {
                        resultText.setText("read NG");
                    }
                }
            } catch (IOException ioe) {
                showMsg("Read:NG" + ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0203
// J332_0204_0204
        case 5:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (dis.read(byt, 0, byt.length) == -1) {
                        resultText.setText("read OK");
                    } else {
                        resultText.setText("read NG");
                    }
                }
            } catch (IOException ioe) {
                showMsg("Read:NG" + ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0204
// J332_0204_0205
        case 6:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readBoolean();
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0205
// J332_0204_0206
        case 7:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readByte();
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0206
// J332_0204_0207
        case 8:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readChar();
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0207
// J332_0204_0208
        case 9:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readFully(byt);
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0208
// J332_0204_0209
        case 10:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readFully(byt, 0, byt.length);
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
           break;
// J332_0203_0209
// J332_0204_0210
        case 11:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readInt();
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0210
        case 12:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readLong();
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0211
// J332_0204_0211
        case 13:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readShort();
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0212
        case 14:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readUnsignedByte();
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0213
        case 15:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readUnsignedShort();
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
// J332_0203_0214
        case 16:
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    dis.readUTF();
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg("Reading NG : " + e.toString());  
            } finally {
                try {
                    if (dis != null) dis.close();
                } catch (IOException ie) {
                    showMsg("close:NG " + ie.toString());
                }
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            if (aComponent == execButton1) {
                test1();
            }
            if (aComponent == execButton2) {
//                test2();
            }
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}