/**
 * J332_0204_0101.java
 * 
 * J332_0204_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0204_0101.java,v 1.1 2002/02/01 09:20:03 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when reading Scratchpad 
 * @extends IApplication
 */
public class J332_0204_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when reading Scratchpad
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle1       = null;  /* subtitle 1 */
    private  Label     subTitle2       = null;  /* subtitle 2 */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton      = null;  /* execute button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4"
    };
    private byte             byt[]     = null;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle1      = new Label("at the time of reading");
        subTitle2      = new Label("reading that straddles the boundary");
        menuList       = new ListBox(ListBox.CHOICE,4);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 2, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * read from the scratchpad
     */
    void test() {
        byt = new byte[20];

        switch (menuList.getSelectedIndex()) {
// J332_0204_0101
        case 0:
            try {
                InputStream is =
                     Connector.openInputStream("scratchpad:///0");
                if (is.read(byt) == 10) {
                    resultText.setText("read OK");
                } else {
                    resultText.setText("read NG");
                }
                is.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());  
            }
            break;
// J332_0204_0102
        case 1:
            try {
                InputStream is =
                     Connector.openInputStream("scratchpad:///0");
                if (is.read(byt, 2, byt.length - 2) == 10) {
                    resultText.setText("read OK");
                } else {
                    resultText.setText("read NG");
                }
                is.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());  
            }
            break;
// J332_0204_0201
        case 2:
            try {
                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                if (dis.read(byt) == 10) {
                    resultText.setText("read OK");
                } else {
                    resultText.setText("read NG");
                }
            dis.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0204_0202
        case 3:
            try {
                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                if (dis.read(byt, 2, byt.length - 2) == 10) {
                    resultText.setText("read OK");
                } else {
                    resultText.setText("read NG");
                }
                dis.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            if (aComponent == execButton) {
                test();
            }
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}