/**
 * J332_0301_0101.java
 * 
 * J332_0301_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0301_0101.java,v 1.1 2002/02/01 09:20:03 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when writing into the Scratchpad 
 * @extends IApplication
 */
public class J332_0301_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when writing into the Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle1       = null;  /* subtitle 1 */
    private  Label     subTitle2       = null;  /* subtitle 2 */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton      = null;  /* execute button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  boolean   okFlag          = false; /* Flag for determination of test result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2"
    };
    private int              counter;
    private int              i;
    private byte             byt[]     = null;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle1      = new Label("writing size behavior");
        subTitle2      = new Label("SPsize restriction behavior 1");
        menuList       = new ListBox(ListBox.CHOICE,2);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * write to the scratchpad
     */
    void test() {
        switch (menuList.getSelectedIndex()) {
// J332_0301_0101
        case 0:
            byt     = new byte[10];
            counter = 11;

            try {
                OutputStream os =
                    Connector.openOutputStream("scratchpad:///0");
                    os.write(byt);
                os.close();

                InputStream is =
                    Connector.openInputStream("scratchpad:///0");
                int i;
                for (i = 0; i < counter; i++) {
                    if (is.read() == -1) {
                        if (i == 10) {
                            resultText.setText("write OK");
                        } else {
                            resultText.setText("the write operations NG");
                        }
                    }
                }
                is.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0301_0102
        case 1:
            byt     = new byte[11];
            try {
                OutputStream os =
                    Connector.openOutputStream("scratchpad:///0");
                    os.write(byt);
                    os.close();
            } catch (ConnectionException ce) {
                if (ce.getStatus() ==
                    ConnectionException.SCRATCHPAD_OVERSIZE) {
                    resultText.setText(
                        "ConnectionException(SCRATCHPAD_OVERSIZE):OK");
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
        case 2:
            break;
        case 3:
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}