/**
 * J332_0302_0101.java
 * 
 * J332_0302_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0302_0101.java,v 1.2 2002/04/25 06:31:46 torikatu Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when writing into the Scratchpad 
 * @extends IApplication
 */
public class J332_0302_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when writing into the Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle1       = null;  /* subtitle 1 */
    private  Label     subTitle2       = null;  /* subtitle 2 */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton      = null;  /* execute button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  boolean   okFlag          = false; /* Flag for determination of test result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4",
        "4.Test 5",
        "5.Test 6",
        "6.Test 7",
        "7.Test 8",
        "8.Test 9",
        "9.Test 10",
        "10.Test 11",
        "11.Test 12",
        "12.Test 13",
        "13.Test 14",
    };
    private int         counter;
    private int         i;
    private byte        byt;
    private byte        byteArray[]    = null;

    static final        int spSize     = 24;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle1      = new Label("after writing");
        subTitle2      = new Label("writing the boundary byte");
        menuList       = new ListBox(ListBox.CHOICE,2);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * write to the scratchpad
     */
    void test() {
        int  okCount  = 1;

        switch (menuList.getSelectedIndex()) {
// J332_0302_0101
        case 0:
            byt      = 9;
            counter  = spSize;

            try {
                OutputStream os =
                    Connector.openOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    os.write(byt);

                    if (i == spSize) {
                        okFlag = true;
                    } else {
                        okFlag = false;
                    }
                }

                if (okFlag == true) {
                    resultText.setText("write OK");
                } else {
                    resultText.setText("the write operations NG");
                }

                os.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0302_0102
        case 1:
            byteArray     = new byte[spSize];
            counter       = spSize + 10;

            try {
                OutputStream os =
                    Connector.openOutputStream("scratchpad:///0");
                    os.write(byteArray);
                os.close();

                InputStream is =
                    Connector.openInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (is.read() == -1) {
                        if (i == spSize + 1) {
                            resultText.setText("write OK");
                            break;
                        } else {
                            resultText.setText("the write operations NG");
                        }
                    }
                }
                is.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0302_0103
        case 2:
            byteArray     = new byte[spSize];
            counter       = spSize + 10;

            try {
                OutputStream os =
                    Connector.openOutputStream("scratchpad:///0");
                    os.write(byteArray, 2, byteArray.length - 2);
                os.close();

                InputStream is =
                    Connector.openInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (is.read() == -1) {
                        if (i == spSize + 1) {
                            resultText.setText("write OK");
                            break;
                        } else {
                            resultText.setText("the write operations NG");
                        }
                    }
                }
                is.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0302_0201
        case 3:
            byt      = 9;
            counter  = spSize;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    dos.write(byt);

                    if (i == spSize) {
                        okFlag = true;
                    } else {
                        okFlag = false;
                    }
                }

                if (okFlag == true) {
                    resultText.setText("write OK");
                } else {
                    resultText.setText("the write operations NG");
                }

                dos.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0302_0202
        case 4:
            byteArray  = new byte[spSize];
            counter    = spSize + 10;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");
                    dos.write(byteArray);
                dos.close();

                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (dis.read() == -1) {
                        if (i == spSize + 1) {
                            resultText.setText("write OK");
                            break;
                        } else {
                            resultText.setText("the write operations NG");
                        }
                    }
                }
                dis.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0302_0203
        case 5:
            byteArray  = new byte[spSize];
            counter    = spSize + 10;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");
                    dos.write(byteArray, 2, byteArray.length - 2);
                dos.close();

                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (dis.read() == -1) {
                        if (i == spSize + 1) {
                            resultText.setText("write OK");
                            break;
                        } else {
                            resultText.setText("the write operations NG");
                        }
                    }
                }
                dis.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0302_0204
        case 6:
            counter  = spSize;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++){
                    if (i % 2 == 0) {
                        dos.writeBoolean(true);    /* 0 */
                    } else {
                        dos.writeBoolean(false);   /* 1 */
                    }
                }
                dos.close();

                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (dis.readBoolean() == true) {
                        if (i % 2 == 0) {
                            okCount++;
                        }
                    }
                }

                if (okCount == (counter / 2) + 1) {
                    resultText.setText("write OK");
                } else {
                    resultText.setText("the write operations NG");
                }
                dis.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0302_0205
        case 7:
            counter  = spSize;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++){
                    if (i % 2 == 0) {
                        dos.writeByte(0);
                    } else {
                        dos.writeByte(1);
                    }
                }
                dos.close();

                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= spSize; i++) {
                    if (dis.readByte() == 0) {
                        okCount++;
                    }
                }

                if (okCount == (spSize / 2) + 1) {
                    resultText.setText("write OK");
                } else {
                    resultText.setText("the write operations NG");
                }
                dis.close();
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0302_0206
        case 8:
            int  writCharInt = 1;
            counter          = spSize / 2;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    if (i % 2 == 0) {
                        dos.writeChar(0);
                    } else {
                        dos.writeChar(1);
                    }
                }
                dos.close();

                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (dis.readChar() == 0) {
                        okCount++;
                    }
                }

                if (okCount == (counter / 2) + 1) {
                    resultText.setText("write OK");
                } else {
                    resultText.setText("the write operations NG");
                }
                dis.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
// J332_0302_0207
        case 9:
            counter           = spSize / 2;
            char readCharStr  = 'A';

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    if (i % 2 == 0) {
                        dos.writeChars("A");
                    } else {
                        dos.writeChars("B");
                    }
                }
                dos.close();

                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (dis.readChar() == readCharStr) {
                        okCount++;
                    }
                }

                if (okCount == (counter / 2) + 1) {
                    resultText.setText("write OK");
                } else {
                    resultText.setText("the write operations NG");
                }
                dis.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
// J332_0302_0208
        case 10:
            counter  = spSize / 4;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    if (i % 2 == 0) {
                        dos.writeInt(2);
                    } else {
                        dos.writeInt(4);
                    }
                }
                dos.close();

                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (dis.readInt() == 2) {
                        okCount++;
                    }
                }

                if (okCount == (counter / 2) + 1) {
                    resultText.setText("write OK");
                } else {
                    resultText.setText("the write operations NG");
                }
                dis.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
// J332_0302_0209
        case 11:
            counter  = spSize / 4;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    if (i % 2 == 0) {
                        dos.writeInt(4);
                    } else {
                        dos.writeInt(2);
                    }
                }
                dos.close();

                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (dis.readInt() == 4) {
                        okCount++;
                    }
                }

                if (okCount == (counter / 2) + 1) {
                    resultText.setText("write OK");
                } else {
                    resultText.setText("the write operations NG");
                }
                dis.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
// J332_0302_0210
        case 12:
            counter  = spSize / 4;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    if (i % 2 == 0) {
                        dos.writeInt(5);
                    } else {
                        dos.writeInt(6);
                    }
                }
                dos.close();

                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    if (dis.readInt() == 5) {
                        okCount++;
                    }
                }

                if (okCount == (counter / 2) + 1) {
                    resultText.setText("write OK");
                } else {
                    resultText.setText("the write operations NG");
                }
                dis.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
// J332_0302_0211
        case 13:
            counter           = spSize / 4;
            String readUTFStr = null;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    if (i % 2 == 0) {
                        dos.writeUTF("X");
                    } else {
                        dos.writeUTF("Y");
                    }
                }
                dos.close();

                DataInputStream dis =
                    Connector.openDataInputStream("scratchpad:///0");
                for (i = 1; i <= counter; i++) {
                    readUTFStr = dis.readUTF();
                    if (readUTFStr.equals("X") == true) {
                        okCount++;
                    }
                }
                if (okCount == (counter / 2) + 1) {
                    resultText.setText("write OK");
                } else {
                    resultText.setText("the write operations NG");
                }
                dis.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}