/**
 * J332_0303_0101.java
 * 
 * J332_0303_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0303_0101.java,v 1.1 2002/02/01 09:20:04 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when writing into the Scratchpad 
 * @extends IApplication
 */
public class J332_0303_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when writing into the Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle        = null;  /* Sub title */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton      = null;  /* execute button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  boolean   okFlag          = false; /* Flag for determination of test result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4",
        "4.Test 5",
        "5.Test 6",
        "6.Test 7",
        "7.Test 8",
        "8.Test 9",
        "9.Test 10",
        "10.Test 11",
        "11.Test 12",
        "12.Test 13",
        "13.Test 14",
    };
    private int         counter;
    private int         i;
    private byte        byt;
    private byte        byteArray[]    = null;

    static final        int spSize     = 24;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle      = new Label("writing from the boundary");
        menuList       = new ListBox(ListBox.CHOICE,2);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);
        add(subTitle);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * write to the scratchpad
     */
    void test() {
        int  okCount  = 1;

        switch (menuList.getSelectedIndex()) {
// J332_0303_0101
        case 0:
            byt      = 9;
            counter  = spSize + 1;

            try {
                OutputStream os =
                    Connector.openOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    os.write(byt);

                    if (i == spSize) {
                        okFlag = true;
                    } else {
                        okFlag = false;
                    }
                }
                os.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0303_0102
        case 1:
            byteArray  = new byte[spSize + 1];

            try {
                OutputStream os =
                    Connector.openOutputStream("scratchpad:///0");
                os.write(byteArray);
                os.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0303_0103
        case 2:
            byteArray  = new byte[spSize + 1];

            try {
                OutputStream os =
                    Connector.openOutputStream("scratchpad:///0");
                    os.write(byteArray, 0, byteArray.length);
                os.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0303_0201
        case 3:
            byt      = 9;
            counter  = spSize + 1;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    dos.write(byt);
                }
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0303_0202
        case 4:
            byteArray  = new byte[spSize + 1];

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");
                    dos.write(byteArray);
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0303_0203
        case 5:
            byteArray  = new byte[spSize + 1];

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");
                    dos.write(byteArray, 0, byteArray.length);
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0303_0204
        case 6:
            counter  = spSize + 1;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++){
                    if (i % 2 == 0) {
                        dos.writeBoolean(true);    /* 0 */
                    } else {
                        dos.writeBoolean(false);   /* 1 */
                    }
                }
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0303_0205
        case 7:
            counter  = spSize + 1;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++){
                    dos.writeByte(1);
                }
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0303_0206
        case 8:
            counter  = (spSize / 2) + 1;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    dos.writeChar(1);
                }
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {
                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
// J332_0303_0207
        case 9:
            counter  = (spSize / 2) + 1;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    dos.writeChars("A");
                    }
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
// J332_0303_0208
        case 10:
            counter  = (spSize / 4) + 1;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    dos.writeInt(2);
                }
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
// J332_0303_0209
        case 11:
            counter  = (spSize / 4) + 1;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    dos.writeInt(4);
                }
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
// J332_0303_0210
        case 12:
            counter  = (spSize / 4) + 1;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    dos.writeInt(5);
                }
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
// J332_0303_0211
        case 13:
            counter           = spSize + 1;
            String readUTFStr = null;

            try {
                DataOutputStream dos =
                    Connector.openDataOutputStream("scratchpad:///0");

                for (i = 1; i <= counter; i++) {
                    dos.writeUTF("A");
                }
                dos.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
                resultText.setText("the write operations NG");
            } catch(Exception e) {
                showMsg(e.toString());
                resultText.setText("the write operations NG");
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}