/**
 * J332_0304_0101.java
 * 
 * J332_0304_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0304_0101.java,v 1.1 2002/02/01 09:20:05 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when writing into the Scratchpad 
 * @extends IApplication
 */
public class J332_0304_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when writing into the Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    private  Label     subTitle        = null;  /* Sub title */
    private  ListBox   menuList        = null;  /* Menu list */
    private  Button    execButton      = null;  /* execute button */
    private  TextBox   resultText      = null;  /* Text box for displaying the result */
    private  boolean   okFlag          = false; /* Flag for determination of test result */
    private  String[]  menuListItem    = {
        "0.Test 1",
        "1.Test 2"
    };
    private int         counter;
    private int         i;
    private byte        byt;
    private byte        byteArray[]    = null;

    static final int    spSize         = 10;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle      = new Label("writing when it straddles the boundary");
        menuList       = new ListBox(ListBox.CHOICE,2);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);
        add(subTitle);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * write to the scratchpad
     */
    void test() {
        byteArray     = new byte[spSize + 1];

        switch (menuList.getSelectedIndex()) {
// J332_0304_0101
        case 0:
            try {
                OutputStream os =
                    Connector.openOutputStream("scratchpad:///0");
                os.write(byteArray);
                os.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
// J332_0304_0102
        case 1:
            try {
                OutputStream os =
                    Connector.openOutputStream("scratchpad:///0");
                    os.write(byteArray, 0, byteArray.length);
                os.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.SCRATCHPAD_OVERSIZE) {                    resultText.setText(
                        "OK:ConnectionException(SCRATCHPAD_OVERSIZE)");
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}