/**
 * J332_0305_0101.java
 * 
 * J332_0305_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0305_0101.java,v 1.1 2002/02/01 09:20:05 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when writing into the Scratchpad 
 * @extends IApplication
 */
public class J332_0305_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when writing into the Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    Label           subTitle1       = null;  /* subtitle 1 */
    Label           subTitle2       = null;  /* subtitle 2 */
    Button          execButton      = null;  /* execute button */
    TextBox         resultText      = null;  /* Text box for displaying the result */
    boolean         okFlag          = false; /* Flag for determination of test result */
    int              counter;
    int              i;
    byte             byt[]          = null;
    InputStream      is             = null;
    DataInputStream  dis            = null;
    OutputStream     os             = null;
    DataOutputStream dos            = null;
    ListBox         menuList        = null;  /* Menu list */
    String[]        menuListItem    = {
        "0.Test 1",
        "1.Test 2"
    };
	StreamConnection	sc			= null;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle1      = new Label("behavior at the time of reading exception ");
        subTitle2      = new Label("buffer status at the time of exception");
        menuList       = new ListBox(ListBox.CHOICE,4);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * write to the scratchpad
     */
    void test() {

        switch (menuList.getSelectedIndex()) {
//J322_0305_0101
        case 0:
            counter = 10;
	        try {
	            os = Connector.openOutputStream("scratchpad:///0");

	            for (i = 1; i <= counter; i++) {
	                os.write(i);
	            }
	            os.close();
	        } catch (IOException ioe) {}
            try {
                os = Connector.openOutputStream("scratchpad:///0");

                for (i = 1; i <= counter+1; i++) {
                    os.write(i);
                }

                dis = Connector.openDataInputStream("scratchpad:///0");
                dis.read();
                dis.close();
            } catch (IOException ioe) {
                try {
                    os.close();

                    dis = Connector.openDataInputStream("scratchpad:///0");

                    int value1 = 0;
                    int value2 = 0;
                    for (i = 1; i <= counter; i++) {
                        value1 = dis.read();
                        value2 = value2 + value1;
                    }

                    if (value2 == 55) {
                        okFlag = true;
                        resultText.setText("write OK");
                    } else {
                        resultText.setText("the write operations NG");
                    }
                    dis.close();
                } catch (IOException ioe2) {
                    showMsg(ioe2.toString());
                }
            } catch (Exception e) {
                showMsg(e.toString());
            }

            if (!okFlag) {
                resultText.setText("NG");
            }

            break;
//J322_0305_0102
        case 1:
            counter = 10;
            ioeThread testIoeThread = new ioeThread();
	        try {
	            os = Connector.openOutputStream("scratchpad:///0");

	            for (i = 1; i <= counter; i++) {
	                os.write(0);
	            }
	            os.close();
	        } catch (IOException ioe) {}

            try {
                os = Connector.openOutputStream("scratchpad:///0");

                for (i = 1; i <= counter+1; i++) {
                    os.write(i);
                }
                dis = Connector.openDataInputStream("scratchpad:///0");
                dis.read();
                dis.close();
            } catch (IOException ioe) {
                try {
                    os.close();
                    counter = 10;
                    dis = Connector.openDataInputStream("scratchpad:///0");
                    for (i = 1; i <= counter; i++) {
                        if (dis.read() == i) {
                            resultText.setText("write OK");
                            okFlag = true;
                        }
                    }
                    dis.close();

                } catch (IOException ioe2) {}
            } catch (Exception e) {
                showMsg(e.toString());
                resultText.setText("read NG");
            }

            if (!okFlag) {
                resultText.setText("NG");
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
     void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }

//J322_0305_0102
    /**
     * thread to generate IO exception
     * @extends Thread
     */
    class ioeThread extends Thread {
        /**
         * ioeThread constructor
         */
        public ioeThread() {}

        /**
         *  run method
         */
         public void run() {
            counter = 10;
            try {
                os = Connector.openOutputStream("scratchpad:///0");

                for (i = 1; i <= counter+1; i++) {
                    os.write(i);
                }
                dis = Connector.openDataInputStream("scratchpad:///0");
                dis.read();
                dis.close();
            } catch (IOException ioe) {
                try {
                    os.close();
            counter = 10;
                    dis = Connector.openDataInputStream("scratchpad:///0");
                    for (i = 1; i <= counter; i++) {
                        if (dis.read() == i) {
                            resultText.setText("write OK");
                            okFlag = true;
                        }
                    }
                    dis.close();

                } catch (IOException ioe2) {}
            } catch (Exception e) {
                showMsg(e.toString());
                resultText.setText("read NG");
            }
        }
    }

}