/**
 * J332_0305_0201.java
 * 
 * J332_0305_0201
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0305_0201.java,v 1.1 2002/02/01 09:20:05 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the boundary behavior when writing into the Scratchpad 
 * @extends IApplication
 */
public class J332_0305_0201 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the boundary behavior when writing into the Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    Label           subTitle1       = null;  /* subtitle 1 */
    Label           subTitle2       = null;  /* subtitle 2 */
    ListBox         menuList        = null;  /* Menu list */
    Button          execButton      = null;  /* execute button */
    TextBox         resultText      = null;  /* Text box for displaying the result */
    boolean         flag            = false; /* Flag for determination of test result */
    String[]        menuListItem    = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4"
    };
    int              counter;
    int              i;
    byte             byt[]          = null;
    InputStream      is             = null;
    DataInputStream  dis            = null;
    OutputStream     os             = null;
    DataOutputStream dos            = null;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle1      = new Label("behavior at the time of writing exception");
        subTitle2      = new Label("save the stream status at the time of exception");
        menuList       = new ListBox(ListBox.CHOICE,4);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * write to the scratchpad
     */
    void test() {
        counter = 10;

        byte[] dataByte1 = {
            (byte)'a',
            (byte)'b',
            (byte)'c',
            (byte)'d',
            (byte)'e',
            (byte)'f',
            (byte)'g',
            (byte)'h',
            (byte)'i',
            (byte)'j'
        };

        byte[] dataByte2 = {
            (byte)'b',
            (byte)'c',
            (byte)'d',
            (byte)'e',
            (byte)'f',
            (byte)'g',
            (byte)'h',
            (byte)'i',
            (byte)'j',
            (byte)'k'
        };

        byte[] dataByte3 = {
            (byte)'c',
            (byte)'d',
            (byte)'e',
            (byte)'f',
            (byte)'g',
            (byte)'h',
            (byte)'i',
            (byte)'j',
            (byte)'k',
            (byte)'l'
        };

        byte[] dataByte4 = {
            (byte)'d',
            (byte)'e',
            (byte)'f',
            (byte)'g',
            (byte)'h',
            (byte)'i',
            (byte)'j',
            (byte)'k',
            (byte)'l',
            (byte)'m'
        };

        switch (menuList.getSelectedIndex()) {

// J332_0305_0201
        case 0:
            try {
                os = Connector.openOutputStream("scratchpad:///0");
                os.write(dataByte1);
                os.close();
            } catch (ConnectionException ce) {
                if (ce.getStatus() ==
                    ConnectionException.SCRATCHPAD_OVERSIZE) {
                    flag = true;
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    os.close();
                } catch (IOException ioe) {
                    showMsg(ioe.toString());
                }
            }
//flag = true;

            if (flag) {
                try {
                    dis = Connector.openDataInputStream(
                        "scratchpad:///0");
//2002/10/03 Doja1.5                    if (dis.read() == 97){
                    if (dis.read() == 0){
                        resultText.setText("write OK");
                    } else {
                        resultText.setText("the write operations NG");
                    }
                    dis.close();
                } catch (IOException ioe) {
                    showMsg(ioe.toString());
                } catch (Exception e) {
                    showMsg(e.toString());
                } finally {
                    try {
                        dis.close();
                    } catch (IOException ioe) {
                        showMsg(ioe.toString());
                    }
                }
            } else {
                resultText.setText("NG");
            }
            break;
// J332_0305_0202
        case 1:
            try {
                os = Connector.openOutputStream("scratchpad:///0");
                os.write(dataByte2, 0, dataByte2.length);

            } catch (ConnectionException ce) {
                if (ce.getStatus() ==
                    ConnectionException.SCRATCHPAD_OVERSIZE) {
                    flag = true;
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    os.close();
                } catch (IOException ioe) {
                    showMsg(ioe.toString());
                }
            }
//flag = true;

            if (flag) {
                try {
                    dis = Connector.openDataInputStream(
                        "scratchpad:///0");
//2002/10/03 Doja1.5                    if (dis.read() == 98){
                    if (dis.read() == 0){
                        resultText.setText("write OK");
                    } else {
                        resultText.setText("the write operations NG");
                    }
                    dis.close();
                } catch (IOException ioe) {
                    showMsg(ioe.toString());
                } catch (Exception e) {
                    showMsg(e.toString());
                } finally {
                    try {
                        dis.close();
                    } catch (IOException ioe) {
                        showMsg(ioe.toString());
                    }
                }
            } else {
                resultText.setText("NG");
            }
            break;
// J332_0305_0203
        case 2:
            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                dos.write(dataByte3);
                dos.close();
            } catch (ConnectionException ce) {
                if (ce.getStatus() ==
                    ConnectionException.SCRATCHPAD_OVERSIZE) {
                    flag = true;
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    dos.close();
                } catch (IOException ioe) {
                    showMsg(ioe.toString());
                }
            }
//flag = true;

            if (flag) {
                try {
                    dis = Connector.openDataInputStream(
                        "scratchpad:///0");
                    if (dis.read() == 0){
                        resultText.setText("write OK");
                    } else {
                        resultText.setText("the write operations NG");
                    }
                    dis.close();
                } catch (IOException ioe) {
                    showMsg(ioe.toString());
                } catch (Exception e) {
                    showMsg(e.toString());
                } finally {
                    try {
                        dis.close();
                    } catch (IOException ioe) {
                        showMsg(ioe.toString());
                    }
                }
            } else {
                resultText.setText("NG");
            }
            break;
// J332_0301_0204
        case 3:
            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                dos.write(dataByte4, 0, dataByte4.length);

            } catch (ConnectionException ce) {
                if (ce.getStatus() ==
                    ConnectionException.SCRATCHPAD_OVERSIZE) {
                    flag = true;
                } else {
                    showMsg(ce.toString());
                }
            } catch (IOException ioe) {
                showMsg(ioe.toString());
            } catch (Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    dos.close();
                } catch (IOException ioe) {
                    showMsg(ioe.toString());
                }
            }
//flag = true;
            if (flag) {
                try {
                    dis = Connector.openDataInputStream(
                        "scratchpad:///0");
                    if (dis.read() == 0){
                        resultText.setText("write OK");
                    } else {
                        resultText.setText("the write operations NG");
                    }
                    dis.close();
                } catch (IOException ioe) {
                    showMsg(ioe.toString());
                } catch (Exception e) {
                    showMsg(e.toString());
                } finally {
                    try {
                        dis.close();
                    } catch (IOException ioe) {
                        showMsg(ioe.toString());
                    }
                }
            } else {
                resultText.setText("NG");
            }
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}