/**
 * J332_0401_0102.java
 * 
 * J332_0401_0102
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0401_0102.java,v 1.1 2002/02/01 09:20:05 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the skip behavior of Scratchpad 
 * @extends IApplication
 */
public class J332_0401_0102 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the skip behavior of Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    Label            subTitle1     = null;  /* subtitle 1 */
    Label            subTitle2     = null;  /* subtitle 2 */
    ListBox          menuList      = null;  /* Menu list */
    Button           execButton    = null;  /* execute button */
    TextBox          resultText    = null;  /* Text box for displaying the result */
    boolean          okFlag        = false; /* Flag for determination of test result */
    String[]         menuListItem  = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4"
    };
    int              counter;
    int              i;
    byte             byt[]         = null;
    InputStream      is            = null;
    DataInputStream  dis           = null;
    OutputStream     os            = null;
    DataOutputStream dos           = null;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle1      = new Label("skip operation");
        subTitle2      = new Label("read mode");
        menuList       = new ListBox(ListBox.CHOICE,6);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * The method of confirming operations
     */
    void test() {
        counter = 10;

        /* initialize SPPad */
        try {
            os = Connector.openOutputStream("scratchpad:///0");
            for (i = 1; i <= 10; i++) {
                os.write(0);
            }
            os.close();
        } catch(IOException ioe) {
            showMsg(ioe.toString());
        } catch(Exception e) {
            showMsg(e.toString());
        } finally {
            try {
                os.close();
            } catch(IOException ioe2) {}
        }

        /* behavior check */
        switch (menuList.getSelectedIndex()) {
        case 0:
            try {
                os = Connector.openOutputStream("scratchpad:///0");
                for (i = 1; i <= 10; i++) {
                    os.write(i);
                }
                os.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    os.close();
                } catch(IOException ioe2) {}
            }
// J332_0401_0102
            try {
                is = Connector.openInputStream("scratchpad:///0");
                is.skip(9);
                if (is.read() == 10) {
                    okFlag = true;
                }
                is.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    is.close();
                } catch(IOException ioe2) {}
            }

            if (okFlag) {
                resultText.setText("read OK");
            } else {
                resultText.setText("NG");
            }
            break;
        case 1:
            try {
                os = Connector.openDataOutputStream("scratchpad:///0");
                for (i = 1; i <= 10; i++) {
                    os.write(i);
                }
                os.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    os.close();
                } catch(IOException ioe2) {}
            }
// J332_0401_0103
            try {
                is = Connector.openInputStream("scratchpad:///0");
                is.skip(10);
                if (is.read() == -1) {
                    okFlag = true;
                }
                is.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    is.close();
                } catch(IOException ioe2) {}
            }

            if (okFlag) {
                resultText.setText("read OK");
            } else {
                resultText.setText("NG");
            }
            break;
        case 2:
            try {
                dos = Connector.openDataOutputStream("scratchpad:///0");
                for (i = 1; i <= 10; i++) {
                    dos.write(i + 10);
                }
                dos.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    dos.close();
                } catch(IOException ioe2) {}
            }
// J332_0401_0202
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                dis.skip(9);
                if (dis.read() == 20) {
                    okFlag = true;
                }
                dis.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    dis.close();
                } catch(IOException ioe2) {}
            }

            if (okFlag) {
                resultText.setText("read OK");
            } else {
                resultText.setText("NG");
            }
            break;
        case 3:
            try {
                os = Connector.openOutputStream("scratchpad:///0");
                for (i = 1; i <= 10; i++) {
                    os.write(i + 10);
                }
                os.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    os.close();
                } catch(IOException ioe2) {}
            }
// J332_0401_0203
            try {
                dis = Connector.openDataInputStream("scratchpad:///0");
                dis.skip(10);
                if (dis.read() == -1) {
                    okFlag = true;
                }
                dis.close();
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            } finally {
                try {
                    dis.close();
                } catch(IOException ioe2) {}
            }

            if (okFlag) {
                resultText.setText("read OK");
            } else {
                resultText.setText("NG");
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}