/**
 * J332_0501_0101.java
 * 
 * J332_0501_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J332_0501_0101.java,v 1.1 2002/02/01 09:20:06 waka Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the behavior of the number of multiply opened Scratchpad
 * @extends IApplication
 */
public class J332_0501_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the behavior of the number of multiply opened Scratchpad 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    Label            subTitle1     = null;  /* subtitle 1 */
    Label            subTitle2     = null;  /* subtitle 2 */
    ListBox          menuList      = null;  /* Menu list */
    Button           execButton    = null;  /* execute button */
    TextBox          resultText    = null;  /* Text box for displaying the result */
    boolean          okFlag        = false; /* Flag for determination of test result */
    String[]         menuListItem  = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3"
    };
    InputStream      is1           = null;
    InputStream      is2           = null;
    InputStream      is3           = null;
    InputStream      is4           = null;
    InputStream      is5           = null;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle1      = new Label("read mode");
        subTitle2      = new Label("check the number of simultaneous accesses");
        menuList       = new ListBox(ListBox.CHOICE,3);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);
        add(subTitle1);
        add(subTitle2);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * The method of confirming operations
     */
    void test() {
        /* behavior check */
        switch (menuList.getSelectedIndex()) {
// J322_0501_0101
        /* open 4 multiply under the READ mode */
        case 0:
            try {
                is1 = Connector.openInputStream("scratchpad:///0");
                is2 = Connector.openInputStream("scratchpad:///0");
                is3 = Connector.openInputStream("scratchpad:///0");
                is4 = Connector.openInputStream("scratchpad:///0");

                is1.close();
                is2.close();
                is3.close();
                is4.close();

                okFlag = true;
            } catch(IOException ioe) {
                showMsg("main:" + ioe.toString());
            } catch(Exception e) {
                showMsg("main:" + e.toString());
            }

            if (okFlag) {
                resultText.setText("Open:OK");
            } else {
                resultText.setText("NG");
            }
            break;
// J322_0501_0201
        /* open more than 4 multiply under the READ mode */
        case 1:
            okFlag =false;

            try {
                /* open 5 of them to generate ConnectionException */
                is1 = Connector.openInputStream("scratchpad:///0");
                is2 = Connector.openInputStream("scratchpad:///0");
                is3 = Connector.openInputStream("scratchpad:///0");
                is4 = Connector.openInputStream("scratchpad:///0");
                is5 = Connector.openInputStream("scratchpad:///0");

                is1.close();
                is2.close();
                is3.close();
                is4.close();
                is5.close();
            } catch(ConnectionException ce) {
                if (ce.getStatus() == ConnectionException.RESOURCE_BUSY) {
                    okFlag = true;
                }
            } catch(IOException ioe) {
                showMsg("main:" + ioe.toString());
            } catch(Exception e) {
                showMsg("main:" + e.toString());
            }

            if (okFlag) {
                resultText.setText("ConException.RESOURCE_BUSY:OK");
            } else {
                resultText.setText("NG:more than 4 is opened multiply");
            }
            break;
// J322_0501_0202
        /* open more than 4 multiply under the READ mode, and reconnect after releasing them */
        case 2:
            okFlag =false;
            try {
                /* open 5 of them to generate ConnectionException  */
                is1 = Connector.openInputStream("scratchpad:///0");
                is2 = Connector.openInputStream("scratchpad:///0");
                is3 = Connector.openInputStream("scratchpad:///0");
                is4 = Connector.openInputStream("scratchpad:///0");
                is5 = Connector.openInputStream("scratchpad:///0");

                is1.close();
                is2.close();
                is3.close();
                is4.close();
                is5.close();
            } catch(ConnectionException ce) {
                /* after the exception is thrown, get connection once more. */
                if (ce.getStatus() == ConnectionException.RESOURCE_BUSY) {
                    try {
                        InputStream in =
                            Connector.openInputStream("scratchpad:///0");
                        okFlag = true;
                    } catch(IOException ioe2) {}
                }
            } catch(IOException ioe) {
                showMsg("main:" + ioe.toString());
            } catch(Exception e) {
                showMsg("main:" + e.toString());
            }

            if (okFlag) {
                resultText.setText("get connection: OK");
            } else {
                resultText.setText("NG:more than 4 is opened multiply");
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}