/**
 * J333_0201_0101.java
 * 
 * J333_0201_0101
 * MenuPanel
 * 
 * communication interlocking test (Scratchpad)
 * 
 * $Id: J333_0201_0101.java,v 1.2 2002/03/09 06:38:57 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * main class for checking the repeat behavior of single operation of Scratchpad
 * @extends IApplication
 */
public class J333_0201_0101 extends IApplication {
    /**
     * Commencing method to i-appli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }
}

/**
 * screen to check the repeat behavior of single operation of Scratchpad
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MenuPanel extends Panel implements SoftKeyListener,ComponentListener {
    Label            subTitle      = null;  /* subtitle 1 */
    ListBox          menuList      = null;  /* Menu list */
    String[]         menuListItem  = {
        "0.Test 1",
        "1.Test 2",
        "2.Test 3",
        "3.Test 4",
        "4.Test 5"
    };                                      /* menu items */
    Button           execButton    = null;  /* execute button */
    TextBox          resultText    = null;  /* Text box for displaying the result */
    boolean          okFlag        = false; /* Flag for determination of test result */
    InputStream      is            = null;
    InputConnection  ic            = null;
    OutputStream     os            = null;
    OutputConnection oc            = null;
    Connection       con           = null;

    /**
     * Constructor of MenuPanel class
     */
    MenuPanel() {
        try {
            showMainPanel();
        } catch(Exception e) {
            showMsg(e.toString());
        } catch(Error e) {
            showMsg(e.toString());
        }
    }

    /**
     * Display the main panel
     */
    public void showMainPanel() {
        setTitle("boundary behavior at the time of reading SP");

        /* Create and add components */
        subTitle      = new Label("repeat between modes");
        menuList       = new ListBox(ListBox.CHOICE,7);
        execButton     = new Button("execute");
        resultText     = new TextBox("",getWidth(), 3, TextBox.DISPLAY_ANY);
        add(subTitle);
        add(menuList);
        add(execButton);
        add(resultText);

        /* Setting of the Menu items */
        menuList.setItems(menuListItem);

        /* Setting of the soft key label */
        setSoftLabel(Frame.SOFT_KEY_1,"exit");

        /* Listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * The method of confirming operations
     */
    void test() {
        int i          = 0;
        int counter    = 100;
        int readValue  = 0;
        int writeValue = 10;
        
        /* behavior check */
        switch (menuList.getSelectedIndex()) {
// J332_0201_0101
// J332_0201_0201
        /* the write operations WRITE mode, the read operations READ mode */
        case 0:
            try {
                for (i = 1; i <= counter; i++) {
                    /* behavior of the write operations WRITE mode*/
                    os = Connector.openOutputStream("scratchpad:///0");
                    os.write(writeValue);
                    os.close();

                    /* behavior of the read  READ mode */
                    is = Connector.openInputStream("scratchpad:///0");
                    readValue = is.read();
                    is.close();

                    /* judge if the read and write operations have the same value */
                    if (writeValue != readValue) {
                        return;
                    }

                    /* the OK flag is on when it's repeated for 100 times  */
                    if (i == 100) {
                        okFlag = true;
                    }
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            }

            /* OK should display when the OK flag is on */
            if (okFlag) {
                    resultText.setText("OK to read and write");
            } else {
                resultText.setText("NG");
            }
            break;
// J332_0201_0102
// J332_0201_0301
        /* the write operations READ_WRITE mode the read operations READ mode */
        case 1:
            try {
                for (i = 1; i <= counter; i++) {
                    /* the behavior of the write operations READ_WRITE mode*/
                    con = Connector.open(
                        "scratchpad:///0", Connector.READ_WRITE, true);
                    oc = (OutputConnection)con;
                    os = oc.openOutputStream();
                    os.write(writeValue);
                    os.close();
                    con.close();

                    /* behavior of the read  READ mode*/
                    is = Connector.openInputStream("scratchpad:///0");
                    readValue = is.read();
                    is.close();

                    /* judge if the read and write operations have the same value */
                    if (writeValue != readValue) {
                        return;
                    }

                    /* the OK flag is on when it's repeated for 100 times  */
                    if (i == 100) {
                        okFlag = true;
                    }
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            }

            /* OK should display when the OK flag is on */
            if (okFlag) {
                    resultText.setText("OK to read and write");
            } else {
                resultText.setText("NG");
            }
            break;
// J332_0201_0202
// J332_0201_0302
        /* the write operations WRITE mode the read operations READ_READ mode */
        case 2:
            try {
                for (i = 1; i <= counter; i++) {
                    /* behavior of the write operations WRITE mode*/
                    os = Connector.openOutputStream("scratchpad:///0");
                    os.write(writeValue);
                    os.close();

                    /* behavior of the read operations READ_WRITE mode*/
                    con = Connector.open(
                        "scratchpad:///0", Connector.READ_WRITE, true);
                    ic =(InputConnection)con;
                    is = ic.openInputStream();
                    readValue = is.read();
                    is.close();
                    con.close();

                    /* judge if the read and write operations have the same value */
                    if (writeValue != readValue) {
                        return;
                    }

                    /* the OK flag is on when it's repeated for 100 times  */
                    if (i == 100) {
                        okFlag = true;
                    }
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            }

            /* OK should display when the OK flag is on */
            if (okFlag) {
                    resultText.setText("OK to read and write");
            } else {
                resultText.setText("NG");
            }
            break;
// J332_0201_0401
        /* the write operations READ_WRITE mode the read operations READ_WRITE mode */
        case 3:
            try {
                for (i = 1; i <= counter; i++) {
                    /* the behavior of the write operations READ_WRITE mode*/
                    con = Connector.open(
                        "scratchpad:///0", Connector.READ_WRITE, true);
                    oc = (OutputConnection)con;
                    os = oc.openOutputStream();
                    os.write(writeValue);
                    os.close();
					con.close();

                    /* behavior of the read operations READ_WRITE mode*/
                    con = Connector.open(
                        "scratchpad:///0", Connector.READ_WRITE, true);
                    ic =(InputConnection)con;
                    is = ic.openInputStream();
                    readValue = is.read();
                    is.close();
                    con.close();

                    /* judge if the read and write operations have the same value */
                    if (writeValue != readValue) {
                        return;
                    }

                    /* the OK flag is on when it's repeated for 100 times  */
                    if (i == 100) {
                        okFlag = true;
                    }
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            }

            /* OK should display when the OK flag is on */
            if (okFlag) {
                    resultText.setText("OK to read and write");
            } else {
                resultText.setText("NG");
            }
            break;
// J332_0102_0402
        /* the read and write operations on the same connection READ_WRITE mode */
        case 4:
            try {
                for (i = 1; i <= counter; i++) {
                    /* open the connection */
                    con = Connector.open(
                        "scratchpad:///0", Connector.READ_WRITE, true);

                    /* the behavior of the write operations READ_WRITE mode*/
                    oc = (OutputConnection)con;
                    os = oc.openOutputStream();
                    os.write(writeValue);
                    os.close();

                    /* behavior of the read operations READ_WRITE mode*/
                    ic =(InputConnection)con;
                    is = ic.openInputStream();
                    readValue = is.read();
                    is.close();
                    con.close();

                    /* judge if the read and write operations have the same value */
                    if (writeValue != readValue) {
                        return;
                    }

                    /* the OK flag is on when it's repeated for 100 times  */
                    if (i == 100) {
                        okFlag = true;
                    }
                }
            } catch(IOException ioe) {
                showMsg(ioe.toString());
            } catch(Exception e) {
                showMsg(e.toString());
            }

            /* OK should display when the OK flag is on */
            if (okFlag) {
                    resultText.setText("OK to read and write");
            } else {
                resultText.setText("NG");
            }
            break;
        default:
            break;
        }
    }

    /**
     * Display a message dialog
     * @param  aMsg  Dialog message
     */
    void showMsg(String aMsg) {
        Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "Message");
        msgDialog.setText(aMsg);
        msgDialog.show();
    }

    /**
     * No action to be made once soft key is pressed
     * @param aSoftKey  Type of soft key
     */
    public void softKeyPressed(int aSoftKey) {}

    /**
     * Terminate the application when soft key1 is released
     * @param aSoftKey  Type of soft key
     */
    public void softKeyReleased(int aSoftKey) {
        if (aSoftKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * Receive events occurred in components
     * @param aComponent  Component where an event occurred
     * @param aType       Event type
     * @param aParam     Event parameter
     */
    public void componentAction(Component aComponent, int aAction, int aParam) {        if (aAction == ComponentListener.BUTTON_PRESSED) {
            test();
        }
        if (aAction == ComponentListener.SELECTION_CHANGED) {
            resultText.setText("");
        }
    }
}