/**
 * J341_0101_0101
 * MainPanel
 *
 * communication (resource):check the behavior when it is opened (resource name operation) 
 *
 * $Id: J341_0101_0101.java,v 1.1 2002/02/01 09:30:25 yuki_o Exp $
 */

import com.nttdocomo.ui.*;
import javax.microedition.io.*;
import java.io.*;


/**
 * main class
 * @extends IApplication
 */
public class J341_0101_0101 extends IApplication {

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * communication (resource)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener {
    Button executeButton = new Button("execute");
    ListBox menuList = new ListBox(ListBox.CHOICE);
    String[] menuListItem = {
        "1.filename",
        "2.blank1",
        "3.blank2",
        "4.period1",
        "5.period2",
        "6.period3",
        "7.http",
        "8.https",
        "9.resource",
        "10.scratchpad",
//2002/08/19 DoJa1.5        "11.obex"
    };

    /**
     * constructor of MainPanel class
     */
    public MainPanel() {
        /* configuration of display items */
        menuList.setItems(menuListItem);
        setTitle("communication (resource)");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* add each component to the screen */
        add(menuList);
        add(executeButton);

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * operate nothing when soft key is pushed down
     * @param index of anIndex key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * end the application when soft key 1 is released
     * @param index of anIndex key
     */
    public void softKeyReleased(int anIndex) {

        /* end the application when soft key 1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * receive events occurred in components
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     * 
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if (aComponent == executeButton) {
            test();
        }
    }

    /*
     * dialog display method
     * @param   aText displayed character strings 
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * method to execute the test
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        String[] url = new String[1];

        /* execute each of the tests */
        switch( idx ) {

//J341_0101_0101
            case 0:
                try {
                    InputStream is = Connector.openInputStream("resource:///filename");
                    if(is != null){
                        showDialog("OPEN:OK");
                    }
                    is.close();
                }
                catch (Exception e) {
                    showDialog("OPEN:NG");
                    System.out.println(e.toString());
                }
                break;

//J341_0101_0102
            case 1:
                try {
                    InputStream is = Connector.openInputStream("resource:/// blank1");
                    if(is != null){
                        showDialog("OPEN:OK");
                    }
                    is.close();
                }
                catch (Exception e) {
                    showDialog("OPEN:NG");
                }
                break;

//J341_0101_0103
            case 2:
                try {
                    InputStream is = Connector.openInputStream("resource:///blank 2");
                    if(is != null){
                        showDialog("OPEN:OK");
                    }
                    is.close();
                }
                catch (Exception e) {
                    showDialog("OPEN:NG");
                }
                break;

//J341_0101_0104
            case 3:
                try {
                    InputStream is = Connector.openInputStream("resource:///.period1");
                    if(is != null){
                        showDialog("OPEN:OK");
                    }
                    is.close();
                }
                catch (Exception e) {
                    showDialog("OPEN:NG");
                }
                break;

//J341_0101_0105
            case 4:
                try {
                    InputStream is = Connector.openInputStream("resource:///period.2");
                    if(is != null){
                        showDialog("OPEN:OK");
                    }
                    is.close();
                }
                catch (Exception e) {
                    showDialog("OPEN:NG");
                }
                break;

//J341_0101_0106
            case 5:
                try {
                    InputStream is = Connector.openInputStream("resource:///period...3");
                    if(is != null){
                        showDialog("OPEN:OK");
                    }
                    is.close();
                }
                catch (Exception e) {
                    showDialog("OPEN:NG");
                }
                break;

//J341_0101_0107
            case 6:
                try {
                    InputStream is = Connector.openInputStream("resource:///http");
                    if(is != null){
                        showDialog("OPEN:OK");
                    }
                    is.close();
                }
                catch (Exception e) {
                    showDialog("OPEN:NG");
                }
                break;

//J341_0101_0108
            case 7:
                try {
                    InputStream is = Connector.openInputStream("resource:///https");
                    if(is != null){
                        showDialog("OPEN:OK");
                    }
                    is.close();
                }
                catch (Exception e) {
                    showDialog("OPEN:NG");
                }
                break;

//J341_0101_0109
            case 8:
                try {
                    InputStream is = Connector.openInputStream("resource:///resource");
                    if(is != null){
                        showDialog("OPEN:OK");
                    }
                    is.close();
                }
                catch (Exception e) {
                    showDialog("OPEN:NG");
                }
                break;

//J341_0101_0110
            case 9:
                try {
                    InputStream is = Connector.openInputStream("resource:///scratchpad");
                    if(is != null){
                        showDialog("OPEN:OK");
                    }
                    is.close();
                }
                catch (Exception e) {
                    showDialog("OPEN:NG");
                }
                break;

//2002/08/19 DoJa1.5//J341_0101_0111
//2002/08/19 DoJa1.5            case 10:
//2002/08/19 DoJa1.5                try {
//2002/08/19 DoJa1.5                    InputStream is = Connector.openInputStream("resource:///obex");
//2002/08/19 DoJa1.5                    if(is != null){
//2002/08/19 DoJa1.5                        showDialog("OPEN:OK");
//2002/08/19 DoJa1.5                    }
//2002/08/19 DoJa1.5                    is.close();
//2002/08/19 DoJa1.5                }
//2002/08/19 DoJa1.5                catch (Exception e) {
//2002/08/19 DoJa1.5                    showDialog("OPEN:NG");
//2002/08/19 DoJa1.5                }
//2002/08/19 DoJa1.5                break;
        }
    }
}

