/**
 * J341_0101_0401
 * MainPanel
 *
 * communication (resource):check the behavior when it is opened (resource name operation) 
 *
 * $Id: J341_0101_0401.java,v 1.1 2002/02/01 09:30:25 yuki_o Exp $
 */

import com.nttdocomo.ui.*;
import javax.microedition.io.*;
import java.io.*;
import javax.microedition.*;


/**
 * main class
 * @extends IApplication
 */
public class J341_0101_0401 extends IApplication {

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * communication (resource)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    Button executeButton = new Button("execute");
    ListBox menuList = new ListBox(ListBox.CHOICE);
    String[] menuListItem = {
        "1.READ",
        "2.WRITE",
        "3.READ_WRITE",
        "4.IS",
        "5.DIS",
        "6.openIS",
        "7.openDIS",
        "8.openOS",
        "9.openDOS"
    };

    /**
     * constructor of MainPanel class
     */
    public MainPanel() {
        /* configuration of display items */
        menuList.setItems(menuListItem);
        setTitle("communication (resource)");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* add each component to the screen */
        add(menuList);
        add(executeButton);

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * operate nothing when soft key is pushed down
     * @param index of anIndex key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * end the application when soft key 1 is released
     * @param index of anIndex key
     */
    public void softKeyReleased(int anIndex) {

        /* end the application when soft key 1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * receive events occurred in components
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     * 
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if (aComponent == executeButton) {
            test();
        }
    }

    /*
     * dialog display method
     * @param   aText displayed character strings 
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * method to execute the test
     */
    public void test() {
        int idx = menuList.getSelectedIndex();

        /* execute each of the tests */
        switch( idx ) {
//J341_0101_0401
            case 0:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    if(ic != null){
                        showDialog("OK");
                        ic.close();
                    }
                }
                catch (Exception e) {
                    showDialog("NG");
                }
                break;
//J341_0101_0402
            case 1:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.WRITE);
                    if(ic != null){
                        showDialog("NG");
                        ic.close();
                    }
                }
                catch (IllegalArgumentException iae) {
                    showDialog("OK:IllegalArgumentException("+iae.getMessage()+")");
                }
                catch (Exception e) {
                    showDialog("NG:"+e.toString());
                }
                break;
//J341_0101_0403
            case 2:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ_WRITE);
                    if(ic != null){
                        showDialog("NG");
                        ic.close();
                    }
                }
                catch (IllegalArgumentException iae) {
                    showDialog("OK:IllegalArgumentException("+iae.getMessage()+")");
                }
                catch (Exception e) {
                    showDialog("NG:"+e.toString());
                }
                break;
//J341_0101_0404
            case 3:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    InputStream is = ic.openInputStream();
                    if(is != null){
                        showDialog("OK");
                        is.close();
                        ic.close();
                    }
                }
                catch (Exception e) {
                    showDialog("NG:"+e.toString());
                }
                break;
//J341_0101_0405
            case 4:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    if(dis != null){
                        showDialog("OK");
                        dis.close();
                        ic.close();
                    }
                }
                catch (Exception e) {
                    showDialog("NG:"+e.toString());
                }
                break;
//J341_0101_0408
            case 5:
                try {
                    InputStream is = Connector.openInputStream("resource:///filename");
                    if(is != null){
                        showDialog("OK");
                        is.close();
                    }
                }
                catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
//J341_0101_0409
            case 6:
                try {
                    DataInputStream dis = Connector.openDataInputStream("resource:///filename");
                    if(dis != null){
                        showDialog("OK");
                        dis.close();
                    }
                }
                catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
//J341_0101_0410
            case 7:
                try {
                    OutputStream os = Connector.openOutputStream("resource:///filename");
                    if(os != null){
                        showDialog("NG");
                        os.close();
                    }
                }
                catch (IllegalArgumentException iae) {
                    showDialog("OK:IllegalArgumentException");
                }
                catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
//J341_0101_0411
            case 8:
                try {
                    DataOutputStream dos = Connector.openDataOutputStream("resource:///filename");
                    if(dos != null){
                        showDialog("NG");
                        dos.close();
                    }
                }
                catch (IllegalArgumentException iae) {
                    showDialog("OK:IllegalArgumentException");
                }
                catch (Exception e) {
                    showDialog(e.toString());
                }
                break;
        }
    }
}

