/**
 * J341_0103_0101
 * MainPanel
 *
 * communication (resource):check the behavior when it is opened (resource name operation) 
 *
 * $Id: J341_0103_0101.java,v 1.1 2002/02/01 09:30:26 yuki_o Exp $
 */

import com.nttdocomo.ui.*;
import javax.microedition.io.*;
import java.io.*;
import javax.microedition.*;
import java.lang.*;



/**
 * main class
 * @extends IApplication
 */
public class J341_0103_0101 extends IApplication {

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * communication (resource)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    Button executeButton = new Button("execute");
    ListBox menuList = new ListBox(ListBox.CHOICE);

    String[] menuListItem = {
        "1.IS-read1",
        "2.IS-read2",
        "3.IS-read3",
        "4.DIS-read1",
        "5.DIS-read2",
        "6.DIS-read3",
        "7.DIS-readBoolean",
        "8.DIS-readByte",
        "9.DIS-readChar",
        "10.DIS-readFully1",
        "11.DIS-readFully2",
        "12.DIS-readInt",
        "13.DIS-readLong",
        "14.DIS-readShort",
        "15.DIS-readUB",
        "16.DIS-readUS",
        "17.DIS-readUTF",
    };

    /**
     * constructor of MainPanel class
     */
    public MainPanel() {
        /* configuration of display items */
        menuList.setItems(menuListItem);
        setTitle("communication (resource)");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* add each component to the screen */
        add(menuList);
        add(executeButton);

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * operate nothing when soft key is pushed down
     * @param index of anIndex key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * end the application when soft key 1 is released
     * @param index of anIndex key
     */
    public void softKeyReleased(int anIndex) {

        /* end the application when soft key 1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * receive events occurred in components
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     * 
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if (aComponent == executeButton) {
            test();
        }
    }

    /*
     * dialog display method
     * @param   aText displayed character strings 
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * method to execute the test
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        int data = 0;
        boolean flag = true;

        /* execute each of the tests */
        switch( idx ) {
//J341_0103_0101
            case 0:
                data = 0;
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    InputStream     is = ic.openInputStream();
                    data = is.read();
                    is.close();
                    ic.close();

                    if(data == '1'){
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0102
            case 1:
                data = 0;
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    InputStream     is = ic.openInputStream();
                    byte[] b = new byte[5];
                    data = is.read(b);
                    is.close();
                    ic.close();

                    String s = new String(b);
                    if(data == 5 && s.compareTo("12345") == 0){
                        showDialog("read OK");
                    }

                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0103
            case 2:
                data = 0;
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    InputStream     is = ic.openInputStream();
                    byte[] b = new byte[10];
                    data = is.read(b,0,10);
                    is.close();
                    ic.close();

                    String s = new String(b);
                    if(data == 10 && s.compareTo("1234567890") == 0){
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0201
            case 3:
                data = 0;
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    data = dis.read();
                    dis.close();
                    ic.close();

                    if(data == '1'){
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0202
            case 4:
                data = 0;
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    byte[] b = new byte[5];
                    data = dis.read(b);
                    dis.close();
                    ic.close();

                    String s = new String(b);
                    if(data == 5 && s.compareTo("12345") == 0){
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0203
            case 5:
                data = 0;
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    byte[] b = new byte[10];
                    data = dis.read(b,0,10);
                    dis.close();
                    ic.close();

                    String s = new String(b);
                    if(data == 10 && s.compareTo("1234567890") == 0){
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0204
            case 6:
                flag = false;
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///boolean",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    flag = dis.readBoolean();
                    dis.close();
                    ic.close();

                    if(flag == true){
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0205
            case 7:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///byte",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    byte b = dis.readByte();
                    dis.close();
                    ic.close();

                    if(b == '1') {
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0206
            case 8:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///char",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    char c = dis.readChar();
                    dis.close();
                    ic.close();

                    if(c == '1' ) {
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0207
            case 9:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    byte[] b = new byte[5];
                    dis.readFully(b);
                    dis.close();
                    ic.close();

                    String s = new String(b);
                    if(s.compareTo("12345") == 0) {
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0208
            case 10:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    byte[] b = new byte[10];
                    dis.readFully(b,0,10);
                    dis.close();
                    ic.close();

                    String s = new String(b);
                    if(s.compareTo("1234567890") == 0) {
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0209
            case 11:
                try {
                    data = 0;
                    InputConnection ic = (InputConnection) Connector.open("resource:///int",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    data = dis.readInt();
                    dis.close();
                    ic.close();

                    if(data == '1') {
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0210
            case 12:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///long",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    long l = dis.readLong();
                    dis.close();
                    ic.close();

                    if(l == '1') {
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0211
            case 13:
                try {
                    InputConnection ic = (InputConnection) Connector.open("resource:///short",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    short s = dis.readShort();
                    dis.close();
                    ic.close();

                    if(s == '1') {
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0212
            case 14:
                try {
                    data = 0;
                    InputConnection ic = (InputConnection) Connector.open("resource:///byte",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    data = dis.readUnsignedByte();
                    dis.close();
                    ic.close();

                    if(data == '1') {
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0213
            case 15:
                try {
                    data = 0;
                    InputConnection ic = (InputConnection) Connector.open("resource:///short",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    data = dis.readUnsignedShort();
                    dis.close();
                    ic.close();

                    if(data == '1') {
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

//J341_0103_0214
            case 16:
                try {
                    data = 0;
                    InputConnection ic = (InputConnection) Connector.open("resource:///utf",Connector.READ);
                    DataInputStream dis = ic.openDataInputStream();
                    String s = dis.readUTF();
                    dis.close();
                    ic.close();

                    if(s.compareTo("1") == 0) {
                        showDialog("read OK");
                    }
                }
                catch (Exception e) {
                    showDialog("NG:" + e.toString());
                }
                break;

        }
    }
}

