/**
 * J341_0104_0101
 * MainPanel
 *
 * communication (resource):check the behavior when it is opened (resource name operation) 
 *
 * $Id: J341_0104_0101.java,v 1.2 2002/03/06 08:38:38 takanao Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;
import javax.microedition.io.*;
import java.io.*;
import javax.microedition.*;
import java.util.*;
import java.lang.*;


/**
 * main class
 * @extends IApplisation
 */
public class J341_0104_0101 extends IApplication {

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * communication (resource)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    Button executeButton = new Button("execute");
    ListBox menuList     = new ListBox(ListBox.CHOICE);
    InputConnection   ic = null;

    String[] menuListItem = {
        "1.IS->Con",
        "2.DIS->Con",
        "3.Con->IS",
        "4.Con->DIS",
        "5.openIS",
        "6.openDIS"
    };

    /**
     * constructor of MainPanel class
     */
    public MainPanel() {
        /* configuration of display items */
        menuList.setItems(menuListItem);
        setTitle("communication (resource)");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* add each component to the screen */
        add(menuList);
        add(executeButton);
        

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * operate nothing when soft key is pushed down
     * @param index of anIndex key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * end the application when soft key 1 is released
     * @param index of anIndex key
     */
    public void softKeyReleased(int anIndex) {

        /* end the application when soft key 1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * receive events occurred in components
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     * 
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if (aComponent == executeButton) {
            test();
        }

    }

    /*
     * dialog display method
     * @param   aText displayed character strings 
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }


    /**
     * method to execute the test
     */
    public void test() {
        int      idx = menuList.getSelectedIndex();

        /* execute each of the tests */
        switch( idx ) {
//J341_0104_0101
            case 0:
                    /* get InputStream -> close InputStream -> Connection close */
                    try{
                        ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                        InputStream is = ic.openInputStream();
                        is.close();
                        ic.close();
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }

                    /* check that Connection has been closed and released */
                    try{
                        InputStream is = Connector.openInputStream("resource:///filename");
                        if(is != null){
                            showDialog("OK");
                        }
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }
                break;

//J341_0104_0102
            case 1:
                    /* get DataInputStream -> DataInputStream close -> Connection close */
                    try{
                        ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                        DataInputStream dis = ic.openDataInputStream();
                        dis.close();
                        ic.close();
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }

                    /* check that Connection has been closed and released */
                    try{
                        DataInputStream dis = Connector.openDataInputStream("resource:///filename");
                        if(dis != null){
                            showDialog("OK");
                        }
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }
                break;

//J341_0104_0103
            case 2:
                    /* get InputStream -> Connection close -> InputStream close */
                    try{
                        ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                        InputStream is = ic.openInputStream();
                        ic.close();
                        is.close();
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }

                    /* check that Connection has been closed and released */
                    try{
                        InputStream is = Connector.openInputStream("resource:///filename");
                        if(is != null){
                            showDialog("OK");
                        }
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }
                break;

//J341_0104_0104
            case 3:
                    /* get DataInputStream -> Connection close -> DataInputStream close */
                    try{
                        ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                        DataInputStream dis = ic.openDataInputStream();
                        ic.close();
                        dis.close();
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }

                    /* check that Connection has been closed and released */
                    try{
                        DataInputStream dis = Connector.openDataInputStream("resource:///filename");
                        if(dis != null){
                            showDialog("OK");
                        }
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }
                break;

//J341_0104_0201
            case 4:
                    /* 
                     * get InputStream by Connector#openInputStream. 
                     * -> InputStream close 
                     */
                    try{
                        InputStream is = Connector.openInputStream("resource:///filename");
                        is.close();
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }

                    /* check that Connection has been closed and released */
                    try{
                        InputStream is = Connector.openInputStream("resource:///filename");
                        if(is != null){
                            showDialog("OK");
                            }
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }
                break;

//J341_0104_0202
            case 5:
                    /* 
                     * get DataInputStream by Connector#openDataInputStream. 
                     * -> DataInputStream close 
                     */
                    try{
                        DataInputStream dis =  Connector.openDataInputStream("resource:///filename");
                        dis.close();
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }

                    /* check that Connection has been closed and released */
                    try{
                        DataInputStream dis = Connector.openDataInputStream("resource:///filename");
                        if(dis != null){
                            showDialog("OK");
                        }
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }
                break;
        }
    }
}

