/**
 * J341_0105_0101
 * MainPanel
 *
 * communication (resource):check the behavior when it is opened (resource name operation) 
 *
 * $Id: J341_0105_0101.java,v 1.1 2002/02/01 09:30:27 yuki_o Exp $
 */

import com.nttdocomo.ui.*;
import javax.microedition.io.*;
import java.io.*;
import javax.microedition.*;
import java.util.*;


/**
 * main class
 * @extends IApplication
 */
public class J341_0105_0101 extends IApplication {

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * communication (resource)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    Button executeButton = new Button("execute");
    ListBox menuList = new ListBox(ListBox.CHOICE);

    String[] menuListItem = {
        "test 1",
        "test 2",
        "test 3"
    };

    /**
     * constructor of MainPanel class
     */
    public MainPanel() {
        /* configuration of display items */
        menuList.setItems(menuListItem);
        setTitle("communication (resource)");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* add each component to the screen */
        add(menuList);
        add(executeButton);

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * operate nothing when soft key is pushed down
     * @param index of anIndex key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * end the application when soft key 1 is released
     * @param index of anIndex key
     */
    public void softKeyReleased(int anIndex) {

        /* end the application when soft key 1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * receive events occurred in components
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     * 
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if (aComponent == executeButton) {
            test();
        }

    }

    /*
     * dialog display method
     * @param   aText displayed character strings 
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }


    /**
     * method to execute the test
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        InputConnection ic1 = null;
        InputConnection ic2 = null;
        InputStream     is1 = null;
        InputStream     is2 = null;

        /* execute each of the tests */
        switch( idx ) {

//J341_0105_0101
            case 0:
                /* get  multiple streams (1) */
                try{
                   ic1 = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                   ic2 = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                }
                catch(IOException ioe){
                    showDialog("OK(" + ioe.toString() + ")");
                }
                catch(Exception e){
                    showDialog("NG:"+ e.toString());
                }

                if( ic1 != null && ic2 != null ){
                    showDialog("OK");
                    try{
                        ic1.close();
                        ic2.close();
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }
                }
                break;

//J341_0105_0102
            case 1:
                /* get  multiple streams from one connection */
                try{
                    ic1 = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    is1 = ic1.openInputStream();
                    is2 = ic1.openInputStream();
                }
                catch(IOException ioe){
                    showDialog("OK(" + ioe.toString() + ")");
                }
                catch(Exception e){
                    showDialog("open:NG" + e.toString());
                }

                if( is1 != null && is2 != null ){
                    showDialog("OK");
                    try{
                        is1.close();
                        is2.close();
                        ic1.close();
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }
                }
                break;

//J341_0105_0103
            case 2:
                /* open  multiple resources that have different path name */
                try{
                   ic1 = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                   ic2 = (InputConnection) Connector.open("resource:///test/testfile",Connector.READ);
                }
                catch(IOException ioe){
                    showDialog("OK(" + ioe.toString() + ")");
                }
                catch(Exception e){
                    showDialog("NG:"+ e.toString());
                }

                if( ic1 != null && ic2 != null ){
                    showDialog("OK");
                    try{
                        ic1.close();
                        ic2.close();
                    }
                    catch(Exception e){
                        showDialog("NG:" + e.toString());
                    }
                }
                break;
        }
    }
}

