/**
 * J342_0202_0101
 * MainPanel
 *
 * communication (resource):check the behavior when it is opened (resource name operation) 
 *
 * $Id: J342_0202_0101.java,v 1.1 2002/02/01 09:30:31 yuki_o Exp $
 */

import com.nttdocomo.ui.*;
import javax.microedition.io.*;
import java.io.*;
import javax.microedition.*;
import java.lang.*;



/**
 * main class
 * @extends IApplication
 */
public class J342_0202_0101 extends IApplication {

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * communication (resource)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    Button executeButton = new Button("execute");
    ListBox menuList = new ListBox(ListBox.CHOICE);

    String[] menuListItem = {
        "1.IS-read1",
        "2.IS-read2",
        "3.IS-read3"
    };

    /**
     * constructor of MainPanel class
     */
    public MainPanel() {
        /* configuration of display items */
        menuList.setItems(menuListItem);
        setTitle("communication (resource)");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* add each component to the screen */
        add(menuList);
        add(executeButton);

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * operate nothing when soft key is pushed down
     * @param index of anIndex key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * end the application when soft key 1 is released
     * @param index of anIndex key
     */
    public void softKeyReleased(int anIndex) {

        /* end the application when soft key 1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * receive events occurred in components
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     * 
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if (aComponent == executeButton) {
            test();
        }
    }

    /*
     * dialog display method
     * @param   aText displayed character strings 
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * method to execute the test
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        int     len  = 0;
        InputStream     is = null;

        /* execute each of the tests */
        switch( idx ) {
//J342_0202_0101
            case 0:
                byte b = 0;
                /* open stream */
                try{
                    is = Connector.openInputStream("resource:///dataA");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(is);

                 /* read the last data */
                try{
                    b = (byte) is.read();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( b == (byte) 'a'){
                    showDialog("OK");
                }else{
                    showDialog("a=" + (byte) 'a' + " b=" + b);
                }

                /* close the connection */
                try{
                    is.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0102
            case 1:
               byte[] b1 = new byte[2];
                /* open stream */
                try{
                    is = Connector.openInputStream("resource:///dataB");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(is);

                 /* read the last data */
                try{
                    len = is.read(b1);
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( b1[0] == 'a' && b1[1]=='b' && len == 2 ){
                    showDialog("OK");
                }else{
                    showDialog("[0]=" + b1[0] + " [1]=" + b1[1]);
                }

                /* close the connection */
                try{
                    is.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0103
            case 2:
                byte[] b2 = new byte[2];
                /* open stream */
                try{
                    is = Connector.openInputStream("resource:///dataB");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(is);

                 /* read the last data */
                try{
                    len = is.read(b2,0,2);
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( b2[0] == 'a' && b2[1]=='b' && len == 2 ){
                    showDialog("OK");
                }else{
                    showDialog("[0]=" + b2[0] + " [1]=" + b2[1]);
                }

                /* close the connection */
                try{
                    is.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

        }

    }

    public void readData(InputStream is){
        byte[] sts = new byte[6];
        try{
            is.read(sts,0,6);
        }
        catch(Exception e){
            showDialog("NG:" + e.toString());
        }
    }
}

