/**
 * J342_0202_0201
 * MainPanel
 *
 * communication (resource):check the behavior when it is opened (resource name operation) 
 *
 * $Id: J342_0202_0201.java,v 1.1 2002/02/01 09:30:31 yuki_o Exp $
 */

import com.nttdocomo.ui.*;
import javax.microedition.io.*;
import java.io.*;
import javax.microedition.*;
import java.lang.*;



/**
 * main class
 * @extends IApplication
 */
public class J342_0202_0201 extends IApplication {

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * communication (resource)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    Button executeButton = new Button("execute");
    ListBox menuList = new ListBox(ListBox.CHOICE);

    String[] menuListItem = {
        "1.DIS-read1",
        "2.DIS-read2",
        "3.DIS-read3",
        "4.DIS-readBoolean",
        "5.DIS-readByte",
        "6.DIS-readChar",
        "7.DIS-readFully1",
        "8.DIS-readFully2",
        "9.DIS-readInt",
        "10.DIS-readLong",
        "11.DIS-readShort",
        "12.DIS-readUB",
        "13.DIS-readUS",
        "14.DIS-readUTF",
    };

    /**
     * constructor of MainPanel class
     */
    public MainPanel() {
        /* configuration of display items */
        menuList.setItems(menuListItem);
        setTitle("communication (resource)");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* add each component to the screen */
        add(menuList);
        add(executeButton);

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * operate nothing when soft key is pushed down
     * @param index of anIndex key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * end the application when soft key 1 is released
     * @param index of anIndex key
     */
    public void softKeyReleased(int anIndex) {

        /* end the application when soft key 1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * receive events occurred in components
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     * 
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if (aComponent == executeButton) {
            test();
        }
    }

    /*
     * dialog display method
     * @param   aText displayed character strings 
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * method to execute the test
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        int     len  = 0;
        DataInputStream     dis = null;

        /* execute each of the tests */
        switch( idx ) {
//J342_0202_0201
            case 0:
                byte b = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte1");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    b = (byte) dis.read();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( b == (byte) 'a'){
                    showDialog("OK");
                }else{
                    showDialog("a=" + (byte) 'a' + " b=" + b);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0202
            case 1:
               byte[] b1 = new byte[2];
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    len = dis.read(b1);
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( b1[0] == 'a' && b1[1]=='b' && len == 2 ){
                    showDialog("OK");
                }else{
                    showDialog("[0]=" + b1[0] + " [1]=" + b1[1]);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0203
            case 2:
                byte[] b2 = new byte[2];
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    len = dis.read(b2,0,2);
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( b2[0] == 'a' && b2[1]=='b' && len == 2 ){
                    showDialog("OK");
                }else{
                    showDialog("[0]=" + b2[0] + " [1]=" + b2[1]);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0204
            case 3:
                boolean dataBoolean = false;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataBoolean");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    dataBoolean = dis.readBoolean();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( dataBoolean == true ){
                    showDialog("OK");
                }else{
                    showDialog("boolean=" + dataBoolean);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0205
            case 4:
                byte byteData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte1");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    byteData = dis.readByte();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( byteData == (byte) 'a'){
                    showDialog("OK");
                }else{
                    showDialog("a=" + (byte) 'a' + " b=" + byteData);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0206
            case 5:
                char charData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataChar");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    charData = dis.readChar();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
//2002/09/25 Doja1.5                if( charData == (char) ''){
                if( charData == (char) '\uE63E'){
                    showDialog("OK");
                }else{
                    showDialog("char=" + charData);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0207
            case 6:
                byte[] byteA1 = new byte[2];
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    dis.readFully(byteA1);
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( byteA1[0] == 'a' && byteA1[1]=='b'){
                    showDialog("OK");
                }else{
                    showDialog("[0]=" + byteA1[0] + " [1]=" + byteA1[1]);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0208
            case 7:
                byte[] byteA2 = new byte[2];
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    dis.readFully(byteA2,0,2);
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( byteA2[0] == 'a' && byteA2[1]=='b'){
                    showDialog("OK");
                }else{
                    showDialog("[0]=" + byteA2[0] + " [1]=" + byteA2[1]);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0209
            case 8:
                int intData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataInt");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    intData = dis.readInt();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                int A = 12345;
                if( intData == A){
                    showDialog("OK");
                }else{
                    showDialog("intData=" + intData);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0210
            case 9:
                long longData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataLong");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    longData = dis.readLong();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                long B = 1234567L;
                if( longData == B){
                    showDialog("OK");
                }else{
                    showDialog("longData=" + longData);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0211
            case 10:
                short shortData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataShort");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    shortData = dis.readShort();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                short C = 1234;
                if( shortData == C){
                    showDialog("OK");
                }else{
                    showDialog("shortData=" + shortData);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0212
            case 11:
                int UByteData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte1");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    UByteData = dis.readUnsignedByte();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if( UByteData == 'a'){
                    showDialog("OK");
                }else{
                    showDialog("UByteData=" + UByteData);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0213
            case 12:
                int UShortData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataShort");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    UShortData = dis.readUnsignedShort();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                short sd = 1234;
                if( UShortData == sd){
                    showDialog("OK");
                }else{
                    showDialog("UShortData=" + UShortData);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0202_0214
            case 13:
                String stringData = null;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataUTF");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    stringData =  dis.readUTF();
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                String testData = "unicode";
                if( stringData.compareTo(testData) == 0){
                    showDialog("OK");
                }else{
                    showDialog("stringData=" + stringData);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;
        }
    }

    public void readData(DataInputStream dis){
        byte[] sts = new byte[6];
        try{
            dis.read(sts,0,6);
        }
        catch(Exception e){
            showDialog("NG:" + e.toString());
        }
    }
}

