/**
 * J342_0204_0201
 * MainPanel
 *
 * communication (resource):check the behavior when it is opened (resource name operation) 
 *
 * $Id: J342_0204_0201.java,v 1.1 2002/02/01 09:30:32 yuki_o Exp $
 */

import com.nttdocomo.ui.*;
import javax.microedition.io.*;
import java.io.*;
import javax.microedition.*;
import java.lang.*;



/**
 * main class
 * @extends IApplication
 */
public class J342_0204_0201 extends IApplication {

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * communication (resource)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    Button executeButton = new Button("execute");
    ListBox menuList = new ListBox(ListBox.CHOICE);

    String[] menuListItem = {
        "1.DIS-read1",
        "2.DIS-read2",
        "3.DIS-readChar",
        "4.DIS-readFully1",
        "5.DIS-readFully2",
        "6.DIS-readInt",
        "7.DIS-readLong",
        "8.DIS-readShort",
        "9.DIS-readUS",
        "10.DIS-readUTF",
    };

    /**
     * constructor of MainPanel class
     */
    public MainPanel() {
        /* configuration of display items */
        menuList.setItems(menuListItem);
        setTitle("communication (resource)");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* add each component to the screen */
        add(menuList);
        add(executeButton);

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * operate nothing when soft key is pushed down
     * @param index of anIndex key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * end the application when soft key 1 is released
     * @param index of anIndex key
     */
    public void softKeyReleased(int anIndex) {

        /* end the application when soft key 1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * receive events occurred in components
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     * 
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if (aComponent == executeButton) {
            test();
        }
    }

    /*
     * dialog display method
     * @param   aText displayed character strings 
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * method to execute the test
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        int     len  = 0;
        DataInputStream     dis = null;

        /* execute each of the tests */
        switch( idx ) {

//J342_0204_0201
            case 0:
               byte[] b1 = new byte[4];
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    len = dis.read(b1);
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if(len == 1 ){
                    showDialog("OK");
                }else{
                    showDialog("len=" + len);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0204_0202
            case 1:
                byte[] b2 = new byte[4];
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    len = dis.read(b2,0,4);
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }
                if(len == 1 ){
                    showDialog("OK");
                }else{
                    showDialog("len=" + len);
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0204_0204
            case 2:
                char charData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    charData = dis.readChar();
                }
                catch(EOFException eof){
                    showDialog("OK:EOFException");
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0204_0205
            case 3:
                byte[] byteA1 = new byte[2];
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    dis.readFully(byteA1);
                }
                catch(EOFException eof){
                    showDialog("OK:EOFException");
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0204_0206
            case 4:
                byte[] byteA2 = new byte[2];
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    dis.readFully(byteA2,0,2);
                }
                catch(EOFException eof){
                    showDialog("OK:EOFException");
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0204_0207
            case 5:
                int intData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    intData = dis.readInt();
                }
                catch(EOFException eof){
                    showDialog("OK:EOFException");
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0204_0208
            case 6:
                long longData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    longData = dis.readLong();
                }
                catch(EOFException eof){
                    showDialog("OK:EOFException");
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0204_0209
            case 7:
                short shortData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    shortData = dis.readShort();
                }
                catch(EOFException eof){
                    showDialog("OK:EOFException");
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0204_0210
            case 8:
                int UShortData = 0;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    UShortData = dis.readUnsignedShort();
                }
                catch(EOFException eof){
                    showDialog("OK:EOFException");
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;

//J342_0204_0211
            case 9:
                String stringData = null;
                /* open stream */
                try{
                    dis = Connector.openDataInputStream("resource:///dataByte2");
                } catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* read data up to the last-1 position */
                readData(dis);

                 /* read the last data */
                try{
                    stringData =  dis.readUTF();
                }
                catch(EOFException eof){
                    showDialog("OK:EOFException");
                }
                catch(Exception e){
                    showDialog("NG:EndData" + e.toString());
                }

                /* close the connection */
                try{
                    dis.close();
                }
                catch(Exception e){
                    showDialog("NG:close" + e.toString());
                }
                break;
        }
    }

    public void readData(DataInputStream dis){
        byte[] sts = new byte[6];
        try{
            dis.read(sts,0,6);
        }
        catch(Exception e){
            showDialog("NG:" + e.toString());
        }
    }
}

