/**
 * J342_0301_0201
 * MainPanel
 *
 * communication (resource):check the behavior when it is opened (resource name operation) 
 *
 * $Id: J342_0301_0201.java,v 1.1 2002/02/01 09:30:33 yuki_o Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;
import javax.microedition.io.*;
import java.io.*;
import javax.microedition.*;
import java.util.*;


/**
 * main class
 * @extends IApplication
 */
public class J342_0301_0201 extends IApplication {

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * communication (resource)
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener,ComponentListener{
    Button executeButton = new Button("execute");
    ListBox menuList = new ListBox(ListBox.CHOICE);
    TextBox tb = new TextBox("",20,3,TextBox.DISPLAY_ANY);
    InputConnection ic = null;
    InputConnection lastIC = null;
    Vector          IC = new Vector();
    Vector         DIS = new Vector();

    String[] menuListItem = {
        "test 1",
        "test 2"
    };

    /**
     * constructor of MainPanel class
     */
    public MainPanel() {
        /* configuration of display items */
        menuList.setItems(menuListItem);
        setTitle("communication (resource)");
        setSoftLabel(SOFT_KEY_1, "exit");

        /* add each component to the screen */
        add(menuList);
        add(executeButton);
        add(tb);
        

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
    }

    /**
     * operate nothing when soft key is pushed down
     * @param index of anIndex key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * end the application when soft key 1 is released
     * @param index of anIndex key
     */
    public void softKeyReleased(int anIndex) {

        /* end the application when soft key 1 is released */
        if (anIndex == SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * receive events occurred in components
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     * 
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if (aComponent == executeButton) {
            test();
        }

    }

    /*
     * dialog display method
     * @param   aText displayed character strings 
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }


    /**
     * method to execute the test
     */
    public void test() {
        int idx = menuList.getSelectedIndex();
        int flag = 0;

        /* execute each of the tests */
        switch( idx ) {
//J342_0301_0201
            case 0:
                /* get the stream (MAX) */
                while(true){
                    try{
                        InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                        IC.addElement(ic);
                    }
                    catch(ConnectionException ce){
                        int status = ce.getStatus();
                        String  st = null;

                        if(status == ConnectionException.RESOURCE_BUSY){
                            st = "RESOURCE_BUSY";
                        } else if(status == ConnectionException.NO_RESOURCE){
                            st = "NO_RESOURCE";
                        }

                        showDialog("OK:ConnectionException(" + st + ")" + ce.getMessage());
                        lastIC = (InputConnection) IC.lastElement();
                        break;

                    }
                    catch(Exception e){
                        showDialog( e.toString());
                        lastIC = (InputConnection) IC.lastElement();
                        break;
                    }
                }
                break;

//J342_0301_0202
            case 1:
                /* get the stream (MAX) */
                while(true){
                    try{
                        InputConnection ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                        IC.addElement(ic);
                    }
                    catch(ConnectionException ce){
                        int status = ce.getStatus();
                        String  st = null;

                        if(status == ConnectionException.RESOURCE_BUSY){
                            st = "RESOURCE_BUSY";
                        } else if(status == ConnectionException.NO_RESOURCE){
                            st = "NO_RESOURCE";
                        }

                        showDialog("OK:ConnectionException(" + st + ")" + ce.getMessage());
                        lastIC = (InputConnection) IC.lastElement();
                        break;

                    }
                    catch(Exception e){
                        showDialog( e.toString());
                        lastIC = (InputConnection) IC.lastElement();
                        break;
                    }
                }

                /* close the stream that has gotten last */
                try{
                    lastIC.close();
                }
                catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* get InputStream -> close InputStream -> Connection close */
                try{
                    ic = (InputConnection) Connector.open("resource:///filename",Connector.READ);
                    InputStream is = ic.openInputStream();
                    is.close();
                    ic.close();
                }
                catch(Exception e){
                    showDialog("NG:" + e.toString());
                }

                /* check that Connection has been closed and released */
                try{
                    InputStream is = Connector.openInputStream("resource:///filename");
                    if(is != null){
                        showDialog("OK");
                    }
                }
                catch(Exception e){
                    showDialog("NG:" + e.toString());
                }
                break;
        }
    }
}

