/**
 * J351_0103_0101
 *
 * behavior of another communication during the scratchpad communication
 *
 * $Id: J351_0103_0101.java,v 1.1 2002/02/08 01:47:43 takanao Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * behavior of another communication during the scratchpad communication
 * @extends IApplication
 */
public class J351_0103_0101 extends IApplication {

    MainPanel testPanel = new MainPanel();

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * menu screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* menu */
    String[] menuItem = {
        "00 reading resource while writing",
        "01 reading resource while reading",
//2002/08/08 DoJa1.5        "02 writing OBEXc(PUT)",
//2002/08/08 DoJa1.5        "03 writing OBEXc(GET)",
//2002/08/08 DoJa1.5        "04 reading OBEXc(PUT)",
//2002/08/08 DoJa1.5        "05 reading OBEXc(GET)",
//2002/08/08 DoJa1.5        "06 writing OBEXs(PUT)",
//2002/08/08 DoJa1.5        "07 writing OBEXs(GET)",
//2002/08/08 DoJa1.5        "08 reading OBEXs(PUT)",
//2002/08/08 DoJa1.5        "09 reading OBEXs(GET)",
    };

    /* definition of GUI parts */
    TextBox resultBox = new TextBox(null, 20, 16, TextBox.DISPLAY_ANY);
    ListBox menuList = new ListBox(ListBox.CHOICE);
    TextBox testBox = new TextBox(null, 20, 1, TextBox.DISPLAY_ANY);
    TextBox otherBox = new TextBox(null, 20, 1, TextBox.DISPLAY_ANY);
       
    Button  testButton = new Button("execute");

    /* communication Thread */
    HttpThread httpThread;
    SPThread spThread;
    RSThread rsThread;
//2002/08/08 DoJa1.5    ObexClientThread obexClientThread;
//2002/08/08 DoJa1.5    ObexServerThread obexServerThread;

    /**
     * panel generation
     */
    public MainPanel() {

        /* GUI setting */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("scratchpad-wise communication behavior ");
        menuList.setItems(menuItem);

        /* GUI arrangement */
        add(menuList);
        add(testButton);
        add(testBox);
        add(otherBox);
        add(resultBox);

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

    }

    /** 
     * soft key handler
     * @param aKey the key that has been pushed down
     */
    public void softKeyPressed(int aKey) {}

    /** 
     * soft key handler
     * @param aKey the key that has been pushed up
     */
    public void softKeyReleased(int aKey) {
        /* when soft key is released, end the application */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * component event handler
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if (aType == ComponentListener.BUTTON_PRESSED) {
            int index = menuList.getSelectedIndex();
            if (index < 0) {
                return;
            }
            if (aComponent == testButton) {
                try {
                    doTest(index);
                } catch (Exception e) {
                    Dialog dialog = new Dialog(Dialog.DIALOG_ERROR, "error");
                    dialog.setText(e.getClass().getName());
                    dialog.show();
                }
            }
        }
    }

    /**
     * add the outputs to resultBox
     * @param anyBox the TextBox that will be outputted to
     * @param aMessage output character strings
     */
    static public void addResult(TextBox anyBox, String aMessage) {
        anyBox.setText(anyBox.getText()+aMessage);
    }

    /**
     * execute the specified test
     * @param aTestNumber test number
     * @throws Exception when unexpected exceptions are thrown
     */
    public void doTest(int aTestNumber) throws Exception {

        resultBox.setText("test:");
        testBox.setText(null);
        otherBox.setText(null);


        switch (aTestNumber) {
        case 0:
            // J351_0103_0101

            /* generate the test Thread  */
            spThread = new SPThread(SPThread.WRITE, testBox);
            rsThread = new RSThread(otherBox);

            /* start the test */
            addResult(resultBox, "[start]");
            spThread.start();
            rsThread.start();

            /* layover the both of Thread */
            spThread.join();
            rsThread.join();

            addResult(resultBox, "[completed]\n");

            /* data verification */
            addResult(resultBox, "verification:");
            addResult(resultBox, spThread.isVerified() ? "[SpOK]" : "[SpNG]");
            break;

        case 1:
            // J351_0103_0201
            /* generate the test Thread  */
            spThread = new SPThread(SPThread.READ, testBox);
            rsThread = new RSThread(otherBox);

            /* start the test */
            addResult(resultBox, "[start]");
            spThread.start();
            rsThread.start();

            /* layover the both of Thread */
            spThread.join();
            rsThread.join();

            addResult(resultBox, "[completed]\n");

            break;

//2002/08/08 DoJa1.5        case 2:
            // J351_0103_0301
            /* generate the test Thread  */
//2002/08/08 DoJa1.5            spThread = new SPThread(SPThread.WRITE, testBox);
//2002/08/08 DoJa1.5            obexClientThread = new ObexClientThread(ObexClientThread.PUT, otherBox);

            /* start the test */
//2002/08/08 DoJa1.5            addResult(resultBox, ""start "");
//2002/08/08 DoJa1.5            spThread.start();
//2002/08/08 DoJa1.5            obexClientThread.start();

            /* layover the both of Thread */
//2002/08/08 DoJa1.5            spThread.join();
//2002/08/08 DoJa1.5            obexClientThread.join();

//2002/08/08 DoJa1.5            addResult(resultBox, ""completed"\n");

            /* data verification */
//2002/08/08 DoJa1.5            addResult(resultBox, "verification:");
//2002/08/08 DoJa1.5            addResult(resultBox, spThread.isVerified() ? "[SpOK]" : "[SpNG]");

//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 3:
            // J351_0103_0302
            /* generate the test Thread  */
//2002/08/08 DoJa1.5            spThread = new SPThread(SPThread.WRITE, testBox);
//2002/08/08 DoJa1.5            obexClientThread = new ObexClientThread(ObexClientThread.GET, otherBox);

            /* start the test */
//2002/08/08 DoJa1.5            addResult(resultBox, ""start "");
//2002/08/08 DoJa1.5            spThread.start();
//2002/08/08 DoJa1.5            obexClientThread.start();

            /* layover the both of Thread */
//2002/08/08 DoJa1.5            spThread.join();
//2002/08/08 DoJa1.5            obexClientThread.join();

//2002/08/08 DoJa1.5            addResult(resultBox, ""completed"\n");

            /* data verification */
//2002/08/08 DoJa1.5            addResult(resultBox, "verification:");
//2002/08/08 DoJa1.5            addResult(resultBox, spThread.isVerified() ? "[SpOK]" : "[SpNG]");
//2002/08/08 DoJa1.5            addResult(resultBox, obexClientThread.isVerified() ? "[ObexOK]" : "[ObexNG]");

//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 4:
            // J351_0103_0401
            /* generate the test Thread  */
//2002/08/08 DoJa1.5            spThread = new SPThread(SPThread.READ, testBox);
//2002/08/08 DoJa1.5            obexClientThread = new ObexClientThread(ObexClientThread.PUT, otherBox);

            /* start the test */
//2002/08/08 DoJa1.5            addResult(resultBox, ""start "");
//2002/08/08 DoJa1.5            spThread.start();
//2002/08/08 DoJa1.5            obexClientThread.start();

            /* layover the both of Thread */
//2002/08/08 DoJa1.5            spThread.join();
//2002/08/08 DoJa1.5            obexClientThread.join();

//2002/08/08 DoJa1.5            addResult(resultBox, ""completed"\n");

//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 5:
            // J351_0103_0402
            /* generate the test Thread  */
//2002/08/08 DoJa1.5            spThread = new SPThread(SPThread.READ, testBox);
//2002/08/08 DoJa1.5            obexClientThread = new ObexClientThread(ObexClientThread.GET, otherBox);

            /* start the test */
//2002/08/08 DoJa1.5            addResult(resultBox, ""start "");
//2002/08/08 DoJa1.5            spThread.start();
//2002/08/08 DoJa1.5            obexClientThread.start();

            /* layover the both of Thread */
//2002/08/08 DoJa1.5            spThread.join();
//2002/08/08 DoJa1.5            obexClientThread.join();

//2002/08/08 DoJa1.5            addResult(resultBox, ""completed"\n");

            /* data verification */
//2002/08/08 DoJa1.5            addResult(resultBox, "verification:");
//2002/08/08 DoJa1.5            addResult(resultBox, obexClientThread.isVerified() ? "[ObexOK]" : "[ObexNG]");

//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 6:
            // J351_0103_0501
            /* no break*/

//2002/08/08 DoJa1.5        case 7:
            // J351_0103_0502
            /* generate the test Thread  */
//2002/08/08 DoJa1.5            spThread = new SPThread(SPThread.WRITE, testBox);
//2002/08/08 DoJa1.5            obexServerThread = new ObexServerThread(otherBox);

            /* start the test */
//2002/08/08 DoJa1.5            addResult(resultBox, ""start "");
//2002/08/08 DoJa1.5            spThread.start();
//2002/08/08 DoJa1.5            obexServerThread.start();

            /* layover the both of Thread */
//2002/08/08 DoJa1.5            spThread.join();
//2002/08/08 DoJa1.5            obexServerThread.join();

//2002/08/08 DoJa1.5            addResult(resultBox, ""completed"\n");

            /* data verification */
//2002/08/08 DoJa1.5            addResult(resultBox, "verification:");
//2002/08/08 DoJa1.5            addResult(resultBox, spThread.isVerified() ? "[SpOK]" : "[SpNG]");

//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 8:
            // J351_0103_0601
            /* no break*/

//2002/08/08 DoJa1.5        case 9:
            // J351_0103_0602
            /* generate the test Thread  */
//2002/08/08 DoJa1.5            spThread = new SPThread(SPThread.READ, testBox);
//2002/08/08 DoJa1.5            obexServerThread = new ObexServerThread(otherBox);

            /* start the test */
//2002/08/08 DoJa1.5            addResult(resultBox, ""start "");
//2002/08/08 DoJa1.5            spThread.start();
//2002/08/08 DoJa1.5            obexServerThread.start();

            /* layover the both of Thread */
//2002/08/08 DoJa1.5            spThread.join();
//2002/08/08 DoJa1.5            obexServerThread.join();

//2002/08/08 DoJa1.5            addResult(resultBox, ""completed"\n");

//2002/08/08 DoJa1.5            break;

        default:
            break;
        }
    }
}


/**
 * Http communication Thread
 * @extends Thread
 */
class HttpThread extends Thread {

    TextBox resultBox;
    String  postURL;

    final static int HTTP_MAX = 5120;

    HttpConnection con = null;

    /**
     * constructor of Http communication class
     * @param anURL destination URL
     * @param aBox TextBox for status display
     */
    public HttpThread(String anURL, TextBox aBox) {
        resultBox = aBox;
        postURL = anURL;

        OutputStream out = null;

        resultBox.setText("Http:under preparation");

        /* prepare the HTTP connection at POST */
        try {
            con = (HttpConnection)Connector.open(postURL, Connector.READ_WRITE);
            con.setRequestMethod(HttpConnection.POST);
            out = con.openOutputStream();
        
            /* prepare the POST data of HTTP_MAX byte */
            for (int i=0; i<HTTP_MAX; i++) {
                out.write('A');
            }
        } catch (IOException ioe) {
            MainPanel.addResult(resultBox, "[IOE]");
        } finally {
            if (out != null) {
                try {
                    out.close();
                    out = null;
                } catch (IOException ioe) {
                    System.out.println("[Close ERROR]");
                }
            }
        }
        resultBox.setText("Http:ready OK");
    }

    /**
     * main loop of Http communication class
     */
    public void run() {
        resultBox.setText("Http:start test");

        /* execute the Http connection */
        try {
            con.connect();
        } catch (ConnectionException ce) {
            MainPanel.addResult(resultBox, "NG[CE="+ce.getStatus()+"]");
            return;
        } catch (IOException ioe) {
            MainPanel.addResult(resultBox, "NG[IOE]");
            return;
        }
        MainPanel.addResult(resultBox, "OK");
    }

    /**
     * data verification method
     * @return true, if data is identical to what has been expected. false if data is considered as an error
     */
    public boolean isVerified() {

        InputStream in = null;

        /*
         * due to cgil, POST data is returned as response
         * check the data for HTTP_MAX byte
         */
        try {
            in = con.openInputStream();
            for (int i=0; i<HTTP_MAX; i++) {
                if (in.read() != 'A') {
                    return false;
                }
            }
        } catch (Exception e) {
            return false;
        } finally {
            try {
                if (in != null) {
                    in.close();
                    in = null;
                }
                if (con != null) {
                    con.close();
                    con = null;
                }
            } catch (IOException ioe) {

            }
        }
        return true;
    }
}

/**
 * Thread for scratchpad read and write operations 
 * @extends Thread
 */
class SPThread extends Thread {

    static public int WRITE = 0;
    static public int READ = 1;
    final static int SP_MAX = 102400;

    int openMode;

    TextBox resultBox;
    
    /**
     * constructor of Thread which operates the scratchpad read and write operations 
     * @param aMode 1= the read mode(READ) 0=the write mode(WRITE)
     * @param aTextBox TextBox for status display
     */
    public SPThread(int aMode, TextBox aTextBox) {
        openMode = aMode;
        resultBox = aTextBox;

        /*
         * initialize the scratchpad
         * set 'A' as an initial value when reading, set 0 when checking the writing
         */
        int writeData = (openMode == READ) ? 'A' : 0;

        OutputStream out = null;

        resultBox.setText("SP:under preparation");
        try {
            out = Connector.openOutputStream("scratchpad:///0");

            for (int i=0; i<SP_MAX; i++) {
                out.write(writeData);
            }
        } catch (IOException ioe) {
            MainPanel.addResult(resultBox, "[IOE]");
        } finally {
            try {
                if (out != null) {
                    out.close();
                    out = null;
                }
            } catch (IOException ioe) {
                MainPanel.addResult(resultBox, "[IOE]");
            }
        }
        resultBox.setText("SP:ready OK");
    }

    /**
     * main loop for the class of scratchpad read and write operations 
     */
    public void run() {

        OutputStream out = null;
        InputStream  in  = null;

        resultBox.setText("SP:start test");

        if (openMode == WRITE) {

            /* write*/
            try {
                out = Connector.openOutputStream("scratchpad:///0");
                
                for (int i=0; i<SP_MAX; i++) {
                    out.write('A');
                }
            } catch (IOException ioe) {
                MainPanel.addResult(resultBox, "NG[IOE]");
                return;
            } finally {
                try {
                    if (out != null) {
                        out.close();
                        out = null;
                    }
                } catch (IOException ioe) {
                    MainPanel.addResult(resultBox, "close[IOE]");
                }
            }
            MainPanel.addResult(resultBox, "OK");

        } else {
            
            /* read*/
            try {
                in = Connector.openInputStream("scratchpad:///0");
                
                for (int i=0; i<SP_MAX; i++) {
                    if (in.read() != 'A') {
                        MainPanel.addResult(resultBox, "NG[Data error]");
                        return;
                    }
                }
            } catch (IOException ioe) {
                MainPanel.addResult(resultBox, "NG[IOE]");
                return;
            } finally {
                try {
                    if (in != null) {
                        in.close();
                        in = null;
                    }
                } catch (IOException ioe) {
                    MainPanel.addResult(resultBox, "[IOE]");
                }
            }
            MainPanel.addResult(resultBox, "OK");
        }

    }

    /**
     * data verification method
     * @return true, if data is identical to what has been expected. false if data is considered as an error
     */
    public boolean isVerified() {

        InputStream in = null;

        try {
            in = Connector.openInputStream("scratchpad:///0");
            
            for (int i=0; i<SP_MAX; i++) {
                if (in.read() != 'A') {
                    return false ;
                }
            }
        } catch (IOException ioe) {
            return false;
        } finally {
            try {
                if (in != null) {
                    in.close();
                    in = null;
                }
            } catch (IOException ioe) {
            }
        }
        return true;
    }
}

/**
 * Thread for reading resource
 * @extends Thread
 */
class RSThread extends Thread {

    final static int RS_MAX = 10240;

    TextBox resultBox;

    /**
     * Constructor of the Thread for reading resource 
     * @param aTextBox TextBox for status display
     */
    public RSThread(TextBox aTextBox) {
        resultBox = aTextBox;

        resultBox.setText("RS:ready OK");
    }

    /**
     * main loop for the resource read  class
     */
    public void run() {

        InputStream  in  = null;

        resultBox.setText("RS:start test");

        /* read*/
        try {
            in = Connector.openInputStream("resource:///data");
            
            for (int i=0; i<RS_MAX; i++) {
                if (in.read() != 'A') {
                    MainPanel.addResult(resultBox, "NG[Data error]");
                    return;
                }
            }
        } catch (IOException ioe) {
            MainPanel.addResult(resultBox, "NG[IOE]");
            return;
        } finally {
            try {
                if (in != null) {
                    in.close();
                    in = null;
                }
            } catch (IOException ioe) {
                MainPanel.addResult(resultBox, "[IOE]");
            }
        }
        MainPanel.addResult(resultBox, "OK");
    }
}

/**
 * Thread for ObexClient read and write operations
 * @extends Thread
 */
//2002/08/08 DoJa1.5class ObexClientThread extends Thread {

//2002/08/08 DoJa1.5    int openMode;
//2002/08/08 DoJa1.5    TextBox resultBox;

//2002/08/08 DoJa1.5    final static int PUT = 0;
//2002/08/08 DoJa1.5    final static int GET = 1;

//2002/08/08 DoJa1.5    final static int OBEX_MAX = 10240;

//2002/08/08 DoJa1.5    ClientObexConnection coc = null;

    /**
     * constructor for the  class of OBEX client communication
     * @param aMode operation mode(PUT,GET) 
     * @param aBox TextBox for status display
     */
//2002/08/08 DoJa1.5    public ObexClientThread(int aMode, TextBox aBox) {

//2002/08/08 DoJa1.5        openMode = aMode;
//2002/08/08 DoJa1.5        resultBox = aBox;

//2002/08/08 DoJa1.5        OutputStream out = null;

//2002/08/08 DoJa1.5        resultBox.setText("Obex:under preparation");

//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            coc = (ClientObexConnection)Connector.open("obex:/irclient");
//2002/08/08 DoJa1.5            coc.connect();

//2002/08/08 DoJa1.5            if (openMode == PUT) {
//2002/08/08 DoJa1.5                coc.setOperation(ObexConnection.PUT);
//2002/08/08 DoJa1.5                coc.setName("put-test");
                
//2002/08/08 DoJa1.5                out = coc.openOutputStream();
                
                /* prepare the PUT data of OBEX_MAX byte */
//2002/08/08 DoJa1.5                for (int i=0; i<OBEX_MAX; i++) {
//2002/08/08 DoJa1.5                    out.write('A');
//2002/08/08 DoJa1.5                }

//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    try {
//2002/08/08 DoJa1.5                        out.close();
//2002/08/08 DoJa1.5                        out = null;
//2002/08/08 DoJa1.5                    } catch (IOException ioe) {
//2002/08/08 DoJa1.5                        System.out.println("[Close ERROR]");
//2002/08/08 DoJa1.5                    }
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } else {
//2002/08/08 DoJa1.5                coc.setOperation(ObexConnection.GET);
//2002/08/08 DoJa1.5                coc.setName("get-test");
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5        } catch (IOException ioe) {
//2002/08/08 DoJa1.5            MainPanel.addResult(resultBox, "open[IOE]");
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5        resultBox.setText("OBEX:ready OK");
//2002/08/08 DoJa1.5    }

    /**
     * main loop for the class of OBEX client communication
     */
//2002/08/08 DoJa1.5    public void run() {

//2002/08/08 DoJa1.5        resultBox.setText("OBEX: start the test");
        
//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            coc.sendRequest();

//2002/08/08 DoJa1.5        } catch (IOException ioe) {
//2002/08/08 DoJa1.5            MainPanel.addResult(resultBox, "NG[communication IOE]");
//2002/08/08 DoJa1.5            return;
//2002/08/08 DoJa1.5        } finally {
//2002/08/08 DoJa1.5            if (openMode == PUT) {
//2002/08/08 DoJa1.5                try {
//2002/08/08 DoJa1.5                    if (coc != null) {
//2002/08/08 DoJa1.5                        coc.close();
//2002/08/08 DoJa1.5                        coc = null;
//2002/08/08 DoJa1.5                    }
//2002/08/08 DoJa1.5                } catch (IOException ioe) {
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5        }

//2002/08/08 DoJa1.5        MainPanel.addResult(resultBox, "OK");
//2002/08/08 DoJa1.5    }

    /**
     * data verification method
     * @return true, if data is identical to what has been expected. false if data is considered as an error
     */
//2002/08/08 DoJa1.5    public boolean isVerified() {

//2002/08/08 DoJa1.5        InputStream in = null;

        /* verify the GET response  */
//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            in = coc.openInputStream();
//2002/08/08 DoJa1.5            for (int i=0; i<OBEX_MAX; i++) {
//2002/08/08 DoJa1.5                if (in.read() != 'A') {
//2002/08/08 DoJa1.5                    return false;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5        } catch (Exception e) {
//2002/08/08 DoJa1.5            return false;
//2002/08/08 DoJa1.5        } finally {
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                if (in != null) {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (coc != null) {
//2002/08/08 DoJa1.5                    coc.close();
//2002/08/08 DoJa1.5                    coc = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                return false;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5        }
//2002/08/08 DoJa1.5        return true;
//2002/08/08 DoJa1.5    }

//2002/08/08 DoJa1.5}

/**
 * Thread for ObexServer read and write operations
 * @extends Thread
 */
//2002/08/08 DoJa1.5class ObexServerThread extends Thread {

//2002/08/08 DoJa1.5    TextBox resultBox;

//2002/08/08 DoJa1.5    final static int OBEX_MAX = 10240;

//2002/08/08 DoJa1.5    ServerObexConnection soc = null;

//2002/08/08 DoJa1.5    int operation;

    /**
     * constructor for the  class of OBEX server communication
     * @param aBox TextBox for status display
     */
//2002/08/08 DoJa1.5    public ObexServerThread(TextBox aBox) {

//2002/08/08 DoJa1.5        resultBox = aBox;

//2002/08/08 DoJa1.5        resultBox.setText("Obex:under preparation");
//2002/08/08 DoJa1.5        resultBox.setText("OBEX:ready OK");
//2002/08/08 DoJa1.5    }

    /**
     * main loop for the class of OBEX server communication
     */
//2002/08/08 DoJa1.5    public void run() {

//2002/08/08 DoJa1.5        resultBox.setText("OBEX: start the test");

//2002/08/08 DoJa1.5        OutputStream out = null;
//2002/08/08 DoJa1.5        InputStream in = null;

//2002/08/08 DoJa1.5        try {
//2002/08/08 DoJa1.5            soc = (ServerObexConnection)Connector.open("obex:/irserver");
//2002/08/08 DoJa1.5            soc.accept();

//2002/08/08 DoJa1.5            soc.receiveRequest();
            
//2002/08/08 DoJa1.5            operation = soc.getOperation();

//2002/08/08 DoJa1.5            if (operation == ObexConnection.PUT) {

                /* verify the PUT request  */
//2002/08/08 DoJa1.5                in = soc.openInputStream();
//2002/08/08 DoJa1.5                for (int i=0; i<OBEX_MAX; i++) {
//2002/08/08 DoJa1.5                    if (in.read() != 'A') {
//2002/08/08 DoJa1.5                        MainPanel.addResult(resultBox, "NG[Data error]");
//2002/08/08 DoJa1.5                        in.close();
//2002/08/08 DoJa1.5                        in = null;
//2002/08/08 DoJa1.5                        return;
//2002/08/08 DoJa1.5                    }
//2002/08/08 DoJa1.5                }

//2002/08/08 DoJa1.5                if (in != null) {
//2002/08/08 DoJa1.5                    try {
//2002/08/08 DoJa1.5                        in.close();
//2002/08/08 DoJa1.5                        in = null;
//2002/08/08 DoJa1.5                    } catch (IOException ioe) {
//2002/08/08 DoJa1.5                        System.out.println("[Close ERROR]");
//2002/08/08 DoJa1.5                    }
//2002/08/08 DoJa1.5                }

//2002/08/08 DoJa1.5            } else if (operation == ObexConnection.GET) {

//2002/08/08 DoJa1.5                out = soc.openOutputStream();
                
                /* prepare the response  of OBEX_MAX byte */
//2002/08/08 DoJa1.5                for (int i=0; i<OBEX_MAX; i++) {
//2002/08/08 DoJa1.5                    out.write('A');
//2002/08/08 DoJa1.5                }

//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    try {
//2002/08/08 DoJa1.5                        out.close();
//2002/08/08 DoJa1.5                        out = null;
//2002/08/08 DoJa1.5                    } catch (IOException ioe) {
//2002/08/08 DoJa1.5                        System.out.println("[Close ERROR]");
//2002/08/08 DoJa1.5                    }
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            soc.sendResponse(ObexConnection.SUCCESS);
            
//2002/08/08 DoJa1.5        } catch (IOException ioe) {
//2002/08/08 DoJa1.5            MainPanel.addResult(resultBox, "NG[communication IOE]");
//2002/08/08 DoJa1.5            return;
//2002/08/08 DoJa1.5        } finally {
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                if (soc != null) {
//2002/08/08 DoJa1.5                    soc.close();
//2002/08/08 DoJa1.5                    soc =null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5        }

//2002/08/08 DoJa1.5        MainPanel.addResult(resultBox, "OK");
//2002/08/08 DoJa1.5    }

//2002/08/08 DoJa1.5}
