/**
 * J351_0201_0101
 *
 * copy operations between schemes
 *
 * $Id: J351_0201_0101.java,v 1.1 2002/02/08 01:47:45 takanao Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.io.*;

/**
 * copy operations between schemes
 * @extends IApplication
 */
public class J351_0201_0101 extends IApplication {

    MainPanel testPanel = new MainPanel();

    /**
     * startup method of iappli
     */
    public void start() {
        Display.setCurrent(testPanel);
    }
}

/**
 * menu screen
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener {

    /* menu */
    String[] menuItem = {
        "00 HTTP->SP",
//2002/08/08 DoJa1.5        "01 HTTP->ObexClient",
//2002/08/08 DoJa1.5        "02 HTTP->ObexServer",
        "03 SP->HTTP",
//2002/08/08 DoJa1.5        "04 SP->ObexClient",
//2002/08/08 DoJa1.5        "05 SP->ObexServer",
        "06 RS->HTTP",
        "07 RS->SP",
//2002/08/08 DoJa1.5        "08 RS->ObexClient",
//2002/08/08 DoJa1.5        "09 RS->ObexServer",
//2002/08/08 DoJa1.5        "10 ObexClient->HTTP",
//2002/08/08 DoJa1.5        "11 ObexClient->SP",
//2002/08/08 DoJa1.5        "12 ObexServer->HTTP",
//2002/08/08 DoJa1.5        "13 ObexServer->SP",
    };

    final static int MAX_DATA = 5120;

    /* destination URL */
    String httpPOST;
    String httpData;

    /* definition of GUI parts */
    TextBox resultBox = new TextBox(null, 20, 16, TextBox.DISPLAY_ANY);
    ListBox menuList = new ListBox(ListBox.CHOICE);
       
    Button  testButton = new Button("execute");

    /**
     * panel generation
     */
    public MainPanel() {

        /* GUI setting */
        setSoftLabel(Frame.SOFT_KEY_1, "exit");
        setTitle("copy operations between schemes");
        menuList.setItems(menuItem);

        /* GUI arrangement */
        add(menuList);
        add(testButton);
        add(resultBox);

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);

        /* URL setting */
        httpPOST = IApplication.getCurrentApp().getSourceURL()+"../cgi-bin/postdirect.cgi";
        httpData = IApplication.getCurrentApp().getSourceURL()+"../data";

    }

    /** 
     * soft key handler
     * @param aKey the key that has been pushed down
     */
    public void softKeyPressed(int aKey) {}

    /** 
     * soft key handler
     * @param aKey the key that has been pushed up
     */
    public void softKeyReleased(int aKey) {
        /* when soft key is released, end the application */
        if (aKey == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }

    /**
     * component event handler
     * @param aComponent the component that has been generated an event
     * @param aType event type
     * @param aParam event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {
        if (aType == ComponentListener.BUTTON_PRESSED) {
            int index = menuList.getSelectedIndex();
            if (index < 0) {
                return;
            }
            if (aComponent == testButton) {
                try {
                    doTest(index);
                } catch (Exception e) {
                    Dialog dialog = new Dialog(Dialog.DIALOG_ERROR, "error");
                    dialog.setText(e.getClass().getName());
                    dialog.show();
                }
            }
        }
    }

    /**
     * add outputs to the TextBox
     * @param anyBox the TextBox that will be outputted to
     * @param aMessage output character strings
     */
    static public void addResult(TextBox anyBox, String aMessage) {
        anyBox.setText(anyBox.getText()+aMessage);
    }

    /**
     * execute the specified test
     * @param aTestNumber test number
     * @throws Exception when unexpected exceptions are thrown
     */
    public void doTest(int aTestNumber) throws Exception {

        HttpConnection httpcon = null;
//2002/08/08 DoJa1.5        ClientObexConnection coc = null;
//2002/08/08 DoJa1.5       ServerObexConnection soc = null;

        InputStream in = null;
        OutputStream out = null;

        int inData;
        int dataCount = 0;

        switch (aTestNumber) {

        case 0:
            // J351_0201_0101

            /* prepare the targeted connection */
            resultBox.setText("test preparation:");
            try {

                httpcon = (HttpConnection)Connector.open(httpData, Connector.READ);
                httpcon.setRequestMethod(HttpConnection.GET);
                httpcon.connect();
                in = httpcon.openInputStream();
                out = Connector.openOutputStream("scratchpad:///0");
            
            } catch (Exception e) {
                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
                return;
            }
            addResult(resultBox, "OK\n");
            addResult(resultBox, "test:");

            /* data copy */
            try {
                while ((inData = in.read())>0) {
                    out.write(inData);
                    dataCount++;
                }

                if (in != null)  {
                    in.close();
                    in = null;
                }
                if (out != null) {
                    out.close();
                    out = null;
                }
                if (httpcon != null) {
                    httpcon.close();
                    httpcon = null;
                }
            } catch (IOException ioe) {
                addResult(resultBox, "NG\"IOE during copying\"");
                return;
            }

            /* check the number of byte of copied data */
            if (dataCount != MAX_DATA) {
                addResult(resultBox, "data size NG \n");
                return;
            }
            
            addResult(resultBox, "OK\n");
            addResult(resultBox, "verification:");

            /* verify the copied data */
            try {
                in = Connector.openInputStream("scratchpad:///0");
                for (int i=0; i<MAX_DATA; i++) {
                    if (in.read() != 'A') {
                        addResult(resultBox, "NG[Data]");
                        return;
                    }
                }
                addResult(resultBox, "OK");
                if (in != null)  {
                    in.close();
                    in = null;
                }
            } catch (Exception e) {
                addResult(resultBox, "NG["+e.getClass().getName()+"]");
            }

            break;

//2002/08/08 DoJa1.5        case 1:
            // J351_0201_0102

//2002/08/08 DoJa1.5            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                httpcon = (HttpConnection)Connector.open(httpData, Connector.READ);
//2002/08/08 DoJa1.5                httpcon.setRequestMethod(HttpConnection.GET);
//2002/08/08 DoJa1.5                httpcon.connect();
//2002/08/08 DoJa1.5                in = httpcon.openInputStream();

//2002/08/08 DoJa1.5                coc = (ClientObexConnection)Connector.open("obex:/irclient");
//2002/08/08 DoJa1.5                coc.connect();
//2002/08/08 DoJa1.5                coc.setOperation(ObexConnection.PUT);
//2002/08/08 DoJa1.5                coc.setName("put-test");
                
//2002/08/08 DoJa1.5                out = coc.openOutputStream();
            
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "test:");

            /* data copy */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                while ((inData = in.read())>0) {
//2002/08/08 DoJa1.5                    out.write(inData);
//2002/08/08 DoJa1.5                    dataCount++;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    out.close();
//2002/08/08 DoJa1.5                    out = null;
//2002/08/08 DoJa1.5                }

//2002/08/08 DoJa1.5                coc.sendRequest();

//2002/08/08 DoJa1.5                if (in != null) {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (httpcon != null) {
//2002/08/08 DoJa1.5                    httpcon.close();
//2002/08/08 DoJa1.5                    httpcon = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (coc != null) {
//2002/08/08 DoJa1.5                    coc.close();
//2002/08/08 DoJa1.5                    coc = null;
//2002/08/08 DoJa1.5                }

//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG"IOE during copying"");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
            /* check the number of byte of copied data */
//2002/08/08 DoJa1.5            if (dataCount != MAX_DATA) {
//2002/08/08 DoJa1.5                addResult(resultBox, "data size NG \n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 2:
            // J351_0201_0103

//2002/08/08 DoJa1.5            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                httpcon = (HttpConnection)Connector.open(httpData, Connector.READ);
//2002/08/08 DoJa1.5                httpcon.setRequestMethod(HttpConnection.GET);
//2002/08/08 DoJa1.5                httpcon.connect();
//2002/08/08 DoJa1.5                in = httpcon.openInputStream();

//2002/08/08 DoJa1.5                soc = (ServerObexConnection)Connector.open("obex:/irserver");
//2002/08/08 DoJa1.5                soc.accept();
//2002/08/08 DoJa1.5                soc.receiveRequest();
                
//2002/08/08 DoJa1.5                if (soc.getOperation() != ObexConnection.GET) {
//2002/08/08 DoJa1.5                    addResult(resultBox, "wrong procedure.use GET to connect\n");
//2002/08/08 DoJa1.5                    return;
//2002/08/08 DoJa1.5                }
                
//2002/08/08 DoJa1.5                out = soc.openOutputStream();
            
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "test:");

            /* data copy */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                while ((inData = in.read())>0) {
//2002/08/08 DoJa1.5                    out.write(inData);
//2002/08/08 DoJa1.5                    dataCount++;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    out.close();
//2002/08/08 DoJa1.5                    out = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (in != null) {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (httpcon != null) {
//2002/08/08 DoJa1.5                    httpcon.close();
//2002/08/08 DoJa1.5                    httpcon = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                soc.sendResponse(ObexConnection.SUCCESS);
//2002/08/08 DoJa1.5                if (soc != null) {
//2002/08/08 DoJa1.5                    soc.close();
//2002/08/08 DoJa1.5                    soc = null;
//2002/08/08 DoJa1.5                }

//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG"IOE during copying"");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
            /* check the number of byte of copied data */
//2002/08/08 DoJa1.5            if (dataCount != MAX_DATA) {
//2002/08/08 DoJa1.5                addResult(resultBox, "data size NG \n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");

//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 3:
        case 1:
            // J351_0201_0201
            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
            try {
                setupScratchpad('A');

                in = Connector.openInputStream("scratchpad:///0");

                httpcon = (HttpConnection)Connector.open(httpPOST, Connector.READ_WRITE);
                httpcon.setRequestMethod(HttpConnection.POST);
                httpcon.setRequestProperty("Content-Type", "text/plain");
                out = httpcon.openOutputStream();
            
            } catch (Exception e) {
                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
                return;
            }
            addResult(resultBox, "OK\n");
            addResult(resultBox, "test:");

            /* data copy */
            try {
                while ((inData = in.read())>0) {
                    out.write(inData);
                    dataCount++;
                }
                if (out != null) {
                    out.close();
                    out = null;
                }
                if (in != null) {
                    in.close();
                    in = null;
                }
                httpcon.connect();
        
            } catch (IOException ioe) {
                addResult(resultBox, "NG\"IOE during copying\"");
                return;
            }
            
            /* check the number of byte of copied data */
            if (dataCount != MAX_DATA) {
                addResult(resultBox, "data size NG \n");
                return;
            }
            
            addResult(resultBox, "OK\n");
            addResult(resultBox, "verification:");

            /* verify the copied data */
            try {
                in = httpcon.openInputStream();
                for (int i=0; i<MAX_DATA; i++) {
                    if (in.read() != 'A') {
                        addResult(resultBox, "NG[Data]");
                        return;
                    }
                }
                addResult(resultBox, "OK");
                if (in != null)  {
                    in.close();
                    in = null;
                }
                if (httpcon != null) {
                    httpcon.close();
                    httpcon = null;
                }
            } catch (Exception e) {
                addResult(resultBox, "NG["+e.getClass().getName()+"]");
            }
            break;

//2002/08/08 DoJa1.5        case 4:
            // J351_0201_0202

//2002/08/08 DoJa1.5            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
//2002/08/08 DoJa1.5            try {

//2002/08/08 DoJa1.5                setupScratchpad('A');

//2002/08/08 DoJa1.5                in = Connector.openInputStream("scratchpad:///0");

//2002/08/08 DoJa1.5                coc = (ClientObexConnection)Connector.open("obex:/irclient");
//2002/08/08 DoJa1.5                coc.connect();
//2002/08/08 DoJa1.5                coc.setOperation(ObexConnection.PUT);
//2002/08/08 DoJa1.5                coc.setName("put-test");
                
//2002/08/08 DoJa1.5                out = coc.openOutputStream();
            
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "test:");

            /* data copy */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                while ((inData = in.read())>0) {
//2002/08/08 DoJa1.5                    out.write(inData);
//2002/08/08 DoJa1.5                    dataCount++;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    out.close();
//2002/08/08 DoJa1.5                    out = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (in != null) {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                coc.sendRequest();
//2002/08/08 DoJa1.5                if (coc != null) {
//2002/08/08 DoJa1.5                    coc.close();
//2002/08/08 DoJa1.5                    coc = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG"IOE during copying"");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
            /* check the number of byte of copied data */
//2002/08/08 DoJa1.5            if (dataCount != MAX_DATA) {
//2002/08/08 DoJa1.5                addResult(resultBox, "data size NG \n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 5:
            // J351_0201_0203
//2002/08/08 DoJa1.5            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
//2002/08/08 DoJa1.5            try {

//2002/08/08 DoJa1.5                setupScratchpad('A');

//2002/08/08 DoJa1.5                in = Connector.openInputStream("scratchpad:///0");

//2002/08/08 DoJa1.5                soc = (ServerObexConnection)Connector.open("obex:/irserver");
//2002/08/08 DoJa1.5                soc.accept();
//2002/08/08 DoJa1.5                soc.receiveRequest();
                
//2002/08/08 DoJa1.5                if (soc.getOperation() != ObexConnection.GET) {
//2002/08/08 DoJa1.5                    addResult(resultBox, "wrong procedure.use GET to connect\n");
//2002/08/08 DoJa1.5                    return;
//2002/08/08 DoJa1.5                }
                
//2002/08/08 DoJa1.5                out = soc.openOutputStream();
            
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "test:");

            /* data copy */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                while ((inData = in.read())>0) {
//2002/08/08 DoJa1.5                    out.write(inData);
//2002/08/08 DoJa1.5                    dataCount++;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    out.close();
//2002/08/08 DoJa1.5                    out = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (in != null) {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                soc.sendResponse(ObexConnection.SUCCESS);
//2002/08/08 DoJa1.5                if (soc != null) {
//2002/08/08 DoJa1.5                    soc.close();
//2002/08/08 DoJa1.5                    soc = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG"IOE during copying"");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
            /* check the number of byte of copied data */
//2002/08/08 DoJa1.5            if (dataCount != MAX_DATA) {
//2002/08/08 DoJa1.5                addResult(resultBox, "data size NG \n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 6:
        case 2:
            // J351_0201_0301

            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
            try {

                in = Connector.openInputStream("resource:///data");

                httpcon = (HttpConnection)Connector.open(httpPOST, Connector.READ_WRITE);
                httpcon.setRequestMethod(HttpConnection.POST);
                httpcon.setRequestProperty("Content-Type", "text/plain");
                out = httpcon.openOutputStream();
            
            } catch (Exception e) {
                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
                return;
            }
            addResult(resultBox, "OK\n");
            addResult(resultBox, "test:");

            /* data copy */
            try {
                while ((inData = in.read())>0) {
                    out.write(inData);
                    dataCount++;
                }
                if (out != null) {
                    out.close();
                    out = null;
                }
                if (in != null) {
                    in.close();
                    in = null;
                }

                httpcon.connect();
                
            } catch (IOException ioe) {
                addResult(resultBox, "NG\"IOE during copying\"");
                return;
            }
            
            /* check the number of byte of copied data */
            if (dataCount != MAX_DATA) {
                addResult(resultBox, "data size NG \n");
                return;
            }
            
            addResult(resultBox, "OK\n");
            addResult(resultBox, "verification:");

            /* verify the copied data */
            try {
                in = httpcon.openInputStream();
                for (int i=0; i<MAX_DATA; i++) {
                    if (in.read() != 'A') {
                        addResult(resultBox, "NG[Data]");
                        return;
                    }
                }
                addResult(resultBox, "OK");
                if (in != null)  {
                    in.close();
                    in = null;
                }
                if (httpcon != null) {
                    httpcon.close();
                    httpcon = null;
                }
            } catch (Exception e) {
                addResult(resultBox, "NG["+e.getClass().getName()+"]");
            }
            break;

//2002/08/08 DoJa1.5        case 7:
        case 3:
            // J351_0201_0302

            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
            try {
                in  = Connector.openInputStream("resource:///data");
                out = Connector.openOutputStream("scratchpad:///0");
            
            } catch (Exception e) {
                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
                return;
            }
            addResult(resultBox, "OK\n");
            addResult(resultBox, "test:");

            /* data copy */
            try {
                while ((inData = in.read())>0) {
                    out.write(inData);
                    dataCount++;
                }
                if (in != null)  {
                    in.close();
                    in = null;
                }
                if (out != null) {
                    out.close();
                    out = null;
                }

            } catch (IOException ioe) {
                addResult(resultBox, "NG\"IOE during copying\"");
                return;
            }
            
            /* check the number of byte of copied data */
            if (dataCount != MAX_DATA) {
                addResult(resultBox, "data size NG \n");
                return;
            }
            
            addResult(resultBox, "OK\n");
            addResult(resultBox, "verification:");

            /* verify the copied data */
            try {
                in = Connector.openInputStream("scratchpad:///0");
                for (int i=0; i<MAX_DATA; i++) {
                    if (in.read() != 'A') {
                        addResult(resultBox, "NG[Data]");
                        return;
                    }
                }
                addResult(resultBox, "OK");
                if (in != null)  {
                    in.close();
                    in = null;
                }
            } catch (Exception e) {
                addResult(resultBox, "NG["+e.getClass().getName()+"]");
            }
            break;

//2002/08/08 DoJa1.5        case 8:
            // J351_0201_0303
//2002/08/08 DoJa1.5            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
//2002/08/08 DoJa1.5            try {

//2002/08/08 DoJa1.5                in = Connector.openInputStream("resource:///data");

//2002/08/08 DoJa1.5                coc = (ClientObexConnection)Connector.open("obex:/irclient");
//2002/08/08 DoJa1.5                coc.connect();
//2002/08/08 DoJa1.5                coc.setOperation(ObexConnection.PUT);
//2002/08/08 DoJa1.5                coc.setName("put-test");
                
//2002/08/08 DoJa1.5                out = coc.openOutputStream();
            
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "test:");

            /* data copy */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                while ((inData = in.read())>0) {
//2002/08/08 DoJa1.5                    out.write(inData);
//2002/08/08 DoJa1.5                    dataCount++;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    out.close();
//2002/08/08 DoJa1.5                    out = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (in != null) {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                coc.sendRequest();
//2002/08/08 DoJa1.5                if (coc != null) {
//2002/08/08 DoJa1.5                    coc.close();
//2002/08/08 DoJa1.5                    coc = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG"IOE during copying"");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
            /* check the number of byte of copied data */
//2002/08/08 DoJa1.5            if (dataCount != MAX_DATA) {
//2002/08/08 DoJa1.5                addResult(resultBox, "data size NG \n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 9:
            // J351_0201_0304
//2002/08/08 DoJa1.5            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
//2002/08/08 DoJa1.5            try {

//2002/08/08 DoJa1.5                in = Connector.openInputStream("resource:///data");

//2002/08/08 DoJa1.5                soc = (ServerObexConnection)Connector.open("obex:/irserver");
//2002/08/08 DoJa1.5                soc.accept();
//2002/08/08 DoJa1.5                soc.receiveRequest();
                
//2002/08/08 DoJa1.5                if (soc.getOperation() != ObexConnection.GET) {
//2002/08/08 DoJa1.5                    addResult(resultBox, "wrong procedure.use GET to connect\n");
//2002/08/08 DoJa1.5                    return;
//2002/08/08 DoJa1.5                }
                
//2002/08/08 DoJa1.5                out = soc.openOutputStream();
            
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "test:");

            /* data copy */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                while ((inData = in.read())>0) {
//2002/08/08 DoJa1.5                    out.write(inData);
//2002/08/08 DoJa1.5                    dataCount++;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    out.close();
//2002/08/08 DoJa1.5                    out = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (in != null) {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                soc.sendResponse(ObexConnection.SUCCESS);
//2002/08/08 DoJa1.5                if (soc != null) {
//2002/08/08 DoJa1.5                    soc.close();
//2002/08/08 DoJa1.5                    soc = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG"IOE during copying"");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
            /* check the number of byte of copied data */
//2002/08/08 DoJa1.5            if (dataCount != MAX_DATA) {
//2002/08/08 DoJa1.5                addResult(resultBox, "data size NG \n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 10:
            // J351_0201_0401

//2002/08/08 DoJa1.5            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
//2002/08/08 DoJa1.5            try {

//2002/08/08 DoJa1.5                coc = (ClientObexConnection)Connector.open("obex:/irclient");
//2002/08/08 DoJa1.5                coc.connect();
//2002/08/08 DoJa1.5                coc.setOperation(ObexConnection.GET);
//2002/08/08 DoJa1.5                coc.sendRequest();
//2002/08/08 DoJa1.5                in = coc.openInputStream();

//2002/08/08 DoJa1.5                httpcon = (HttpConnection)Connector.open(httpPOST, Connector.READ_WRITE);
//2002/08/08 DoJa1.5                httpcon.setRequestMethod(HttpConnection.POST);
//2002/08/08 DoJa1.5                httpcon.setRequestProperty("Content-Type", "text/plain");
//2002/08/08 DoJa1.5                out = httpcon.openOutputStream();
            
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "test:");

            /* data copy */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                while ((inData = in.read())>0) {
//2002/08/08 DoJa1.5                    out.write(inData);
//2002/08/08 DoJa1.5                    dataCount++;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    out.close();
//2002/08/08 DoJa1.5                    out = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (in != null) {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (coc != null) {
//2002/08/08 DoJa1.5                    coc.close();
//2002/08/08 DoJa1.5                    coc = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                httpcon.connect();
                
//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG"IOE during copying"");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
            /* check the number of byte of copied data */
//2002/08/08 DoJa1.5            if (dataCount != MAX_DATA) {
//2002/08/08 DoJa1.5                addResult(resultBox, "data size NG \n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "verification:");

            /* verify the copied data */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                in = httpcon.openInputStream();
//2002/08/08 DoJa1.5                for (int i=0; i<MAX_DATA; i++) {
//2002/08/08 DoJa1.5                    if (in.read() != 'A') {
//2002/08/08 DoJa1.5                        addResult(resultBox, "NG[Data]");
//2002/08/08 DoJa1.5                        return;
//2002/08/08 DoJa1.5                    }
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                addResult(resultBox, "OK");
//2002/08/08 DoJa1.5                if (in != null)  {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (httpcon != null) {
//2002/08/08 DoJa1.5                    httpcon.close();
//2002/08/08 DoJa1.5                    httpcon = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]");
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 11:
            // J351_0201_0402

//2002/08/08 DoJa1.5            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                coc = (ClientObexConnection)Connector.open("obex:/irclient");
//2002/08/08 DoJa1.5                coc.connect();
//2002/08/08 DoJa1.5                coc.setOperation(ObexConnection.GET);
//2002/08/08 DoJa1.5                coc.sendRequest();
//2002/08/08 DoJa1.5                in = coc.openInputStream();
//2002/08/08 DoJa1.5                out = Connector.openOutputStream("scratchpad:///0");
            
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "test:");

            /* data copy */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                while ((inData = in.read())>0) {
//2002/08/08 DoJa1.5                    out.write(inData);
//2002/08/08 DoJa1.5                    dataCount++;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (in != null)  {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    out.close();
//2002/08/08 DoJa1.5                    out = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (coc != null)  {
//2002/08/08 DoJa1.5                    coc.close();
//2002/08/08 DoJa1.5                    coc = null;
//2002/08/08 DoJa1.5                }

//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG"IOE during copying"");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
            /* check the number of byte of copied data */
//2002/08/08 DoJa1.5            if (dataCount != MAX_DATA) {
//2002/08/08 DoJa1.5                addResult(resultBox, "data size NG \n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "verification:");

            /* verify the copied data */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                in = Connector.openInputStream("scratchpad:///0");
//2002/08/08 DoJa1.5                for (int i=0; i<MAX_DATA; i++) {
//2002/08/08 DoJa1.5                    if (in.read() != 'A') {
//2002/08/08 DoJa1.5                        addResult(resultBox, "NG[Data]");
//2002/08/08 DoJa1.5                        return;
//2002/08/08 DoJa1.5                    }
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                addResult(resultBox, "OK");
//2002/08/08 DoJa1.5                if (in != null)  {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]");
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 12:
            // J351_0201_0501

//2002/08/08 DoJa1.5            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
//2002/08/08 DoJa1.5            try {

//2002/08/08 DoJa1.5                soc = (ServerObexConnection)Connector.open("obex:/irserver");
//2002/08/08 DoJa1.5                soc.accept();
//2002/08/08 DoJa1.5                soc.receiveRequest();
                
//2002/08/08 DoJa1.5                if (soc.getOperation() != ObexConnection.PUT) {
//2002/08/08 DoJa1.5                    addResult(resultBox, "wrong procedure.use PUT to connect\n");
//2002/08/08 DoJa1.5                    return;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                in = soc.openInputStream();

//2002/08/08 DoJa1.5                httpcon = (HttpConnection)Connector.open(httpPOST, Connector.READ_WRITE);
//2002/08/08 DoJa1.5                httpcon.setRequestMethod(HttpConnection.POST);
//2002/08/08 DoJa1.5                httpcon.setRequestProperty("Content-Type", "text/plain");
//2002/08/08 DoJa1.5                out = httpcon.openOutputStream();
            
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "test:");

            /* data copy */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                while ((inData = in.read())>0) {
//2002/08/08 DoJa1.5                    out.write(inData);
//2002/08/08 DoJa1.5                    dataCount++;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    out.close();
//2002/08/08 DoJa1.5                    out = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (in != null) {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                soc.sendResponse(ObexConnection.SUCCESS);
//2002/08/08 DoJa1.5                if (soc != null) {
//2002/08/08 DoJa1.5                    soc.close();
//2002/08/08 DoJa1.5                    soc = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                httpcon.connect();
                
//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG"IOE during copying"");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
            /* check the number of byte of copied data */
//2002/08/08 DoJa1.5            if (dataCount != MAX_DATA) {
//2002/08/08 DoJa1.5                addResult(resultBox, "data size NG \n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "verification:");

            /* verify the copied data */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                in = httpcon.openInputStream();
//2002/08/08 DoJa1.5                for (int i=0; i<MAX_DATA; i++) {
//2002/08/08 DoJa1.5                    if (in.read() != 'A') {
//2002/08/08 DoJa1.5                        addResult(resultBox, "NG[Data]");
//2002/08/08 DoJa1.5                        return;
//2002/08/08 DoJa1.5                    }
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                addResult(resultBox, "OK");
//2002/08/08 DoJa1.5                if (in != null)  {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (httpcon != null) {
//2002/08/08 DoJa1.5                    httpcon.close();
//2002/08/08 DoJa1.5                    httpcon = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]");
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            break;

//2002/08/08 DoJa1.5        case 13:
            // J351_0201_0502
//2002/08/08 DoJa1.5            resultBox.setText("test preparation:");

            /* prepare the targeted connection */
//2002/08/08 DoJa1.5            try {

//2002/08/08 DoJa1.5                soc = (ServerObexConnection)Connector.open("obex:/irserver");
//2002/08/08 DoJa1.5                soc.accept();
//2002/08/08 DoJa1.5                soc.receiveRequest();
                
//2002/08/08 DoJa1.5                if (soc.getOperation() != ObexConnection.PUT) {
//2002/08/08 DoJa1.5                    addResult(resultBox, "wrong procedure.use PUT to connect\n");
//2002/08/08 DoJa1.5                    return;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                in = soc.openInputStream();

//2002/08/08 DoJa1.5                out = Connector.openOutputStream("scratchpad:///0");
            
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]\n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "test:");

            /* data copy */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                while ((inData = in.read())>0) {
//2002/08/08 DoJa1.5                    out.write(inData);
//2002/08/08 DoJa1.5                    dataCount++;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (in != null)  {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                if (out != null) {
//2002/08/08 DoJa1.5                    out.close();
//2002/08/08 DoJa1.5                    out = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                soc.sendResponse(ObexConnection.SUCCESS);
//2002/08/08 DoJa1.5                if (soc != null)  {
//2002/08/08 DoJa1.5                    soc.close();
//2002/08/08 DoJa1.5                    soc = null;
//2002/08/08 DoJa1.5                }

//2002/08/08 DoJa1.5            } catch (IOException ioe) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG"IOE during copying"");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
            /* check the number of byte of copied data */
//2002/08/08 DoJa1.5            if (dataCount != MAX_DATA) {
//2002/08/08 DoJa1.5                addResult(resultBox, "data size NG \n");
//2002/08/08 DoJa1.5                return;
//2002/08/08 DoJa1.5            }
            
//2002/08/08 DoJa1.5            addResult(resultBox, "OK\n");
//2002/08/08 DoJa1.5            addResult(resultBox, "verification:");

            /* verify the copied data */
//2002/08/08 DoJa1.5            try {
//2002/08/08 DoJa1.5                in = Connector.openInputStream("scratchpad:///0");
//2002/08/08 DoJa1.5                for (int i=0; i<MAX_DATA; i++) {
//2002/08/08 DoJa1.5                    if (in.read() != 'A') {
//2002/08/08 DoJa1.5                        addResult(resultBox, "NG[Data]");
//2002/08/08 DoJa1.5                        return;
//2002/08/08 DoJa1.5                    }
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5                addResult(resultBox, "OK");
//2002/08/08 DoJa1.5                if (in != null)  {
//2002/08/08 DoJa1.5                    in.close();
//2002/08/08 DoJa1.5                    in = null;
//2002/08/08 DoJa1.5                }
//2002/08/08 DoJa1.5            } catch (Exception e) {
//2002/08/08 DoJa1.5                addResult(resultBox, "NG["+e.getClass().getName()+"]");
//2002/08/08 DoJa1.5            }
//2002/08/08 DoJa1.5            break;

        default:
            break;
        }
    }

    /**
     * scratchpad setting
     * @param aData data to be set
     * @throw when exceptions are generated in the lower method at the time of configuring Exceptions
     */
    public void setupScratchpad(int aData) throws Exception {

        OutputStream out = null;
        out = Connector.openOutputStream("scratchpad:///0");
        for (int i=0; i<MAX_DATA; i++) {
            out.write(aData);
        }
        out.close();
    }

}

