/**
 * J421_0101_1201.java
 * 
 * J421_0101_1201
 * MenuPanel
 * 
 * check the interruption behavior during Java execution (browser activation from iappli)
 * 
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;
/**
 * man class of checking the interruption behavior during Java execution
 * @extends IApplication
 */
public class J421_0101_1201 extends IApplication {

        private Label   timerLabel    = null;  /* display by timer event */
        private Label   countLabel    = null;  /* display the thread behavior */
        private int     interval      = 500;
        private long    timerCount    = 0;
        private boolean stopFlag      = true;
        private Label   statusLabel   = null;  /* Button */

    /**
     * startup method of iaapli
     */
    public void start() {
        MenuPanel menuPanel = new MenuPanel();
        Display.setCurrent(menuPanel);
    }

    /**
     * menu screen of checking the interruption behavior during Java execution
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     * @implements TimerListener
     */
    class MenuPanel
        extends Panel
             implements SoftKeyListener,ComponentListener,TimerListener {

        private Ticker  infoTicker    = null;  /* guidance that Java is under execution */
        private Button  testButton    = null;  /* operation check button */
        private Button  connectButton = null;  /* connect button */
        private Button  vibratorButton = null;  /* vibrator button */
        private Timer   timer;

        /**
         * constructor of MenuPanel class
         */
        MenuPanel() {
            try {
                showMainPanel();
            } catch(Exception e) {
                showMsg(e.getMessage());
            } catch(Error e) {
                showMsg(e.getMessage());
            }
        }

        /**
         * display the menu screen
         */
        public void showMainPanel() {
            setTitle("interruption");
            Label subTitle    = new Label("interruption during the Java operation");
            statusLabel = new Label();
            infoTicker        = new Ticker("Java activating");
            testButton        = new Button("event queue");
            connectButton     = new Button("connection");
            vibratorButton     = new Button("vibrator");
            timerLabel  = new Label();
            countLabel  = new Label();

            subTitle.setSize(getWidth(), subTitle.getHeight());
            testButton.setSize(getWidth(), testButton.getHeight());
            connectButton.setSize(getWidth(), connectButton.getHeight());
            vibratorButton.setSize(getWidth(), vibratorButton.getHeight());
            statusLabel.setSize(getWidth(),timerLabel.getHeight());
            timerLabel.setSize(getWidth(),timerLabel.getHeight());
            countLabel.setSize(getWidth(),countLabel.getHeight());
            statusLabel.setAlignment(Label.CENTER);

            add(subTitle);
            add(infoTicker);
            add(connectButton);
            add(vibratorButton);
            add(testButton);
            add(statusLabel);
            add(countLabel);
            add(timerLabel);

            /* soft key label setting */
            setSoftLabel(Frame.SOFT_KEY_1,"exit");
            setSoftLabel(Frame.SOFT_KEY_2,"stop");

            /* listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);

        }

        void testConnect() {
            showMsg("start communication after 5 seconds");
            try {
                Thread.sleep(5000);
            } catch( Exception e ) {}

            /* execute the HTTP connection */
            statusLabel.setText("connecting");
            HttpConnection con = null;
            InputStream is = null;

           int c = 1;
           long beforemem = 0;
           long aftermem = 0;
           Runtime rt =  Runtime.getRuntime();
           while (c != 20){
             try {
                beforemem = rt.freeMemory();

                con = (HttpConnection) Connector.open(
                    getSourceURL() + "../res/anima8.gif",Connector.READ,true);
                con.setRequestMethod(HttpConnection.GET);
                con.connect();
                con.close();
                rt.gc();

            } catch( InterruptedIOException ie ) {
                showMsg("InterruptedIOException");
                
                aftermem = rt.freeMemory();
//                showMsg("Before Interruption->" + beforemem + "\nAfter Interruption->" + aftermem);
            } catch( Exception e ) {
                statusLabel.setText("connection error");
                showMsg("NG:" + e.toString());
                return;
            } 

                c++;
           }
          statusLabel.setText("connection completed");
        }

//J421_0101_1205
        void vibratorStart() {

            PhoneSystem.setAttribute(PhoneSystem.DEV_VIBRATOR,
                      PhoneSystem.ATTR_VIBRATOR_ON);

        }

//J421_0101_1207
        void eventStart() {
            /* Thread generation */
            CountThread testCountThread = new CountThread();
            stopFlag = false;
            testCountThread.start();

            /* create timer  */
            timer = new Timer();
            timer.setTime(interval);
            timer.setRepeat(true);
            timer.setListener(this);
            this.timer.start();

        }

        /**
         * display the message dialog
         * @param  aMsg dialog message
         */
        void showMsg(String aMsg) {
            Dialog msgDialog = new Dialog(Dialog.BUTTON_OK, "msg");
            msgDialog.setText(aMsg);
            msgDialog.show();
        }

        /**
         * operate nothing when the soft key is pressed 
         * @param aSoftKey soft key type
         */
        public void softKeyPressed(int aSoftKey) {}

        /**
         * when soft key 1 is released, end the application, 
         * and in the case of soft key 2, transit to the all screen
         * @param aSoftKey soft key type
         */
        public void softKeyReleased(int aSoftKey) {
            if (aSoftKey == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
            if (aSoftKey == Frame.SOFT_KEY_2) {
                if( !stopFlag ) {
                    stopFlag = true;
                        timer.stop();
                }
            }
        }

        /**
         * receive events generated in the components
         * @param aComponent component that has generated events
         * @param aType event type
         * @param aParam event parameter
         */
        public void componentAction(
            Component aComponent, int aAction, int aParam) {
            if (aAction == ComponentListener.BUTTON_PRESSED) {
                if (aComponent == connectButton) {
                    testConnect();
                }
                if (aComponent == testButton) {
                    eventStart();
                }
                if (aComponent == vibratorButton) {
                    vibratorStart();
                }
            }
        }

        /**
         * timer event process event
         * @param   source timer object
         */
        public void timerExpired(Timer source) {
            /* update the timer counter value */
            timerCount++;

            timerLabel.setText("TimerCount:" + String.valueOf(timerCount));
            timerLabel.setAlignment(Label.CENTER);
            try {
                Thread.sleep(2*interval);
            } catch( Exception e ) {}
        }

	    /**
	     * countLabel display thread
	     * @extends Thread
	     */
	    class CountThread extends Thread {
	        long    count=0;

	        /**
	         * CountThread constructor
	         */
	        public CountThread() {}

	        /**
	         *  run method
	         */
	         public void run() {

	            while(true) {
	                count++;
	                countLabel.setText("Count:" + String.valueOf(count));
	                try {
	                    Thread.sleep(interval);
	                } catch( InterruptedException ie ) {
	                    showMsg("NG:Thread.sleep()-InterruptedException");
	                } catch( Exception e ) {
	                    showMsg(e.toString());
	                    break;
	                }
	            }
	        }
	    }
    }
}
