/**
 * J423_0301_0101
 * MainPanel
 * TimerPanel
 * TimerCanvas
 *
 * checking the return from the interruption during the apli timer operation
 *
 * $Id: J423_0301_0101.java,v 1.1 2002/02/07 08:23:18 lan Exp $
 */

import java.io.*;
import javax.microedition.io.*;
import com.nttdocomo.lang.*;
import com.nttdocomo.io.*;
import com.nttdocomo.ui.*;
import com.nttdocomo.util.*;


/**
 * main class of checking the return from the interruption during the apli timer operation
 * @extends IApplication
 */
public class J423_0301_0101 extends IApplication {
    /**
     * startup method of iaapli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }

    /**
     * event acceptance
     * @param   type event type
     * @param   param event parameter
     */
    public void processSystemEvent(int type, int param) {}


    /**
     * dialog display method
     * @param   aText displayed character strings
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }


    /**
     * main screen of checking the interruption behavior during the appli timer operation
     * @extends Panel
     * @implements SoftKeyListener
     * @implements ComponentListener
     */
    class MainPanel extends Panel implements SoftKeyListener, ComponentListener {
        String[] menuListItem = {
            "1 Timer(Repeat)",
            "2 ShortTimer(Repeat)",
            "3 Timer(OneShot)",
            "4 ShortTimer(OneShot)"
        };

        Label   lab              = new Label("timer");
        ListBox menuList         = new ListBox(ListBox.CHOICE);
        Button  execButton       = new Button("execute");

        /**
         * constructor of MainPanel class
         */
        public MainPanel() {
            /* configure the displayed items */
            menuList.setItems(menuListItem);
            setTitle("check the return from interruption");
            setSoftLabel(Frame.SOFT_KEY_1, "exit");

            /* add each component to the screen */
            add(lab);
            add(menuList);
            execButton.setSize(getWidth(),execButton.getHeight());
            add(execButton);

            /* listener setting */
            setSoftKeyListener(this);
            setComponentListener(this);
        }


        /**
         * operate nothing when the soft key is pressed down
         * @param   anIndex soft key index
         */
        public void softKeyPressed(int anIndex) {}

        /**
         * process when the soft key is released
         * @param   anIndex soft key index
         */
        public void softKeyReleased(int anIndex) {
            /* when the soft key 1 is released, end the application */
            if (anIndex == Frame.SOFT_KEY_1) {
                IApplication.getCurrentApp().terminate();
            }
        }

        /**
         * receive events generated in the components
         * @param aComponent component that has generated events
         * @param aType event type
         * @param aParam event parameter
         */
        public void componentAction(Component aComponent, int aType, int aParam) {
            /* when the execute button is pressed down */
            if (aComponent == execButton
                && aType == ComponentListener.BUTTON_PRESSED) {
                int idx = menuList.getSelectedIndex();
                boolean repeat = true;
                if( idx >= 2 ) {
                    repeat = false;
                }
                if( idx == 0 || idx == 2 ) {
                    TimerPanel timerP = new TimerPanel(this,repeat);
                    Display.setCurrent(timerP);
                    timerP.timer.start();
                } else {
                    TimerCanvas timerC = new TimerCanvas(this,repeat);
                    Display.setCurrent(timerC);
                    timerC.st.start();
                }
            }
        }
    }
}


/**
 * timer event Q screen-check that the events queued up after the suspension get cleared
 * @extends Panel
 * @implements SoftKeyListener
 * @implements TimerListener
 */
class TimerPanel extends Panel implements SoftKeyListener, TimerListener {
    Frame   previous;
    boolean repeat;
    Label   lab1 = new Label("TimerCount:");
    Label   lab2 = new Label("ThreadCount:");
    Label   timerLabel = new Label();
    Label   countLabel = new Label();
    Timer   timer;
    int     interval = 500;
    long    timerCount = 0;
    boolean stopFlag = true;

    /**
     * constructor of TimerPanel class
     * @param   aFrame    the previous screen Frame
     * @param   aRepeat    attribution that indicates whether it belongs to timer repeat of one shot
     */
    public TimerPanel(Frame aFrame, boolean aRepeat) {
        previous = aFrame;
        repeat = aRepeat;

        /* configure the displayed items */
        if( repeat ) {
            setTitle("Timer(Repeat)");
        } else {
            setTitle("Timer(OneShot)");
        }
        setSoftLabel(Frame.SOFT_KEY_2, "back");

        /* add each component to the screen */
        int w = getWidth();
        int h = lab1.getHeight();
        lab1.setSize(w*3/4,h);
        lab2.setSize(w*3/4,h);
        timerLabel.setSize(w/5,h);
        countLabel.setSize(w/5,h);
        add(lab1);
        add(timerLabel);
        add(lab2);
        add(countLabel);

        /* listener setting */
        setSoftKeyListener(this);

        /* creation of Timer */
        timer = new Timer();
        timer.setTime(interval);
        timer.setRepeat(repeat);
        timer.setListener(this);

        /* create the count Thread at the same time */
        CountThread countTh = new CountThread();
        stopFlag = false;
        countTh.start();
    }


    /**
     * operate nothing when the soft key is pressed down
     * @param   anIndex soft key index
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * process when the soft key is released
     * @param   anIndex soft key index
     */
    public void softKeyReleased(int anIndex) {
        /* return to the previous screen when the soft key 2 is released  */
        if (anIndex == Frame.SOFT_KEY_2) {
            if( !stopFlag ) {
                stopFlag = true;
                timer.stop();
            }
            Display.setCurrent(previous);
        }
    }


    /**
     * timer event process event
     * @param   source timer object
     */
    public void timerExpired(Timer source) {
        /* update the timer counter value */
        timerCount++;
        timerLabel.setText(String.valueOf(timerCount));
        timerLabel.setAlignment(Label.CENTER);
        if( repeat ) {
            /* delay the process to store the event queue of timer */
            try {
                Thread.sleep(2*interval);
            } catch( Exception e ) {}
        } else {
            /* in the case of OneShot timer, start again */
            timer.start();
        }
    }


    /**
     * countLabel display thread
     * @extends Thread
     */
    class CountThread extends Thread {
        long    count=0;

        /**
         * CountThread constructor
         */
        public CountThread() {}

       /**
        *  run method
        */
       public void run() {
            while(!stopFlag) {
                count++;
                countLabel.setText(String.valueOf(count));
                try {
                    Thread.sleep(interval);
                } catch( Exception e ) {
                    break;
                }
            }
        }
    }
}


/**
 * timer event Q screen-check that the events queued up after the suspension get cleared
 * @extends Canvas
 */
class TimerCanvas extends Canvas {
    Frame   previous;
    boolean repeat;
    int interval = 500;
    ShortTimer st = null;
    Font    font;
    int fH, fD;
    int sH, sW;
    int count = 0;
    int counter = 0;
    boolean stopFlag = true;

    /**
     * constructor of TimerCanvas class
     * @param   aFrame    the previous screen Frame
     * @param   aRepeat    attribution that indicates whether it belongs to timer repeat of one shot
     */
    public TimerCanvas(Frame aFrame, boolean aRepeat) {
        previous = aFrame;
        repeat = aRepeat;
        setSoftLabel(Canvas.SOFT_KEY_2, "back");
        font = Font.getFont(Font.FACE_SYSTEM | Font.STYLE_BOLD | Font.SIZE_LARGE);
        fH = font.getHeight();
        fD = font.getDescent();
        sH = getHeight();
        sW = getWidth();

        /* creation of timer */
        try {
            st = ShortTimer.getShortTimer(this,0,interval,repeat);
        } catch( Exception e ) {
            showDialog("test incapability error:" + e.toString());
            return;
        }
        /* create the count Thread at the same time */
        CountThread countTh = new CountThread();
        stopFlag = false;
        countTh.start();
    }


    /**
     * dialog display method
     * @param   aText displayed character strings
     */
    public void showDialog(String aText) {
        Dialog  d = new Dialog(Dialog.BUTTON_OK, "result");
        d.setText(aText);
        d.show();
    }

    /**
     * canvas drawing paint method 
     * @param g    Graphics object for canvas
     */
    public void paint(Graphics g) {
        paintTimer();
        paintCounter();
    }


    /**
     * drawing method for timer event
     */
    public void paintTimer() {
        Graphics g = getGraphics();
        int c;

        g.lock();

        /* fill the screen background */
        c = Graphics.getColorOfName(Graphics.BLACK);
        g.fillRect(0,0,sW,sH/2);

        /* title display */
        g.setColor(g.getColorOfName(g.RED));
        if( repeat ) {
            g.drawString("ShortTimer(Repeat)",0,fH+1);
        } else {
            g.drawString("ShortTimer(OneShot)",0,fH+1);
        }

        /* counter value display */
        String str = "TimerCount: " + String.valueOf(count);
        c = Graphics.getColorOfName(Graphics.GREEN);
        g.setColor(c);
        g.setFont(font);
        g.drawString(str,1,sH/2-10);

        g.unlock(true);

    }

    /**
     * drawing method for counter tread
     */
    public void paintCounter() {
        Graphics g = getGraphics();
        int c;

        g.lock();

        /* fill the screen background */
        c = Graphics.getColorOfName(Graphics.BLACK);
        g.fillRect(0,sH/2,sW,sH/2);

        /* counter value display */
        String str = "ThreadCount: " + String.valueOf(counter);
        c = Graphics.getColorOfName(Graphics.YELLOW);
        g.setColor(c);
        g.setFont(font);
        g.drawString(str,1,sH/2+fH+5);

        g.unlock(true);

    }


    /**
     * event acceptance method
     * @param type  event type
     * @param param event parameter
     */
    public void processEvent(int type, int param) {
        /* interruption occurred in this moment or while waiting for the previous event */

        /* timer event */
        if (type == Display.TIMER_EXPIRED_EVENT) {
            count++;
            paintTimer();
            if( repeat ) {
                /* delay the process to store the event queue of timer */
                try {
                    Thread.sleep(2*interval);
                } catch( Exception e ) {}
            } else {
                /* in the case of OneShot timer, start again */
                st.start();
            }
        }

        /* key event  */
        if (type == Display.KEY_RELEASED_EVENT) {
            /* when the back key is pressed */
            if( param == Display.KEY_SOFT2 ) {
                stopFlag = true;
                /* destruct the short timer */
                if( st != null ) {
                    st.dispose();
                }
                /* return to the main menu screen */
                Display.setCurrent(previous);
            }
        }
    }


    /**
     * counter display thread
     * @extends Thread
     */
    class CountThread extends Thread {
        /**
         * CountThread constructor
         */
        public CountThread() {}

       /**
        *  run method
        */
       public void run() {
            while(!stopFlag) {
                counter++;
                paintCounter();
                try {
                    Thread.sleep(interval);
                } catch( Exception e ) {
                    break;
                }
            }
        }
    }
}
