/**
 * J423_0306_0101
 * MainPanel
 *
 * check the return from the application interruption 
 *
 * $Id: J423_0306_0101.java,v 1.1 2002/02/07 08:22:38 hoshi Exp $
 */

import com.nttdocomo.ui.*;
import com.nttdocomo.lang.*;
import java.lang.*;

/**
 * main class of checking the return from the application interruption 
 * @extends IApplication
 */
public class J423_0306_0101 extends IApplication {

    /**
     * startup method of iaapli
     */
    public void start() {
        Display.setCurrent(new MainPanel());
    }
}

/**
 * main screen of checking the return from the application interruption 
 * @extends Panel
 * @implements SoftKeyListener
 * @implements ComponentListener
 * @implements MediaListener
 */
class MainPanel extends Panel implements SoftKeyListener, ComponentListener,
    MediaListener {

    private ListBox menuList = new ListBox(ListBox.CHOICE);
    private VisualPresenter vp = new VisualPresenter();
    private MediaImage mi = null;
    private Button button = new Button("execute");
    private TextBox textBox = new TextBox ("", 20, 1, TextBox.DISPLAY_ANY);
    private  String[] menuListItem = {
        "0.test 1",
    };

    /** 
     * constructor of ManPanel
     */
    public MainPanel(){
        try{
            /* display MainPanel */
            showMainPanel();
        }catch(Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"error ");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }
    }

    /** 
     * display the main panel
     */
    void showMainPanel(){

        /* configure the displayed items */
        setTitle("class behavior check");
        menuList.setItems(menuListItem);
        add(menuList);
        add(button);
        add(textBox);
        add(vp);

        try {
            mi = MediaManager.getImage("resource:///anima8.gif");
            mi.use();
            vp.setImage(mi);
        } catch (Exception e){
            Dialog errDialog = new Dialog(Dialog.DIALOG_ERROR,"error ");
            errDialog.setText("Error:" +e.toString());
            errDialog.show();
        }

        setSoftLabel(Frame.SOFT_KEY_1, "exit");

        /* listener setting */
        setSoftKeyListener(this);
        setComponentListener(this);
        vp.setMediaListener(this);
    }

    /**
     * receive events generated in the components
     * @param aComponent component that has generated events
     * @param aType event type
     * @param aParam event parameter
     */
    public void componentAction(Component aComponent, int aType, int aParam) {

        if ( aComponent == button && aType == BUTTON_PRESSED ) {
            switch(menuList.getSelectedIndex()){
                case 0:
                    vp.play();
                    break;
            }
        }
    }

    /**
     * receive events generated in media
     * @param aSource  media presenter of originating side
     * @param aType event type
     * @param aParam event parameter
     */
    public void mediaAction(MediaPresenter aSource, int aType, int aParam) {
        if ( aType == VisualPresenter.VISUAL_STOPPED ) {
            textBox.setText("NG:STOPPED");
        }
    }

    /**
     * operate nothing when the soft key is pressed down
     * @param index of the anIndex key
     */
    public void softKeyPressed(int anIndex) {}

    /**
     * when the soft key 1 is released, end the application
     * @param index of the anIndex key
     */
    public void softKeyReleased(int anIndex) {
        if (anIndex == Frame.SOFT_KEY_1) {
            IApplication.getCurrentApp().terminate();
        }
    }
}
