#!/usr/bin/perl
#
# kwdConv.pl

# ==============================================================<<< config >>>
# target directory
$target_dir = '.';

# the keyword before conversion ( search keyword )
$kwd_before = 'SERVER_URL';

# target file extension
#  note : ('html','jam','asis') meens "*.html, *.jam, *.asis"
@target_ext = ('html', 'jam', 'asis');

# log file name
$logfile = "kwdConv.log";
# ============================================================================

# etc
$prog_name    = "kwdConv.pl";
$flag_match   = "[o] ";
$flag_error   = "[x] ";
$flag_unmatch = "[-] ";
$flag_msg     = "[ ] ";

$prompt = "*";

# ------------------------------------------------------<<< argument check >>>
#   $ARGV[0] : the keyword after conversion

&disp_usage if $ARGV[0] eq "";

# ----------------------------------------------------------<<< initialize >>>
$src = "";
$filecount = 0;
$totalFiles = 0;

# get argument
$kwd_after = $ARGV[0];

# ------------------------------------------<<< search directory and files >>>

# open log file on current directory.
open(LOGFILE, ">>$logfile") || die "cannot open logfile '$logfile'.";
print LOGFILE "**** run at ".localtime()."\n";

# cange directory to $target_dir
chdir( $target_dir ) || die &disp_usage("cannot change direcoty '$target_dir'.");

# write log header
print LOGFILE "| target directory      '$target_dir'\n";
print LOGFILE "| target file extention '".join(',', @target_ext)."'\n";
print LOGFILE "| search keyword        '$kwd_before'\n";
print LOGFILE "| convert keyword       '$kwd_after'\n\n";

# scan and count the target files.
print "scanning number of the target files ... ";
&search_files( $target_dir, 0);
print chr(8),"[OK]\n  number of target files : $filecount/$totalFiles","\n";
print LOGFILE "$flag_msg *** number of target files : $filecount ***\n";

# replace keyword in the target files.
if( $filecount==0 ){
  print "\ntarget file is not exist.\n\n";
  &writelog("$flag_nomatch target file is not exist.");
} else {
  # replace text in the target files.
  chdir( $target_dir ) || die &disp_usage("cannot change direcoty '$target_dir'.");
  print "scanning the keyword in the target files ... ";
  &search_files( $target_dir, 1);

  # display results.
  print chr(8),"[OK]\n",$src;
}

# close logfile
close(LOGFILE);

# ==========================================================<<< procedures >>>
# ---------------------------------------------------------------------# SUB #
# ----------------------------------------------------[ convert_kwd( $path ) ]
# note : convert keyword in the $filename file on current directory
sub convert_kwd{
  local( $dir, $filename ) = @_;
  local( $flag ) = 0;
  local( $tmpfile ) = $filename.".convert_kwd_tmp";

  if(!open( IN, $filename)){
    &writelog( "$flag_error cannot open target file '$dir/$filename'" );
    return();
  }

  if(!open( TMP, ">$tmpfile")){
    &writelog( "$flag_error cannot open temporary file '$dir/$tmpfile'" );
    return();
  }
  # the src of temp file are the result of changeing master file. 
  while (<IN>){
    if( /$kwd_before/ ){
      $flag = 1;
      $_ =~ s/$kwd_before/$kwd_after/g;
    }
    print TMP $_;
  }
  close( TMP );
  close( IN );

  if ($flag){
    # ***** keyword match!! *****
    &writelog( "$flag_match match   '$dir/$filename'" );

    # ***** overwrite master file *****
    #  note: the src of master file is overwrite to the src of temp file.
    # open master file for write
    if(!open( IN, ">$filename")){
      &writelog( "$flag_error cannot open master file for write '$dir/$filename'\n$flag_error   so, master file was not changed." );
      return();
    }

    # open temfile for read
    if(!open( TMP, "$tmpfile")){
      &writelog( "$flag_error cannot open cnverted temporary file '$dir/$tmpfile'\n$flag_error   so, master file was not changed." );
      return();
    }

    # overwrite master file src to temporary file src
    while(<TMP>){
      print IN;
    }

    close( TMP );
    close( IN );

    # delete temporary file
    if(!unlink($tmpfile)){
      &writelog( "$flag_error cannot delete temporary file '$dir/$tmpfile'" );
    }

  } else {
    # ***** keyword unmatch!! *****
    &writelog( "$flag_unmatch unmatch '$dir/$filename'" );

    # delete temporary file
    if(!unlink($tmpfile)){
      &writelog( "$flag_error cannot delete temporary file '$dir/$tmpfile'" );
    }
  }
}

# --------------------------------------------------------[ writelog( $msg ) ]
# note : write msg to log file
sub writelog{
  local($msg) = @_;
  print LOGFILE $msg."\n";
  $src .= $msg."\n";
}

# ----------------------------------------------[ search_files( $dir, $flag) ]
# note : search files and sub directories on current directory
sub search_files{
  local( $dir, $flag ) = @_;
  local( $dev, $ino, $mode, $links );
  local( $count, $filename, $file_ext, $fullpath );

  # display processing symbol.
  $prompt = ($prompt eq '*') ? ' ' : '*';
  print $prompt;

  ( $dev, $ino, $mode, $links ) = stat('.') unless $links;

  opendir( DIRECTORY, '.' ) || return;
  local( @files ) = readdir( DIRECTORY );
  close( DIRECTORY );

  # $count : number of files in current directory.
  $count = $links -2;

  for( @files ){
    next if $_ eq '.';
    next if $_ eq '..';
    $fullpath = "$dir/$_";

    # count up number of files.
    $totalFiles++ if $flag == 0 && !(-d $_);

    # split filename and extension
    ($filename, $file_ext)  = /(.*)\.(.*)/;

    # check target file extension
    if ($_!~/$logfile\b|$prog_name\b/){
      foreach $tgt_ext (@target_ext){
        if ( $tgt_ext eq $file_ext ){
          # this file is target
          $filecount++ if $flag == 0;
          &convert_kwd( $dir, $_ ) if $flag;
        }
      }
    }
    next if $count == 0;

    ($dev, $ino, $mode, $links) = lstat($_);
    next unless -d _;

    # delete processing symbol.
    print chr(8);

    if(!chdir($_)){
      # cannot change directory
      writelog( "$flag_error cannot change directory '$_'");
      return();
    } else {
      &search_files( $fullpath, $flag );
    }
    chdir '..';
    --$count;
  }
}

# ---------------------------------------------[ disp_usage( error_message ) ]
# note : display error message and usage.
sub disp_usage{
  local($tgt) = join(",", @target_ext);
  print "\n","    *** ERROR ***","\n","    @_","\n\n" if @_;
  print <<"EOL";

    *** USAGE ***
    Usage: kwdConv.pl 'convert_kwd'
      [Argument]
        convert_kwd   the keyword after conversion

      [Definition]
        target_dir =  current directory
        target_ext = '$tgt'
                      target file extension
        search_kwd = '$kwd_before'
                      the keyword before conversion (search keyword)
        
       ex.)
         \$ kwdConv.pl "server_name"

EOL
exit;
}
